(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1042588,      28350]
NotebookOptionsPosition[   1010526,      27882]
NotebookOutlinePosition[   1010865,      27897]
CellTagsIndexPosition[   1010822,      27894]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Quarter-plane lattice paths with interacting boundaries: the \
Kreweras and reverse Kreweras models",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\n",
 StyleBox["Ruijie Xu, Nicholas R. Beaton and Aleksander L. Owczarek\n\nSome \
calculations accompanying the solution to",
  FontSize->18],
 StyleBox[" Kreweras ",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["walks with general boundary weights (a,b,c). Symbols and equation \
numbers match the manuscript where possible.\n\nNote: Many symbols are reused \
between this notebook and the reverse Kreweras notebook -- be sure to quit \
the kernel before switching to the other one, or use a different kernel for \
each.\n\n(This block needs to be expanded to run some preliminary commands!)",
  
  FontSize->18]
}], "Subtitle",
 CellChangeTimes->{{3.750824805958762*^9, 3.750824842119121*^9}, {
  3.7508249241054707`*^9, 3.750824928018138*^9}, {3.7508250192823887`*^9, 
  3.750825027737978*^9}, {3.750825098608947*^9, 3.750825158227562*^9}, {
  3.750825445963887*^9, 3.750825476209941*^9}, {3.7508255475293293`*^9, 
  3.750825586691904*^9}, {3.750830675618618*^9, 3.750830730296144*^9}, {
  3.759698024614566*^9, 3.759698061086362*^9}, {3.76082306585702*^9, 
  3.760823066987214*^9}, {3.7679890234150877`*^9, 3.767989051007194*^9}, {
  3.767989088190913*^9, 
  3.767989150326499*^9}},ExpressionUUID->"ecc4ad1b-d1f6-4a0d-9aad-\
7ed9e3c81bd0"],

Cell[TextData[{
 StyleBox["Preliminaries",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["It will be useful to have some series to substitute into equations \
to check their validity.",
  FontSize->18,
  FontColor->GrayLevel[0.5]]
}], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 
  3.750826127406416*^9}},ExpressionUUID->"06bc1e98-bb67-48f1-860b-\
ca8c8ac930d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "shorthand", " ", "to", " ", "apply", " ", "a", " ", "function", " ", "f", 
    " ", "to", " ", "the", " ", "terms", " ", "of", " ", "a", " ", "series"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"f_", ",", "S_"}], "]"}], ":=", 
   RowBox[{"MapAt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "/@", "#"}], "&"}], ",", "S", ",", "3"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.750825870168775*^9, 3.750825899254999*^9}, {
   3.750825949723229*^9, 3.750825950338171*^9}, {3.750826120147867*^9, 
   3.750826127406775*^9}, 3.7618786870070343`*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"59969c7c-7107-4b1c-a56d-abecfb14bd09"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "mathematica", " ", "sometimes", " ", "has", " ", "trouble", " ", "when", 
    " ", "combining", " ", "multiple", " ", "series", " ", "in", " ", "the", 
    " ", "same", " ", "variable"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"so", " ", 
    RowBox[{"here", "'"}], "s", " ", "a", " ", "way", " ", "of", " ", 
    "dealing", " ", "with", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplificate", "[", "S_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", "n"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"-", "3"}], "]"}], "]"}], "/", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"S", "[", 
            RowBox[{"[", 
             RowBox[{"-", "3"}], "]"}], "]"}], "/", 
           RowBox[{"S", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"S", "[", 
               RowBox[{"[", "3", "]"}], "]"}], "]"}], "-", "1"}], ")"}], "/", 
           
           RowBox[{"S", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}]}]}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}]}], "]"}], ".", 
     RowBox[{"S", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"O", "[", 
      RowBox[{"S", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"-", "2"}], "]"}], "]"}], "/", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.760746561361539*^9, 3.760746694864303*^9}, {
  3.760746750948298*^9, 3.760746775776778*^9}, {3.760747397991107*^9, 
  3.76074741402074*^9}, {3.760747472376697*^9, 3.760747520460362*^9}, {
  3.760748526894298*^9, 3.760748565932456*^9}, {3.7607494965192204`*^9, 
  3.7607495188361387`*^9}, {3.7608187259883013`*^9, 3.7608187274096518`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"4da374a9-6e9a-40e4-89a3-f058473d49d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"this", " ", "will", " ", "also", " ", "be", " ", "useful"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.7508927273243437`*^9, 3.750892740092514*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"268b89fc-6837-4c98-880d-67e223590443"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  RowBox[{"ParsedBoxWrapper", "[", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<_\>\"", ",", "\"\<_\>\""}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  RowBox[{"ParsedBoxWrapper", "[", 
   RowBox[{"SubsuperscriptBox", "[", 
    RowBox[{"\"\<_\>\"", ",", "\"\<_\>\"", ",", "\"\<_\>\""}], "]"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.750892947603434*^9, 3.750892947605592*^9}, {
  3.750898836843748*^9, 3.750898849890044*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"9927e9db-bed3-4fef-aca5-db8a87bdf2c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"calculate", " ", "the", " ", "coefficients", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"polynomials", " ", "in", " ", "a"}], ",", "b", ",", "c"}], 
     ")"}], " ", "recursively"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"let", " ", 
    RowBox[{"q", "[", 
     RowBox[{"n", ",", "i", ",", "j"}], "]"}], " ", "be", " ", "the", " ", 
    "total", " ", "weight", " ", "of", " ", "walks", " ", "of", " ", "length",
     " ", "n", " ", "ending", " ", "at", " ", "coordinate", " ", 
    RowBox[{"(", 
     RowBox[{"i", ",", "j"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "q", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"0", ",", "0", ",", "0"}], "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"n_", ",", "i_", ",", "j_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"n", ",", "i", ",", "j"}], "]"}], "=", "0"}], ")"}], "/;", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", "<", "0"}], "||", 
        RowBox[{"i", "<", "0"}], "||", 
        RowBox[{"j", "<", "0"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "i_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"n", ",", "i", ",", "j"}], "]"}], "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", 
           RowBox[{"i", "-", "1"}], ",", 
           RowBox[{"j", "-", "1"}]}], "]"}], "+", 
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", 
           RowBox[{"i", "+", "1"}], ",", "j"}], "]"}], "+", 
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", "i", ",", 
           RowBox[{"j", "+", "1"}]}], "]"}]}], "]"}]}], ")"}], "/;", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"i", ">", "0"}], "&&", 
       RowBox[{"j", ">", "0"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "0", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"n", ",", "0", ",", "j"}], "]"}], "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"b", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", "1", ",", "j"}], "]"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", "0", ",", 
            RowBox[{"j", "+", "1"}]}], "]"}]}]}], "]"}]}], ")"}], "/;", 
     RowBox[{"(", 
      RowBox[{"j", ">", "0"}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "i_", ",", "0"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"n", ",", "i", ",", "0"}], "]"}], "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", "i", ",", "1"}], "]"}]}], "+", 
         RowBox[{"a", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", 
            RowBox[{"i", "+", "1"}], ",", "0"}], "]"}]}]}], "]"}]}], ")"}], "/;", 
     RowBox[{"(", 
      RowBox[{"i", ">", "0"}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "0", ",", "0"}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"n", ",", "0", ",", "0"}], "]"}], "=", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", "0", ",", "1"}], "]"}]}], "+", 
        RowBox[{"c", " ", 
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", "1", ",", "0"}], "]"}]}]}], "]"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759698184234085*^9, 3.7596982217613163`*^9}, {
  3.759698258155881*^9, 3.759698294268837*^9}, {3.7596983789831038`*^9, 
  3.759698409898426*^9}, {3.759698510115234*^9, 3.7596985631260443`*^9}, {
  3.75969862392305*^9, 3.759698645612405*^9}, {3.759698687080782*^9, 
  3.7596986950233717`*^9}, {3.759698763211735*^9, 3.759698789660714*^9}, {
  3.759698829070547*^9, 3.759699035566721*^9}, {3.759699098111526*^9, 
  3.759699136189612*^9}, {3.759700762333128*^9, 3.759700766628811*^9}, {
  3.760823459598728*^9, 3.760823471724677*^9}, {3.760823680224833*^9, 
  3.7608237277902937`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"aa66d61f-48d9-4bb3-9c7b-437b67615d43"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", "generating", " ", "functions"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "QQ", ",", "QQcx", ",", "QQcy", ",", "QQcxy", ",", "QQeval", ",", 
     "QQcxeval", ",", "QQcyeval", ",", "QQdk", ",", "QQdkeval"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQ", "[", "N_", "]"}], ":=", 
    RowBox[{
     RowBox[{"QQ", "[", "N", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"x", "^", "i"}], "*", 
           RowBox[{"y", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "coefficients", " ", "of", " ", "specific", " ", "powers", " ", "of", 
      " ", "x"}], ",", "y", ",", " ", 
     RowBox[{"or", " ", "both"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcx", "[", 
     RowBox[{"N_", ",", "i_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcx", "[", 
      RowBox[{"N", ",", "i"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"y", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcy", "[", 
     RowBox[{"N_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcy", "[", 
      RowBox[{"N", ",", "j"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"x", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcxy", "[", 
     RowBox[{"N_", ",", "i_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcxy", "[", 
      RowBox[{"N", ",", "i", ",", "j"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "evaluating", " ", "QQ", " ", "at", " ", "some", " ", "other", " ", 
     "values", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQeval", "[", 
     RowBox[{"N_", ",", "xx_", ",", "yy_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQeval", "[", 
      RowBox[{"N", ",", "xx", ",", "yy"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"xx", "^", "i"}], "*", 
           RowBox[{"yy", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcxeval", "[", 
     RowBox[{"N_", ",", "i_", ",", "yy_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcxeval", "[", 
      RowBox[{"N", ",", "i", ",", "yy"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"yy", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcyeval", "[", 
     RowBox[{"N_", ",", "j_", ",", "xx_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcyeval", "[", 
      RowBox[{"N", ",", "j", ",", "xx"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"xx", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", "generalised", " ", "diagonal", " ", "term"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQdk", "[", 
     RowBox[{"N_", ",", "k_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQdk", "[", 
      RowBox[{"N", ",", "k"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", 
             RowBox[{"i", "+", "k"}]}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"x", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQdkeval", "[", 
     RowBox[{"N_", ",", "k_", ",", "xx_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQdkeval", "[", 
      RowBox[{"N", ",", "k", ",", "xx"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", 
             RowBox[{"i", "+", "k"}]}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"xx", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.75969915207519*^9, 3.7596993469503727`*^9}, {
  3.759699380116457*^9, 3.7596994883664007`*^9}, {3.7597003963632097`*^9, 
  3.759700407060787*^9}, {3.759700439867523*^9, 3.7597007359779787`*^9}, {
  3.7597009771006403`*^9, 3.759701047997175*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"e0af43c6-dc8c-4768-bc3b-8f0f02cd2fd7"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 5.1",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.760824004669656*^9, 
  3.760824006907593*^9}, {3.760832918548829*^9, 
  3.760832918581484*^9}},ExpressionUUID->"9ba78d60-5b57-4183-aea1-\
831b648977d5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "kernel", " ", "and", " ", "A"}], ",", "B", ",", 
    "G"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"K", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{"1", "-", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", " ", "y"}], "+", 
        RowBox[{"1", "/", "x"}], "+", 
        RowBox[{"1", "/", "y"}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"A", "=", 
    RowBox[{"1", "/", "y"}]}], "\[IndentingNewLine]", 
   RowBox[{"B", "=", 
    RowBox[{"1", "/", "x"}]}], "\[IndentingNewLine]", 
   RowBox[{"G", "=", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.760824009406481*^9, 3.760824049849609*^9}, {
  3.7608240839835443`*^9, 3.760824105189397*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"cae15228-a804-4dda-a000-dc3de29e661e"],

Cell[BoxData[
 FractionBox["1", "y"]], "Output",
 CellChangeTimes->{3.7608241140027514`*^9, 3.760837017904873*^9, 
  3.7609075135714912`*^9, 3.760993371986136*^9, 3.761250331356339*^9, 
  3.7613339733421907`*^9, 3.761360605439691*^9, 3.761420775745667*^9, 
  3.761443410351295*^9, 3.761514279461505*^9, 3.7675807934983034`*^9, 
  3.7676439597550373`*^9, 3.7891578954157867`*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"746f0e25-8811-4ee7-884d-831d71a64537"],

Cell[BoxData[
 FractionBox["1", "x"]], "Output",
 CellChangeTimes->{3.7608241140027514`*^9, 3.760837017904873*^9, 
  3.7609075135714912`*^9, 3.760993371986136*^9, 3.761250331356339*^9, 
  3.7613339733421907`*^9, 3.761360605439691*^9, 3.761420775745667*^9, 
  3.761443410351295*^9, 3.761514279461505*^9, 3.7675807934983034`*^9, 
  3.7676439597550373`*^9, 3.7891578954180527`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"4154c0df-4528-4c87-bd39-fa3bbe4509ea"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.7608241140027514`*^9, 3.760837017904873*^9, 
  3.7609075135714912`*^9, 3.760993371986136*^9, 3.761250331356339*^9, 
  3.7613339733421907`*^9, 3.761360605439691*^9, 3.761420775745667*^9, 
  3.761443410351295*^9, 3.761514279461505*^9, 3.7675807934983034`*^9, 
  3.7676439597550373`*^9, 3.7891578954203997`*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"cc6a7e46-bf80-4a08-8e29-21254408f0ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "rhs", " ", "of", " ", "eqn", " ", 
    RowBox[{"(", "5.1", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"mainFE", "=", 
     RowBox[{
      RowBox[{"1", "/", "c"}], "+", 
      RowBox[{
       RowBox[{"1", "/", "a"}], 
       RowBox[{"(", 
        RowBox[{"a", "-", "1", "-", 
         RowBox[{"t", " ", "a", " ", "A"}]}], ")"}], 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "b"}], 
       RowBox[{"(", 
        RowBox[{"b", "-", "1", "-", 
         RowBox[{"t", " ", "b", " ", "B"}]}], ")"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"a", " ", "b", " ", "c"}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "b", " ", "c"}]}], ")"}]}], "+", 
         RowBox[{"t", " ", "G"}]}], ")"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "verifying", " ", "eqn", " ", 
     RowBox[{"(", "5.1", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE", "-", 
     RowBox[{
      RowBox[{"K", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "\[Rule]", 
       RowBox[{"QQ", "[", "12", "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], "\[Rule]", 
       RowBox[{"QQcx", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7597092880979433`*^9, 3.759709315881922*^9}, {
  3.759709403848383*^9, 3.759709475162389*^9}, {3.75970952212619*^9, 
  3.759709566303985*^9}, {3.75970972370592*^9, 3.759709791983199*^9}, {
  3.759802356788431*^9, 3.7598023582711487`*^9}, {3.760829447161601*^9, 
  3.760829450401085*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"39ee226e-04ff-40c5-9c13-7f8c1054ef47"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.760829436214841*^9, 3.76083701826731*^9, 
  3.760907514390814*^9, 3.760993372377137*^9, 3.7612503319068108`*^9, 
  3.761333975934944*^9, 3.761360606271769*^9, 3.761420776698186*^9, 
  3.761443410774396*^9, 3.7615142798968687`*^9, 3.7675807946153035`*^9, 
  3.767643960230102*^9, 3.7891578959511843`*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"b4a2c864-460a-4ee3-ac1c-09e4f924f22d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 5.2",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.760824004669656*^9, 
  3.760824006907593*^9}, {3.760832918548829*^9, 
  3.7608329243865356`*^9}},ExpressionUUID->"6d6a9b38-9dae-46a5-b1fb-\
2d4c00edb6f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"apply", " ", "the", " ", "kernel", " ", "symmetries"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"mainFE0", "=", "mainFE"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE1", "=", 
     RowBox[{"mainFE0", "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE2", "=", 
     RowBox[{"mainFE1", "/.", 
      RowBox[{"{", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE3", "=", 
     RowBox[{"mainFE2", "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE4", "=", 
     RowBox[{"mainFE3", "/.", 
      RowBox[{"{", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE5", "=", 
     RowBox[{"mainFE4", "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.75970989143775*^9, 3.7597100087953873`*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"894509c9-9782-425f-8146-a64321b72830"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "vector", " ", "V", " ", "from", " ", "eqn", " ", 
    RowBox[{"(", "5.2", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "order", " ", "is", " ", "arbitrary"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"V", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], ",", " ", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "0"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "the", " ", "coefficient", " ", "matrix", " ", "M"}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"M", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE0", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE1", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE2", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE3", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE4", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE5", ",", "V"}], "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759711022762516*^9, 3.7597111342858763`*^9}, {
  3.759711278965399*^9, 3.7597112890881*^9}, {3.7597113272375603`*^9, 
  3.759711327867112*^9}, {3.759711364723501*^9, 3.7597113735658007`*^9}, {
  3.760829914990836*^9, 3.760829916338739*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"620a52d8-f75c-41ff-a388-5b7849f8a4db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "y"]}], "a"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "x"]}], "b"], ",", "0", ",", "0", ",", "0", 
     ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "y"]}], "a"], ",", "0", ",", "0", ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "y"]}], "b"], ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "y"]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "x"]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "x"]}], "a"], ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], "b"], ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], "a"], ",", "0", ",", 
     "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "x"]}], "b"], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.759711328224057*^9, 3.75971137895121*^9, 3.7597147084819*^9, 
   3.759714947559157*^9, 3.759786135117076*^9, 3.75978699468305*^9, 
   3.759798494109972*^9, 3.76031669599691*^9, 3.760323981874164*^9, 
   3.760387756131559*^9, 3.7606516084364862`*^9, 3.76066097156022*^9, 
   3.7607362515105257`*^9, 3.760818740748885*^9, 3.7608205554505577`*^9, 
   3.7608299195044003`*^9, 3.760837018392288*^9, 3.760907525448248*^9, 
   3.760993372632481*^9, 3.7612503321200323`*^9, 3.761333976230287*^9, 
   3.761360606442589*^9, 3.761420776989427*^9, 3.761443410937003*^9, 
   3.761514280084321*^9, {3.7675807960293036`*^9, 3.7675808124643035`*^9}, 
   3.767643974523786*^9, 3.789158152395954*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"d847db8f-efd3-4bea-8d9a-87ae27768265"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"write", " ", "this", " ", "using"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ap", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"1", "/", "a"}], 
     RowBox[{"(", 
      RowBox[{"a", "-", "1", "-", 
       RowBox[{"t", " ", 
        RowBox[{"a", "/", "y"}]}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bp", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"1", "/", "b"}], 
     RowBox[{"(", 
      RowBox[{"b", "-", "1", "-", 
       RowBox[{"t", " ", 
        RowBox[{"b", "/", "x"}]}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ap", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", "0", ",", "0", ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Bp", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", 
        RowBox[{"Ap", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", "0", 
        ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", "0", ",", 
        RowBox[{"Ap", "[", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"y", ",", "x"}], "]"}], ",", 
        RowBox[{"Ap", "[", 
         RowBox[{"y", ",", "x"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"Ap", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", "0", 
        ",", 
        RowBox[{"Bp", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", "0"}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ap", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", "0", ",", "0", 
        ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", "0", ",", "0"}],
        "}"}]}], "}"}], "-", "M"}]}]}]], "Input",
 CellChangeTimes->{{3.759711390291848*^9, 3.759711442540081*^9}, {
  3.75971199832868*^9, 3.759711998407507*^9}, {3.76082998839817*^9, 
  3.7608299903880672`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"00a6a211-5a35-4a1a-81fe-096a6bf550dc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.760829992335185*^9, 3.7608370185058203`*^9, 3.7609075256018867`*^9, 
   3.760993372737916*^9, 3.7612503322406807`*^9, 3.7613339763147793`*^9, 
   3.761360606598708*^9, 3.761420777106029*^9, 3.761443411227332*^9, 
   3.761514280254171*^9, {3.7675807960453033`*^9, 3.7675808124853034`*^9}, 
   3.7676439745337067`*^9, 3.789158152406681*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"33f10168-7e84-45bd-a03b-ea300bdf1caf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "vector", " ", "C", " ", "is", " ", "everything", " ", 
     "else"}], ",", " ", 
    RowBox[{"see", " ", "eqn", " ", 
     RowBox[{"(", "5.2", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"CC", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mainFE0", ",", "mainFE1", ",", "mainFE2", ",", "mainFE3", ",", 
      "mainFE4", ",", "mainFE5"}], "}"}], "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Rule]", "0"}], "&"}], "/@", "V"}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7597120140910273`*^9, 3.759712036475932*^9}, {
  3.759712094055369*^9, 3.759712114046336*^9}, {3.759712164851583*^9, 
  3.759712209392116*^9}, {3.759714893942273*^9, 3.759714895606483*^9}, {
  3.766380885627*^9, 3.766380886507*^9}, {3.789157915790599*^9, 
  3.789157921245633*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"585994ec-a4f0-4ce7-8c96-4fed50282cc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.760830321008286*^9, 3.7608370186215067`*^9, 3.760907525734127*^9, 
   3.760993372871915*^9, 3.761250332354033*^9, 3.761333976396677*^9, 
   3.761360607184134*^9, 3.7614207772371893`*^9, 3.761443411365189*^9, 
   3.761514280516171*^9, {3.7675807960663033`*^9, 3.767580812507303*^9}, 
   3.76764397459627*^9, 3.789158152483042*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"e6283703-d080-4aaf-bcd9-5c221778d47c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"M", " ", "has", " ", "rank", " ", "5"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"MatrixRank", "[", "M", "]"}]}]], "Input",
 CellChangeTimes->{{3.760830941552259*^9, 3.7608309598746862`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"1e606ab0-1a92-496d-82c5-97c087c305fd"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.7608309468117867`*^9, 3.760830960472844*^9}, 
   3.760837018738373*^9, 3.760907525887151*^9, 3.7609933729998617`*^9, 
   3.7612503324704943`*^9, 3.761333976480033*^9, 3.761360607460786*^9, 
   3.761420777360805*^9, 3.7614434115202103`*^9, 3.761514280671185*^9, {
   3.7675807961213036`*^9, 3.7675808125253034`*^9}, 3.767643974607544*^9, 
   3.789158152492581*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"e1743b30-f032-46ad-9f0d-0bfcf40aa9ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "vector", " ", "N", " ", "spans", " ", "the", " ", 
     "nullspace", " ", "of", " ", "M"}], ",", " ", 
    RowBox[{"see", " ", "eqn", " ", 
     RowBox[{"(", "5.4", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NullSpace", "[", 
     RowBox[{"M", "\[Transpose]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "clean", " ", "up", " ", "the", " ", "denominators", " ", "a", " ", 
     "bit"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"NN", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"%", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "t"}], "+", "y", "-", 
        RowBox[{"a", " ", "y"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "t"}], "+", "x", "-", 
        RowBox[{"a", " ", "x"}]}], ")"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b", " ", "t"}], "+", "y", "-", 
         RowBox[{"b", " ", "y"}]}], ")"}], "/", "y"}]}], "//", "Factor"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"and", " ", "see"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NN", ".", "M"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760830972453038*^9, 3.760830976648431*^9}, {
  3.760831811033325*^9, 3.76083181108075*^9}, {3.760831852656899*^9, 
  3.76083192299692*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"616dcae5-1e49-4429-b5f1-5ec85f32bc32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "y", "-", 
      RowBox[{"b", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
        RowBox[{"a", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
        RowBox[{"b", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", " ", "t"}], "+", "y", "-", 
        RowBox[{"b", " ", "y"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], "x"]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
       RowBox[{"a", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
       RowBox[{"b", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "t"}], "+", "y", "-", 
       RowBox[{"a", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], "x"], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}]}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "y", "-", 
      RowBox[{"a", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "t"}], "+", "y", "-", 
       RowBox[{"a", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "t"}], "+", "y", "-", 
       RowBox[{"b", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "a", "+", 
       RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], "y"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "t"}], "+", "x", "-", 
        RowBox[{"a", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "t"}], "+", "y", "-", 
        RowBox[{"a", " ", "y"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", " ", "t"}], "+", "y", "-", 
        RowBox[{"b", " ", "y"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], "y"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.760830977867395*^9, {3.760831879508259*^9, 3.7608319232556*^9}, 
   3.760837018855482*^9, 3.7609075260395527`*^9, 3.7609933731207047`*^9, 
   3.761250332607575*^9, 3.761333976567109*^9, 3.761360607616173*^9, 
   3.761420777497387*^9, 3.7614434116863747`*^9, 3.76151428083779*^9, {
   3.767580796271303*^9, 3.7675808125523033`*^9}, 3.7676439802646437`*^9, 
   3.789158152580874*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"64a33f26-3a84-4340-9dea-4043c0a54b91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.760830977867395*^9, {3.760831879508259*^9, 3.7608319232556*^9}, 
   3.760837018855482*^9, 3.7609075260395527`*^9, 3.7609933731207047`*^9, 
   3.761250332607575*^9, 3.761333976567109*^9, 3.761360607616173*^9, 
   3.761420777497387*^9, 3.7614434116863747`*^9, 3.76151428083779*^9, {
   3.767580796271303*^9, 3.7675808125523033`*^9}, 3.7676439802646437`*^9, 
   3.789158152583281*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"f43d8978-1ff8-4b69-b1e2-0468a47840a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"unlike", " ", "reverse", " ", "Kreweras"}], ",", " ", 
    RowBox[{
     RowBox[{"this", " ", "time", " ", 
      RowBox[{"N", ".", "C"}]}], " ", "\[NotEqual]", " ", "0"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"fullOSrhs", "=", 
   RowBox[{
    RowBox[{"NN", ".", "CC"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", "Factor"}], "]"}], 
     "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.760832086821735*^9, 3.760832123843174*^9}, {
  3.7609957014120483`*^9, 3.760995703233428*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"10392ece-dd4a-4ec8-9dd0-376b1b5cc25b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["t", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"x", " ", 
        SuperscriptBox["y", "2"]}]}], ")"}]}], 
    RowBox[{"c", " ", "x", " ", "y"}]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "b"}], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}], "+", 
      RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
    SuperscriptBox["t", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", "y"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SuperscriptBox["x", "2"], " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"x", " ", 
       SuperscriptBox["y", "2"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], 
   RowBox[{"c", " ", "x", " ", "y"}]]}]], "Output",
 CellChangeTimes->{{3.760832104833178*^9, 3.7608321241378593`*^9}, 
   3.760837019028781*^9, 3.76090753132253*^9, 3.760993373254652*^9, 
   3.760995704191392*^9, 3.76125033275744*^9, 3.761333976668376*^9, 
   3.76136060827671*^9, 3.7614207776626043`*^9, 3.761443411885215*^9, 
   3.761514281004862*^9, {3.7675807963403034`*^9, 3.7675808125783033`*^9}, 
   3.767643980390266*^9, 3.789158152675544*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"22673ff1-dc1a-43d2-b2b2-76986ecc39f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", "we", " ", "need", " ", "to", " ", 
    RowBox[{"extract", " ", "[", 
     RowBox[{"y", "^", "0"}], "]"}], " ", "of", " ", 
    RowBox[{"N", ".", "Q"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"fullOSlhs", "=", 
   RowBox[{"NN", ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"y", ",", 
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"y", ",", "x"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", 
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "}"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.760836994743431*^9, 3.760836994861926*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"6a920c35-346a-4685-80f9-111dfd958d0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "t"}], "+", "y", "-", 
       RowBox[{"a", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "t"}], "+", "y", "-", 
       RowBox[{"b", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", 
       FractionBox["1", 
        RowBox[{"x", " ", "y"}]]}], "]"}]}], "y"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", "y", "-", 
     RowBox[{"b", " ", "y"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "+", 
     RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "y", "-", 
      RowBox[{"a", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "y", "-", 
      RowBox[{"b", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "x"}], "]"}]}], "y"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "y", "-", 
      RowBox[{"b", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "y"}], "]"}]}], "x"], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", "x", "-", 
     RowBox[{"b", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "y", "-", 
     RowBox[{"a", " ", "y"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "+", 
     RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"y", ",", "x"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "y", "-", 
      RowBox[{"a", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"y", ",", 
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]]}], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.760833182935164*^9, {3.760836996374241*^9, 3.760837019147448*^9}, 
   3.7609075315663757`*^9, 3.760993373383335*^9, 3.761250332892103*^9, 
   3.761333976763681*^9, 3.761360608450325*^9, 3.7614207778155003`*^9, 
   3.761443412088544*^9, 3.7615142811565027`*^9, {3.7675807963623037`*^9, 
   3.767580812601303*^9}, 3.767643980401547*^9, 3.789158152686953*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"8114375c-5223-4adc-b855-9c5b01816d39"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"this", " ", "is", " ", "not", " ", "too", " ", "complicated"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSlhsy0", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{"fullOSlhs", ",", 
          RowBox[{"Q", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ",", "y", ",", "0"}], 
       "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "//", "Factor"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefficientList", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"fullOSlhs", ",", 
         RowBox[{"Q", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}]}], "]"}], 
       ",", "y"}], "]"}], "//", "Factor"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "2"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefficientList", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"fullOSlhs", ",", 
         RowBox[{"Q", "[", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "]"}], ",", "y"}],
       "]"}], "//", "Factor"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "/", "x"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "2", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "/", 
       RowBox[{"x", "^", "2"}]}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{"fullOSlhs", ",", 
          RowBox[{"Q", "[", 
           RowBox[{"y", ",", "x"}], "]"}]}], "]"}], ",", "y", ",", "0"}], 
       "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "//", "Factor"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOSlhs", ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "1"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "/", "x"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "2"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}], "/", 
       RowBox[{"x", "^", "2"}]}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"fullOSlhs", ",", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", 
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "1"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "/", "x"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "2"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}], "/", 
       RowBox[{"x", "^", "2"}]}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.7608331945776653`*^9, 3.7608332293581457`*^9}, {
  3.760833263479957*^9, 3.760833269666884*^9}, {3.760833304611205*^9, 
  3.760833374046363*^9}, {3.760833435282324*^9, 3.760833605936533*^9}, {
  3.7608364983330936`*^9, 3.760836648352213*^9}, {3.7608370049094353`*^9, 
  3.7608370121617002`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"f080b300-8c8e-4a86-af8a-271dda84da23"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "t", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", " ", "t"}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"x", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.789158152773881*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"82e63fea-3f10-4711-b1f7-cb8c5a1212f1"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "-", "b", "+", 
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", 
      RowBox[{"-", "1"}], "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", "x", "-", 
     RowBox[{"b", " ", "x"}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "2"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.7891581528812733`*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"0a354dd7-933d-41fd-aa72-824b41424a80"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}]}], ")"}], " ", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], "x"]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "-", "b", "+", 
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], 
   SuperscriptBox["x", "2"]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "2", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], 
   SuperscriptBox["x", "2"]]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.789158152975945*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"64b8830f-c01b-416c-97f2-67c7c9561e18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", "a", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"b", " ", "t"}], "+", "x", "-", 
    RowBox[{"b", " ", "x"}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "x"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.7891581529782333`*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"1e767623-9649-46a9-a89d-bcaa36fee702"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", "x", "-", 
     RowBox[{"b", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "-", 
     SuperscriptBox["a", "2"], "+", "b", "-", 
     RowBox[{"3", " ", "a", " ", "b"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "a"}], "-", 
      SuperscriptBox["a", "2"], "+", "b", "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.789158153083743*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"5307c4f0-7c64-42f7-86d5-a5c22a7d70d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "t"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "-", 
     RowBox[{"3", " ", "a", " ", "b"}], "-", 
     SuperscriptBox["b", "2"], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}]}], "y"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a", "+", 
     RowBox[{"2", " ", "b"}], "-", 
     RowBox[{"2", " ", "a", " ", "b"}], "-", 
     SuperscriptBox["b", "2"], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"]}], "-", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", "y"}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "t", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   SuperscriptBox["y", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.789158153086389*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"81dc04c2-75fb-467e-8747-bf473d4bfd30"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "t"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "-", 
     RowBox[{"3", " ", "a", " ", "b"}], "-", 
     SuperscriptBox["b", "2"], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a", "+", 
      RowBox[{"2", " ", "b"}], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "x"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.7608332701472816`*^9, {3.760833310208354*^9, 3.760833374280868*^9}, {
   3.760833448436651*^9, 3.7608335403540783`*^9}, {3.7608335731597433`*^9, 
   3.760833606138125*^9}, {3.760836590040559*^9, 3.7608366129805613`*^9}, 
   3.7608366492237787`*^9, 3.760837019258543*^9, 3.7609075359254303`*^9, 
   3.760993373498868*^9, 3.761250333020358*^9, 3.761333976847085*^9, 
   3.7613606086362877`*^9, 3.7614207779662457`*^9, 3.76144341225991*^9, 
   3.761514281321579*^9, {3.7675807963763037`*^9, 3.7675808126223035`*^9}, 
   3.767643986684177*^9, 3.78915815319307*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"fe3d1f9e-6573-4eda-adcf-ae16e5aec497"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it", " ", "manually"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSlhs", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
       RowBox[{"QQeval", "[", 
        RowBox[{"12", ",", "ecks", ",", "why"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"#", ",", "y", ",", "0"}], "]"}], "&"}], ",", "%"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", "fullOSlhsy0", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "1", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "2", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "2", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "1"}], "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "2"}], "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", 
          RowBox[{"-", "2"}], ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "1", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "2", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "2"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.760836964933188*^9, 3.760836967246656*^9}, {
  3.760837026435528*^9, 3.760837400257341*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"14b6c708-60c4-4c83-b6e0-ba36e8f0d6c3"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760837031888235*^9, {3.760837080374774*^9, 3.7608370946679373`*^9}, {
   3.760837132980369*^9, 3.760837395027137*^9}, 3.7609075427385597`*^9, 
   3.760993376121875*^9, 3.7612503357039223`*^9, 3.761333979496622*^9, 
   3.761360612238339*^9, 3.7614207814564533`*^9, 3.7614434150220947`*^9, 
   3.761514284342285*^9, {3.7675807997933035`*^9, 3.7675808143133035`*^9}, 
   3.767643991657761*^9, 3.789158155194304*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"e774e3de-92e5-492a-81f2-62b63de48806"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "want", " ", "to", " ", "use", " ", "some", " ", "boundary", 
    " ", "and", " ", "diagonal", " ", "relations", " ", "to", " ", 
    "eliminate", " ", "some", " ", "of", " ", "these", " ", "terms"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"equation", " ", "for", " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Qx1eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", " ", "x", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"b", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "-", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"b", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "2"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Q1xeqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", " ", "x", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"a", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "-", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"a", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxeval", "[", 
        RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
       RowBox[{"QQcxeval", "[", 
        RowBox[{"12", ",", "1", ",", "x"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
       RowBox[{"QQcxeval", "[", 
        RowBox[{"12", ",", "2", ",", "x"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Qx0eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "a", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"c", "-", "a"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", "a", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"c", "-", "a"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "-", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", "a", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q0xeqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "b", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"c", "-", "b"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", "b", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"c", "-", "b"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "-", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", "b", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxeval", "[", 
        RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
       RowBox[{"QQcxeval", "[", 
        RowBox[{"12", ",", "1", ",", "x"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{
      SubsuperscriptBox["Q", 
       RowBox[{"-", "1"}], "d"], "[", 
      FractionBox["1", "x"], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Qdm1eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "-", 
     RowBox[{"t", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", " ", "x", " ", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "2"}], "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], 
      RowBox[{"(", 
       RowBox[{"a", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", 
         RowBox[{"-", "1"}], "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", 
         RowBox[{"-", "2"}], "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Qdp1eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubsuperscriptBox["Q", "2", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"b", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", "x", " ", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"b", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "-", 
     RowBox[{"t", " ", "x", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "2", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "2", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Qd0eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", "1", "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"c", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "x", " ", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{"(", 
       RowBox[{"c", "-", "1"}], ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", 
         RowBox[{"-", "1"}], "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q01eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q00eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "c", " ", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "c", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q10eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q11eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "0"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q20eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "3", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "2"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q02eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "3"}]]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "3"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "3"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "2"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "1"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q21eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "3", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"equation", " ", "for", " ", 
     SubscriptBox["Q", 
      RowBox[{"3", ",", "0"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q30eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "0"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"4", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "3", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "3", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "4", ",", "0"}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.760837741751061*^9, 3.760837818956602*^9}, {
   3.7608387080723867`*^9, 3.760838813991351*^9}, {3.760838890596493*^9, 
   3.760838905129263*^9}, {3.760838991543439*^9, 3.760839112639247*^9}, {
   3.7608396577794228`*^9, 3.7608398096445837`*^9}, {3.7608400424794197`*^9, 
   3.7608401070762367`*^9}, {3.760840950913637*^9, 3.760840953421507*^9}, {
   3.7608409933821898`*^9, 3.76084117661285*^9}, {3.7608413042839117`*^9, 
   3.7608413044834213`*^9}, {3.760841730296171*^9, 3.76084188940453*^9}, {
   3.760841997770872*^9, 3.760842170081064*^9}, 3.760842282660568*^9, {
   3.760842874368539*^9, 3.760842904220953*^9}, {3.7608429348669024`*^9, 
   3.7608431321831007`*^9}, {3.7610096798506393`*^9, 3.761009806184197*^9}, {
   3.76101187587547*^9, 3.761011932928981*^9}, {3.761432591748859*^9, 
   3.761432731890156*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"3987d976-8bb6-45ea-a0c3-153ae310d457"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"0", ",", "1"}]], " ", "t"}], "x"], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "-", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "x"], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581553825283`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"417743a3-2331-490f-99ab-24757d5da761"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.78915815543978*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"ae1d319d-17c3-4e13-86f7-0f44b3e0d700"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]], " ", "t"}], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", "t"}], "x"], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "-", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "x"], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.78915815550241*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"628183de-afb3-460c-a105-c639588d732b"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.78915815556209*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"5b0655d7-fd54-4360-a812-09e52bcde60a"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "-", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], "x"], "-", 
  RowBox[{"Q", "[", 
   RowBox[{"x", ",", "0"}], "]"}], "+", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], "x"], "+", 
  RowBox[{"a", " ", "t", " ", 
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155564878*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"b2d53eaf-4a80-4dda-a61c-abbfba57d1d3"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581555674562`*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"e58d62ad-448a-4ca3-86e2-1ebe2fb76755"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "b"}], "+", "c"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "b"}], "+", "c"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "-", 
  FractionBox[
   RowBox[{"b", " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], "x"], "-", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "x"}], "]"}], "+", 
  FractionBox[
   RowBox[{"b", " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "x"}], "]"}]}], "x"], "+", 
  RowBox[{"b", " ", "t", " ", 
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581555699*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"ecfc80ad-ce7e-4364-b5f5-2a8c671fe8f9"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155572446*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"e85bb9f4-19fd-47dc-b205-1d8ab0a1eb46"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "1"}]], " ", "t"}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SubscriptBox["Q", 
     RowBox[{"2", ",", "0"}]], " ", "t"}], "x"], "-", 
  RowBox[{"t", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "-", 
  RowBox[{
   SubsuperscriptBox["Q", 
    RowBox[{"-", "1"}], "d"], "[", 
   FractionBox["1", "x"], "]"}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubsuperscriptBox["Q", 
      RowBox[{"-", "1"}], "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "2"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581555747967`*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"484e84ca-1150-4d7f-b1b6-cfb75e5d6d49"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581555772333`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"ddc343ae-aa19-4d85-a28c-4484929aaf1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "-", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "-", 
  RowBox[{
   SubsuperscriptBox["Q", "1", "d"], "[", 
   FractionBox["1", "x"], "]"}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubsuperscriptBox["Q", "2", "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155579733*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"d74153a8-3768-406a-bbbb-e8bedbb45966"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155582375*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"62fcfb74-7af7-4988-9fb9-1e907262aac5"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "-", 
  RowBox[{
   SubsuperscriptBox["Q", "0", "d"], "[", 
   FractionBox["1", "x"], "]"}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubsuperscriptBox["Q", "1", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "1"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581555847063`*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"2104043e-f39e-41a2-b5ec-850c500ac68e"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581556656857`*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"cd89b2f5-d2c1-4704-bdf8-9879c6a471c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]]}], "+", 
  RowBox[{"b", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{"b", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155667692*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"78701672-07f6-4b23-a67d-f6ec14356d53"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155669828*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"9d34bccf-815e-4adb-ba91-37b71e1ec129"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"c", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "-", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155671969*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"53b9f1dd-77dc-42db-9517-e1b3086861e9"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581556740103`*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"c030b7f5-e1cf-471a-ba59-5264ccda11db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]]}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155676152*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"4889b54f-72eb-4311-8940-b3ac27fb6773"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155678309*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"134be84f-543d-42b2-8ee6-5ff4ab37fc39"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"1", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"2", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"t", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155770754*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"5d729c74-16bd-4777-b063-6cadc8b9bc46"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155866569*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"72f54270-94a8-4621-9c2b-f89a28080a30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]]}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"3", ",", "0"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581558757668`*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"47aaea37-dcb7-40c9-8b82-952cb29f0d0b"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158155963719*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"d4ab3855-b77a-40cd-b605-e8e6ad926477"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "2"}]]}], "+", 
  RowBox[{"b", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "3"}]], " ", "t"}], "+", 
  RowBox[{"b", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "2"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581560538063`*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"f2989c27-88a7-4681-8ee3-64c233fa64bc"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158156060254*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"696aea53-d4e1-4d4e-8cf6-df618d6b393a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "1"}]]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"2", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"3", ",", "1"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.7891581561509533`*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"df187d4e-0825-4d89-8907-c86346973f3d"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158156235454*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"9871ff4a-5c88-459f-852a-b0989e75da6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"3", ",", "0"}]]}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"3", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"4", ",", "0"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158156243886*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"40c30140-da38-45ff-a910-c4166a13cff5"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760838790613168*^9, 3.760838815040036*^9}, 
   3.760838906178866*^9, 3.760839043811372*^9, 3.760839113422627*^9, 
   3.760839781665148*^9, 3.760840111456462*^9, 3.760841177662475*^9, 
   3.760841305725896*^9, {3.7608418776336937`*^9, 3.7608418898445177`*^9}, {
   3.760842146252985*^9, 3.7608421714324293`*^9}, 3.7608422843880053`*^9, 
   3.760842976602737*^9, 3.760843052805924*^9, 3.760843133221107*^9, 
   3.7609075493062887`*^9, 3.7609933762869463`*^9, 3.761009807350511*^9, 
   3.7610119332042933`*^9, 3.76125033587184*^9, 3.761333979650215*^9, 
   3.761360612535549*^9, 3.7614207816787653`*^9, 3.7614326858774*^9, 
   3.7614327323943644`*^9, 3.7614434151908484`*^9, 3.761514284529998*^9, {
   3.7675807999383035`*^9, 3.7675808143873034`*^9}, 3.7676439977706127`*^9, 
   3.789158156320902*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"e3137439-e88e-4904-b071-0ebe0c7ee2ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "then", " ", "use", " ", "all", " ", "these", " ", 
    "to", " ", "eliminate", " ", "things", " ", "from", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{"y", "^", "0"}], "]"}], " ", "of", " ", "the", " ", "LHS", " ", 
    "of", " ", "the", " ", "full", " ", "orbit", " ", "sum"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"thus", " ", "obtaining", " ", "eqn", " ", 
    RowBox[{"(", "5.7", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Total", "[", "fullOSlhsy0", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q1xeqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q0xeqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qx1eqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "2"}]], "[", "x", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qx0eqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qdm1eqn", "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "2"}], "d"], "[", 
         FractionBox["1", "x"], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qd0eqn", "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "1"}], "d"], "[", 
         FractionBox["1", "x"], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qdp1eqn", "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         SubsuperscriptBox["Q", "2", "d"], "[", 
         FractionBox["1", "x"], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q01eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "2"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSlhsy0v2", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", "__", "]"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "2"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "}"}], ",", "Factor"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.760843242902163*^9, 3.760843660140705*^9}, {
  3.760994024605438*^9, 3.760994036057096*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"6995ba39-8285-470d-823b-4aab814781b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"c", " ", "t", " ", 
     SuperscriptBox["x", "3"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], " ", "b", " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"a", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"b", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "3"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", "x"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"a", " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"b", " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"a", " ", "b", " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "x"}], "]"}]}], 
   RowBox[{"b", " ", "t", " ", 
    SuperscriptBox["x", "3"]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], 
   RowBox[{"a", " ", "t", " ", 
    SuperscriptBox["x", "3"]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"t", " ", "x"}], "+", 
      RowBox[{"a", " ", "t", " ", "x"}], "-", 
      RowBox[{"b", " ", "t", " ", "x"}], "-", 
      RowBox[{"a", " ", "b", " ", "t", " ", "x"}], "-", 
      SuperscriptBox["x", "2"], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], 
   RowBox[{"t", " ", 
    SuperscriptBox["x", "4"]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", 
      RowBox[{"b", " ", "t"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
      RowBox[{"2", " ", "x"}], "-", 
      RowBox[{"a", " ", "x"}], "-", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], 
   SuperscriptBox["x", "3"]]}]], "Output",
 CellChangeTimes->{
  3.760843267551189*^9, {3.7608433034909563`*^9, 3.760843318510272*^9}, {
   3.760843358996285*^9, 3.7608434749070663`*^9}, {3.760843528138998*^9, 
   3.7608436621148567`*^9}, 3.760907559908621*^9, 3.760993376683579*^9, 
   3.7609940404907084`*^9, 3.7612503367420053`*^9, 3.7613339804369087`*^9, 
   3.761360613660749*^9, 3.761420782904355*^9, 3.761443416824654*^9, 
   3.76151428629053*^9, {3.7675808005843034`*^9, 3.767580814549303*^9}, 
   3.7676440116254263`*^9, 3.78915815648288*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"bec3a94b-37c0-42e0-9086-75f5103a508e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it", " ", "manually"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSlhs", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
       RowBox[{"QQeval", "[", 
        RowBox[{"12", ",", "ecks", ",", "why"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"#", ",", "y", ",", "0"}], "]"}], "&"}], ",", "%"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0v2", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "1", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.760843684306559*^9, 3.760843724041244*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"15532b2c-09eb-430e-8428-9d31c95b6970"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760843729912813*^9, 3.7609075622360163`*^9, 3.760993378404389*^9, 
   3.761250338479266*^9, 3.761333982355111*^9, 3.761360615586749*^9, 
   3.761420784660486*^9, 3.7614434185071917`*^9, 3.761514287953158*^9, {
   3.7675808023023033`*^9, 3.7675808162463036`*^9}, 3.767644016292899*^9, 
   3.789158158280279*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"a79f809a-4659-415d-ae3e-fb3087a2d446"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "for", " ", "the", " ", "RHS", " ", "of", " ", "the", " ", 
    "full", " ", "orbit", " ", "sum"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "do", " ", "a", " ", "partial", " ", "fraction", 
    " ", "expansion", " ", "of", " ", 
    RowBox[{"1", "/", "K"}], " ", "as", " ", "per", " ", "Lemma", " ", "6"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"t", "/", "x"}]}], ")"}], "^", "2"}], "-", 
      RowBox[{"4", 
       RowBox[{"t", "^", "2"}], "x"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "0"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", "/", "x"}], "-", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "t", " ", "x"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "1"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", "/", "x"}], "+", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "t", " ", "x"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"K", "[", 
       RowBox[{"x", ",", 
        SubscriptBox["Y", "0"]}], "]"}], ",", 
      RowBox[{"K", "[", 
       RowBox[{"x", ",", 
        SubscriptBox["Y", "1"]}], "]"}]}], "}"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{"Expand", "@*", "PowerExpand"}], ",", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["Y", "0"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{"Expand", "@*", "PowerExpand"}], ",", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["Y", "1"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7609947070113297`*^9, 3.760994715558049*^9}, {
  3.7609951974712276`*^9, 3.760995227047181*^9}, {3.760995347436524*^9, 
  3.7609955229728813`*^9}, {3.760995622862715*^9, 3.760995624955127*^9}, {
  3.789158044056233*^9, 3.78915804444903*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"82413766-2a09-41e3-8f73-131c5707933c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.760995484741539*^9, 3.760995504558052*^9}, 
   3.760995625282198*^9, 3.7612503386690474`*^9, 3.761333982578844*^9, 
   3.76136061640234*^9, 3.761420784817795*^9, 3.761443418654429*^9, 
   3.7615142881521893`*^9, {3.7675808024163036`*^9, 3.767580816318303*^9}, 
   3.767644021356776*^9, 3.789158158442631*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"20783cff-cef8-4f93-aa35-a6cd0121f251"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"t", "+", 
   FractionBox[
    SuperscriptBox["t", "2"], "x"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "2"]], "+", "x"}], ")"}], " ", 
    SuperscriptBox["t", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "4"],
    SeriesData[$CellContext`t, 0, {}, 1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   1, $CellContext`x^(-1), $CellContext`x^(-2) + $CellContext`x}, 1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760995484741539*^9, 3.760995504558052*^9}, 
   3.760995625282198*^9, 3.7612503386690474`*^9, 3.761333982578844*^9, 
   3.76136061640234*^9, 3.761420784817795*^9, 3.761443418654429*^9, 
   3.7615142881521893`*^9, {3.7675808024163036`*^9, 3.767580816318303*^9}, 
   3.767644021356776*^9, 3.789158158453207*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"36a1e93a-0cb5-406c-a21a-ff2ce2c3edb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"x", " ", "t"}]], "-", 
   FractionBox["1", 
    SuperscriptBox["x", "2"]], "-", "t", "-", 
   FractionBox[
    SuperscriptBox["t", "2"], "x"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        SuperscriptBox["x", "2"]]}], "-", "x"}], ")"}], " ", 
    SuperscriptBox["t", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "4"],
    SeriesData[$CellContext`t, 0, {}, -1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {$CellContext`x^(-1), (-1) $CellContext`x^(-2), -1, \
(-1)/$CellContext`x, (-1) $CellContext`x^(-2) - $CellContext`x}, -1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760995484741539*^9, 3.760995504558052*^9}, 
   3.760995625282198*^9, 3.7612503386690474`*^9, 3.761333982578844*^9, 
   3.76136061640234*^9, 3.761420784817795*^9, 3.761443418654429*^9, 
   3.7615142881521893`*^9, {3.7675808024163036`*^9, 3.767580816318303*^9}, 
   3.767644021356776*^9, 3.78915815845595*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"4fda3879-ae30-46eb-876e-43df7f9cf69f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "then", " ", "analogously", " ", "to", " ", "eqn", " ", 
    RowBox[{"(", "4.21", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"K", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["Y", "0"], "/", "y"}]}], ")"}]}], "+", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"y", "/", 
           SubscriptBox["Y", "1"]}]}], ")"}]}], "-", "1"}], ")"}]}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.766381033299*^9, 3.766381034179*^9}, {
  3.7891581071594963`*^9, 3.789158110489048*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"6d73a7bd-ab8b-4830-89fe-5bfca1d9dde2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7609956566786833`*^9, 3.761250338844696*^9, 3.761333982861902*^9, 
   3.761360616572454*^9, 3.761420784944048*^9, 3.7614434188005*^9, 
   3.761514288351788*^9, {3.7675808024973035`*^9, 3.7675808163423033`*^9}, 
   3.76764402149855*^9, 3.7891581585286694`*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"21a66745-0e58-45ba-af6e-a27b174b4220"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "keeping", " ", "these", " ", "unevaluated", " ", "will", " ", "make", " ",
     "calculations", " ", "a", " ", "bit", " ", "easier"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["YY", "0"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", "/", "x"}], "-", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{"2", "t", " ", "x"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["YY", "1"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", "/", "x"}], "+", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{"2", "t", " ", "x"}], ")"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7610009401251183`*^9, 3.761000978761723*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"79b8c0a5-75c4-40e7-9758-94c6f61fa6ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"so", " ", "we", " ", "can", " ", "compute", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{"y", "^", "0"}], "]"}], " ", "of", " ", "the", " ", "RHS", " ", 
    "of", " ", "the", " ", "full", " ", "orbit", " ", "sum"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", "fullOSrhs", "]"}], ",", "y", ",", 
         RowBox[{"-", "1"}]}], "]"}], "/", 
       SubscriptBox["YY", "1"]}], "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", "fullOSrhs", "]"}], ",", "y", ",", "0"}], 
       "]"}], "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", "fullOSrhs", "]"}], ",", "y", ",", "1"}], 
       "]"}], "*", 
      RowBox[{
       SubscriptBox["YY", "0"], "/", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "+", 
     
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", "fullOSrhs", "]"}], ",", "y", ",", "2"}], 
       "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["YY", "0"], "^", "2"}], "/", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "+", 
     
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", "fullOSrhs", "]"}], ",", "y", ",", "3"}], 
       "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["YY", "0"], "^", "3"}], "/", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSrhsy0", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Q", "[", "__", "]"}], ",", "Simplify"}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.76099572081081*^9, 3.760995733271468*^9}, {
  3.760996046724725*^9, 3.760996052967643*^9}, {3.760996090397217*^9, 
  3.7609961054611073`*^9}, {3.760996148776186*^9, 3.7609961725918283`*^9}, {
  3.760996204306085*^9, 3.760996206116447*^9}, {3.7609963524732113`*^9, 
  3.760996359467675*^9}, {3.760996404884697*^9, 3.760996469890243*^9}, {
  3.760996508163548*^9, 3.760996607241034*^9}, {3.761000985143017*^9, 
  3.76100101920639*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"360ec4e7-5e94-45d3-a21a-b6330b0aa0e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"8", " ", "c", " ", 
      SuperscriptBox["x", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "t"}], "+", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
      SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["t", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["x", "3"]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["x", "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"6", "+", 
          RowBox[{
           SuperscriptBox["x", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
       RowBox[{"2", " ", "t", " ", 
        SuperscriptBox["x", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{
           SuperscriptBox["x", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["t", "3"], " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["x", "6"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["x", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"5", " ", 
              SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}]}], 
      ")"}]}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "c", " ", 
     SuperscriptBox["x", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "t"}], "+", "x", "+", 
       RowBox[{"x", " ", 
        SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
     SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", 
         RowBox[{"b", " ", "c"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["t", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["x", "3"]}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["x", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
      RowBox[{"2", " ", "t", " ", 
       SuperscriptBox["x", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["t", "3"], " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["x", "6"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"5", " ", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}]}], ")"}], 
    " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.760996093221006*^9, 3.760996105742687*^9}, {
   3.760996446359868*^9, 3.760996471381679*^9}, {3.760996509930677*^9, 
   3.76099657270613*^9}, 3.760996609308234*^9, 3.761001025328704*^9, 
   3.761250339237769*^9, 3.761333983309227*^9, 3.761360617054553*^9, 
   3.761420785352565*^9, 3.761443419177514*^9, 3.7615142888074093`*^9, {
   3.7675808028393035`*^9, 3.7675808163783035`*^9}, 3.767644025348075*^9, 
   3.789158158931683*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"a5b7d35d-b17b-4921-8f01-3157950f1250"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"we", " ", "can", " ", "check", " ", "it"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fullOSrhs", "/", 
      RowBox[{"K", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"#", "+", 
          RowBox[{"y", "^", "\[Pi]"}], "+", 
          RowBox[{"y", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "y"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}],
        "&"}], ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fullOSrhsy0", "/.", 
      RowBox[{
      "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.760996631473873*^9, 3.7609967045102673`*^9}, {
  3.761001052744144*^9, 3.761001059133308*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"7e3a8d04-560c-459e-b0b4-b21ca42b67df"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "16"],
  SeriesData[$CellContext`t, 0, {}, 16, 16, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760996684380018*^9, 3.760996705997727*^9}, 
   3.761001065646953*^9, 3.7612503434268827`*^9, 3.761333988232224*^9, 
   3.761360621678505*^9, 3.761420789920485*^9, 3.761443423399843*^9, 
   3.761514293278215*^9, {3.7675808043433037`*^9, 3.7675808177473035`*^9}, 
   3.7676440316325083`*^9, 3.7891581608197927`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"caf59ac3-890b-4d1d-a346-7ec8d792eb4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "check", " ", "it", " ", "some", " ", "more"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSlhsy0v2", "-", "fullOSrhsy0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
       RowBox[{"QQeval", "[", 
        RowBox[{"12", ",", "ecks", ",", "why"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759803643441286*^9, 3.7598037077875977`*^9}, {
  3.760996785432983*^9, 3.7609968505599203`*^9}, {3.761001074884556*^9, 
  3.761001079834175*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"3b694bb2-9daa-409b-ac7a-10295711eee8"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7609968226750917`*^9, 3.760996852038948*^9}, 
   3.761001083294614*^9, 3.7612503451519814`*^9, 3.7613339900227013`*^9, 
   3.761360623549315*^9, 3.761420791711289*^9, 3.7614434255860662`*^9, 
   3.7615142950349503`*^9, {3.7675808050513034`*^9, 3.7675808180923033`*^9}, 
   3.767644032527051*^9, 3.789158161859728*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"f63d2138-bdd6-4657-9a76-7589aebfaf34"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", "to", " ", "compute", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], ">"}], "]"}], " ", "part", " ", "of", " ", "this"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"unlike", " ", "reverse", " ", "Kreweras"}], ",", " ", 
    RowBox[{"we", " ", "will", " ", "not", " ", "need", " ", 
     RowBox[{"the", " ", "[", 
      RowBox[{
       RowBox[{"x", "^"}], "<"}], "]"}], " ", "part"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"however", ",", " ", 
    RowBox[{
    "we", " ", "unfortunately", " ", "end", " ", "up", " ", "leaving", " ", 
     "the", " ", "realm", " ", "of", " ", "algebraic", " ", "functions", " ", 
     "here"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.761001740709128*^9, 3.761001751663117*^9}, {
  3.7610052977086287`*^9, 3.761005348501301*^9}, {3.76100706308281*^9, 
  3.761007069359874*^9}, {3.761008617636916*^9, 3.761008617713846*^9}, {
  3.761008818699544*^9, 3.761008818788453*^9}, {3.76101166983366*^9, 
  3.761011669979192*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"86059985-c31c-44e3-9c06-10c96c4b9b34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"LHS", " ", "is", " ", "straightforward"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"eqn", " ", 
    RowBox[{"(", "5.11", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"fullOSlhsy0v2", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Q", "[", "__", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["Q", "0", "d"], "[", 
           FractionBox["1", "x"], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["Q", "1", "d"], "[", 
           FractionBox["1", "x"], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{"Select", "[", 
     RowBox[{"%", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Exponent", "[", 
         RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOSlhsy0v2", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOSlhsy0v2", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "1"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "2"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]]}], "-", 
        RowBox[{
         RowBox[{"x", "^", "2"}], 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "2"}]]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "3"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]]}], "-", 
        RowBox[{
         RowBox[{"x", "^", "2"}], 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "2"}]]}], "-", 
        RowBox[{
         RowBox[{"x", "^", "3"}], 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "3"}]]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOSlhsy0v2", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "1"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "2"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]]}], "-", 
        RowBox[{
         RowBox[{"x", "^", "2"}], 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "3"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]]}], "-", 
        RowBox[{
         RowBox[{"x", "^", "2"}], 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         RowBox[{"x", "^", "3"}], 
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOSlhsy0v2", ",", 
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
     "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOSlhsy0v2", ",", 
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xpos", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
     "*", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]]}]}]}]}]], "Input",
 CellChangeTimes->{{3.761006379781167*^9, 3.761006400660947*^9}, {
  3.761006437573637*^9, 3.761006631977804*^9}, {3.761006754287574*^9, 
  3.7610068090000887`*^9}, {3.761007135106971*^9, 3.76100720076197*^9}, {
  3.761007234086903*^9, 3.761007619058669*^9}, {3.7610086256938753`*^9, 
  3.761008708121086*^9}, {3.761008796110258*^9, 3.7610088428590393`*^9}, {
  3.76101167396646*^9, 3.761011769600196*^9}, {3.7618873240330343`*^9, 
  3.7618873395570345`*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"3112156c-a446-4489-848f-340372e52ba1"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"a", " ", "b"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b"}], "+", 
     SuperscriptBox["b", "2"], "-", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["b", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}]}], ")"}], " ", "t", " ", "x"}], 
  "c"]], "Output",
 CellChangeTimes->{{3.761008829360642*^9, 3.761008843341033*^9}, 
   3.7610117737178802`*^9, 3.761012114792768*^9, 3.761250345362733*^9, 
   3.761333990157716*^9, 3.761360623848974*^9, 3.761420791856378*^9, 
   3.76144342578666*^9, 3.761514295288887*^9, {3.7675808051033034`*^9, 
   3.7675808181263037`*^9}, 3.767644040266911*^9, 3.7891581620685472`*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"c1121e73-2e6a-444b-a1f3-da2bfc66e33c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b"}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "3"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "c"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c"}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", "c"}], "-", 
     RowBox[{"4", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "c"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", "t", " ", "x", " ", 
   
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], 
  RowBox[{"a", " ", "b", " ", "c"}]]], "Output",
 CellChangeTimes->{{3.761008829360642*^9, 3.761008843341033*^9}, 
   3.7610117737178802`*^9, 3.761012114792768*^9, 3.761250345362733*^9, 
   3.761333990157716*^9, 3.761360623848974*^9, 3.761420791856378*^9, 
   3.76144342578666*^9, 3.761514295288887*^9, {3.7675808051033034`*^9, 
   3.7675808181263037`*^9}, 3.767644040266911*^9, 3.789158162071354*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"47c50b9a-644a-400b-beb3-5f9a021c6765"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "b"}], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "-", 
         SuperscriptBox["b", "3"], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "3"]}]}], ")"}], " ", "x"}], "b"], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a", "+", 
      RowBox[{"2", " ", "b"}], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], ")"}]}], 
   RowBox[{"b", " ", "t"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      SuperscriptBox["a", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], " ", "x"}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], ")"}]}], 
   RowBox[{"b", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "a"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], " ", "x"}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "2"}]], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], ")"}]}], 
   SuperscriptBox["x", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], " ", "x"}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "2"}]], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "3"}]], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], ")"}]}], 
   SuperscriptBox["x", "3"]]}]], "Output",
 CellChangeTimes->{{3.761008829360642*^9, 3.761008843341033*^9}, 
   3.7610117737178802`*^9, 3.761012114792768*^9, 3.761250345362733*^9, 
   3.761333990157716*^9, 3.761360623848974*^9, 3.761420791856378*^9, 
   3.76144342578666*^9, 3.761514295288887*^9, {3.7675808051033034`*^9, 
   3.7675808181263037`*^9}, 3.767644040266911*^9, 3.789158162075201*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"c397fac3-967b-4312-affb-95dac75b12f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["a", "3"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b"}], "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", "b"}], "+", 
          SuperscriptBox["b", "2"], "-", 
          RowBox[{"2", " ", "a", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "3"]}]}], ")"}], " ", "x"}], "a"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "a"}], "-", 
      SuperscriptBox["a", "2"], "+", "b", "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}], 
   RowBox[{"a", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["a", "3"], "-", "b", "+", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], " ", "x"}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}], 
   RowBox[{"a", " ", "x"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "b"}], ")"}], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], " ", "x"}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}], 
   SuperscriptBox["x", "2"]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], " ", "x"}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}], 
   SuperscriptBox["x", "3"]]}]], "Output",
 CellChangeTimes->{{3.761008829360642*^9, 3.761008843341033*^9}, 
   3.7610117737178802`*^9, 3.761012114792768*^9, 3.761250345362733*^9, 
   3.761333990157716*^9, 3.761360623848974*^9, 3.761420791856378*^9, 
   3.76144342578666*^9, 3.761514295288887*^9, {3.7675808051033034`*^9, 
   3.7675808181263037`*^9}, 3.767644040266911*^9, 3.789158162079965*^9},
 CellLabel->
  "Out[140]=",ExpressionUUID->"1576c0a7-56bf-4fc8-ae5c-c407d0273db4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "a"}], "+", 
    RowBox[{"2", " ", "b"}], "+", 
    RowBox[{"a", " ", "b"}]}], ")"}], " ", "t", " ", "x", " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.761008829360642*^9, 3.761008843341033*^9}, 
   3.7610117737178802`*^9, 3.761012114792768*^9, 3.761250345362733*^9, 
   3.761333990157716*^9, 3.761360623848974*^9, 3.761420791856378*^9, 
   3.76144342578666*^9, 3.761514295288887*^9, {3.7675808051033034`*^9, 
   3.7675808181263037`*^9}, 3.767644040266911*^9, 3.789158162083551*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"89323ce4-3da5-4d6b-b109-a3ae3c7fa752"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
  SubscriptBox["Q", 
   RowBox[{"0", ",", "1"}]], " ", 
  SuperscriptBox["t", "2"], " ", "x"}]], "Output",
 CellChangeTimes->{{3.761008829360642*^9, 3.761008843341033*^9}, 
   3.7610117737178802`*^9, 3.761012114792768*^9, 3.761250345362733*^9, 
   3.761333990157716*^9, 3.761360623848974*^9, 3.761420791856378*^9, 
   3.76144342578666*^9, 3.761514295288887*^9, {3.7675808051033034`*^9, 
   3.7675808181263037`*^9}, 3.767644040266911*^9, 3.789158162085836*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"0a104ed8-c6c4-4241-8c55-e03dff9aaeec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSlhsy0v2", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "1", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", "fullOSlhsy0xpos", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "3"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "3"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "2"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "2"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "3", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.761007670848504*^9, 3.7610080181586237`*^9}, {
  3.7610080892057657`*^9, 3.761008174314802*^9}, {3.7610082735303993`*^9, 
  3.7610083018479548`*^9}, {3.761011821160819*^9, 3.761011842996057*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"01a31721-6cdb-4f0e-b646-6ac32e0e9040"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7610077143908157`*^9, 3.761007778936481*^9, {3.761007810059003*^9, 
   3.7610078324784327`*^9}, {3.7610078888141537`*^9, 3.761008019838619*^9}, {
   3.761008095247286*^9, 3.761008166110257*^9}, {3.761008279392424*^9, 
   3.761008304722371*^9}, 3.7610088494347277`*^9, {3.7610118378632383`*^9, 
   3.761011843796433*^9}, 3.761012119308605*^9, 3.761250345649159*^9, 
   3.761333990460243*^9, 3.7613606241834*^9, 3.761420792154439*^9, 
   3.761443426093439*^9, 3.761514295671657*^9, {3.767580805382303*^9, 
   3.7675808183653035`*^9}, 3.767644043866229*^9, 3.789158162350609*^9},
 CellLabel->
  "Out[149]=",ExpressionUUID->"567ec1db-89e3-4e75-8c31-93a8d9e9fe6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"can", " ", "do", " ", "some", " ", "eliminations"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", "fullOSlhsy0xpos", "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q02eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "3"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q01eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "2"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q11eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "2"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q20eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSlhsy0xposv2", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", "__", "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]]}], "}"}], ",", "Factor"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", "fullOSlhsy0xpos", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "3"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "3"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "2"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "2"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "3", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSlhsy0xposv2", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "3", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.761009841912489*^9, 3.761009981369919*^9}, {
  3.761010013853603*^9, 3.7610100151440067`*^9}, {3.76101005621841*^9, 
  3.761010124810892*^9}, {3.761010181827834*^9, 3.76101043591118*^9}, {
  3.7610119533069277`*^9, 3.76101199751721*^9}, {3.7610121750804033`*^9, 
  3.761012185443202*^9}},
 CellLabel->
  "In[150]:=",ExpressionUUID->"de034dc0-d40b-4ee5-8353-a5a26c9a5dcd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]], " ", "t"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
   SubscriptBox["Q", 
    RowBox[{"3", ",", "0"}]], " ", 
   SuperscriptBox["t", "2"]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"a", " ", "t", " ", "x"}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "t", " ", "x"}], "-", 
     RowBox[{"b", " ", "t", " ", "x"}], "-", 
     RowBox[{"a", " ", "b", " ", "t", " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "-", 
     SuperscriptBox["x", "2"], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "b", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"a", " ", 
     SuperscriptBox["x", "2"]}]], 
   RowBox[{
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", "x"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", "x"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}]}], ")"}]}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", "x"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c", " ", "t", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", "x"}], 
      "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", "t", " ", "x"}], 
      "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", "x"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", "x"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", "x"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", "x"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a", " ", "c", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"b", " ", "c", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "x"}], "]"}]}], 
   RowBox[{"b", " ", "t", " ", 
    SuperscriptBox["x", "3"]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], 
   RowBox[{"a", " ", "t", " ", 
    SuperscriptBox["x", "3"]}]]}]], "Output",
 CellChangeTimes->{{3.761009900416655*^9, 3.761009981960218*^9}, 
   3.7610100156164837`*^9, {3.7610100672087927`*^9, 3.761010127982718*^9}, {
   3.761010195500614*^9, 3.761010282575387*^9}, 3.761010333633009*^9, 
   3.761010436853717*^9, 3.7610120136086206`*^9, 3.761012122358429*^9, 
   3.7610121868301277`*^9, 3.761250345794586*^9, 3.761333990620474*^9, 
   3.761360624357916*^9, 3.7614207922815647`*^9, 3.7614434262411957`*^9, 
   3.761514295904755*^9, {3.7675808054823036`*^9, 3.767580818436303*^9}, 
   3.767644048596846*^9, 3.789158162435368*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"14fffdc5-8024-4da9-a794-1cfa594675ee"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761009900416655*^9, 3.761009981960218*^9}, 
   3.7610100156164837`*^9, {3.7610100672087927`*^9, 3.761010127982718*^9}, {
   3.761010195500614*^9, 3.761010282575387*^9}, 3.761010333633009*^9, 
   3.761010436853717*^9, 3.7610120136086206`*^9, 3.761012122358429*^9, 
   3.7610121868301277`*^9, 3.761250345794586*^9, 3.761333990620474*^9, 
   3.761360624357916*^9, 3.7614207922815647`*^9, 3.7614434262411957`*^9, 
   3.761514295904755*^9, {3.7675808054823036`*^9, 3.767580818436303*^9}, 
   3.767644048596846*^9, 3.789158162621743*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"60b60e5a-5183-457e-8af2-1144f98d86a0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], ">"}], "]"}], " ", "part", " ", "of", " ", "the", 
    " ", "RHS", " ", "is", " ", "probably", " ", "not", " ", "algebraic"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "but", " ", "it", " ", "will", " ", "be", " ", "useful", " ", "to", " ", 
    "name", " ", "the", " ", "coefficients"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[Eta]", "=", 
    RowBox[{"fullOSrhsy0", "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", "0"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Eta]", 
     RowBox[{"0", ",", "0"}]], "=", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"fullOSrhsy0", ",", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"and", " ", "then"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"this", " ", "is", " ", "eqn", " ", 
     RowBox[{"(", "5.12", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSrhsy0xpos", "=", 
    RowBox[{"\[Theta]", "+", 
     RowBox[{
      SubscriptBox["\[Theta]", 
       RowBox[{"0", ",", "0"}]], 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.7610142802145853`*^9, 3.761014296229203*^9}, {
  3.761252149983861*^9, 3.761252170377973*^9}, {3.761252641472727*^9, 
  3.761252647176413*^9}, {3.7612526935501957`*^9, 3.761252705913467*^9}, {
  3.761253208003797*^9, 3.76125321527945*^9}, {3.761265219345112*^9, 
  3.761265264434412*^9}, {3.789158138660873*^9, 3.7891581387048693`*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"e75d24bb-f92a-49d6-9db5-50160afc0bea"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "c", " ", 
     SuperscriptBox["x", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "t"}], "+", "x", "+", 
       RowBox[{"x", " ", 
        SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
     SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["t", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["x", "3"]}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["x", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
      RowBox[{"2", " ", "t", " ", 
       SuperscriptBox["x", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["t", "3"], " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["x", "6"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"5", " ", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7612526448514423`*^9, 3.761252647494193*^9}, 
   3.761252706345688*^9, 3.76125321590901*^9, 3.7612652674147177`*^9, 
   3.761333990972987*^9, 3.7613606255411367`*^9, 3.761420792471827*^9, 
   3.761443426430751*^9, 3.761514296123252*^9, {3.7675808056453037`*^9, 
   3.7675808185603037`*^9}, 3.767644053827511*^9, 3.7891581626305523`*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"b6f1376e-f670-49f2-a34b-1141800ad619"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", "c", " ", 
    SuperscriptBox["x", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "+", "x", "+", 
      RowBox[{"x", " ", 
       SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
    SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "b"}], " ", "c"}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"b", "-", "c", "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["t", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"6", "+", 
        RowBox[{
         SuperscriptBox["x", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
        SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["x", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{
         SuperscriptBox["x", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["t", "3"], " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["x", "6"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["x", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"5", " ", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7612526448514423`*^9, 3.761252647494193*^9}, 
   3.761252706345688*^9, 3.76125321590901*^9, 3.7612652674147177`*^9, 
   3.761333990972987*^9, 3.7613606255411367`*^9, 3.761420792471827*^9, 
   3.761443426430751*^9, 3.761514296123252*^9, {3.7675808056453037`*^9, 
   3.7675808185603037`*^9}, 3.767644053827511*^9, 3.7891581627174*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"c22730c7-d61a-45c7-a117-e1dc80c47760"],

Cell[BoxData[
 RowBox[{"\[Theta]", "+", 
  RowBox[{
   SubscriptBox["\[Theta]", 
    RowBox[{"0", ",", "0"}]], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7612526448514423`*^9, 3.761252647494193*^9}, 
   3.761252706345688*^9, 3.76125321590901*^9, 3.7612652674147177`*^9, 
   3.761333990972987*^9, 3.7613606255411367`*^9, 3.761420792471827*^9, 
   3.761443426430751*^9, 3.761514296123252*^9, {3.7675808056453037`*^9, 
   3.7675808185603037`*^9}, 3.767644053827511*^9, 3.789158162866921*^9},
 CellLabel->
  "Out[164]=",ExpressionUUID->"ed97f5c6-a5b3-4d76-8c7f-65c1891403d6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "we", " ", "can", " ", "evaluate", " ", "them", " ", 
    "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"\[Theta]s", ",", 
     SubscriptBox["\[Theta]s", 
      RowBox[{"0", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Theta]s", "[", "N_", "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Theta]s", "[", "N", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "#", "]"}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Exponent", "[", 
             RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], 
        "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"\[Eta]", "/.", 
          RowBox[{
          "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "N"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Theta]s", 
      RowBox[{"0", ",", "0"}]], "[", "N_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Theta]s", 
       RowBox[{"0", ",", "0"}]], "[", "N", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "#", "]"}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Exponent", "[", 
             RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], 
        "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Eta]", 
           RowBox[{"0", ",", "0"}]], "/.", 
          RowBox[{
          "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "N"}], "}"}]}], "]"}]}], 
      "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.761252716065627*^9, 3.761252750948019*^9}, {
  3.7612527956357803`*^9, 3.761252806718614*^9}, {3.761252871328673*^9, 
  3.761253064729494*^9}, {3.761265288344595*^9, 3.761265297048875*^9}},
 CellLabel->
  "In[165]:=",ExpressionUUID->"31d15361-532b-49ff-8779-77053c27f584"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ApplyToSeries", "[", 
  RowBox[{"Factor", ",", 
   RowBox[{"\[Theta]s", "[", "9", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ApplyToSeries", "[", 
  RowBox[{"Factor", ",", 
   RowBox[{
    SubscriptBox["\[Theta]s", 
     RowBox[{"0", ",", "0"}]], "[", "9", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.761253069223461*^9, 3.761253175723481*^9}},
 CellLabel->
  "In[168]:=",ExpressionUUID->"5b5cd206-7917-4fb0-b1d0-3db0ef5a0805"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["t", "3"]}], "c"], "+", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["t", "5"]}], "c"], "+", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["t", "6"]}], "c"], "+", 
   FractionBox[
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["t", "7"]}], "c"], "+", 
   FractionBox[
    RowBox[{"5", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["t", "8"]}], "c"], "+", 
   FractionBox[
    RowBox[{"5", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["x", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x", "+", 
       SuperscriptBox["x", "2"]}], ")"}], " ", 
     SuperscriptBox["t", "9"]}], "c"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 3, 10, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {$CellContext`a ($CellContext`a - $CellContext`b) $CellContext`b \
$CellContext`c^(-1) $CellContext`x^2, 
    0, $CellContext`a ($CellContext`a - $CellContext`b) $CellContext`b \
$CellContext`c^(-1) $CellContext`x^3, $CellContext`a ($CellContext`a - \
$CellContext`b) $CellContext`b $CellContext`c^(-1) $CellContext`x^2, 
    2 $CellContext`a ($CellContext`a - $CellContext`b) $CellContext`b \
$CellContext`c^(-1) $CellContext`x^4, 
    5 $CellContext`a ($CellContext`a - $CellContext`b) $CellContext`b \
$CellContext`c^(-1) $CellContext`x^3, 
    5 $CellContext`a ($CellContext`a - $CellContext`b) $CellContext`b \
$CellContext`c^(-1) $CellContext`x^2 (1 + $CellContext`x) (
     1 - $CellContext`x + $CellContext`x^2)}, 3, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76125307488173*^9, 3.7612531761839037`*^9}, 
   3.7612653000835333`*^9, 3.761333991594146*^9, 3.7613606268297977`*^9, 
   3.761420792869403*^9, 3.7614434269254103`*^9, 3.761514297061165*^9, {
   3.7675808058343034`*^9, 3.7675808186113033`*^9}, 3.767644056491727*^9, 
   3.789158163038439*^9},
 CellLabel->
  "Out[168]=",ExpressionUUID->"a2b9cabc-5f6f-44e0-9aa1-84df4f892a6e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["t", "3"]}], "c"]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "b"}], "-", 
       RowBox[{"a", " ", "c"}], "-", 
       RowBox[{"b", " ", "c"}], "+", 
       RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
     SuperscriptBox["x", "3"], " ", 
     SuperscriptBox["t", "5"]}], "c"], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "b"}], "-", 
       RowBox[{"a", " ", "c"}], "-", 
       RowBox[{"b", " ", "c"}], "+", 
       RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["t", "6"]}], "c"], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
       SuperscriptBox["x", "4"]}], ")"}], " ", 
     SuperscriptBox["t", "7"]}], "c"], "-", 
   FractionBox[
    RowBox[{"5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
       SuperscriptBox["x", "3"]}], ")"}], " ", 
     SuperscriptBox["t", "8"]}], "c"], "-", 
   FractionBox[
    RowBox[{"5", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x", "+", 
         SuperscriptBox["x", "2"]}], ")"}]}], ")"}], " ", 
     SuperscriptBox["t", "9"]}], "c"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 3, 10, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {-($CellContext`a - $CellContext`b) $CellContext`c^(-1) ($CellContext`a \
$CellContext`b - $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c) \
$CellContext`x^2, 
    0, -($CellContext`a - $CellContext`b) $CellContext`c^(-1) ($CellContext`a \
$CellContext`b - $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c) \
$CellContext`x^3, -($CellContext`a - $CellContext`b) $CellContext`c^(-1) \
($CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b $CellContext`c) \
$CellContext`x^2, (-2) ($CellContext`a - $CellContext`b) $CellContext`c^(-1) \
($CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b $CellContext`c) \
$CellContext`x^4, (-5) ($CellContext`a - $CellContext`b) $CellContext`c^(-1) \
($CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b $CellContext`c) \
$CellContext`x^3, (-5) ($CellContext`a - $CellContext`b) $CellContext`c^(-1) \
($CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b $CellContext`c) \
$CellContext`x^2 (1 + $CellContext`x) (
     1 - $CellContext`x + $CellContext`x^2)}, 3, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76125307488173*^9, 3.7612531761839037`*^9}, 
   3.7612653000835333`*^9, 3.761333991594146*^9, 3.7613606268297977`*^9, 
   3.761420792869403*^9, 3.7614434269254103`*^9, 3.761514297061165*^9, {
   3.7675808058343034`*^9, 3.7675808186113033`*^9}, 3.767644056491727*^9, 
   3.78915816304182*^9},
 CellLabel->
  "Out[169]=",ExpressionUUID->"900a7882-bb9e-477c-9a41-4658276e4c31"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 5.3",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.760824004669656*^9, 
  3.760824006907593*^9}, {3.760832918548829*^9, 3.7608329243865356`*^9}, {
  3.761002048797266*^9, 
  3.761002048852255*^9}},ExpressionUUID->"8047f6f5-eb93-4c51-97e3-\
fb87da749da7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "vector", " ", 
    SubscriptBox["V", "2"], " ", "from", " ", "eqn", " ", 
    RowBox[{"(", "5.14", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], ",", " ", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "0"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "the", " ", "coefficient", " ", "matrix", " ", 
     SubscriptBox["M", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["M", "2"], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE0", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE1", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE2", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE3", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE4", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE5", ",", 
        SubscriptBox["V", "2"]}], "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759793271658119*^9, 3.759793383382826*^9}, {
  3.766381300547*^9, 3.766381303803*^9}, {3.7663813597799997`*^9, 
  3.766381360307*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"83a6d2d1-ab5e-46a9-90ea-dbaef77958f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "x"]}], "b"], ",", "0", ",", "0", ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "y"]}], "a"], ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "y"]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "x"]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], "x"]}], "a"], ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], "x"]}], "b"], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.759793368567596*^9, 3.759793383866971*^9}, 
   3.7597985010291*^9, 3.760316703665843*^9, 3.7603239904750147`*^9, 
   3.760387765130632*^9, 3.7606516156413307`*^9, 3.76066098140086*^9, 
   3.760736259595249*^9, 3.7608187478154078`*^9, 3.760820563918811*^9, 
   3.760995575900413*^9, 3.761002309877667*^9, 3.761250346106785*^9, 
   3.761333991927354*^9, 3.761360627108803*^9, 3.761420793021315*^9, 
   3.761443427092444*^9, 3.761514297274893*^9, 3.7675808236403036`*^9, 
   3.767583331488303*^9, 3.767644060861618*^9, 3.789158406931196*^9},
 CellLabel->
  "Out[171]=",ExpressionUUID->"9bcbc31d-46d7-4bf6-af83-f2c2adcd2d9e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "vector", " ", 
     SubscriptBox["C", "2"], " ", "is", " ", "everything", " ", "else"}], ",",
     " ", 
    RowBox[{"see", " ", "eqn", " ", 
     RowBox[{"(", "5.14", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["CC", "2"], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mainFE0", ",", "mainFE1", ",", "mainFE2", ",", "mainFE3", ",", 
      "mainFE4", ",", "mainFE5"}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "0"}], "]"}], "\[Rule]", 
       "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "0"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759793479270163*^9, 3.7597935229640102`*^9}, {
  3.7891581800066433`*^9, 3.7891581810739603`*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"f9fba70c-954b-42ca-8f75-e66b06c0b034"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a", "-", 
        FractionBox[
         RowBox[{"a", " ", "t"}], "y"]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "a"]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b", "-", 
        FractionBox[
         RowBox[{"b", " ", "t"}], "y"]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "b"]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b", "-", 
        RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "b"]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], 
     RowBox[{"a", " ", "b", " ", "c"}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a", "-", 
        RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "a"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7597935242133417`*^9, 3.7597985012092*^9, 
  3.760316703788608*^9, 3.760323990589883*^9, 3.760387765230414*^9, 
  3.760651615742779*^9, 3.760660981520501*^9, 3.760736259719737*^9, 
  3.760818747939431*^9, 3.7608205640586367`*^9, 3.7609955760603456`*^9, 
  3.761002327817758*^9, 3.7612503462463083`*^9, 3.761333992116971*^9, 
  3.761360627935917*^9, 3.7614207931393147`*^9, 3.7614434272419662`*^9, 
  3.761514297475739*^9, 3.7675808237413034`*^9, 3.7675833315123034`*^9, 
  3.76764406100191*^9, 3.789158407108738*^9},
 CellLabel->
  "Out[172]=",ExpressionUUID->"95b4a2b3-81ce-444e-ba06-857df9337ecc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["M", "2"], " ", "has", " ", "rank", " ", "4"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MatrixRank", "[", 
    SubscriptBox["M", "2"], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "so", " ", "we", " ", "have", " ", "two", " ", "choices", " ", "for", " ",
      "the", " ", "nullspace", " ", "vector", " ", 
     SubscriptBox["N", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"NullSpace", "[", 
    RowBox[{
     RowBox[{"(", 
      SubscriptBox["M", "2"], ")"}], "\[Transpose]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"choose", " ", "this", " ", "one"}], ",", " ", 
     RowBox[{"see", " ", "eqn", " ", 
      RowBox[{"(", "5.16", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["NN", "2"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"%", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Last", "[", "#", "]"}], "\[Equal]", "0"}], "&"}]}], "]"}],
        "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
         RowBox[{"b", " ", "x"}]}], ")"}]}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "t"}], "+", "y", "-", 
         RowBox[{"a", " ", "y"}]}], ")"}], "/", "y"}]}], "//", "Factor"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "check", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["NN", "2"], ".", 
     SubscriptBox["M", "2"]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.76100251926151*^9, 3.761002572990782*^9}, {
  3.766381287428*^9, 3.766381290123*^9}, {3.766381376212*^9, 
  3.766381376883*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"03b14200-7e24-48a2-8cf3-f3e2b38bb407"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.761002343479082*^9, {3.761002523701157*^9, 3.761002574779933*^9}, 
   3.7612503464744864`*^9, 3.7613339922881813`*^9, 3.7613606280914583`*^9, 
   3.761420793252646*^9, 3.76144342739065*^9, 3.761514297693055*^9, 
   3.7675808237603035`*^9, 3.767583331535303*^9, 3.767644065231462*^9, 
   3.7891584071205683`*^9},
 CellLabel->
  "Out[173]=",ExpressionUUID->"7f3ca92e-a1dc-47ce-845b-5b47b063134e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
         RowBox[{"b", " ", "x"}]}], ")"}], " ", "y"}], 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b", " ", "t"}], "+", "y", "-", 
         RowBox[{"b", " ", "y"}]}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b", " ", "t"}], "+", "x", "-", 
         RowBox[{"b", " ", "x"}]}], ")"}], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "+", 
         RowBox[{"a", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "t"}], "+", "x", "-", 
         RowBox[{"a", " ", "x"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b", " ", "t"}], "+", "y", "-", 
         RowBox[{"b", " ", "y"}]}], ")"}]}]], ",", "0", ",", "1"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "t"}], "+", "x", "-", 
          RowBox[{"a", " ", "x"}]}], ")"}], " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "b", "+", 
          RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
          RowBox[{"b", " ", "x"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "t"}], "+", "y", "-", 
          RowBox[{"a", " ", "y"}]}], ")"}]}]]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
         RowBox[{"a", " ", "x"}]}], ")"}], " ", "y"}], 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "t"}], "+", "y", "-", 
         RowBox[{"a", " ", "y"}]}], ")"}]}]], ",", "0", ",", "0", ",", "1", 
     ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.761002343479082*^9, {3.761002523701157*^9, 3.761002574779933*^9}, 
   3.7612503464744864`*^9, 3.7613339922881813`*^9, 3.7613606280914583`*^9, 
   3.761420793252646*^9, 3.76144342739065*^9, 3.761514297693055*^9, 
   3.7675808237603035`*^9, 3.767583331535303*^9, 3.767644065231462*^9, 
   3.789158407201498*^9},
 CellLabel->
  "Out[174]=",ExpressionUUID->"4bc425cb-9171-42d2-907f-202936c5cc00"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
        RowBox[{"a", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
        RowBox[{"b", " ", "x"}]}], ")"}]}], "x"]}], ",", "0", ",", "0", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "t"}], "+", "y", "-", 
       RowBox[{"a", " ", "y"}]}], ")"}]}], "y"], ",", "0"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.761002343479082*^9, {3.761002523701157*^9, 3.761002574779933*^9}, 
   3.7612503464744864`*^9, 3.7613339922881813`*^9, 3.7613606280914583`*^9, 
   3.761420793252646*^9, 3.76144342739065*^9, 3.761514297693055*^9, 
   3.7675808237603035`*^9, 3.767583331535303*^9, 3.767644065231462*^9, 
   3.789158407212536*^9},
 CellLabel->
  "Out[175]=",ExpressionUUID->"fb1a96c4-de12-43e9-88f7-6d5a7db6ea8a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.761002343479082*^9, {3.761002523701157*^9, 3.761002574779933*^9}, 
   3.7612503464744864`*^9, 3.7613339922881813`*^9, 3.7613606280914583`*^9, 
   3.761420793252646*^9, 3.76144342739065*^9, 3.761514297693055*^9, 
   3.7675808237603035`*^9, 3.767583331535303*^9, 3.767644065231462*^9, 
   3.789158407215827*^9},
 CellLabel->
  "Out[176]=",ExpressionUUID->"158d5896-cf71-404d-9244-6627c3cc6968"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "this", " ", "time", " ", "we", " ", "divide", " ", "by", " ", "the", " ", 
    "kernel", " ", "and", " ", "take", " ", "the", " ", 
    RowBox[{"y", "^", "0"}], " ", "term"}], ",", " ", 
   RowBox[{"as", " ", "per", " ", "eqn", " ", 
    RowBox[{"(", "5.17", ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7597939110330343`*^9, 3.7597939367558737`*^9}, {
  3.7610044372381353`*^9, 3.761004437541134*^9}, {3.7618875457900343`*^9, 
  3.7618875467970343`*^9}, {3.7663814379709997`*^9, 3.766381439571*^9}, {
  3.7891582028674297`*^9, 3.789158222182646*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"1a609f62-d37d-432b-b0cb-f9fc8e74982c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "LHS", " ", "is", " ", "straightforward"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"halfOSlhs", "=", 
    RowBox[{
     SubscriptBox["NN", "2"], ".", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "x"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"halfOSlhs", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}], "//", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"halfOSlhs", ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"halfOSlhs", ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{"%", "*", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      RowBox[{"1", "/", "x"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.759793938278565*^9, 3.759793953046056*^9}, {
  3.759794011359384*^9, 3.7597940399995203`*^9}, {3.7597984515359697`*^9, 
  3.7597984517470417`*^9}, {3.761004964635795*^9, 3.7610050562437477`*^9}, {
  3.761005250380579*^9, 3.761005260894147*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"52da4a75-0101-48be-a817-064e7b4b901e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x", " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "y", "-", 
      RowBox[{"a", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "x"}], "]"}]}], "y"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "y"}], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761004443031966*^9, {
   3.761004981076014*^9, 3.7610050011940937`*^9}, 3.761005058113701*^9, 
   3.7610052623150387`*^9, 3.761250346791339*^9, 3.761333992664328*^9, 
   3.761360628516778*^9, 3.761420793502863*^9, 3.761443427720171*^9, 
   3.7615142982553*^9, 3.7675808238433037`*^9, 3.7675833315923033`*^9, 
   3.7676440698230886`*^9, 3.789158407306427*^9},
 CellLabel->
  "Out[178]=",ExpressionUUID->"e468175a-dfa3-490c-aafa-1b0f0bf9f3b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", " ", "t"}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"x", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761004443031966*^9, {
   3.761004981076014*^9, 3.7610050011940937`*^9}, 3.761005058113701*^9, 
   3.7610052623150387`*^9, 3.761250346791339*^9, 3.761333992664328*^9, 
   3.761360628516778*^9, 3.761420793502863*^9, 3.761443427720171*^9, 
   3.7615142982553*^9, 3.7675808238433037`*^9, 3.7675833315923033`*^9, 
   3.7676440698230886`*^9, 3.789158407309259*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"cc6732af-1185-478f-9980-69f546006fd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", "x", "-", 
     RowBox[{"b", " ", "x"}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}]}], "y"]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761004443031966*^9, {
   3.761004981076014*^9, 3.7610050011940937`*^9}, 3.761005058113701*^9, 
   3.7610052623150387`*^9, 3.761250346791339*^9, 3.761333992664328*^9, 
   3.761360628516778*^9, 3.761420793502863*^9, 3.761443427720171*^9, 
   3.7615142982553*^9, 3.7675808238433037`*^9, 3.7675833315923033`*^9, 
   3.7676440698230886`*^9, 3.789158407311426*^9},
 CellLabel->
  "Out[182]=",ExpressionUUID->"a2c9d82e-e91a-470f-b0c8-2c5d7799bd11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"b", " ", "t"}], "+", "x", "-", 
    RowBox[{"b", " ", "x"}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "x"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761004443031966*^9, {
   3.761004981076014*^9, 3.7610050011940937`*^9}, 3.761005058113701*^9, 
   3.7610052623150387`*^9, 3.761250346791339*^9, 3.761333992664328*^9, 
   3.761360628516778*^9, 3.761420793502863*^9, 3.761443427720171*^9, 
   3.7615142982553*^9, 3.7675808238433037`*^9, 3.7675833315923033`*^9, 
   3.7676440698230886`*^9, 3.789158407314157*^9},
 CellLabel->
  "Out[183]=",ExpressionUUID->"d16e08a1-b9b0-4764-a40f-4dc48e7f9d28"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"b", " ", "x"}]}], ")"}]}], "x"]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761004443031966*^9, {
   3.761004981076014*^9, 3.7610050011940937`*^9}, 3.761005058113701*^9, 
   3.7610052623150387`*^9, 3.761250346791339*^9, 3.761333992664328*^9, 
   3.761360628516778*^9, 3.761420793502863*^9, 3.761443427720171*^9, 
   3.7615142982553*^9, 3.7675808238433037`*^9, 3.7675833315923033`*^9, 
   3.7676440698230886`*^9, 3.789158407316401*^9},
 CellLabel->
  "Out[184]=",ExpressionUUID->"62bc09f1-71f9-434d-816a-e8c4a8ea679d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
      RowBox[{"b", " ", "x"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761004443031966*^9, {
   3.761004981076014*^9, 3.7610050011940937`*^9}, 3.761005058113701*^9, 
   3.7610052623150387`*^9, 3.761250346791339*^9, 3.761333992664328*^9, 
   3.761360628516778*^9, 3.761420793502863*^9, 3.761443427720171*^9, 
   3.7615142982553*^9, 3.7675808238433037`*^9, 3.7675833315923033`*^9, 
   3.7676440698230886`*^9, 3.789158407318616*^9},
 CellLabel->
  "Out[185]=",ExpressionUUID->"29fe1b58-a9d1-450d-a27b-2ee0d4e75fb8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"halfOSlhs", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
       RowBox[{"QQeval", "[", 
        RowBox[{"12", ",", "ecks", ",", "why"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", "#", "]"}], ",", "y", ",", "0"}], "]"}], 
       "&"}], ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Total", "[", "halfOSlhsy0", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.761005075241293*^9, 3.76100523599986*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"1bf9b6a3-4dfa-4bb1-9df4-3a953ca15a11"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761005080016252*^9, 3.7610051069256763`*^9}, {
   3.761005157129675*^9, 3.7610051666291313`*^9}, {3.761005209045044*^9, 
   3.761005265110969*^9}, 3.761250347161936*^9, 3.7613339931240664`*^9, 
   3.7613606290065517`*^9, 3.761420793899623*^9, 3.761443428101343*^9, 
   3.761514298666519*^9, 3.7675808242613034`*^9, 3.7675833319963036`*^9, 
   3.767644072357812*^9, 3.789158407706243*^9},
 CellLabel->
  "Out[189]=",ExpressionUUID->"c368d05e-3105-47c1-a975-6909a8bbb79f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"as", " ", "for", " ", "the", " ", "RHS"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "this", " ", "will", " ", "be", " ", "divided", " ", "by", " ", "the", " ",
     "kernel"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"halfOSrhs", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["NN", "2"], ".", 
     SubscriptBox["CC", "2"]}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Q", "[", "__", "]"}], ",", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], "]"}], 
     "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.761015425529462*^9, 3.7610154427603807`*^9}},
 CellLabel->
  "In[190]:=",ExpressionUUID->"a4b0325f-854a-4c0d-9f77-3158dca9ea6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "-", 
     SuperscriptBox["x", "2"], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"b", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["x", "2"]}]}], 
    RowBox[{"c", " ", "x"}]]}], "+", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}]}], 
   RowBox[{"c", " ", "y"}]], "+", 
  FractionBox[
   RowBox[{"b", " ", "t", " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", "y"}], "c"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         SuperscriptBox["x", "2"], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{"b", " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{"a", " ", "b", " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}], 
      RowBox[{"a", " ", "b", " ", "c", " ", "x"}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b", " ", "t"}], "+", "x", "-", 
         RowBox[{"b", " ", "x"}]}], ")"}]}], 
      RowBox[{"b", " ", "c", " ", "y"}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", "t", " ", "x", " ", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "t"}], "+", "x", "-", 
         RowBox[{"a", " ", "x"}]}], ")"}], " ", "y"}], 
      RowBox[{"a", " ", "c"}]]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "t"}], "+", "x", "-", 
          RowBox[{"b", " ", "x"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "a", "-", "b", "+", 
          RowBox[{"a", " ", "b"}], "+", 
          RowBox[{"a", " ", "b", " ", 
           SuperscriptBox["t", "2"], " ", "x"}]}], ")"}]}], "b"]}], "+", 
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"b", " ", "t"}], "+", "x", "-", 
         RowBox[{"b", " ", "x"}]}], ")"}]}], 
      RowBox[{"b", " ", "y"}]], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "t", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", " ", "t"}], "+", "x", "-", 
        RowBox[{"b", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", "t"}], "+", "x", "-", 
          RowBox[{"a", " ", "x"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "a", "-", "b", "+", 
          RowBox[{"a", " ", "b"}], "+", 
          RowBox[{"a", " ", "b", " ", 
           SuperscriptBox["t", "2"], " ", "x"}]}], ")"}]}], "a"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "t"}], "+", "x", "-", 
         RowBox[{"a", " ", "x"}]}], ")"}]}], "y"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", "x", 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "t"}], "+", "x", "-", 
         RowBox[{"a", " ", "x"}]}], ")"}], " ", "y"}], "a"]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.761015444130288*^9, 3.76125034729617*^9, 
  3.7613339932646513`*^9, 3.761360629289486*^9, 3.761420794013413*^9, 
  3.761443428229871*^9, 3.7615142989095783`*^9, 3.7675808242873034`*^9, 
  3.767583332028303*^9, 3.767644075548274*^9, 3.789158407795426*^9},
 CellLabel->
  "Out[190]=",ExpressionUUID->"317493a8-42e1-42a0-843e-1f9ebc432ef0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"we", "'"}], "ve", " ", "already", " ", "seen", " ", "the", " ", 
     "factorisation", " ", "of", " ", "the", " ", "kernel"}], ",", " ", 
    RowBox[{
    "so", " ", "we", " ", "know", " ", "how", " ", "to", " ", "deal", " ", 
     "with", " ", "this"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "now", " ", "we", " ", "can", " ", "compute", " ", "the", " ", 
    RowBox[{"y", "^", "0"}], " ", "term", " ", "of", " ", "the", " ", "RHS"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"halfOSrhs", ",", "y", ",", 
         RowBox[{"-", "1"}]}], "]"}], "/", 
       SubscriptBox["YY", "1"]}], "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"halfOSrhs", ",", "y", ",", "0"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"halfOSrhs", ",", "y", ",", "1"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["YY", "0"], "/", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"halfOSrhsy0", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Q", "[", "__", "]"}], ",", "Simplify"}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.761015490106105*^9, 3.761015500866293*^9}, {
  3.76101553108526*^9, 3.761015611647344*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"0d973736-0f9b-4e10-b708-5d5e16f90026"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"t", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], ")"}]}], 
       "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"t", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["x", "3"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "t", " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{"t", "-", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], ")"}], " ", 
     
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "x"}], "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"t", "+", "x", "+", 
          RowBox[{"x", " ", 
           SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}]}], 
      ")"}]}]}], 
   RowBox[{"2", " ", "c", " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "+", "x", "+", 
      RowBox[{"x", " ", 
       SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
    SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", "x", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "t"}], "+", "x", "+", 
       RowBox[{"x", " ", 
        SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
     SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "-", "c", "+", 
         RowBox[{"b", " ", "c"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["x", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["t", "2"], " ", 
             SuperscriptBox["x", "2"]}], "-", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"t", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["x", "3"]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", "t", " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], ")"}], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "x"}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", "x", "+", 
            RowBox[{"x", " ", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "x"}], ")"}]}], "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "t"}], "+", 
         RowBox[{"2", " ", "a", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a", " ", 
          SuperscriptBox["t", "3"], " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a", "-", 
            RowBox[{"2", " ", "a", " ", 
             SuperscriptBox["x", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"]}]}], 
        ")"}]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "x"}], "]"}]}], 
   RowBox[{"2", " ", "b", " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "+", "x", "+", 
      RowBox[{"x", " ", 
       SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
    SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "x"}], ")"}]}], "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "t"}], "+", 
         RowBox[{"2", " ", "a", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "x", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a", " ", 
          SuperscriptBox["t", "3"], " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a", "-", 
            RowBox[{"2", " ", "a", " ", 
             SuperscriptBox["x", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}], ")"}], "2"]}]}], 
        ")"}]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], 
   RowBox[{"2", " ", "a", " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "+", "x", "+", 
      RowBox[{"x", " ", 
       SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}], " ", 
    SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]]}]], "Output",
 CellChangeTimes->{{3.761015550781946*^9, 3.761015575155221*^9}, 
   3.76101561370255*^9, 3.761250347729081*^9, 3.761333993708126*^9, 
   3.761360630140748*^9, 3.761420794449638*^9, 3.761443428536912*^9, 
   3.761514299241726*^9, 3.7675808245743036`*^9, 3.7675833325503035`*^9, 
   3.767644082218803*^9, 3.789158408299074*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"5c4a7d67-c2e7-45c1-b328-966775229d5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"halfOSrhs", "/", 
      RowBox[{"K", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", "#", "]"}], ",", "y", ",", "0"}], "]"}], 
       "&"}], ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"halfOSrhsy0", "/.", 
      RowBox[{
      "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{"Expand", "@*", "Simplify"}], ",", "%"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.761250420882732*^9, 3.761250546143111*^9}, {
  3.7612506029304743`*^9, 3.761250687757669*^9}, {3.7612511069427032`*^9, 
  3.7612511231745577`*^9}},
 CellLabel->
  "In[193]:=",ExpressionUUID->"5cd8fc67-644f-42d9-820c-0901db0c05c1"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7612504370264797`*^9, 3.7612504475400047`*^9}, {
   3.76125049960994*^9, 3.761250527787952*^9}, {3.761250614530353*^9, 
   3.761250703374866*^9}, {3.761251118142166*^9, 3.7612511382148447`*^9}, 
   3.761334004626905*^9, 3.7613606406393547`*^9, 3.76142080477592*^9, 
   3.761443439136894*^9, 3.761514309079226*^9, 3.767580833311303*^9, 
   3.7675833443123035`*^9, 3.767644091072056*^9, 3.789158418553767*^9},
 CellLabel->
  "Out[197]=",ExpressionUUID->"4ada3a5f-caf5-488c-96fc-160e1f6fdda4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "check", " ", "some", " ", "more"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Total", "[", "halfOSlhsy0", "]"}], "-", "halfOSrhsy0"}], "/.", 
      RowBox[{
      "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Simplify", ",", "%"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7612507225396423`*^9, 3.7612508023066587`*^9}, {
  3.761251143415825*^9, 3.761251157593298*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"1e8f5a9d-fefb-4002-ad72-af542857cb11"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7612507886231203`*^9, 3.761250802879244*^9}, {
   3.761251147923437*^9, 3.7612511636194363`*^9}, 3.76133400825511*^9, 
   3.76136064511559*^9, 3.761420808414515*^9, 3.761443442819439*^9, 
   3.761514312624703*^9, 3.7675808361783037`*^9, 3.7675833474013033`*^9, 
   3.767644094217321*^9, 3.789158422660344*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"95beea4b-631d-4133-8cf9-e8fe8152a1aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"now", " ", "combining", " ", "the", " ", "full"}], "-", 
    RowBox[{"orbit", " ", "sum", " ", "with", " ", "the", " ", "half"}], "-", 
    
    RowBox[{"orbit", " ", "sum", " ", "to", " ", "obtain", " ", "eqn", " ", 
     RowBox[{"(", "5.20", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"eliminating", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Total", "[", "halfOSlhsy0", "]"}], "-", "halfOSrhsy0"}], "/.", 
     
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"fullOSlhsy0xposv2", "\[Equal]", "fullOSrhsy0xpos"}], ",", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSy0", "=", 
     RowBox[{"Collect", "[", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], ",", 
         RowBox[{"Q", "[", 
          RowBox[{"x", ",", "0"}], "]"}], ",", 
         RowBox[{
          SubsuperscriptBox["Q", "0", "d"], "[", 
          FractionBox["1", "x"], "]"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], ",", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], ",", 
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]]}], "}"}], ",", "Factor"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"let", "'"}], "s", " ", "check", " ", "it", " ", "before", " ", 
     "doing", " ", "anything", " ", "else"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"halfOSy0", "/.", 
        RowBox[{
        "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"\[Theta]s", "[", "9", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["\[Theta]", 
           RowBox[{"0", ",", "0"}]], "\[Rule]", 
          RowBox[{
           SubscriptBox["\[Theta]s", 
            RowBox[{"0", ",", "0"}]], "[", "9", "]"}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcy", "[", 
          RowBox[{"9", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["Q", "0", "d"], "[", 
          FractionBox["1", "x"], "]"}], "\[Rule]", 
         RowBox[{"QQdkeval", "[", 
          RowBox[{"9", ",", "0", ",", 
           RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "3", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
     "Simplificate"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.761252051583099*^9, 3.761252070982489*^9}, 
   3.7612532248196917`*^9, {3.761254446108717*^9, 3.761254636337617*^9}, {
   3.761254685040826*^9, 3.76125468643505*^9}, {3.761254893888184*^9, 
   3.7612549509371758`*^9}, {3.7612549903262587`*^9, 3.761255025897131*^9}, {
   3.7612552738082542`*^9, 3.7612553814483356`*^9}, {3.761255422446273*^9, 
   3.761255438543816*^9}, {3.761255600604629*^9, 3.76125560292553*^9}, {
   3.761255644412595*^9, 3.7612556620624247`*^9}, {3.761255746824749*^9, 
   3.761255752277516*^9}, {3.761255819015998*^9, 3.7612558485903378`*^9}, {
   3.7612562968459682`*^9, 3.761256336436689*^9}, {3.7618876890000343`*^9, 
   3.7618876911730347`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"c49ad65d-f460-4025-af29-c6dee62cb93d"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7612544499803762`*^9, 3.761254462577726*^9}, {
   3.761254507191885*^9, 3.7612545186127357`*^9}, {3.761254552381267*^9, 
   3.761254598081286*^9}, 3.761254638022258*^9, {3.7612549269390574`*^9, 
   3.761254952115589*^9}, {3.761254999001503*^9, 3.7612550369082603`*^9}, {
   3.7612553045322733`*^9, 3.76125531938743*^9}, {3.761255351827403*^9, 
   3.7612553826914873`*^9}, 3.761255423491431*^9, 3.761255604281766*^9, {
   3.761255646928513*^9, 3.761255663147612*^9}, {3.7612557489091578`*^9, 
   3.7612557547908688`*^9}, {3.761255826638364*^9, 3.761255834377993*^9}, 
   3.7612563197830677`*^9, 3.761256375202368*^9, 3.761334047982128*^9, 
   3.761360684873666*^9, 3.7614208489002113`*^9, 3.7614434823510103`*^9, 
   3.761514351550343*^9, 3.7675808753343034`*^9, 3.7675833872543035`*^9, 
   3.767644173869452*^9, 3.789158513132635*^9},
 CellLabel->
  "Out[202]=",ExpressionUUID->"51f19f72-7422-482f-babe-40c609814247"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"halfOSy0", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
     " ", "x", "*", "2", "c"}], ",", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Numerator", "[", "%", "]"}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "//",
     "FullSimplify"}], "//", "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Denominator", "[", "%%", "]"}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "//",
     "FullSimplify"}], "//", "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%%", "/", "%"}], "//", "FullSimplify"}], "//", "Factor"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Mu]", 
   RowBox[{"x", ",", "0"}]], "=", 
  RowBox[{"-", "%"}]}]}], "Input",
 CellChangeTimes->{{3.761256529512989*^9, 3.761256537136116*^9}, {
   3.761256573248639*^9, 3.7612566433696947`*^9}, 3.761256769744288*^9, {
   3.761256820336061*^9, 3.761256865728343*^9}, {3.7612569019997063`*^9, 
   3.761256955718689*^9}, {3.761257023436605*^9, 3.7612570237487164`*^9}, {
   3.7612601335522213`*^9, 3.7612601337302837`*^9}, {3.761260260667303*^9, 
   3.7612602623981524`*^9}, {3.761260328991849*^9, 3.761260330598308*^9}, {
   3.761260461719821*^9, 3.761260471191827*^9}, {3.761260967224801*^9, 
   3.761260967629287*^9}, {3.761261072818458*^9, 3.761261077328635*^9}, 
   3.761262119254201*^9},
 CellLabel->
  "In[203]:=",ExpressionUUID->"5524d379-32b2-4278-86bd-1dfd14e7dd09"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", " ", "t"}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "-", 
    RowBox[{"b", " ", "t"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "t"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.7612565374603643`*^9, 3.761256612476129*^9, 3.761256644431355*^9, 
   3.761256770205449*^9, {3.761256823563613*^9, 3.7612568663118362`*^9}, {
   3.76125690789604*^9, 3.761256956252119*^9}, 3.761257025168928*^9, 
   3.7612601413369303`*^9, 3.761260264052404*^9, 3.7612603323028927`*^9, {
   3.7612604625044947`*^9, 3.761260473434718*^9}, 3.76126066795575*^9, 
   3.761260970331738*^9, 3.7612610788199463`*^9, 3.761261345081493*^9, 
   3.761262120763513*^9, 3.7613340491374683`*^9, 3.761360686282867*^9, 
   3.761420850395341*^9, 3.761443484188398*^9, 3.761514352638555*^9, 
   3.7675808772063036`*^9, 3.767583388797303*^9, 3.767644297118949*^9, 
   3.789158514371696*^9},
 CellLabel->
  "Out[207]=",ExpressionUUID->"fb01e04a-8d57-4072-8dd8-cd400bf29829"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"halfOSy0", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
     " ", "x", "*", "2", "c"}], ",", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubsuperscriptBox["\[Nu]", "0", "d"], "=", 
  RowBox[{
   RowBox[{"-", "%"}], "/", 
   RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}]}], "Input",\

 CellChangeTimes->{
  3.7612569893140163`*^9, {3.761257026530088*^9, 3.761257026943952*^9}, {
   3.761260145298169*^9, 3.761260147433386*^9}, {3.761260266978427*^9, 
   3.761260267100521*^9}, {3.7612603361127453`*^9, 3.7612603376636467`*^9}, {
   3.7612604754206133`*^9, 3.761260493589633*^9}, 3.761260616435101*^9, 
   3.7612606634716263`*^9, {3.761260973716106*^9, 3.761260974660163*^9}, {
   3.761261086971616*^9, 3.76126111030373*^9}, 3.761269256208209*^9},
 CellLabel->
  "In[208]:=",ExpressionUUID->"5f80b15f-c41e-4617-b2ce-ca208162e138"],

Cell[BoxData[
 RowBox[{"2", " ", "a", " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "-", "x", "+", 
    RowBox[{"a", " ", "x"}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "t"}], "-", "x", "+", 
    RowBox[{"b", " ", "x"}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "t"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.761256993650735*^9, 3.761257027947866*^9, 3.7612601488019753`*^9, 
   3.7612602679005947`*^9, 3.761260338324736*^9, 3.761260417598918*^9, {
   3.7612604760405827`*^9, 3.76126049461298*^9}, 3.761260669743898*^9, 
   3.761260975175392*^9, 3.7612611137200727`*^9, 3.761261346044984*^9, 
   3.7612692590079107`*^9, 3.761334049375451*^9, 3.7613606865896387`*^9, 
   3.761420850593014*^9, 3.761443484666368*^9, 3.761514352922921*^9, 
   3.7675808773263035`*^9, 3.7675833888693037`*^9, 3.767644299274529*^9, 
   3.7891585145519753`*^9},
 CellLabel->
  "Out[209]=",ExpressionUUID->"74f5aedf-d689-40ab-9021-f657af2259b8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"halfOSy0", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
     " ", "x", "*", "2", "c"}], ",", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Numerator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}], "/", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Denominator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["t", "x"]}], ")"}], "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"], " ", "x"}]}]], "\[Rule]", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "//", 
   "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Mu]", 
   RowBox[{"1", ",", "0"}]], "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "0"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Nu]", 
   RowBox[{"1", ",", "0"}]], "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "%%", "]"}], ",", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.761257040692667*^9, 3.761257045147316*^9}, {
   3.7612601525863333`*^9, 3.761260152754425*^9}, {3.761260273526108*^9, 
   3.761260273659525*^9}, {3.761260341996537*^9, 3.761260343266025*^9}, {
   3.761260397775132*^9, 3.761260429746208*^9}, 3.761260512939982*^9, 
   3.761260543714655*^9, {3.761260575360304*^9, 3.761260617392232*^9}, {
   3.761260702457734*^9, 3.761260703418727*^9}, {3.761260775590624*^9, 
   3.761260819520047*^9}, {3.7612608499652863`*^9, 3.7612608692690697`*^9}, {
   3.7612609814676447`*^9, 3.761260982625538*^9}, {3.7612611279098682`*^9, 
   3.761261194645546*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"ffbe3961-eb1b-44f8-b1d2-0050076af9f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "c"}], " ", "t", " ", "x", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "-", 
    RowBox[{"b", " ", "t"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", "x"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", "x"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"4", " ", "a", " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"4", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.761257054449916*^9, 3.7612601575531483`*^9, 3.761260316875595*^9, {
   3.761260394007552*^9, 3.761260431507801*^9}, {3.761260502833022*^9, 
   3.761260544388157*^9}, {3.761260582065878*^9, 3.7612606184109297`*^9}, 
   3.7612607041232233`*^9, 3.76126082291566*^9, {3.761260860173451*^9, 
   3.76126086949119*^9}, 3.7612609832269897`*^9, 3.761261161415435*^9, 
   3.7612611961462793`*^9, 3.761261347411771*^9, 3.7613340495334597`*^9, 
   3.761360686759878*^9, 3.761420850729554*^9, 3.761443484842703*^9, 
   3.7615143530776567`*^9, 3.7675808774443035`*^9, 3.767583388929303*^9, 
   3.767644302746355*^9, 3.7891585146449137`*^9},
 CellLabel->
  "Out[213]=",ExpressionUUID->"fa3ca5bc-a520-41b6-b8f8-454cccba2eec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"a", "-", "b"}], ")"}], " ", "c", " ", "t", " ", 
  SuperscriptBox["x", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", "x"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", "x"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"4", " ", "a", " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"4", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.761257054449916*^9, 3.7612601575531483`*^9, 3.761260316875595*^9, {
   3.761260394007552*^9, 3.761260431507801*^9}, {3.761260502833022*^9, 
   3.761260544388157*^9}, {3.761260582065878*^9, 3.7612606184109297`*^9}, 
   3.7612607041232233`*^9, 3.76126082291566*^9, {3.761260860173451*^9, 
   3.76126086949119*^9}, 3.7612609832269897`*^9, 3.761261161415435*^9, 
   3.7612611961462793`*^9, 3.761261347411771*^9, 3.7613340495334597`*^9, 
   3.761360686759878*^9, 3.761420850729554*^9, 3.761443484842703*^9, 
   3.7615143530776567`*^9, 3.7675808774443035`*^9, 3.767583388929303*^9, 
   3.767644302746355*^9, 3.789158514743226*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"5df33606-3120-4175-a236-55e327035501"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"halfOSy0", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
     " ", "x", "*", "2", "c"}], ",", 
    SubscriptBox["Q", 
     RowBox[{"2", ",", "0"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Numerator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}], "/", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Denominator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["t", "x"]}], ")"}], "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"], " ", "x"}]}]], "\[Rule]", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "//", 
   "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Mu]", 
   RowBox[{"2", ",", "0"}]], "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "0"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Nu]", 
   RowBox[{"2", ",", "0"}]], "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "%%", "]"}], ",", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.761257090000963*^9, {3.761260167594048*^9, 3.761260167784565*^9}, {
   3.761260355203597*^9, 3.7612603575529623`*^9}, {3.761260709730901*^9, 
   3.761260713770273*^9}, {3.761260887699046*^9, 3.7612608889009733`*^9}, {
   3.761260987913967*^9, 3.761260988250248*^9}, {3.761261205312996*^9, 
   3.761261209799305*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"63cf817a-a815-45d3-a9e6-2ad3fd4ff2d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", "b"}], ")"}], " ", "c", " ", 
  SuperscriptBox["t", "2"], " ", 
  SuperscriptBox["x", "3"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "-", 
    RowBox[{"b", " ", "t"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.761260714245743*^9, 3.761260889748045*^9, 
  3.761260989064312*^9, 3.7612612124059057`*^9, 3.76126135051259*^9, 
  3.7613340497777567`*^9, 3.7613606870105057`*^9, 3.761420850893717*^9, 
  3.761443485238344*^9, 3.761514353259831*^9, 3.7675808775713034`*^9, 
  3.7675833890013037`*^9, 3.767644305511931*^9, 3.789158514832864*^9},
 CellLabel->
  "Out[218]=",ExpressionUUID->"e4ebb12a-ad93-4225-812b-349095ac1ac1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"a", "-", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", "b"}], ")"}], " ", "c", " ", 
  SuperscriptBox["t", "2"], " ", 
  SuperscriptBox["x", "4"]}]], "Output",
 CellChangeTimes->{3.761260714245743*^9, 3.761260889748045*^9, 
  3.761260989064312*^9, 3.7612612124059057`*^9, 3.76126135051259*^9, 
  3.7613340497777567`*^9, 3.7613606870105057`*^9, 3.761420850893717*^9, 
  3.761443485238344*^9, 3.761514353259831*^9, 3.7675808775713034`*^9, 
  3.7675833890013037`*^9, 3.767644305511931*^9, 3.789158514924821*^9},
 CellLabel->
  "Out[219]=",ExpressionUUID->"02a36909-80a0-47a0-a183-49a7364f0921"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"halfOSy0", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
     " ", "x", "*", "2", "c"}], ",", 
    SubscriptBox["Q", 
     RowBox[{"3", ",", "0"}]]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Numerator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}], "/", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Denominator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["t", "x"]}], ")"}], "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"], " ", "x"}]}]], "\[Rule]", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "//", 
   "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Mu]", 
   RowBox[{"3", ",", "0"}]], "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"%", "/.", 
    RowBox[{"\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "0"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Nu]", 
   RowBox[{"3", ",", "0"}]], "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "%%", "]"}], ",", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.761257096571529*^9, {3.761260171891651*^9, 3.7612601720036592`*^9}, {
   3.761260361143497*^9, 3.761260362413101*^9}, {3.7612607207259893`*^9, 
   3.7612607214528313`*^9}, {3.761260894214685*^9, 3.7612608947171383`*^9}, {
   3.761260992042778*^9, 3.761260993155377*^9}, {3.761261217304161*^9, 
   3.7612612207456703`*^9}},
 CellLabel->
  "In[220]:=",ExpressionUUID->"444eb12e-dcc6-40a3-8a60-3d7dabfc43cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
  SuperscriptBox["t", "3"], " ", 
  SuperscriptBox["x", "3"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "-", 
    RowBox[{"b", " ", "t"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.761257099664156*^9, 3.761260173731408*^9, 
  3.7612607221443357`*^9, 3.761260895337614*^9, 3.7612609945988913`*^9, 
  3.761261221687852*^9, 3.761261351725563*^9, 3.761334050007986*^9, 
  3.761360687874146*^9, 3.7614208510435266`*^9, 3.7614434856732073`*^9, 
  3.761514353446384*^9, 3.7675808776783037`*^9, 3.7675833890483036`*^9, 
  3.767644307959141*^9, 3.789158515015396*^9},
 CellLabel->
  "Out[223]=",ExpressionUUID->"d346b2cd-c442-460a-aa8d-c4631ce99a96"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"a", "-", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
  SuperscriptBox["t", "3"], " ", 
  SuperscriptBox["x", "4"]}]], "Output",
 CellChangeTimes->{3.761257099664156*^9, 3.761260173731408*^9, 
  3.7612607221443357`*^9, 3.761260895337614*^9, 3.7612609945988913`*^9, 
  3.761261221687852*^9, 3.761261351725563*^9, 3.761334050007986*^9, 
  3.761360687874146*^9, 3.7614208510435266`*^9, 3.7614434856732073`*^9, 
  3.761514353446384*^9, 3.7675808776783037`*^9, 3.7675833890483036`*^9, 
  3.767644307959141*^9, 3.789158515111977*^9},
 CellLabel->
  "Out[224]=",ExpressionUUID->"5cd21f95-12ed-4de8-8a9a-87c33ba2ab8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"halfOSy0", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
     " ", "x", "*", "2", "c"}], ",", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Numerator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}], "/", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Denominator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["t", "x"]}], ")"}], "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"], " ", "x"}]}]], "\[Rule]", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "//", 
   "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Mu]", 
   RowBox[{"0", ",", "0"}]], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "0"}]}], ",", 
    SubscriptBox["\[Theta]", 
     RowBox[{"0", ",", "0"}]], ",", "Factor"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Nu]", 
   RowBox[{"0", ",", "0"}]], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "%%", "]"}], ",", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "]"}], 
    ",", 
    SubscriptBox["\[Theta]", 
     RowBox[{"0", ",", "0"}]], ",", "Factor"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.761260040668481*^9, 3.761260043086598*^9}, {
  3.7612601769547586`*^9, 3.7612601772041388`*^9}, {3.7612602270183067`*^9, 
  3.7612602272574883`*^9}, {3.761260367365389*^9, 3.76126037032099*^9}, {
  3.761260922033785*^9, 3.761260922865093*^9}, {3.761260998804377*^9, 
  3.7612609991967077`*^9}, {3.761261240907021*^9, 3.761261302568213*^9}, {
  3.761261336569713*^9, 3.761261465414135*^9}},
 CellLabel->
  "In[225]:=",ExpressionUUID->"d8ff1f5d-14f2-489f-b8e4-a1c1854315e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "-", 
  RowBox[{"12", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"11", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", "x"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"11", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"10", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"9", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"4", " ", "a", " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"12", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"16", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"15", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"28", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"20", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"11", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"14", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"12", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"12", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"4", " ", "a", " ", "b", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", "b", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"5", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"a", " ", 
   SuperscriptBox["b", "3"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"6", " ", "a", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"13", " ", 
   SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "3"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"6", " ", "b", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"25", " ", "a", " ", "b", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"32", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"14", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"8", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"22", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"20", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"3", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"14", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"10", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "-", 
  RowBox[{"19", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"10", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{"2", " ", "a", " ", "b", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "b", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"3", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"a", " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"4", " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"8", " ", "a", " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "2"], " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"6", " ", "b", " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"11", " ", "a", " ", "b", " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"3", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "b", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"7", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"9", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"11", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"9", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"29", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"24", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"14", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"22", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"9", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "6"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "6"], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "6"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "6"], " ", 
   SuperscriptBox["x", "4"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"7", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"4", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"4", " ", "a", " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"13", " ", "a", " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"12", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"4", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "2"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"8", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"11", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "5"], " ", 
   SuperscriptBox["x", "5"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "3"], " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "4"], " ", "b", " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["b", "2"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "3"], " ", "c", " ", 
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{"a", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "t"}], "-", 
     RowBox[{"b", " ", "t"}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
     RowBox[{"2", " ", "x"}], "-", 
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"b", " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   SubscriptBox["\[Theta]", 
    RowBox[{"0", ",", "0"}]]}]}]], "Output",
 CellChangeTimes->{
  3.7612600446197767`*^9, 3.761260177901774*^9, 3.761260227851902*^9, 
   3.761260733583778*^9, 3.761260924973349*^9, 3.761260999749627*^9, {
   3.761261298856031*^9, 3.761261303372778*^9}, {3.76126136311512*^9, 
   3.7612613843378487`*^9}, 3.761261436663822*^9, 3.761261467021447*^9, 
   3.761334050285334*^9, 3.761360689043531*^9, 3.761420851271908*^9, 
   3.761443486075357*^9, 3.76151435366927*^9, 3.767580877957303*^9, 
   3.7675833892953033`*^9, 3.767644312597356*^9, 3.789158515284276*^9},
 CellLabel->
  "Out[228]=",ExpressionUUID->"20f30584-2bf6-445e-bf37-91b57aeebc80"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "a"}], " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"5", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "a", " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "b", " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"8", " ", "a", " ", "b", " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"11", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"11", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"5", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", "a", " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"4", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"4", " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"7", " ", "a", " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"7", " ", "b", " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"12", " ", "a", " ", "b", " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"5", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"10", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"8", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"4", " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "c", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}]}], ")"}]}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "4"], " ", 
   SubscriptBox["\[Theta]", 
    RowBox[{"0", ",", "0"}]]}]}]], "Output",
 CellChangeTimes->{
  3.7612600446197767`*^9, 3.761260177901774*^9, 3.761260227851902*^9, 
   3.761260733583778*^9, 3.761260924973349*^9, 3.761260999749627*^9, {
   3.761261298856031*^9, 3.761261303372778*^9}, {3.76126136311512*^9, 
   3.7612613843378487`*^9}, 3.761261436663822*^9, 3.761261467021447*^9, 
   3.761334050285334*^9, 3.761360689043531*^9, 3.761420851271908*^9, 
   3.761443486075357*^9, 3.76151435366927*^9, 3.767580877957303*^9, 
   3.7675833892953033`*^9, 3.767644312597356*^9, 3.789158515423572*^9},
 CellLabel->
  "Out[229]=",ExpressionUUID->"793a25bc-a4cd-4454-88a5-bdfa24c0432c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"halfOSy0", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], "*", 
    RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], "*", "a", 
    " ", "x", "*", "2", "c"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"3", ",", "0"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Numerator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}], "/", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Denominator", "[", "%", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "x", "+", 
        RowBox[{"x", " ", 
         SqrtBox["\[CapitalDelta]\[CapitalDelta]"]}]}], ")"}]}], "/.", 
     RowBox[{
     "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["t", "x"]}], ")"}], "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"], " ", "x"}]}]], "\[Rule]", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], "//", 
   "Factor"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Mu]", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "0"}]}], ",", 
    "\[Theta]", ",", "Factor"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Nu]", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "%%", "]"}], ",", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}], "]"}], 
    ",", "\[Theta]", ",", "Factor"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.761260067577984*^9, 3.761260105153578*^9}, {
   3.761260183952317*^9, 3.7612601842260647`*^9}, {3.7612602344323463`*^9, 
   3.761260236207906*^9}, 3.7612603769605703`*^9, {3.761260940765414*^9, 
   3.761260941529105*^9}, {3.761261006419999*^9, 3.761261006733906*^9}, {
   3.7612614883218718`*^9, 3.7612615483519707`*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"1644d3f2-abf8-4530-8acb-3ebeb43a5195"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", "x"}], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"2", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"11", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"10", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"9", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"5", " ", "a", " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"5", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"3", " ", "a", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"14", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"3", " ", "b", " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"4", " ", "a", " ", "b", " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"7", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"12", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "6"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"4", " ", "a", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"7", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"4", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "6"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "6"]}], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "6"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "6"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
  RowBox[{"a", " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "t"}], "-", 
     RowBox[{"b", " ", "t"}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
     RowBox[{"2", " ", "x"}], "-", 
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"b", " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", "\[Theta]"}]}]], "Output",
 CellChangeTimes->{{3.761260091182982*^9, 3.7612601061110573`*^9}, 
   3.7612601851032133`*^9, 3.761260237255238*^9, 3.761260742809257*^9, 
   3.7612609430636673`*^9, 3.761261007974*^9, {3.761261500224538*^9, 
   3.761261548900556*^9}, 3.7613340506572447`*^9, 3.7613606895945663`*^9, 
   3.761420851466342*^9, 3.761443486617021*^9, 3.761514353967218*^9, 
   3.7675808781643033`*^9, 3.7675833894333034`*^9, 3.767644317933608*^9, 
   3.789158515595314*^9},
 CellLabel->
  "Out[233]=",ExpressionUUID->"0a1684f1-79ad-4e8c-98cd-5c79d49cd38b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "b", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", "x"}], "-", 
     RowBox[{"2", " ", "a", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"5", " ", "a", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"4", " ", "a", " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"3", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "5"], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SuperscriptBox["x", "5"]}]}], ")"}]}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", "c", " ", "t", " ", 
   SuperscriptBox["x", "4"], " ", "\[Theta]"}]}]], "Output",
 CellChangeTimes->{{3.761260091182982*^9, 3.7612601061110573`*^9}, 
   3.7612601851032133`*^9, 3.761260237255238*^9, 3.761260742809257*^9, 
   3.7612609430636673`*^9, 3.761261007974*^9, {3.761261500224538*^9, 
   3.761261548900556*^9}, 3.7613340506572447`*^9, 3.7613606895945663`*^9, 
   3.761420851466342*^9, 3.761443486617021*^9, 3.761514353967218*^9, 
   3.7675808781643033`*^9, 3.7675833894333034`*^9, 3.767644317933608*^9, 
   3.789158515608595*^9},
 CellLabel->
  "Out[234]=",ExpressionUUID->"2648df3c-ba7e-4f07-8bb1-469c1c11adc7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it", " ", "all"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Mu]", 
        RowBox[{"x", ",", "0"}]]}], 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}], 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{"(", 
      RowBox[{"\[Mu]", "+", 
       RowBox[{"\[Nu]", " ", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], 
      ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"0", ",", "0"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], 
       ")"}], 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"1", ",", "0"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"1", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], 
       ")"}], 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"2", ",", "0"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], 
       ")"}], 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"3", ",", "0"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"3", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]\[CapitalDelta]", "]"}]}]}], 
       ")"}], 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "0"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"%", "/.", 
        RowBox[{
        "\[CapitalDelta]\[CapitalDelta]", "\[Rule]", "\[CapitalDelta]"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"\[Theta]s", "[", "12", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["\[Theta]", 
           RowBox[{"0", ",", "0"}]], "\[Rule]", 
          RowBox[{
           SubscriptBox["\[Theta]s", 
            RowBox[{"0", ",", "0"}]], "[", "12", "]"}]}]}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcy", "[", 
          RowBox[{"12", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["Q", "0", "d"], "[", 
          RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
         RowBox[{"QQdkeval", "[", 
          RowBox[{"12", ",", "0", ",", 
           RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"12", ",", "2", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"12", ",", "3", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
     "Simplificate"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.761262530933618*^9, 3.761262863880406*^9}, {
  3.7612692761103697`*^9, 3.761269280628981*^9}},
 CellLabel->
  "In[235]:=",ExpressionUUID->"3f35ea73-5821-45ad-ab9c-b65644a2457c"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7612625447714653`*^9, 3.761262570041807*^9}, {
   3.761262608022176*^9, 3.761262613750123*^9}, 3.761262661016446*^9, {
   3.761262768384871*^9, 3.761262869856661*^9}, 3.7612692874531097`*^9, 
   3.7613340534566307`*^9, 3.761360692945512*^9, 3.761420854537422*^9, 
   3.7614434899756393`*^9, 3.761514356749543*^9, 3.7675808810223036`*^9, 
   3.7675833922293034`*^9, 3.767644325003433*^9, 3.789158520941236*^9},
 CellLabel->
  "Out[236]=",ExpressionUUID->"66a5f9c8-57f6-439e-9afd-8874488b67e4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "now", " ", "for", " ", "the", " ", "canonical", " ", "factorisation", 
     " ", 
     RowBox[{"(", "5.21", ")"}]}], "-", 
    RowBox[{"(", 
     RowBox[{"5", ",", "23"}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Off", "[", 
    RowBox[{"Root", "::", "sbr"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "1"], "=", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["t", "2"], "-", 
         RowBox[{"2", " ", "t", " ", "#"}], "+", 
         SuperscriptBox["#", "2"], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["#", "3"]}]}], "&"}], ",", "1"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "2"], "=", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["t", "2"], "-", 
         RowBox[{"2", " ", "t", " ", "#"}], "+", 
         SuperscriptBox["#", "2"], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["#", "3"]}]}], "&"}], ",", "2"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "3"], "=", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["t", "2"], "-", 
         RowBox[{"2", " ", "t", " ", "#"}], "+", 
         SuperscriptBox["#", "2"], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["#", "3"]}]}], "&"}], ",", "3"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["X", "1"], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["d", "1"], ",", 
         SubscriptBox["d", "2"], ",", 
         SubscriptBox["d", "3"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}], 
         "\[Equal]", 
         RowBox[{"t", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["t", 
            RowBox[{"5", "/", "2"}]]}]}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["X", "2"], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["d", "1"], ",", 
         SubscriptBox["d", "2"], ",", 
         SubscriptBox["d", "3"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}], 
         "\[Equal]", 
         RowBox[{"t", "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t", 
            RowBox[{"5", "/", "2"}]]}]}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["X", "3"], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["d", "1"], ",", 
         SubscriptBox["d", "2"], ",", 
         SubscriptBox["d", "3"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
         "\[Equal]", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"4", " ", 
            SuperscriptBox["t", "2"]}]], "-", 
          RowBox[{"2", " ", "t"}]}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["X", "1"], ",", 
       SubscriptBox["X", "2"], ",", 
       SubscriptBox["X", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761265355565547*^9, 3.761265373808435*^9}, {
  3.761265432884119*^9, 3.761265582095467*^9}, {3.7612656532091703`*^9, 
  3.761265696678351*^9}, {3.7612657624510393`*^9, 3.761265763313283*^9}, {
  3.761265800202565*^9, 3.761265833075286*^9}, {3.766381487356*^9, 
  3.766381516748*^9}},
 CellLabel->
  "In[237]:=",ExpressionUUID->"8ece0b2e-3293-44cb-b395-c03f52e05848"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"2", " ", "t", " ", "#1"}], "-", 
     SuperscriptBox["#1", "2"], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["#1", "3"]}]}], "&"}], ",", "2"}], "]"}]], "Output",
 CellChangeTimes->{{3.7612654361268187`*^9, 3.7612654744789543`*^9}, {
   3.761265552904275*^9, 3.7612655557868357`*^9}, 3.761265660037848*^9, 
   3.761265697901979*^9, 3.76126580062022*^9, 3.761265833345429*^9, 
   3.7613340538468723`*^9, 3.761360693494471*^9, 3.761420854837688*^9, 
   3.76144349036252*^9, 3.761514356964938*^9, 3.7675808816033034`*^9, 
   3.7675833923453035`*^9, 3.767644329611472*^9, 3.789158521213669*^9},
 CellLabel->
  "Out[241]=",ExpressionUUID->"afd21323-a8e1-43a6-aaa8-8de73560472d"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"2", " ", "t", " ", "#1"}], "-", 
     SuperscriptBox["#1", "2"], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["#1", "3"]}]}], "&"}], ",", "1"}], "]"}]], "Output",
 CellChangeTimes->{{3.7612654361268187`*^9, 3.7612654744789543`*^9}, {
   3.761265552904275*^9, 3.7612655557868357`*^9}, 3.761265660037848*^9, 
   3.761265697901979*^9, 3.76126580062022*^9, 3.761265833345429*^9, 
   3.7613340538468723`*^9, 3.761360693494471*^9, 3.761420854837688*^9, 
   3.76144349036252*^9, 3.761514356964938*^9, 3.7675808816033034`*^9, 
   3.7675833923453035`*^9, 3.767644329611472*^9, 3.7891585213414707`*^9},
 CellLabel->
  "Out[242]=",ExpressionUUID->"41f8f614-23d1-48ae-95ac-4f5908fd1720"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"2", " ", "t", " ", "#1"}], "-", 
     SuperscriptBox["#1", "2"], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["#1", "3"]}]}], "&"}], ",", "3"}], "]"}]], "Output",
 CellChangeTimes->{{3.7612654361268187`*^9, 3.7612654744789543`*^9}, {
   3.761265552904275*^9, 3.7612655557868357`*^9}, 3.761265660037848*^9, 
   3.761265697901979*^9, 3.76126580062022*^9, 3.761265833345429*^9, 
   3.7613340538468723`*^9, 3.761360693494471*^9, 3.761420854837688*^9, 
   3.76144349036252*^9, 3.761514356964938*^9, 3.7675808816033034`*^9, 
   3.7675833923453035`*^9, 3.767644329611472*^9, 3.789158521461772*^9},
 CellLabel->
  "Out[243]=",ExpressionUUID->"62320fac-3bff-4fab-b269-e1b147fbe97c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{"t", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["t", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["t", "4"]}], "+", 
     RowBox[{"21", " ", 
      SuperscriptBox["t", 
       RowBox[{"11", "/", "2"}]]}], "+", 
     RowBox[{"80", " ", 
      SuperscriptBox["t", "7"]}], "+", 
     FractionBox[
      RowBox[{"1287", " ", 
       SuperscriptBox["t", 
        RowBox[{"17", "/", "2"}]]}], "4"], "+", 
     RowBox[{"1344", " ", 
      SuperscriptBox["t", "10"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"21", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 21, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, 2, 0, 0, 6, 0, 0, 21, 0, 0, 80, 0, 0, 
      Rational[1287, 4], 0, 0, 1344}, 2, 21, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{"t", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["t", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["t", "4"]}], "-", 
     RowBox[{"21", " ", 
      SuperscriptBox["t", 
       RowBox[{"11", "/", "2"}]]}], "+", 
     RowBox[{"80", " ", 
      SuperscriptBox["t", "7"]}], "-", 
     FractionBox[
      RowBox[{"1287", " ", 
       SuperscriptBox["t", 
        RowBox[{"17", "/", "2"}]]}], "4"], "+", 
     RowBox[{"1344", " ", 
      SuperscriptBox["t", "10"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"21", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 21, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, -2, 0, 0, 6, 0, 0, -21, 0, 0, 80, 0, 0, 
      Rational[-1287, 4], 0, 0, 1344}, 2, 21, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     RowBox[{"2", " ", "t"}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["t", "4"]}], "-", 
     RowBox[{"160", " ", 
      SuperscriptBox["t", "7"]}], "-", 
     RowBox[{"2688", " ", 
      SuperscriptBox["t", "10"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "11"],
      SeriesData[$CellContext`t, 0, {}, -2, 11, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
      Rational[1, 4], 0, 0, -2, 0, 0, -12, 0, 0, -160, 0, 0, -2688}, -2, 11, 
     1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.7612654361268187`*^9, 3.7612654744789543`*^9}, {
   3.761265552904275*^9, 3.7612655557868357`*^9}, 3.761265660037848*^9, 
   3.761265697901979*^9, 3.76126580062022*^9, 3.761265833345429*^9, 
   3.7613340538468723`*^9, 3.761360693494471*^9, 3.761420854837688*^9, 
   3.76144349036252*^9, 3.761514356964938*^9, 3.7675808816033034`*^9, 
   3.7675833923453035`*^9, 3.767644329611472*^9, 3.789158521557763*^9},
 CellLabel->
  "Out[244]=",ExpressionUUID->"e153f6b0-b5e4-4d82-82e9-802ad849e10b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"then", " ", "the", " ", "factorisation", " ", 
     RowBox[{"(", "5.24", ")"}]}], "-", 
    RowBox[{"(", "5.26", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "m"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["X", "1"], "/", "x"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["X", "2"], "/", "x"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "p"], "=", 
     RowBox[{"1", "-", 
      RowBox[{"x", "/", 
       SubscriptBox["X", "3"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "0"], "=", 
     RowBox[{"4", 
      RowBox[{"t", "^", "2"}], 
      SubscriptBox["X", "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"so", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalDelta]", "-", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "0"], 
      SubscriptBox["\[CapitalDelta]", "p"], 
      SubscriptBox["\[CapitalDelta]", "m"]}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.761266849934534*^9, 3.7612669180703707`*^9}, {
   3.761267448406069*^9, 3.761267479232431*^9}, {3.7612676431257677`*^9, 
   3.761267643247663*^9}, 3.7612677210778837`*^9, {3.766381553212*^9, 
   3.7663815583789997`*^9}, {3.789158262224399*^9, 3.7891582953221283`*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"2bbbc3b3-749d-4571-9b21-dd5d139e1055"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.761267479835475*^9, 3.761267644186054*^9, 
  3.7612677216136312`*^9, 3.761334054799431*^9, 3.7613606951491737`*^9, 
  3.761420855379023*^9, 3.761443491769498*^9, 3.761514357646454*^9, 
  3.7675808819653034`*^9, 3.7675833925583034`*^9, 3.767644336917777*^9, 
  3.789158521670611*^9},
 CellLabel->
  "Out[248]=",ExpressionUUID->"5f8c9a4d-c50c-4c3e-b606-492285aa115f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"so", " ", "that", " ", 
     RowBox[{"(", "5.27", ")"}]}], "-", 
    RowBox[{"(", "5.28", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]", "m"]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761267850888378*^9, 3.761267904510886*^9}, {
  3.7663815708199997`*^9, 3.766381586027*^9}, {3.7891582998449717`*^9, 
  3.78915830899086*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"cf06ed3b-afd0-4f6a-bfa3-8b387cf56d14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["t", "2"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["t", "4"]}], "+", 
   RowBox[{"16", " ", "x", " ", 
    SuperscriptBox["t", "5"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "6"],
    SeriesData[$CellContext`t, 0, {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   1, 0, 2 $CellContext`x, 0, 6 $CellContext`x^2, 16 $CellContext`x}, 0, 6, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761267867699053*^9, 3.761267904754859*^9}, 
   3.761334054950108*^9, 3.761360695324885*^9, 3.761420855495268*^9, 
   3.7614434920362043`*^9, 3.761514357809546*^9, 3.7675808820223036`*^9, 
   3.7675833926033034`*^9, 3.767644338587829*^9, 3.789158521772688*^9},
 CellLabel->
  "Out[249]=",ExpressionUUID->"b233b4e1-1354-48d2-9dd9-cdda48215a39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox["t", "x"], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["t", "3"]}], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["t", "4"]}], "x"], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["t", "5"]}], 
    SuperscriptBox["x", "2"]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "6"],
    SeriesData[$CellContext`t, 0, {}, 0, 12, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   1, 0, (-1)/$CellContext`x, 0, 0, 0, -4, 0, (-2)/$CellContext`x, 
    0, (-2) $CellContext`x^(-2)}, 0, 12, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761267867699053*^9, 3.761267904754859*^9}, 
   3.761334054950108*^9, 3.761360695324885*^9, 3.761420855495268*^9, 
   3.7614434920362043`*^9, 3.761514357809546*^9, 3.7675808820223036`*^9, 
   3.7675833926033034`*^9, 3.767644338587829*^9, 3.789158521775257*^9},
 CellLabel->
  "Out[250]=",ExpressionUUID->"65cc3c41-72bc-4984-9cb8-075297fbbaf7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", "we", " ", "divide", " ", "by", " ", 
    RowBox[{"Sqrt", "[", 
     SubscriptBox["\[CapitalDelta]", "p"], "]"}], " ", "and", " ", "take", 
    " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], ">"}], "]"}], " ", 
    RowBox[{"and", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], "<"}], "]"}], " ", "parts"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"for", " ", "simplicity", " ", "define"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["XX", "1"], "/", "x"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SubscriptBox["XX", "2"], "/", "x"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "=", 
     RowBox[{"1", "-", 
      RowBox[{"x", "/", 
       SubscriptBox["XX", "3"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "=", 
     RowBox[{"4", 
      RowBox[{"t", "^", "2"}], 
      SubscriptBox["XX", "3"]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.761269762639695*^9, 3.761269785109144*^9}, {
  3.7612698367145348`*^9, 3.76126987048682*^9}, {3.761269982485186*^9, 
  3.761269985632311*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"5a48f4cf-3494-4efa-bde6-b80c9386e3ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "following", " ", "two", " ", "expansions", " ", "will", " ", 
    "be", " ", "useful"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "expansion", " ", "of", " ", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "+"], "]"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"and", " ", "the", " ", "expansion", " ", "of", " ", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "-"], "]"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Infinity", ",", "5"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", "%"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761269906447692*^9, 3.761269909221918*^9}},
 CellLabel->
  "In[254]:=",ExpressionUUID->"c090ac56-0eb8-4d9a-b3b5-3361841684fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   FractionBox["x", 
    RowBox[{"2", " ", 
     SubscriptBox["XX", "3"]}]], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"]}], 
    RowBox[{"8", " ", 
     SubsuperscriptBox["XX", "3", "2"]}]], "+", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox["x", "3"]}], 
    RowBox[{"16", " ", 
     SubsuperscriptBox["XX", "3", "3"]}]], "+", 
   FractionBox[
    RowBox[{"35", " ", 
     SuperscriptBox["x", "4"]}], 
    RowBox[{"128", " ", 
     SubsuperscriptBox["XX", "3", "4"]}]], "+", 
   FractionBox[
    RowBox[{"63", " ", 
     SuperscriptBox["x", "5"]}], 
    RowBox[{"256", " ", 
     SubsuperscriptBox["XX", "3", "5"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "6"],
    SeriesData[$CellContext`x, 0, {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {
   1, Rational[1, 2]/$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3, 
    Rational[3, 
      8] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-2), 
    Rational[5, 
      16] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-3), 
    Rational[35, 
      128] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-4), 
    Rational[63, 
      256] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-5)}, 0, 
   6, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761269898618029*^9, 3.761269909896388*^9}, 
   3.761270190038576*^9, 3.76133405510961*^9, 3.761360695571349*^9, 
   3.761420855707995*^9, 3.7614434923526897`*^9, 3.761514358121311*^9, 
   3.767580882318303*^9, 3.767583392738303*^9, 3.767644344337221*^9, 
   3.7891585219107103`*^9},
 CellLabel->
  "Out[254]=",ExpressionUUID->"b6f1ccc4-c0ff-40da-a9d3-1571d4f36f04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["XX", "1"]}], "-", 
     SubscriptBox["XX", "2"]}], 
    RowBox[{"2", " ", "x"}]], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["XX", "1"], "-", 
       SubscriptBox["XX", "2"]}], ")"}], "2"], 
    RowBox[{"8", " ", 
     SuperscriptBox["x", "2"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["XX", "1"], "-", 
        SubscriptBox["XX", "2"]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["XX", "1"], "+", 
       SubscriptBox["XX", "2"]}], ")"}]}], 
    RowBox[{"16", " ", 
     SuperscriptBox["x", "3"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["XX", "1"], "-", 
        SubscriptBox["XX", "2"]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        SubsuperscriptBox["XX", "1", "2"]}], "+", 
       RowBox[{"6", " ", 
        SubscriptBox["XX", "1"], " ", 
        SubscriptBox["XX", "2"]}], "+", 
       RowBox[{"5", " ", 
        SubsuperscriptBox["XX", "2", "2"]}]}], ")"}]}], 
    RowBox[{"128", " ", 
     SuperscriptBox["x", "4"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["XX", "1"], "-", 
        SubscriptBox["XX", "2"]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["XX", "1"], "+", 
       SubscriptBox["XX", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"7", " ", 
        SubsuperscriptBox["XX", "1", "2"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["XX", "1"], " ", 
        SubscriptBox["XX", "2"]}], "+", 
       RowBox[{"7", " ", 
        SubsuperscriptBox["XX", "2", "2"]}]}], ")"}]}], 
    RowBox[{"256", " ", 
     SuperscriptBox["x", "5"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "x"], "]"}], "6"],
    SeriesData[$CellContext`x, 
     DirectedInfinity[1], {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 
   DirectedInfinity[1], {
   1, Rational[
     1, 2] (-$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 - \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2), 
    Rational[-1, 
      8] ($CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 - \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2)^2, 
    Rational[-1, 
      16] ($CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 - \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2)^2 ($CellContext`XX\
\[UnderBracket]Subscript\[UnderBracket]1 + \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2), 
    Rational[-1, 
      128] ($CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 - \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2)^2 (
     5 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1^2 + 
     6 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2 + 
     5 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^2), 
    Rational[-1, 
      256] ($CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 - \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2)^2 ($CellContext`XX\
\[UnderBracket]Subscript\[UnderBracket]1 + \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2) (
     7 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1^2 + 
     2 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2 + 
     7 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^2)}, 0, 6, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761269898618029*^9, 3.761269909896388*^9}, 
   3.761270190038576*^9, 3.76133405510961*^9, 3.761360695571349*^9, 
   3.761420855707995*^9, 3.7614434923526897`*^9, 3.761514358121311*^9, 
   3.767580882318303*^9, 3.767583392738303*^9, 3.767644344337221*^9, 
   3.789158522017787*^9},
 CellLabel->
  "Out[256]=",ExpressionUUID->"f52dc292-f461-45c2-b749-6fffde9d35c9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"first", " ", "take", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], ">"}], "]"}], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "unfortunately", " ", "no", " ", "matter", " ", "what", " ", "we", " ", 
    "do", " ", "we", " ", "will", " ", "end", " ", "up", " ", "with", " ", 
    "another", " ", 
    RowBox[{"unknown", " ", "--"}], " ", "the", " ", "simplest", " ", "route",
     " ", "involves", " ", "dividing", " ", "by", " ", 
    RowBox[{"x", "^", "4"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.761270282987237*^9, 3.761270301638982*^9}, {
  3.7612704288010406`*^9, 3.7612704323779573`*^9}, {3.761272151851535*^9, 
  3.761272195196487*^9}},
 CellLabel->
  "In[257]:=",ExpressionUUID->"f7f43918-cbe0-4ecf-81df-16a4917251aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}], " ", "term", " ", "is", " ", 
    "straightforward"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"x", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"xposLHS1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "*", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            RowBox[{"-", "4"}]}], "}"}]}], "]"}], "/", 
        RowBox[{"x", "^", "4"}]}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "0"}]], "*", "x"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "*", 
          RowBox[{"x", "^", "2"}]}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"3", ",", "0"}]], "*", 
          RowBox[{"x", "^", "3"}]}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"4", ",", "0"}]], "*", 
          RowBox[{"x", "^", "4"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            RowBox[{"-", "3"}]}], "}"}]}], "]"}], "/", 
        RowBox[{"x", "^", "3"}]}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "0"}]], "*", "x"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "*", 
          RowBox[{"x", "^", "2"}]}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"3", ",", "0"}]], "*", 
          RowBox[{"x", "^", "3"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            RowBox[{"-", "2"}]}], "}"}]}], "]"}], "/", 
        RowBox[{"x", "^", "2"}]}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "0"}]], "*", "x"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "*", 
          RowBox[{"x", "^", "2"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], "/", 
        RowBox[{"x", "^", "1"}]}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "+", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "0"}]], "*", "x"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}], "//", "Simplify"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"x", ",", "0"}]], "/", 
        RowBox[{"x", "^", "4"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"9", ",", "0"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposLHS1", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"9", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.761270214739634*^9, 3.761270216407365*^9}, {
  3.761270304003706*^9, 3.7612703209330606`*^9}, {3.761270366418523*^9, 
  3.761270441591034*^9}, {3.761271654786063*^9, 3.761271764495205*^9}, {
  3.761272228779887*^9, 3.761272254294726*^9}, {3.761272287706746*^9, 
  3.7612724808263197`*^9}, {3.761272549781478*^9, 3.761272572337946*^9}, {
  3.76127271843155*^9, 3.7612727686520643`*^9}, {3.761275034523546*^9, 
  3.7612752043296947`*^9}, {3.761275240805356*^9, 3.7612752461468678`*^9}, {
  3.761275320680064*^9, 3.7612753211717453`*^9}, {3.761275407175056*^9, 
  3.76127542765972*^9}, {3.7612755013608513`*^9, 3.7612755228188353`*^9}},
 CellLabel->
  "In[258]:=",ExpressionUUID->"bdff623e-1930-4495-8093-273dafadb9d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", 
     SubsuperscriptBox["XX", "3", "4"]}]], 
   RowBox[{"c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "16"}], " ", 
          SubsuperscriptBox["XX", "3", "2"]}], "+", 
         RowBox[{"12", " ", "b", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"16", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "t"}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"10", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"40", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"56", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "t"}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"15", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"44", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"24", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"35", " ", 
             SuperscriptBox["t", "2"]}], "-", 
            RowBox[{"48", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"96", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"256", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"128", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "40"}], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"144", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"t", " ", 
             RowBox[{"(", 
              RowBox[{"35", "-", 
               RowBox[{"192", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "144"}], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"64", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{"40", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"7", "+", 
               RowBox[{"64", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"32", " ", 
          SubsuperscriptBox["XX", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"8", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "288"}], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"64", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{"1408", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"35", "-", 
               RowBox[{"64", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "-", 
         RowBox[{"8", " ", "b", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"112", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"80", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"480", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"704", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"128", " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"24", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"64", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox["t", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"35", "+", 
               RowBox[{"64", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"32", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"144", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"288", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"384", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"48", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "35"}], "+", 
               RowBox[{"128", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"192", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"512", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"128", " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox["t", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"35", "+", 
               RowBox[{"256", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "108"}], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"64", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"35", "+", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"30", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"448", " ", 
                SubsuperscriptBox["XX", "3", "4"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "x", " ", 
     SubsuperscriptBox["XX", "3", "3"]}]], 
   RowBox[{"c", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            SubscriptBox["XX", "3"]}], ")"}]}], "-", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"18", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          SubsuperscriptBox["XX", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "t"}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", "b", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"8", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"112", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "48"}], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "18"}], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"80", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"176", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"8", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"32", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"36", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"32", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "36"}], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"32", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"128", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"64", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "-", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["t", "3"]}], "-", 
            RowBox[{"8", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "6"}], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"24", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"t", " ", 
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"48", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"18", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"24", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"80", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], " ", "x"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", 
     SubsuperscriptBox["XX", "3", "2"]}]], 
   RowBox[{"c", " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       SuperscriptBox["b", "2"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"8", " ", "a", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"5", " ", "b"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"]}]}], ")"}], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "t"}], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}], " ", 
          SubscriptBox["XX", "3"]}], "-", 
         RowBox[{"16", " ", 
          SubsuperscriptBox["XX", "3", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["t", "2"]}], "-", 
            RowBox[{"12", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"80", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "-", 
            RowBox[{"48", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"4", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["t", "2"]}], "-", 
            RowBox[{"24", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"32", " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "9"}], " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"8", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"3", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"18", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", "t", " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "t"}], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"24", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"12", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["t", "2"]}], "-", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], " ", "x"}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
    SuperscriptBox["t", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "b"}], " ", "t"}], "+", 
         RowBox[{"6", " ", 
          SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "-", 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"]}], "-", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"4", " ", 
             SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], " ", "x"}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["x", "3"], " ", 
    SubscriptBox["XX", "3"]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "b"}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", "c", " ", 
    SuperscriptBox["t", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], " ", "x"}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]], " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], 
   SuperscriptBox["x", "4"]], "-", 
  FractionBox[
   RowBox[{"2", " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "x"}], ")"}]}], "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", "x"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"t", " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", "x"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"t", " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "x"}], "-", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", "x"}], ")"}]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "b"}]}], ")"}], " ", "t"}], "-", "x", "+", 
         RowBox[{"2", " ", "b", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], 
   RowBox[{
    SuperscriptBox["x", "4"], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox["x", 
       SubscriptBox["XX", "3"]]}]]}]]}]], "Output",
 CellChangeTimes->{{3.761272545750248*^9, 3.7612725782986298`*^9}, 
   3.761272723423994*^9, 3.761272777111321*^9, 3.761275094668964*^9, 
   3.7612751372671432`*^9, 3.761275205864496*^9, 3.7612752474108047`*^9, 
   3.7612753226348267`*^9, 3.761275430554473*^9, 3.76127552323602*^9, 
   3.761334058304407*^9, 3.761360699531753*^9, 3.761420859117833*^9, 
   3.7614434959191723`*^9, 3.7615143613437233`*^9, 3.7675808856403036`*^9, 
   3.7675833965253034`*^9, 3.767644371487342*^9, 3.789158525784113*^9},
 CellLabel->
  "Out[259]=",ExpressionUUID->"4ede5d14-225f-44d7-affc-068a6164f26a"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761272545750248*^9, 3.7612725782986298`*^9}, 
   3.761272723423994*^9, 3.761272777111321*^9, 3.761275094668964*^9, 
   3.7612751372671432`*^9, 3.761275205864496*^9, 3.7612752474108047`*^9, 
   3.7612753226348267`*^9, 3.761275430554473*^9, 3.76127552323602*^9, 
   3.761334058304407*^9, 3.761360699531753*^9, 3.761420859117833*^9, 
   3.7614434959191723`*^9, 3.7615143613437233`*^9, 3.7675808856403036`*^9, 
   3.7675833965253034`*^9, 3.767644371487342*^9, 3.7891585649662733`*^9},
 CellLabel->
  "Out[263]=",ExpressionUUID->"d26c4638-5a0d-4710-ba3d-c459a8c862f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     RowBox[{"1", "/", "x"}], "]"}], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], "/", 
      RowBox[{"x", "^", "4"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "Infinity", ",", 
          RowBox[{"-", "2"}]}], "}"}]}], "]"}], "*", 
      RowBox[{"x", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]], "/", "x"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "Infinity", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "*", "x", "*", 
      RowBox[{"(", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xposLHS2", "=", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "3"]}]], "\[Rule]", 
       RowBox[{"t", " ", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["XX", "3"], "]"}]}]}]}], "//", "Simplify"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Nu]", "0", "d"], "/", 
       RowBox[{"x", "^", "4"}]}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", "0"], 
        SubscriptBox["\[CapitalDelta]", "m"]}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"9", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposLHS2", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}], "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.761270423845273*^9, 3.761270426224234*^9}, {
   3.761270467027506*^9, 3.761270517371738*^9}, {3.7612705644994926`*^9, 
   3.761270575974675*^9}, {3.761270780277046*^9, 3.761270788878827*^9}, {
   3.7612712762179213`*^9, 3.76127127629737*^9}, 3.761271320947661*^9, {
   3.761271446230624*^9, 3.7612716105480328`*^9}, {3.761272805068891*^9, 
   3.761272812177197*^9}, {3.761272866224422*^9, 3.7612728851457863`*^9}, {
   3.761275527314123*^9, 3.7612757058215237`*^9}, {3.761275756815283*^9, 
   3.761275805831843*^9}},
 CellLabel->
  "In[264]:=",ExpressionUUID->"a75a2105-a744-49d6-8b15-fc485fdbb9ca"],

Cell[BoxData[
 RowBox[{"2", " ", "a", " ", "c", " ", 
  SuperscriptBox["t", "3"], " ", "x", " ", 
  SqrtBox[
   SubscriptBox["XX", "3"]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "b"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "b"}], "+", 
             RowBox[{"a", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox["t", "3"]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["XX", "1"], "+", 
          SubscriptBox["XX", "2"]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "+", 
       RowBox[{"a", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"x", " ", 
           RowBox[{"Q", "[", 
            RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.76127151994177*^9, 3.761271541119793*^9}, {
   3.761271593702636*^9, 3.761271611192472*^9}, 3.76127281267627*^9, 
   3.761272887618534*^9, {3.761275609110765*^9, 3.761275618022711*^9}, {
   3.761275657471652*^9, 3.7612757063050537`*^9}, 3.761275807229219*^9, 
   3.7613341192971992`*^9, 3.761360759198756*^9, 3.761420920510977*^9, 
   3.761443558564426*^9, 3.761514417398273*^9, 3.767580924344303*^9, 
   3.7675834365193033`*^9, 3.767644420325218*^9, 3.789158565780068*^9},
 CellLabel->
  "Out[267]=",ExpressionUUID->"ffde5b46-7cdd-4584-9b2a-4380cec021d1"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76127151994177*^9, 3.761271541119793*^9}, {
   3.761271593702636*^9, 3.761271611192472*^9}, 3.76127281267627*^9, 
   3.761272887618534*^9, {3.761275609110765*^9, 3.761275618022711*^9}, {
   3.761275657471652*^9, 3.7612757063050537`*^9}, 3.761275807229219*^9, 
   3.7613341192971992`*^9, 3.761360759198756*^9, 3.761420920510977*^9, 
   3.761443558564426*^9, 3.761514417398273*^9, 3.767580924344303*^9, 
   3.7675834365193033`*^9, 3.767644420325218*^9, 3.789158566460404*^9},
 CellLabel->
  "Out[271]=",ExpressionUUID->"3c5c9af1-5c0a-41dc-b896-e1ac713e5754"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"1", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}]}], "//", "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", 
       RowBox[{"1", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", "addition", " ", "of", " ", "the", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"O", "[", 
        RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}], ")"}], "*", "x", 
     " ", "term", " ", "is", " ", "because", " ", "some", " ", "versions", 
     " ", "of", " ", "Mathematica", " ", "seem", " ", "to", " ", "include", 
     " ", "unwanted", " ", "terms", " ", "when", " ", "expanding", " ", 
     "around", " ", "infinity"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "Infinity", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}], ")"}], "*", 
        "x"}]}], "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "3"]}]], "\[Rule]", 
       RowBox[{"t", " ", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["XX", "3"], "]"}]}]}]}], "//", "Normal"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"xposRHS1", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"%%%", "+", "%"}], "//", "Simplify"}], ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"1", ",", "0"}]], 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        RowBox[{"x", "^", "4"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xposRHS1", "/", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}], "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.76127301136574*^9, 3.761273150199567*^9}, {
   3.761273184076537*^9, 3.761273317197341*^9}, {3.761273507078474*^9, 
   3.761273511318686*^9}, {3.761275822101739*^9, 3.761275843283341*^9}, {
   3.761275878177166*^9, 3.76127600026923*^9}, {3.7612760406352787`*^9, 
   3.761276050408896*^9}, {3.761276160089918*^9, 3.761276163191951*^9}, {
   3.7675813291243033`*^9, 3.7675813633473034`*^9}, 3.7675840684753036`*^9, {
   3.767644520538924*^9, 3.7676445576540003`*^9}},
 CellLabel->
  "In[272]:=",ExpressionUUID->"321cee97-87f5-436c-a66c-eedd014aa6f8"],

Cell[BoxData[
 RowBox[{"c", " ", 
  SubscriptBox["Q", 
   RowBox[{"1", ",", "0"}]], " ", "t", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     SuperscriptBox["a", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b"}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["t", "3"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b"}], "-", 
       RowBox[{"4", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b", "-", 
          RowBox[{"2", " ", "b", " ", 
           SuperscriptBox["t", "3"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"3", " ", "b"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["t", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
      SuperscriptBox["t", "3"]}], 
     SuperscriptBox["x", "3"]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["x", 
          SubscriptBox["XX", "3"]]}]]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "x"}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "b"}]}], ")"}], " ", "t"}], "-", "x", "+", 
           RowBox[{"2", " ", "b", " ", 
            SuperscriptBox["t", "2"], " ", 
            SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"4", " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{"t", "-", "x", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "2"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{"t", " ", 
               SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "t", " ", "x"}], "-", 
              SuperscriptBox["x", "2"], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "3"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "t"}], " ", "x"}], "-", 
              SuperscriptBox["x", "2"], "+", 
              RowBox[{
               SuperscriptBox["t", "3"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t", " ", "x"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]}], "+", 
    FractionBox[
     RowBox[{"5", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
      SuperscriptBox["t", "3"]}], 
     RowBox[{"8", " ", 
      SubsuperscriptBox["XX", "3", "3"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"a", " ", "b"}]}], ")"}], " ", 
      SuperscriptBox["t", "2"]}], 
     RowBox[{"2", " ", 
      SubsuperscriptBox["XX", "3", "2"]}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SubscriptBox["XX", "3"]}]], 
     RowBox[{"t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"5", " ", "b"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["b", "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"21", " ", "b"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              SuperscriptBox["t", "3"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"12", " ", 
            SuperscriptBox["b", "3"], " ", 
            SuperscriptBox["t", "3"]}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"4", "-", 
              RowBox[{"12", " ", 
               SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"12", " ", "b"}], "+", 
           RowBox[{
            SuperscriptBox["b", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"6", "-", 
              RowBox[{"12", " ", 
               SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "17"}], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["t", "3"], " ", "x", " ", 
     SqrtBox[
      SubscriptBox["XX", "3"]]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
      SuperscriptBox["t", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "t"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "b"}]}], ")"}], " ", "t"}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["XX", "3"]}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SubscriptBox["XX", "3"]}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SubscriptBox["XX", "3"]}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "x", " ", 
       SubsuperscriptBox["XX", "3", "2"]}]], 
     RowBox[{"t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "2"], " ", 
         SubsuperscriptBox["XX", "3", "2"]}], "+", 
        RowBox[{"8", " ", "a", " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"5", " ", "b"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["b", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["XX", "3", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t"}], "-", 
              RowBox[{"9", " ", 
               SubscriptBox["XX", "3"]}]}], ")"}], " ", 
            SubscriptBox["XX", "3"]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["t", "2"]}], "-", 
              RowBox[{"8", " ", "t", " ", 
               SubscriptBox["XX", "3"]}], "+", 
              RowBox[{"84", " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "-", 
              RowBox[{"48", " ", 
               SubsuperscriptBox["XX", "3", "2"]}], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["t", "3"], " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubsuperscriptBox["XX", "3", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "3"], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "t"}], "-", 
              RowBox[{"4", " ", 
               SubscriptBox["XX", "3"]}], "+", 
              RowBox[{"24", " ", 
               SuperscriptBox["t", "2"], " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["t", "2"]}], "+", 
              RowBox[{"8", " ", "t", " ", 
               SubscriptBox["XX", "3"]}], "+", 
              RowBox[{"16", " ", 
               SubsuperscriptBox["XX", "3", "2"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["t", "3"], " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "-", 
              RowBox[{"20", " ", 
               SubsuperscriptBox["XX", "3", "2"]}], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["t", "3"], " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubsuperscriptBox["XX", "3", "2"]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["t", "2"]}], "-", 
              RowBox[{"8", " ", "t", " ", 
               SubscriptBox["XX", "3"]}], "+", 
              RowBox[{"48", " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["b", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               SuperscriptBox["t", "2"]}], "+", 
              RowBox[{"8", " ", "t", " ", 
               SubscriptBox["XX", "3"]}], "+", 
              RowBox[{"24", " ", 
               SubsuperscriptBox["XX", "3", "2"]}], "-", 
              RowBox[{"48", " ", 
               SuperscriptBox["t", "3"], " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "-", 
              RowBox[{"17", " ", 
               SubsuperscriptBox["XX", "3", "2"]}], "+", 
              RowBox[{"8", " ", 
               SuperscriptBox["t", "3"], " ", 
               SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.761273053293816*^9, {3.761273089066814*^9, 3.7612731517079678`*^9}, 
   3.761273187681262*^9, {3.7612732352648573`*^9, 3.7612733188329144`*^9}, 
   3.7612735143749933`*^9, {3.761275925682473*^9, 3.7612760025095587`*^9}, 
   3.761276062919159*^9, 3.761276165716024*^9, 3.7613341224159307`*^9, 
   3.761360762532703*^9, 3.761420924294793*^9, 3.7614435618245*^9, 
   3.761514420454027*^9, 3.767580927035303*^9, {3.7675813304733033`*^9, 
   3.767581365245303*^9}, 3.7675821354463034`*^9, 3.7675834403203034`*^9, 
   3.767644571254936*^9, 3.789158568306108*^9},
 CellLabel->
  "Out[276]=",ExpressionUUID->"ff9f7561-c26a-43ea-8c22-f8d090c060b7"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.761273053293816*^9, {3.761273089066814*^9, 3.7612731517079678`*^9}, 
   3.761273187681262*^9, {3.7612732352648573`*^9, 3.7612733188329144`*^9}, 
   3.7612735143749933`*^9, {3.761275925682473*^9, 3.7612760025095587`*^9}, 
   3.761276062919159*^9, 3.761276165716024*^9, 3.7613341224159307`*^9, 
   3.761360762532703*^9, 3.761420924294793*^9, 3.7614435618245*^9, 
   3.761514420454027*^9, 3.767580927035303*^9, {3.7675813304733033`*^9, 
   3.767581365245303*^9}, 3.7675821354463034`*^9, 3.7675834403203034`*^9, 
   3.767644571254936*^9, 3.789158572932666*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"627a5519-37cd-4ea2-b5be-df22fd5f06b8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"2", ",", "0"}]], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"2", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}]}], "//", "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", 
       RowBox[{"2", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", "addition", " ", "of", " ", "the", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"O", "[", 
        RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}], ")"}], "*", "x", 
     " ", "term", " ", "is", " ", "because", " ", "some", " ", "versions", 
     " ", "of", " ", "Mathematica", " ", "seem", " ", "to", " ", "include", 
     " ", "unwanted", " ", "terms", " ", "when", " ", "expanding", " ", 
     "around", " ", "infinity"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "Infinity", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"O", "[", 
            RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}], ")"}], "*", 
         "x"}]}], ")"}], "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "3"]}]], "\[Rule]", 
       RowBox[{"t", " ", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["XX", "3"], "]"}]}]}]}], "//", "Normal"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"xposRHS2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"%%%", "+", "%"}], "//", "Simplify"}], ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "0"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"2", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"2", ",", "0"}]], 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        RowBox[{"x", "^", "4"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xposRHS2", "/", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}], "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.761273394913179*^9, 3.761273404937079*^9}, {
   3.761273518903373*^9, 3.761273522737348*^9}, {3.761276205686569*^9, 
   3.761276219207013*^9}, {3.766712598698*^9, 3.766712651097*^9}, {
   3.7667135515369997`*^9, 3.766713633657*^9}, {3.7667140474560003`*^9, 
   3.766714083007*^9}, {3.766714127*^9, 3.766714315432*^9}, {
   3.766714484321*^9, 3.76671453312*^9}, {3.7675804906853037`*^9, 
   3.7675805309723034`*^9}, {3.767581307266303*^9, 3.7675813178343034`*^9}, 
   3.767586281205303*^9, 3.7675863778623037`*^9, {3.7676445943528833`*^9, 
   3.7676446067186203`*^9}, 3.767644650719307*^9},
 CellLabel->
  "In[281]:=",ExpressionUUID->"03977d6c-cfbd-41ce-95f3-9d45b80edb12"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", "b"}], ")"}], " ", "c", " ", 
  SubscriptBox["Q", 
   RowBox[{"2", ",", "0"}]], " ", 
  SuperscriptBox["t", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "2"}], "+", "a", "+", "b", "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}], "x"], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "x"}], "-", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", "x"}], ")"}]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "b"}]}], ")"}], " ", "t"}], "-", "x", "+", 
         RowBox[{"2", " ", "b", " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}]}], 
     RowBox[{"x", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox["x", 
         SubscriptBox["XX", "3"]]}]]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}], 
     RowBox[{"2", " ", 
      SubscriptBox["XX", "3"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.761273407433805*^9, 3.761273427379723*^9}, 
   3.7612735241453857`*^9, 3.761276220543497*^9, 3.761334127473193*^9, 
   3.7613607677807837`*^9, 3.761420929178987*^9, 3.761443566549341*^9, 
   3.7615144251403923`*^9, 3.7675809322733035`*^9, 3.7675812674973035`*^9, {
   3.7675813086703033`*^9, 3.7675813207153034`*^9}, 3.7675821402343035`*^9, 
   3.767583445377303*^9, 3.7675862828403034`*^9, 3.767586378547303*^9, 
   3.767644612797154*^9, 3.767644657664425*^9, 3.789158573488336*^9},
 CellLabel->
  "Out[285]=",ExpressionUUID->"b63ead01-9a39-40b9-b30f-d1ae109f1e00"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761273407433805*^9, 3.761273427379723*^9}, 
   3.7612735241453857`*^9, 3.761276220543497*^9, 3.761334127473193*^9, 
   3.7613607677807837`*^9, 3.761420929178987*^9, 3.761443566549341*^9, 
   3.7615144251403923`*^9, 3.7675809322733035`*^9, 3.7675812674973035`*^9, {
   3.7675813086703033`*^9, 3.7675813207153034`*^9}, 3.7675821402343035`*^9, 
   3.767583445377303*^9, 3.7675862828403034`*^9, 3.767586378547303*^9, 
   3.767644612797154*^9, 3.767644657664425*^9, 3.789158573568675*^9},
 CellLabel->
  "Out[289]=",ExpressionUUID->"b68f58f9-14ef-45d9-8cd1-eb0eaf36eafb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"3", ",", "0"}]], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"3", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}]}], "//", "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", 
       RowBox[{"3", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", "addition", " ", "of", " ", "the", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"O", "[", 
        RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}], ")"}], "*", "x", 
     " ", "term", " ", "is", " ", "because", " ", "some", " ", "versions", 
     " ", "of", " ", "Mathematica", " ", "seem", " ", "to", " ", "include", 
     " ", "unwanted", " ", "terms", " ", "when", " ", "expanding", " ", 
     "around", " ", "infinity"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "Infinity", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"O", "[", 
            RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}], ")"}], "*", 
         "x"}]}], ")"}], "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "3"]}]], "\[Rule]", 
       RowBox[{"t", " ", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["XX", "3"], "]"}]}]}]}], "//", "Normal"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"xposRHS3", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"%%%", "+", "%"}], "//", "Simplify"}], ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"3", ",", "0"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"3", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"3", ",", "0"}]], 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        RowBox[{"x", "^", "4"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xposRHS3", "/", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}], "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.761273418122064*^9, 3.76127343056679*^9}, {
  3.76127352671111*^9, 3.761273529712302*^9}, {3.761276225092909*^9, 
  3.761276235328212*^9}, {3.767581383823303*^9, 3.7675813872393036`*^9}, {
  3.76764462126375*^9, 3.767644621432789*^9}},
 CellLabel->
  "In[290]:=",ExpressionUUID->"536a099a-0a40-442b-a03c-51f6d0c4bbbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
  SubscriptBox["Q", 
   RowBox[{"3", ",", "0"}]], " ", 
  SuperscriptBox["t", "3"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", "t"}], "x"], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "x"}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", 
           RowBox[{"2", " ", "b", " ", "t"}], "+", "x", "-", 
           RowBox[{"2", " ", "b", " ", 
            SuperscriptBox["t", "2"], " ", 
            SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"x", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox["x", 
         SubscriptBox["XX", "3"]]}]]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", 
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", 
         RowBox[{"2", " ", "b", " ", "t"}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"]}]}], ")"}]}]}], 
     SubscriptBox["XX", "3"]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.7612734241400957`*^9, 3.761273431225843*^9}, 
   3.76127353081334*^9, 3.761276236070682*^9, 3.761334127863502*^9, 
   3.7613607682161503`*^9, 3.761420929608664*^9, 3.7614435669764557`*^9, 
   3.761514425554934*^9, 3.7675809330123034`*^9, 3.7675813888883038`*^9, 
   3.7675821449023037`*^9, 3.7675834459083033`*^9, 3.7676446394267797`*^9, 
   3.789158573793302*^9},
 CellLabel->
  "Out[294]=",ExpressionUUID->"10c34935-1b67-44eb-b8ce-4d782e0c72a6"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7612734241400957`*^9, 3.761273431225843*^9}, 
   3.76127353081334*^9, 3.761276236070682*^9, 3.761334127863502*^9, 
   3.7613607682161503`*^9, 3.761420929608664*^9, 3.7614435669764557`*^9, 
   3.761514425554934*^9, 3.7675809330123034`*^9, 3.7675813888883038`*^9, 
   3.7675821449023037`*^9, 3.7675834459083033`*^9, 3.7676446394267797`*^9, 
   3.789158573977908*^9},
 CellLabel->
  "Out[298]=",ExpressionUUID->"83b4a0a2-5fad-41b5-9a17-dd718ae5e5c8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "now", " ", "the", " ", "constant", " ", "term", " ", "and", " ", "the", 
     " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "coefficient", " ", "are", " ", 
     "not", " ", "so", " ", "nice"}], ",", " ", 
    RowBox[{
     RowBox[{"since", " ", "they", " ", "contain", " ", "non"}], "-", 
     RowBox[{"algebraic", " ", "terms"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"in", " ", "particular", " ", "\[Nu]", " ", "and", " ", 
    SubscriptBox["\[Nu]", 
     RowBox[{"0", ",", "0"}]], " ", "cause", " ", "trouble", " ", "because", 
    " ", "they", " ", "lead", " ", "to", " ", 
    RowBox[{"(", 
     RowBox[{"series", " ", "with", " ", 
      RowBox[{"1", "/", "x"}], " ", "coefficients"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"series", " ", "with", " ", "x", " ", "coefficients"}], ")"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "the", " ", "best", " ", "we", " ", "can", " ", "do", " ", "is",
     " ", "give", " ", "them", " ", "a", " ", "name", " ", "or", " ", 
    "evaluate", " ", "them", " ", "manually"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7612735774983473`*^9, 3.7612736198154497`*^9}, {
  3.761273704619533*^9, 3.761273787071142*^9}, {3.761273945396247*^9, 
  3.761274017890396*^9}, {3.7612740581670237`*^9, 3.76127408695639*^9}},
 CellLabel->
  "In[299]:=",ExpressionUUID->"415be329-0275-40fc-9620-351c65493371"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "constant", " ", "term"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xposRHS4s", "[", "N_", "]"}], ":=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Factor", "[", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "]"}],
       "&"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Mu]", "/", 
         RowBox[{"x", "^", "4"}]}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Nu]", "/", 
         RowBox[{"x", "^", "4"}]}], "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", "0"], 
          SubscriptBox["\[CapitalDelta]", "m"]}], "]"}]}]}], "/.", 
      RowBox[{"\[Theta]", "\[Rule]", 
       RowBox[{"\[Theta]s", "[", "N", "]"}]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761274109051529*^9, 3.7612742618578367`*^9}, {
  3.761274538760294*^9, 3.761274592308329*^9}, {3.761274623731533*^9, 
  3.76127465082054*^9}, {3.7618884753100348`*^9, 3.761888505174034*^9}, {
  3.7618885428890343`*^9, 3.7618885451030345`*^9}, {3.7618887784150343`*^9, 
  3.7618887791420345`*^9}},
 CellLabel->
  "In[300]:=",ExpressionUUID->"5c5dfa3d-4cb6-40ac-89c2-9bd9d7afad0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}], " ", "term"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xposRHS5s", "[", "N_", "]"}], ":=", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Factor", "[", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "#", "]"}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Exponent", "[", 
             RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], 
        "]"}], "&"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "0"}]], "/", 
          RowBox[{"x", "^", "4"}]}], "/", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", 
           RowBox[{"0", ",", "0"}]], "/", 
          RowBox[{"x", "^", "4"}]}], "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", "0"], 
           SubscriptBox["\[CapitalDelta]", "m"]}], "]"}]}]}], "/.", 
       RowBox[{
        SubscriptBox["\[Theta]", 
         RowBox[{"0", ",", "0"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[Theta]s", 
          RowBox[{"0", ",", "0"}]], "[", "N", "]"}]}]}]}], "]"}], "*", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.761274658211693*^9, 3.761274733576651*^9}, {
   3.7618885538210344`*^9, 3.7618885770290346`*^9}, 3.7618887830400343`*^9},
 CellLabel->
  "In[301]:=",ExpressionUUID->"ac10c33c-ee2e-47b6-8c2e-b816542d5abf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xposRHS4s", "[", "3", "]"}], "\[IndentingNewLine]", 
 RowBox[{"xposRHS5s", "[", "3", "]"}]}], "Input",
 CellChangeTimes->{{3.761274697918376*^9, 3.761274705034768*^9}, {
  3.761334306460812*^9, 3.761334308834092*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"00a15730-a3b5-4525-94a3-9525e2c09a51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", "a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], " ", "x", " ", 
    SuperscriptBox["t", "2"]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "6"}], "+", 
        RowBox[{"7", " ", "a"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"5", " ", "b"}], "-", 
        RowBox[{"7", " ", "a", " ", "b"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}]}], ")"}], " ", 
      SuperscriptBox["x", "2"]}], ")"}], " ", 
    SuperscriptBox["t", "4"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "5"],
    SeriesData[$CellContext`t, 0, {}, 4, 10, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   2 (-1 + $CellContext`a)^2 $CellContext`a $CellContext`b (-2 + \
$CellContext`a + $CellContext`b) $CellContext`x, 0, 0, 
    0, (-2) (-1 + $CellContext`a) $CellContext`a $CellContext`b (-6 + 
     7 $CellContext`a - 2 $CellContext`a^2 + 5 $CellContext`b - 
     7 $CellContext`a $CellContext`b + 
     3 $CellContext`a^2 $CellContext`b - $CellContext`b^2 + $CellContext`a \
$CellContext`b^2) $CellContext`x^2}, 4, 10, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.7612747055794067`*^9, 3.761274737387869*^9, 
  3.761334128550865*^9, 3.761334310424967*^9, 3.76136076892275*^9, 
  3.761420930335614*^9, 3.7614435676890507`*^9, 3.761514426160613*^9, 
  3.7675809334683037`*^9, 3.767581394943303*^9, 3.7675834464113035`*^9, 
  3.7676446723228073`*^9, 3.789158574268355*^9},
 CellLabel->
  "Out[302]=",ExpressionUUID->"33dea26d-176a-42b7-bab5-edec715237f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "a", " ", "b"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"4", " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c"}], "-", 
         RowBox[{"6", " ", "b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "-", 
         RowBox[{"3", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "-", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", "c"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", "x", " ", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], ")"}], " ", 
     SuperscriptBox["t", "2"]}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", "a", " ", "b"}], "+", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{"12", " ", "c"}], "-", 
      RowBox[{"12", " ", "a", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"18", " ", "b", " ", "c"}], "+", 
      RowBox[{"19", " ", "a", " ", "b", " ", "c"}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"11", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", 
    SuperscriptBox["x", "2"], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}], " ", 
    SuperscriptBox["t", "4"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "5"],
    SeriesData[$CellContext`t, 0, {}, 4, 10, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-2) (-1 + $CellContext`a)^2 ((-2) $CellContext`a $CellContext`b + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + 
     4 $CellContext`c + $CellContext`a^2 $CellContext`c - 
     6 $CellContext`b $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c - 2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     4 $CellContext`b^2 $CellContext`c - 
     3 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a^2 \
$CellContext`b^2 $CellContext`c - $CellContext`b^3 $CellContext`c + \
$CellContext`a $CellContext`b^3 $CellContext`c) $CellContext`x $CellContext`Q[
     0, 0], 0, 0, 0, 
    2 (-1 + $CellContext`a) ((-6) $CellContext`a $CellContext`b + 
     7 $CellContext`a^2 $CellContext`b - 2 $CellContext`a^3 $CellContext`b + 
     5 $CellContext`a $CellContext`b^2 - 7 $CellContext`a^2 $CellContext`b^2 + 
     3 $CellContext`a^3 $CellContext`b^2 - $CellContext`a $CellContext`b^3 + \
$CellContext`a^2 $CellContext`b^3 + 12 $CellContext`c - 
     12 $CellContext`a $CellContext`c + 3 $CellContext`a^2 $CellContext`c - 
     18 $CellContext`b $CellContext`c + 
     19 $CellContext`a $CellContext`b $CellContext`c - 
     5 $CellContext`a^2 $CellContext`b $CellContext`c + 
     10 $CellContext`b^2 $CellContext`c - 
     11 $CellContext`a $CellContext`b^2 $CellContext`c + 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`a^3 \
$CellContext`b^2 $CellContext`c - 2 $CellContext`b^3 $CellContext`c + 
     3 $CellContext`a $CellContext`b^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^3 $CellContext`c + $CellContext`a^3 \
$CellContext`b^3 $CellContext`c) $CellContext`x^2 $CellContext`Q[0, 0]}, 4, 
   10, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.7612747055794067`*^9, 3.761274737387869*^9, 
  3.761334128550865*^9, 3.761334310424967*^9, 3.76136076892275*^9, 
  3.761420930335614*^9, 3.7614435676890507`*^9, 3.761514426160613*^9, 
  3.7675809334683037`*^9, 3.767581394943303*^9, 3.7675834464113035`*^9, 
  3.7676446723228073`*^9, 3.789158574482534*^9},
 CellLabel->
  "Out[303]=",ExpressionUUID->"bdee20e8-2e93-4bab-b98a-fcc8f5274b5e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "constructing", " ", "equation", " ", 
    RowBox[{"(", "5.29", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"multiplying", " ", "everything", " ", "by", " ", 
     RowBox[{"x", "^", "4"}], " ", "keeps", " ", "the", " ", "powers", " ", 
     "of", " ", "x", " ", "in", " ", "the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "coefficient", " ", "non"}], "-", 
    "negative"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["P", 
      RowBox[{"x", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "t"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
         RowBox[{"a", " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}], "-", 
        RowBox[{"b", " ", "t"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "t"}], "+", 
        RowBox[{"2", " ", "x"}], "-", 
        RowBox[{"a", " ", "x"}], "-", 
        RowBox[{"b", " ", "x"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "t"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
        RowBox[{"b", " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", 
      RowBox[{"x", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{"x", "^", "4"}], "*", 
      RowBox[{"Factor", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{"xposLHS1", ",", 
          RowBox[{"Q", "[", 
           RowBox[{"x", ",", "0"}], "]"}]}], "]"}], "/", 
        SubscriptBox["P", 
         RowBox[{"x", ",", "0"}]]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", 
      RowBox[{"1", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "4"}], "*", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
          "xposRHS2", "+", "xposRHS3"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]]}], "]"}]}], "//", "Factor"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", 
      RowBox[{"2", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "4"}], "*", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
          "xposRHS2", "+", "xposRHS3"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}], "]"}]}], "//", "Factor"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", 
      RowBox[{"3", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "4"}], "*", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
          "xposRHS2", "+", "xposRHS3"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]]}], "]"}]}], "//", "Factor"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", 
      RowBox[{"4", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "4"}], "*", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
          "xposRHS2", "+", "xposRHS3"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"4", ",", "0"}]]}], "]"}]}], "//", "Factor"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.761334313113237*^9, 3.76133432467467*^9}, {
   3.7613347525229807`*^9, 3.761334775427321*^9}, {3.761334821320788*^9, 
   3.761334910644649*^9}, {3.761334953789974*^9, 3.761334975963996*^9}, {
   3.761335020697138*^9, 3.761335038214232*^9}, {3.761335291278007*^9, 
   3.761335487312511*^9}, {3.76133572634587*^9, 3.761335762763526*^9}, {
   3.761335810014412*^9, 3.761335811554781*^9}, {3.76133608885296*^9, 
   3.76133608949391*^9}, {3.7613370041168327`*^9, 3.761337064877527*^9}, {
   3.761337098676462*^9, 3.761337099101507*^9}, 3.761348557031187*^9, {
   3.7613574074146338`*^9, 3.761357425942794*^9}, {3.761360397221444*^9, 
   3.761360405758325*^9}, {3.76136043668896*^9, 3.76136044492065*^9}, {
   3.761360532448845*^9, 3.761360535081222*^9}, {3.761361893378049*^9, 
   3.761361902014164*^9}, {3.761361950008314*^9, 3.761361990125729*^9}, {
   3.7613621087725983`*^9, 3.7613621189533453`*^9}, {3.761423012277567*^9, 
   3.761423015333684*^9}, {3.7618880561030345`*^9, 3.7618880583170347`*^9}, {
   3.789158338301407*^9, 3.789158339288538*^9}},
 CellLabel->
  "In[304]:=",ExpressionUUID->"7f1eb6d0-d138-480f-8bdf-f95852a4e9af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "these", " ", "are", " ", "unwieldy", " ", "and", " ", "it", " ", "will", 
    " ", "be", " ", "more", " ", "useful", " ", "to", " ", "have", " ", 
    "series", " ", "expansions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", " ", "define", " ", "these"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
     SubscriptBox["Xs", "1"], ",", 
     SubscriptBox["Xs", "2"], ",", 
     SubscriptBox["Xs", "3"], ",", 
     SubscriptBox["\[Sigma]s", 
      RowBox[{"x", ",", "0"}]], ",", 
     SubscriptBox["\[Sigma]s", 
      RowBox[{"1", ",", "0"}]], ",", 
     SubscriptBox["\[Sigma]s", 
      RowBox[{"2", ",", "0"}]], ",", 
     SubscriptBox["\[Sigma]s", 
      RowBox[{"3", ",", "0"}]], ",", "\[Sigma]s", ",", 
     SubscriptBox["\[Sigma]s", 
      RowBox[{"0", ",", "0"}]], ",", "xpos00"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Xs", "1"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["Xs", "1"], "[", "n", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["X", "1"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Xs", "2"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["Xs", "2"], "[", "n", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["X", "2"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Xs", "3"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["Xs", "3"], "[", "n", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["X", "3"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "then", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]s", 
      RowBox[{"x", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]s", 
       RowBox[{"x", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Sigma]", 
           RowBox[{"x", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"t", ">", "0"}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]s", 
      RowBox[{"1", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]s", 
       RowBox[{"1", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Sigma]", 
           RowBox[{"1", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"t", ">", "0"}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]s", 
      RowBox[{"2", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]s", 
       RowBox[{"2", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Sigma]", 
           RowBox[{"2", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"t", ">", "0"}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]s", 
      RowBox[{"3", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]s", 
       RowBox[{"3", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Sigma]", 
           RowBox[{"3", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"t", ">", "0"}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     SubscriptBox["\[Sigma]", 
      RowBox[{"4", ",", "0"}]], " ", "is", " ", "a", " ", "polynomial", " ", 
     "so", " ", "we", " ", 
     RowBox[{"don", "'"}], "t", " ", "need", " ", "to", " ", "do", " ", 
     "anything", " ", "with", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"these", " ", "will", " ", "also", " ", "be", " ", "useful"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xpos00", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"xpos00", "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
            "xposRHS2", "+", "xposRHS3"}], ",", 
           RowBox[{"Q", "[", 
            RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["XX", "1"], "\[Rule]", 
            RowBox[{
             SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
           RowBox[{
            SubscriptBox["XX", "2"], "\[Rule]", 
            RowBox[{
             SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
           RowBox[{
            SubscriptBox["XX", "3"], "\[Rule]", 
            RowBox[{
             SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "/.", 
        RowBox[{
         SqrtBox[
          FractionBox["1", 
           SuperscriptBox["t", "2"]]], "\[Rule]", 
         RowBox[{"1", "/", "t"}]}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "then", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]s", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Sigma]s", "[", "n", "]"}], "=", 
     RowBox[{
      RowBox[{"x", "^", "4"}], "*", 
      RowBox[{"ApplyToSeries", "[", 
       RowBox[{"Factor", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"xposRHS4s", "[", "n", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "//", 
         "Simplificate"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]s", 
      RowBox[{"0", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Sigma]s", 
       RowBox[{"0", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{
      RowBox[{"x", "^", "4"}], "*", 
      RowBox[{"ApplyToSeries", "[", 
       RowBox[{"Factor", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"xposRHS5s", "[", "n", "]"}], "/", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"xpos00", "[", "n", "]"}]}], ")"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "//", 
         "Simplificate"}]}], "]"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.761337107792008*^9, 3.761337225552265*^9}, {
  3.761337263657757*^9, 3.761337299893963*^9}, {3.761337352815637*^9, 
  3.761337678046372*^9}, {3.761337709908844*^9, 3.7613377151111183`*^9}, {
  3.761339225544986*^9, 3.7613393136680603`*^9}, {3.76133956965479*^9, 
  3.761339679837667*^9}, {3.761339844599041*^9, 3.761339853157937*^9}, {
  3.761339891106485*^9, 3.7613398963815327`*^9}, {3.761353866443439*^9, 
  3.7613538673224373`*^9}, {3.761357442022081*^9, 3.761357446128152*^9}, {
  3.7613604706971407`*^9, 3.7613604763103037`*^9}, {3.761360544465372*^9, 
  3.7613605524965553`*^9}, {3.7613613618746977`*^9, 3.761361362447571*^9}, {
  3.761362008792951*^9, 3.7613620103781424`*^9}, {3.76142298888971*^9, 
  3.761423009825027*^9}},
 CellLabel->
  "In[310]:=",ExpressionUUID->"bf9cb6d8-0e7e-4468-a650-4b11015fcd54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[Sigma]s", 
          RowBox[{"x", ",", "0"}]], "[", "9", "]"}]}], 
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"1", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"2", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"3", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Sigma]", 
        RowBox[{"4", ",", "0"}]], 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]]}], "+", 
      RowBox[{"\[Sigma]s", "[", "9", "]"}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"0", ",", "0"}]], "[", "9", "]"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"9", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "//", "Simplificate"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", "%"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761336105752247*^9, 3.761336237315196*^9}, {
  3.761336270153955*^9, 3.761336276284273*^9}, {3.761336318643224*^9, 
  3.7613363515436497`*^9}, {3.761336452047463*^9, 3.761336457153288*^9}, {
  3.761336677175458*^9, 3.76133668117857*^9}, {3.7613367568034267`*^9, 
  3.761336758658361*^9}, {3.7613368515463142`*^9, 3.7613368541987658`*^9}, {
  3.761337790312563*^9, 3.761337904493705*^9}, {3.761338239600178*^9, 
  3.76133825337184*^9}, {3.761338374128883*^9, 3.761338378553985*^9}, {
  3.7613399302278843`*^9, 3.761339970139532*^9}, {3.7613400085734787`*^9, 
  3.761340012091359*^9}, {3.7613401234168167`*^9, 3.76134012653986*^9}, {
  3.7613408014977293`*^9, 3.7613408068439713`*^9}, {3.761360500909663*^9, 
  3.761360516527664*^9}, {3.761360560529306*^9, 3.761360560696986*^9}, {
  3.761360857603859*^9, 3.761360873534505*^9}, {3.761423026678376*^9, 
  3.761423032067843*^9}},
 CellLabel->
  "In[321]:=",ExpressionUUID->"1d276147-5b4d-4589-87ee-25a20f1455dd"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.761336115342319*^9, 3.761336147077964*^9, 3.76133626188037*^9, 
   3.761336297977717*^9, 3.761336340275661*^9, 3.7613363752329407`*^9, 
   3.7613364733517237`*^9, 3.761336699021734*^9, 3.7613368407494907`*^9, 
   3.761337010221602*^9, {3.761337831689023*^9, 3.761337893509508*^9}, 
   3.761337936640511*^9, 3.761338250725032*^9, 3.7613383395726643`*^9, 
   3.761338514010565*^9, 3.761339069504855*^9, {3.7613399381783037`*^9, 
   3.761339960258367*^9}, 3.761339995152713*^9, 3.761340048309104*^9, 
   3.7613402076359367`*^9, 3.761340910009012*^9, 3.76134866797406*^9, 
   3.761357555640421*^9, {3.761360509170513*^9, 3.761360519351115*^9}, {
   3.761360844942232*^9, 3.761360882104149*^9}, 3.761362022003953*^9, 
   3.76142093719737*^9, 3.761423044035427*^9, 3.761443574149231*^9, 
   3.761514432548171*^9, 3.767580938632303*^9, 3.7675814042703037`*^9, 
   3.7675834509683037`*^9, 3.767644704105744*^9, 3.789158586665666*^9},
 CellLabel->
  "Out[323]=",ExpressionUUID->"a5be4ae7-a134-4031-98ff-c6efb63f0c4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"next", " ", "for", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], "<"}], "]"}], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "things", " ", "will", " ", "be", " ", "simplest", " ", "if", " ", "we", 
    " ", "divide", " ", "by", " ", 
    RowBox[{"x", "^", "5"}], " ", "first"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"start", " ", "with", " ", "the", " ", 
    SubsuperscriptBox["Q", "0", "d"], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], "/", 
      RowBox[{"x", "^", "5"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "Infinity", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "*", "x", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]], "/", "x"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"t", ">", "0"}], "&&", 
        RowBox[{"x", ">", "0"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegLHS1", "=", 
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Nu]", "0", "d"], "/", 
        RowBox[{"x", "^", "5"}]}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}], "*", 
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
      RowBox[{"QQdkeval", "[", 
       RowBox[{"9", ",", "0", ",", 
        RowBox[{"1", "/", "x"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xnegLHS1", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"9", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"t", ">", "0"}], "&&", 
        RowBox[{"x", ">", "0"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.761348708799693*^9, 3.76134871666852*^9}, {
  3.761349179859809*^9, 3.761349186157892*^9}, {3.761349222900869*^9, 
  3.761349357340674*^9}, {3.761349490892592*^9, 3.761349497068058*^9}, {
  3.761349589602804*^9, 3.761349589689601*^9}, {3.761349635615836*^9, 
  3.7613498248416357`*^9}, {3.7613500628514214`*^9, 3.761350277743325*^9}, {
  3.7675815155643034`*^9, 3.7675815171293035`*^9}, {3.7675816723153033`*^9, 
  3.7675816736283035`*^9}, {3.7675819501163034`*^9, 3.7675819637693033`*^9}},
 CellLabel->
  "In[324]:=",ExpressionUUID->"d6b8cc59-9f8a-4a73-aee0-3efa53cf90c5"],

Cell[BoxData[
 RowBox[{"4", " ", "a", " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     SuperscriptBox["t", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "b"}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "b"}], "+", 
             RowBox[{"a", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox["t", "3"]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["XX", "1"], "+", 
          SubscriptBox["XX", "2"]}], ")"}]}]}], ")"}], " ", 
     SqrtBox[
      SubscriptBox["XX", "3"]], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "5"], " ", 
     SqrtBox[
      SubscriptBox["XX", "3"]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "-", 
         RowBox[{"a", " ", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], " ", "t"}]}], 
        RowBox[{"a", " ", "t"}]], "+", 
       RowBox[{"x", " ", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", "x"}], ")"}]}], "+", "x"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", "x"}], ")"}]}], "+", "x"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "t", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"t", " ", 
            SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "t", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"t", " ", 
            SuperscriptBox["x", "2"]}]}], ")"}]}]}], ")"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          SubscriptBox["XX", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", 
          SubscriptBox["XX", "2"]}], ")"}], " ", 
        SubscriptBox["XX", "3"]}]], " ", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], 
     SuperscriptBox["x", "6"]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.761349269347596*^9, 3.7613493044716673`*^9}, {
   3.761349340563284*^9, 3.7613493607709923`*^9}, 3.761349500486992*^9, 
   3.76134959081948*^9, 3.761349649948963*^9, {3.761349749509254*^9, 
   3.761349825772539*^9}, {3.761350125286317*^9, 3.761350164981906*^9}, {
   3.761350210413315*^9, 3.761350279910016*^9}, 3.761360900778886*^9, 
   3.761420937998185*^9, 3.7614435750507298`*^9, 3.761514433409204*^9, 
   3.7675809394703035`*^9, 3.7675814191833034`*^9, 3.7675815187203035`*^9, 
   3.7675816755843034`*^9, 3.7675821561233034`*^9, 3.767583451844303*^9, 
   3.7675864110003033`*^9, 3.7676447193498487`*^9, 3.789158587457842*^9},
 CellLabel->
  "Out[327]=",ExpressionUUID->"9a1bbb64-a0a5-4f65-89b2-d4c88c50a764"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761349269347596*^9, 3.7613493044716673`*^9}, {
   3.761349340563284*^9, 3.7613493607709923`*^9}, 3.761349500486992*^9, 
   3.76134959081948*^9, 3.761349649948963*^9, {3.761349749509254*^9, 
   3.761349825772539*^9}, {3.761350125286317*^9, 3.761350164981906*^9}, {
   3.761350210413315*^9, 3.761350279910016*^9}, 3.761360900778886*^9, 
   3.761420937998185*^9, 3.7614435750507298`*^9, 3.761514433409204*^9, 
   3.7675809394703035`*^9, 3.7675814191833034`*^9, 3.7675815187203035`*^9, 
   3.7675816755843034`*^9, 3.7675821561233034`*^9, 3.767583451844303*^9, 
   3.7675864110003033`*^9, 3.7676447193498487`*^9, 3.789158602948897*^9},
 CellLabel->
  "Out[332]=",ExpressionUUID->"a2a786f4-4b28-442e-b84c-7e29594bd48e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "for", " ", "the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"x", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "5"}]}], "}"}]}], "]"}], "/", 
       RowBox[{"x", "^", "5"}]}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "*", "x"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], "*", 
         RowBox[{"x", "^", "2"}]}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]], "*", 
         RowBox[{"x", "^", "3"}]}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"4", ",", "0"}]], "*", 
         RowBox[{"x", "^", "4"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "4"}]}], "}"}]}], "]"}], "/", 
       RowBox[{"x", "^", "4"}]}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "*", "x"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], "*", 
         RowBox[{"x", "^", "2"}]}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"3", ",", "0"}]], "*", 
         RowBox[{"x", "^", "3"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "3"}]}], "}"}]}], "]"}], "/", 
       RowBox[{"x", "^", "3"}]}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "*", "x"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], "*", 
         RowBox[{"x", "^", "2"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "2"}]}], "}"}]}], "]"}], "/", 
       RowBox[{"x", "^", "2"}]}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "*", "x"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], "/", "x"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegLHS2", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"x", ",", "0"}]], "/", 
         RowBox[{"x", "^", "5"}]}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcy", "[", 
       RowBox[{"9", ",", "0"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xnegLHS2", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7613495139232492`*^9, 3.7613495552198353`*^9}, 
   3.761349596892517*^9, {3.761349830942615*^9, 3.761349858715596*^9}, {
   3.76134989253454*^9, 3.761350051522794*^9}, {3.761350282311554*^9, 
   3.761350441711359*^9}, {3.76135065282446*^9, 3.7613506910613737`*^9}},
 CellLabel->
  "In[333]:=",ExpressionUUID->"ba0a482d-7ea3-4c30-9e6a-6943cb4d00c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "a", " ", "c", " ", 
     SubscriptBox["Q", 
      RowBox[{"4", ",", "0"}]], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "-", 
       RowBox[{"b", " ", "t"}], "+", 
       RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], "x"]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"3", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "c", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "-", 
          RowBox[{"b", " ", "t"}], "+", 
          RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
       SuperscriptBox["x", "2"]]}], "-", 
     RowBox[{
      FractionBox["1", "x"], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "c", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "-", 
          RowBox[{"b", " ", "t"}], "+", 
          RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
       SuperscriptBox["x", "4"]]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "3"]], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", "x"], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "b", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "a"}], ")"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"5", " ", "a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"16", " ", 
           SubsuperscriptBox["XX", "3", "3"]}]], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "-", 
                RowBox[{"b", " ", "t"}], "+", 
                RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                   RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "-", 
                   RowBox[{"b", " ", "t"}], "+", 
                   RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}], 
          RowBox[{"8", " ", 
           SubsuperscriptBox["XX", "3", "2"]}]], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"2", " ", 
            SubscriptBox["XX", "3"]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "b"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", "b", " ", 
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox["a", "3"], " ", 
                   SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "2"]], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "b", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"3", " ", "a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"8", " ", 
           SubsuperscriptBox["XX", "3", "2"]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], " ", "t"}], "+", 
              RowBox[{
               SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], " ", "t"}], "-", 
              RowBox[{"b", " ", "t"}], "+", 
              RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], " ", "t"}], "+", 
              RowBox[{
               SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], " ", "t"}], "+", 
                 RowBox[{
                  SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], " ", "t"}], "-", 
                 RowBox[{"b", " ", "t"}], "+", 
                 RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "a"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "c", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "-", 
          RowBox[{"b", " ", "t"}], "+", 
          RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
       SuperscriptBox["x", "3"]]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "2"]], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", "x"], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "b", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"3", " ", "a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"8", " ", 
           SubsuperscriptBox["XX", "3", "2"]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], " ", "t"}], "+", 
              RowBox[{
               SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], " ", "t"}], "-", 
              RowBox[{"b", " ", "t"}], "+", 
              RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], " ", "t"}], "+", 
              RowBox[{
               SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], " ", "t"}], "+", 
                 RowBox[{
                  SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], " ", "t"}], "-", 
                 RowBox[{"b", " ", "t"}], "+", 
                 RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "a"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "c", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "-", 
          RowBox[{"b", " ", "t"}], "+", 
          RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", "t"}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
       SuperscriptBox["x", "5"]]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "4"]], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "2"]], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "b", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "a"}], ")"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"5", " ", "a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"16", " ", 
           SubsuperscriptBox["XX", "3", "3"]}]], "+", 
         FractionBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "-", 
                RowBox[{"b", " ", "t"}], "+", 
                RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                   RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "-", 
                   RowBox[{"b", " ", "t"}], "+", 
                   RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}], 
          RowBox[{"8", " ", 
           SubsuperscriptBox["XX", "3", "2"]}]], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"2", " ", 
            SubscriptBox["XX", "3"]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "b"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", "b", " ", 
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox["a", "3"], " ", 
                   SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", "x"], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "a"}], ")"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "b", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "a"}], ")"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"35", " ", "a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"128", " ", 
           SubsuperscriptBox["XX", "3", "4"]}]], "+", 
         FractionBox[
          RowBox[{"5", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "-", 
                RowBox[{"b", " ", "t"}], "+", 
                RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                   RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "-", 
                   RowBox[{"b", " ", "t"}], "+", 
                   RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}], 
          RowBox[{"16", " ", 
           SubsuperscriptBox["XX", "3", "3"]}]], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"8", " ", 
            SubsuperscriptBox["XX", "3", "2"]}]], 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "a"}], " ", "t"}], "-", 
                RowBox[{"b", " ", "t"}], "+", 
                RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "b"}], " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["a", "2"], " ", "b", " ", 
                 SuperscriptBox["t", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                   RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "-", 
                   RowBox[{"b", " ", "t"}], "+", 
                   RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
                   RowBox[{
                    SuperscriptBox["a", "3"], " ", 
                    SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "b"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                   RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "-", 
                   RowBox[{"b", " ", "t"}], "+", 
                   RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"2", " ", 
            SubscriptBox["XX", "3"]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", "b", " ", 
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox["a", "3"], " ", 
                   SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "b"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                SuperscriptBox["a", "2"], " ", 
                SuperscriptBox["t", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox["a", "3"], " ", 
                   SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", 
                SuperscriptBox["t", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "-", 
                  RowBox[{"b", " ", "t"}], "+", 
                  RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "a"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "3"]], 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "b"}], " ", "t"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "b", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], "2"], "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"(", 
              RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], " ", "t"}], "-", 
               RowBox[{"b", " ", "t"}], "+", 
               RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "a"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "a"}], " ", "t"}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{"3", " ", "a", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "a"}], " ", "t"}], "-", 
             RowBox[{"b", " ", "t"}], "+", 
             RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], " ", "t"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "t"}]}], ")"}]}], 
          RowBox[{"8", " ", 
           SubsuperscriptBox["XX", "3", "2"]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "b"}], ")"}], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], " ", "t"}], "+", 
              RowBox[{
               SuperscriptBox["a", "2"], " ", "t"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], " ", "t"}], "-", 
              RowBox[{"b", " ", "t"}], "+", 
              RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], " ", "t"}], "+", 
              RowBox[{
               SuperscriptBox["b", "2"], " ", "t"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", "a", "-", "b"}], ")"}], " ", "t", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], " ", "t"}], "+", 
                 RowBox[{
                  SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], " ", "t"}], "-", 
                 RowBox[{"b", " ", "t"}], "+", 
                 RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "a"}], ")"}], " ", "a", " ", "t"}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "a"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "a"}], " ", "t"}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", "t"}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], 
          RowBox[{"2", " ", 
           SubscriptBox["XX", "3"]}]]}], ")"}]}]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.761349548227723*^9, 3.761349555900321*^9}, 
   3.761349597368875*^9, {3.76135004165968*^9, 3.761350052646137*^9}, 
   3.761350334817325*^9, 3.761350397938149*^9, 3.761350455783473*^9, {
   3.7613506539968767`*^9, 3.761350691994329*^9}, 3.7613609138828897`*^9, 
   3.761420954583968*^9, 3.761443587421756*^9, 3.7615144453598967`*^9, 
   3.767580989205303*^9, 3.7675817248083034`*^9, 3.767583494075303*^9, 
   3.767644742541485*^9, 3.789158603205832*^9},
 CellLabel->
  "Out[335]=",ExpressionUUID->"36bd8ae9-ddcd-4366-8b1a-14a51d8f0b58"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761349548227723*^9, 3.761349555900321*^9}, 
   3.761349597368875*^9, {3.76135004165968*^9, 3.761350052646137*^9}, 
   3.761350334817325*^9, 3.761350397938149*^9, 3.761350455783473*^9, {
   3.7613506539968767`*^9, 3.761350691994329*^9}, 3.7613609138828897`*^9, 
   3.761420954583968*^9, 3.761443587421756*^9, 3.7615144453598967`*^9, 
   3.767580989205303*^9, 3.7675817248083034`*^9, 3.767583494075303*^9, 
   3.767644742541485*^9, 3.7891586037244987`*^9},
 CellLabel->
  "Out[339]=",ExpressionUUID->"0485db38-684a-457c-8d6b-30d7fac5ecd0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"1", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Series", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], ")"}], "//", "Normal"}], "//",
      "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", 
       RowBox[{"1", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"O", "[", 
      RowBox[{"x", ",", "Infinity"}], "]"}], " ", "term", " ", "is", " ", 
     "to", " ", "deal", " ", "with", " ", "some", " ", "versions", " ", "of", 
     " ", "Mathematica", " ", "including", " ", "unwanted", " ", "things"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", 
     RowBox[{"(", 
      RowBox[{"Normal", "[", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"%", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", 
          RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}]}], "]"}], ")"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%%", "+", "%"}], ")"}], "*", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "//", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"#", ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{
          RowBox[{"t", ">", "0"}], "&&", 
          RowBox[{"x", ">", "0"}]}]}]}], "]"}], "&"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"1", ",", "0"}]], 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        RowBox[{"x", "^", "5"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xnegRHS1", "/", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"t", ">", "0"}], "&&", 
        RowBox[{"x", ">", "0"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7613506989826736`*^9, 3.761350707743919*^9}, {
   3.761350776270144*^9, 3.7613508271646442`*^9}, {3.761350884599642*^9, 
   3.761350907357087*^9}, {3.761350937441443*^9, 3.761351052742651*^9}, {
   3.761351087676675*^9, 3.761351193144711*^9}, {3.7613515430274887`*^9, 
   3.761351757375287*^9}, {3.7613518039184027`*^9, 3.7613518248873243`*^9}, {
   3.761352077028985*^9, 3.761352084315712*^9}, {3.7613521173951273`*^9, 
   3.761352119480804*^9}, {3.7613521604031754`*^9, 3.761352162427486*^9}, {
   3.7675805811503034`*^9, 3.7675805921033034`*^9}, {3.7675823523553033`*^9, 
   3.7675823633933034`*^9}, {3.767582437639303*^9, 3.7675824595773034`*^9}, {
   3.767582493851303*^9, 3.7675824962763033`*^9}, 3.7675825289473033`*^9, {
   3.7675825929873037`*^9, 3.7675826237293034`*^9}, {3.7675826551363034`*^9, 
   3.767582656825303*^9}, {3.7675828047463036`*^9, 3.7675828193453035`*^9}, {
   3.7675832130923033`*^9, 3.7675832157463036`*^9}, 3.7675874705963035`*^9, {
   3.7675876190433035`*^9, 3.7675876310363035`*^9}, {3.7675879287553034`*^9, 
   3.767587967457303*^9}, 3.767651005185837*^9, {3.767651262616593*^9, 
   3.767651336225466*^9}},
 CellLabel->
  "In[340]:=",ExpressionUUID->"2365ba72-0227-4c3a-9a9d-e7650ce12b52"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", "c", " ", 
  SubscriptBox["Q", 
   RowBox[{"1", ",", "0"}]], " ", "t", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"32", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
     SuperscriptBox["t", "3"], " ", 
     SqrtBox[
      SubscriptBox["XX", "3"]]}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["x", "4"]], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "t"}], " ", "x"}], "-", 
              SuperscriptBox["x", "2"], "+", 
              RowBox[{
               SuperscriptBox["t", "3"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t", " ", "x"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{"t", "-", "x", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "2"], " ", 
               SuperscriptBox["x", "2"]}], "-", 
              RowBox[{"t", " ", 
               SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t", " ", "x"}], "+", 
              SuperscriptBox["x", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "3"], " ", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          SubscriptBox["XX", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", 
          SubscriptBox["XX", "2"]}], ")"}], " ", 
        SubscriptBox["XX", "3"]}]]}]}], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["x", "4"], " ", 
       SubsuperscriptBox["XX", "3", "3"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
        SuperscriptBox["x", "2"], " ", 
        SubsuperscriptBox["XX", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "x", " ", 
           SubscriptBox["XX", "3"]}], "+", 
          RowBox[{"2", " ", "b", " ", "x", " ", 
           SubscriptBox["XX", "3"]}], "+", 
          RowBox[{"b", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{"x", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"8", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
        SuperscriptBox["x", "2"], " ", 
        SubsuperscriptBox["XX", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", "b"}]}], ")"}], " ", "x", " ", 
           SubscriptBox["XX", "3"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"4", " ", "b"}]}], ")"}], " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{"x", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["x", "2"], " ", 
           SubsuperscriptBox["XX", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "x", " ", 
              SubscriptBox["XX", "3"]}], "+", 
             RowBox[{"t", " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["x", "3"], " ", 
              SubsuperscriptBox["XX", "3", "3"]}], "-", 
             RowBox[{"20", " ", "t", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["t", "4"], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 SuperscriptBox["x", "3"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
          "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "3"], " ", 
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"24", " ", 
              SuperscriptBox["t", "2"], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", "x", " ", 
              SubscriptBox["XX", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{"4", " ", "x", " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
             RowBox[{"t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox["x", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"5", "-", 
                   RowBox[{"32", " ", 
                    SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "-", 
             RowBox[{"48", " ", 
              SuperscriptBox["t", "3"], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"4", " ", "t", " ", "x", " ", 
              SubscriptBox["XX", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{"4", " ", "x", " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["t", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "6"}], " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "-", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "-", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox["x", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", 
                   RowBox[{"16", " ", 
                    SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           SuperscriptBox["x", "3"], " ", 
           SubsuperscriptBox["XX", "3", "3"]}], "+", 
          RowBox[{"4", " ", "b", " ", "x", " ", 
           SubscriptBox["XX", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"22", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"]}], "+", 
             RowBox[{"9", " ", "t", " ", "x", " ", 
              SubscriptBox["XX", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["t", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{"4", " ", "x", " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}]}], ")"}]}], 
          "-", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", 
              SuperscriptBox["x", "3"], " ", 
              SubsuperscriptBox["XX", "3", "3"]}], "-", 
             RowBox[{"48", " ", "t", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["t", "4"], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 SuperscriptBox["x", "3"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "88"}], " ", 
              SuperscriptBox["x", "3"], " ", 
              SubsuperscriptBox["XX", "3", "3"]}], "-", 
             RowBox[{"84", " ", "t", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["t", "2"], " ", "x", " ", 
              SubscriptBox["XX", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{"4", " ", "x", " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox["x", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"5", "+", 
                   RowBox[{"16", " ", 
                    SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["x", "2"], " ", 
           SubsuperscriptBox["XX", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "x", " ", 
              SubscriptBox["XX", "3"]}], "+", 
             RowBox[{"t", " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "6"}], " ", 
              SuperscriptBox["x", "3"], " ", 
              SubsuperscriptBox["XX", "3", "3"]}], "-", 
             RowBox[{"17", " ", "t", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["t", "4"], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 SuperscriptBox["x", "3"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "24"}], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"48", " ", 
              SuperscriptBox["t", "3"], " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "-", 
             RowBox[{"4", " ", "t", " ", "x", " ", 
              SubscriptBox["XX", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{"4", " ", "x", " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["t", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox["x", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"5", "-", 
                   RowBox[{"16", " ", 
                    SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "48"}], " ", 
              SuperscriptBox["x", "3"], " ", 
              SubsuperscriptBox["XX", "3", "3"]}], "-", 
             RowBox[{"48", " ", "t", " ", 
              SuperscriptBox["x", "2"], " ", 
              SubsuperscriptBox["XX", "3", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["t", "2"], " ", "x", " ", 
              SubscriptBox["XX", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["x", "2"]}], "+", 
                RowBox[{"4", " ", "x", " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["x", "2"], " ", 
                 SubscriptBox["XX", "3"]}], "+", 
                RowBox[{"8", " ", "x", " ", 
                 SubsuperscriptBox["XX", "3", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SubsuperscriptBox["XX", "3", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox["x", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{"5", "+", 
                   RowBox[{"16", " ", 
                    SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",\

 CellChangeTimes->{{3.7613511709043293`*^9, 3.7613511973064613`*^9}, {
   3.761351594359132*^9, 3.7613516456535187`*^9}, 3.761351676772603*^9, 
   3.761351708335195*^9, {3.761351745651949*^9, 3.7613517620782824`*^9}, 
   3.761351829103614*^9, 3.761352087791689*^9, 3.761352123674107*^9, 
   3.76135216689002*^9, 3.761360917802452*^9, 3.761420959740295*^9, 
   3.761443591558168*^9, 3.7615144489432163`*^9, 3.7675809921423035`*^9, 
   3.7675822069863033`*^9, {3.7675823546553035`*^9, 3.767582382507303*^9}, 
   3.7675824655253034`*^9, {3.767582523120303*^9, 3.7675825367943034`*^9}, {
   3.7675826030063033`*^9, 3.7675826251563034`*^9}, 3.7675826670033035`*^9, 
   3.767582828257303*^9, 3.767583497639303*^9, 3.7675856475523033`*^9, 
   3.7675873621153035`*^9, 3.7675874730763035`*^9, 3.7675876330693035`*^9, {
   3.7675879343783035`*^9, 3.7675879617423034`*^9}, 3.7675880091493034`*^9, 
   3.7676447974116993`*^9, 3.7676510129625673`*^9, 3.7676513544722347`*^9, 
   3.789158607346945*^9},
 CellLabel->
  "Out[344]=",ExpressionUUID->"95982eee-acd8-4717-af39-b3822321c088"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7613511709043293`*^9, 3.7613511973064613`*^9}, {
   3.761351594359132*^9, 3.7613516456535187`*^9}, 3.761351676772603*^9, 
   3.761351708335195*^9, {3.761351745651949*^9, 3.7613517620782824`*^9}, 
   3.761351829103614*^9, 3.761352087791689*^9, 3.761352123674107*^9, 
   3.76135216689002*^9, 3.761360917802452*^9, 3.761420959740295*^9, 
   3.761443591558168*^9, 3.7615144489432163`*^9, 3.7675809921423035`*^9, 
   3.7675822069863033`*^9, {3.7675823546553035`*^9, 3.767582382507303*^9}, 
   3.7675824655253034`*^9, {3.767582523120303*^9, 3.7675825367943034`*^9}, {
   3.7675826030063033`*^9, 3.7675826251563034`*^9}, 3.7675826670033035`*^9, 
   3.767582828257303*^9, 3.767583497639303*^9, 3.7675856475523033`*^9, 
   3.7675873621153035`*^9, 3.7675874730763035`*^9, 3.7675876330693035`*^9, {
   3.7675879343783035`*^9, 3.7675879617423034`*^9}, 3.7675880091493034`*^9, 
   3.7676447974116993`*^9, 3.7676510129625673`*^9, 3.7676513544722347`*^9, 
   3.7891586578462973`*^9},
 CellLabel->
  "Out[349]=",ExpressionUUID->"34e8311d-2ad1-4a5a-af9f-6716b53967fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"2", ",", "0"}]], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"2", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Series", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], ")"}], "//", "Simplify"}], "//",
      "Normal"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", 
       RowBox[{"2", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"O", "[", 
      RowBox[{"x", ",", "Infinity"}], "]"}], " ", "term", " ", "is", " ", 
     "to", " ", "deal", " ", "with", " ", "some", " ", "versions", " ", "of", 
     " ", "Mathematica", " ", "including", " ", "unwanted", " ", "things"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", 
     RowBox[{"(", 
      RowBox[{"Normal", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{"%", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}]}], ")"}], "]"}], 
      ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%%", "+", "%"}], ")"}], "*", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], "//", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"#", ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{
          RowBox[{"t", ">", "0"}], "&&", 
          RowBox[{"x", ">", "0"}]}]}]}], "]"}], "&"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"2", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"2", ",", "0"}]], 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        RowBox[{"x", "^", "5"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xnegRHS2", "/", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"t", ">", "0"}], "&&", 
        RowBox[{"x", ">", "0"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7613506989826736`*^9, 3.761350707743919*^9}, {
   3.761350776270144*^9, 3.7613508271646442`*^9}, {3.761350884599642*^9, 
   3.761350907357087*^9}, {3.761350937441443*^9, 3.761351052742651*^9}, {
   3.761351087676675*^9, 3.761351193144711*^9}, {3.7613515430274887`*^9, 
   3.761351757375287*^9}, {3.7613518039184027`*^9, 3.7613518248873243`*^9}, {
   3.761352077028985*^9, 3.761352084315712*^9}, {3.7613521173951273`*^9, 
   3.761352119480804*^9}, {3.7613521604031754`*^9, 3.761352197695815*^9}, {
   3.7675806439633036`*^9, 3.7675806575653033`*^9}, {3.7675829903033037`*^9, 
   3.7675830059393034`*^9}, {3.767583103660303*^9, 3.7675831246703033`*^9}, 
   3.7675831617473035`*^9, {3.7675832001103034`*^9, 3.7675832243173037`*^9}, {
   3.767651421482236*^9, 3.767651442258892*^9}},
 CellLabel->
  "In[350]:=",ExpressionUUID->"97b5ae30-8653-4785-a618-88094450aea0"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", 
    SubscriptBox["XX", "3"]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "b"}], ")"}], " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]], " ", 
   SuperscriptBox["t", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "x", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"2", " ", "a", " ", "x", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"2", " ", "b", " ", "x", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"b", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         SubscriptBox["XX", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"4", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"x", "-", 
                SubscriptBox["XX", "1"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"x", "-", 
                SubscriptBox["XX", "2"]}], ")"}], " ", 
              SubscriptBox["XX", "3"]}]]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"a", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "b"}]}], ")"}], " ", "x"}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["XX", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "b"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"x", "-", 
                SubscriptBox["XX", "1"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"x", "-", 
                SubscriptBox["XX", "2"]}], ")"}], " ", 
              SubscriptBox["XX", "3"]}]]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7613522013102083`*^9, 3.76136095371729*^9, 3.761420996816429*^9, 
   3.76144362542623*^9, 3.76151448132973*^9, 3.7675810150783033`*^9, 
   3.767582231370303*^9, 3.767583007837303*^9, 3.7675830685003033`*^9, {
   3.767583104752303*^9, 3.7675831262223034`*^9}, 3.767583162601303*^9, 
   3.7675832262133036`*^9, 3.767583268594303*^9, 3.767583549049303*^9, 
   3.7675881017953033`*^9, 3.767651459014654*^9, 3.789158658324875*^9},
 CellLabel->
  "Out[354]=",ExpressionUUID->"0f98fd2d-d477-4622-abe4-2c5c411674cc"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7613522013102083`*^9, 3.76136095371729*^9, 3.761420996816429*^9, 
   3.76144362542623*^9, 3.76151448132973*^9, 3.7675810150783033`*^9, 
   3.767582231370303*^9, 3.767583007837303*^9, 3.7675830685003033`*^9, {
   3.767583104752303*^9, 3.7675831262223034`*^9}, 3.767583162601303*^9, 
   3.7675832262133036`*^9, 3.767583268594303*^9, 3.767583549049303*^9, 
   3.7675881017953033`*^9, 3.767651459014654*^9, 3.789158675334218*^9},
 CellLabel->
  "Out[359]=",ExpressionUUID->"4834869e-a012-4f7e-bdb4-04d53f22dee9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"3", ",", "0"}]], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"3", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "//", "Simplify"}], "//", 
     "Normal"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Nu]", 
       RowBox[{"3", ",", "0"}]], "/", 
      RowBox[{"x", "^", "5"}]}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"O", "[", 
      RowBox[{"x", ",", "Infinity"}], "]"}], " ", "term", " ", "is", " ", 
     "to", " ", "deal", " ", "with", " ", "some", " ", "versions", " ", "of", 
     " ", "Mathematica", " ", "including", " ", "unwanted", " ", "things"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", 
     RowBox[{"(", 
      RowBox[{"Normal", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{"%", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "^", "1"}]}], ")"}], "]"}], 
      ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS3", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%%%", "+", "%"}], ")"}], "*", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "0"}]]}], "//", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"#", ",", 
        RowBox[{"Assumptions", "\[Rule]", 
         RowBox[{
          RowBox[{"t", ">", "0"}], "&&", 
          RowBox[{"x", ">", "0"}]}]}]}], "]"}], "&"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"3", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"3", ",", "0"}]], 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        RowBox[{"x", "^", "5"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xnegRHS3", "/", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"t", ">", "0"}], "&&", 
        RowBox[{"x", ">", "0"}]}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7613506989826736`*^9, 3.761350707743919*^9}, {
  3.761350776270144*^9, 3.7613508271646442`*^9}, {3.761350884599642*^9, 
  3.761350907357087*^9}, {3.761350937441443*^9, 3.761351052742651*^9}, {
  3.761351087676675*^9, 3.761351193144711*^9}, {3.7613515430274887`*^9, 
  3.761351757375287*^9}, {3.7613518039184027`*^9, 3.7613518248873243`*^9}, {
  3.761352077028985*^9, 3.761352084315712*^9}, {3.7613521173951273`*^9, 
  3.761352119480804*^9}, {3.7613521604031754`*^9, 3.761352162427486*^9}, {
  3.7613522144700317`*^9, 3.761352235057513*^9}, {3.7675806701453037`*^9, 
  3.7675806749073033`*^9}, {3.767651484740432*^9, 3.767651493380402*^9}},
 CellLabel->
  "In[360]:=",ExpressionUUID->"fbb85a46-baf2-49dc-a4db-8b6428483d3f"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SubscriptBox["XX", "3"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
    SubscriptBox["Q", 
     RowBox[{"3", ",", "0"}]], " ", 
    SuperscriptBox["t", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "x", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", "a", " ", "x", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", "b", " ", "x", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"b", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{"4", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 SubscriptBox["XX", "1"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 SubscriptBox["XX", "2"]}], ")"}], " ", 
               SubscriptBox["XX", "3"]}]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"a", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "b"}]}], ")"}], " ", "x"}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "b"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 SubscriptBox["XX", "1"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 SubscriptBox["XX", "2"]}], ")"}], " ", 
               SubscriptBox["XX", "3"]}]]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.761352274308546*^9, 3.761361029046554*^9, 
  3.761421075022789*^9, 3.761443698870287*^9, 3.761514555438941*^9, 
  3.7675810157433033`*^9, 3.7675832747803035`*^9, 3.7675835515563035`*^9, 
  3.7675881592933035`*^9, 3.767651500282415*^9, 3.7891586756225357`*^9},
 CellLabel->
  "Out[364]=",ExpressionUUID->"3cd92930-7131-478e-ac0d-26301c386306"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.761352274308546*^9, 3.761361029046554*^9, 
  3.761421075022789*^9, 3.761443698870287*^9, 3.761514555438941*^9, 
  3.7675810157433033`*^9, 3.7675832747803035`*^9, 3.7675835515563035`*^9, 
  3.7675881592933035`*^9, 3.767651500282415*^9, 3.789158692527904*^9},
 CellLabel->
  "Out[369]=",ExpressionUUID->"e809f733-7f82-4c31-ba1e-5cd5852a1f92"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "now", " ", "the", " ", "constant", " ", "term", " ", "and", " ", "the", 
     " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "coefficient", " ", "are", " ", 
     "not", " ", "so", " ", "nice"}], ",", " ", 
    RowBox[{
     RowBox[{"since", " ", "they", " ", "contain", " ", "non"}], "-", 
     RowBox[{"algebraic", " ", "terms"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"in", " ", "particular", " ", "\[Nu]", " ", "and", " ", 
    SubscriptBox["\[Nu]", 
     RowBox[{"0", ",", "0"}]], " ", "cause", " ", "trouble", " ", "because", 
    " ", "they", " ", "lead", " ", "to", " ", 
    RowBox[{"(", 
     RowBox[{"series", " ", "with", " ", 
      RowBox[{"1", "/", "x"}], " ", "coefficients"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"series", " ", "with", " ", "x", " ", "coefficients"}], ")"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "the", " ", "best", " ", "we", " ", "can", " ", "do", " ", "is",
     " ", "give", " ", "them", " ", "a", " ", "name", " ", "or", " ", 
    "evaluate", " ", "them", " ", "manually"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7612735774983473`*^9, 3.7612736198154497`*^9}, {
  3.761273704619533*^9, 3.761273787071142*^9}, {3.761273945396247*^9, 
  3.761274017890396*^9}, {3.7612740581670237`*^9, 3.76127408695639*^9}},
 CellLabel->
  "In[370]:=",ExpressionUUID->"c95a4e24-f84f-4cae-8bdd-e65840f9355d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "constant", " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xnegRHS4s", "[", "N_", "]"}], ":=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Factor", "[", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "]"}],
       "&"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Mu]", "/", 
         RowBox[{"x", "^", "5"}]}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Nu]", "/", 
         RowBox[{"x", "^", "5"}]}], "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", "0"], 
          SubscriptBox["\[CapitalDelta]", "m"]}], "]"}]}]}], "/.", 
      RowBox[{"\[Theta]", "\[Rule]", 
       RowBox[{"\[Theta]s", "[", "N", "]"}]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761274109051529*^9, 3.7612742618578367`*^9}, {
  3.761274538760294*^9, 3.761274592308329*^9}, {3.761274623731533*^9, 
  3.76127465082054*^9}, {3.761352398849794*^9, 3.761352422069652*^9}},
 CellLabel->
  "In[371]:=",ExpressionUUID->"aafa0ba8-2615-4c8f-88fd-121e0254e221"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"xnegRHS5s", "[", "N_", "]"}], ":=", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Factor", "[", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "#", "]"}], "+", 
           RowBox[{"x", "^", "\[Pi]"}], "+", 
           RowBox[{"x", "^", 
            RowBox[{"(", 
             RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Exponent", "[", 
             RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], 
        "]"}], "&"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "0"}]], "/", 
          RowBox[{"x", "^", "5"}]}], "/", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", 
           RowBox[{"0", ",", "0"}]], "/", 
          RowBox[{"x", "^", "5"}]}], "*", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", "0"], 
           SubscriptBox["\[CapitalDelta]", "m"]}], "]"}]}]}], "/.", 
       RowBox[{
        SubscriptBox["\[Theta]", 
         RowBox[{"0", ",", "0"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[Theta]s", 
          RowBox[{"0", ",", "0"}]], "[", "N", "]"}]}]}]}], "]"}], "*", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.761274658211693*^9, 3.761274733576651*^9}, {
  3.7613524318801823`*^9, 3.76135245742839*^9}},
 CellLabel->
  "In[372]:=",ExpressionUUID->"06008350-d6c2-498f-a4ef-5d15a5d3999b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xnegRHS4s", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"xnegRHS5s", "[", "1", "]"}]}], "Input",
 CellChangeTimes->{{3.761352460245309*^9, 3.761352471175839*^9}},
 CellLabel->
  "In[373]:=",ExpressionUUID->"2eebf0f5-9e60-4863-aa86-aa2311d0e881"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b"}], ")"}], " ", 
      "t"}], 
     SuperscriptBox["x", "2"]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", "b", "+", 
       RowBox[{"a", " ", "b"}]}], ")"}], " ", 
     SuperscriptBox["t", "2"]}], 
    SuperscriptBox["x", "3"]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["x", "3"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["x", "3"]}], "+", 
         RowBox[{"b", " ", 
          SuperscriptBox["x", "3"]}], "-", 
         RowBox[{"2", " ", "a", " ", "b", " ", 
          SuperscriptBox["x", "3"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b", " ", 
          SuperscriptBox["x", "3"]}]}], ")"}]}], ")"}], " ", 
     SuperscriptBox["t", "3"]}], 
    SuperscriptBox["x", "4"]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "4"],
    SeriesData[$CellContext`t, 0, {}, 2, 8, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-2) (-1 + $CellContext`a)^2 $CellContext`a (-1 + $CellContext`b) \
$CellContext`b $CellContext`x^(-2), 0, 
    2 (-1 + $CellContext`a) $CellContext`a (-1 + $CellContext`b) \
$CellContext`b ($CellContext`a^2 - $CellContext`b + $CellContext`a \
$CellContext`b) $CellContext`x^(-3), 
    0, (-2) (-1 + $CellContext`a) $CellContext`a $CellContext`b \
$CellContext`x^(-4) (-$CellContext`a^2 + $CellContext`a^2 $CellContext`b^2 + \
$CellContext`a $CellContext`x^3 - $CellContext`a^2 $CellContext`x^3 + \
$CellContext`b $CellContext`x^3 - 
     2 $CellContext`a $CellContext`b $CellContext`x^3 + $CellContext`a^2 \
$CellContext`b $CellContext`x^3)}, 2, 8, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761352464763041*^9, 3.761352471376719*^9}, 
   3.761361147398007*^9, 3.761421153332925*^9, 3.761443773269911*^9, 
   3.7615146272065973`*^9, 3.7675810180083036`*^9, 3.7675835538603034`*^9, 
   3.7675881719143033`*^9, 3.767651537298805*^9, 3.789158692840431*^9},
 CellLabel->
  "Out[373]=",ExpressionUUID->"e285e7b7-4468-4408-b63d-e7f4c0bde47e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "x"], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "c"}], "+", 
         RowBox[{"3", " ", "b", " ", "c"}], "-", 
         RowBox[{"3", " ", "a", " ", "b", " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], ")"}], " ", "t"}], 
    SuperscriptBox["x", "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["b", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", "c"}], "-", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", "c"}], "-", 
       RowBox[{"a", " ", "b", " ", "c"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "c"}], "+", 
       RowBox[{"2", " ", "a", " ", 
        SuperscriptBox["b", "2"], " ", "c"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", 
     SuperscriptBox["t", "2"]}], 
    SuperscriptBox["x", "3"]], "+", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["x", "4"]], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["b", "3"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", "c"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", "c"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["b", "2"], " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "b", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", "b", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"2", " ", "a", " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"6", " ", "b", " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"5", " ", "a", " ", "b", " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["b", "2"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"11", " ", "a", " ", 
        SuperscriptBox["b", "2"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["b", "2"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["b", "3"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"5", " ", "a", " ", 
        SuperscriptBox["b", "3"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "3"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["b", "3"], " ", "c", " ", 
        SuperscriptBox["x", "3"]}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", 
     SuperscriptBox["t", "3"]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "4"],
    SeriesData[$CellContext`t, 0, {}, 0, 8, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   2 (-1 + $CellContext`a)^3 (-2 + $CellContext`b) (-1 + $CellContext`b) \
$CellContext`c $CellContext`x^(-1) $CellContext`Q[0, 0], 
    0, (-2) (-1 + $CellContext`a)^2 (-1 + $CellContext`b) (-$CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c + 3 $CellContext`b $CellContext`c - 
     3 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c) $CellContext`x^(-2) \
$CellContext`Q[0, 0], 0, 
    2 (-1 + $CellContext`a) (-1 + $CellContext`b) (-$CellContext`a^3 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`a^2 \
$CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c - $CellContext`a^3 $CellContext`c - \
$CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + 2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c + $CellContext`a^3 \
$CellContext`b^2 $CellContext`c) $CellContext`x^(-3) $CellContext`Q[0, 0], 0, 
    2 (-1 + $CellContext`a) $CellContext`x^(-4) (-$CellContext`a^3 \
$CellContext`b + $CellContext`a^3 $CellContext`b^3 + $CellContext`a^3 \
$CellContext`c + 3 $CellContext`a^2 $CellContext`b $CellContext`c - 
     3 $CellContext`a^3 $CellContext`b $CellContext`c - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b^2 $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`x^3 - $CellContext`a^3 $CellContext`b \
$CellContext`x^3 + $CellContext`a $CellContext`b^2 $CellContext`x^3 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`x^3 + $CellContext`a^3 \
$CellContext`b^2 $CellContext`x^3 + 
     2 $CellContext`a $CellContext`c $CellContext`x^3 + $CellContext`a^2 \
$CellContext`c $CellContext`x^3 + $CellContext`a^3 $CellContext`c \
$CellContext`x^3 - 6 $CellContext`b $CellContext`c $CellContext`x^3 + 
     5 $CellContext`a $CellContext`b $CellContext`c $CellContext`x^3 - 
     6 $CellContext`a^2 $CellContext`b $CellContext`c $CellContext`x^3 + \
$CellContext`a^3 $CellContext`b $CellContext`c $CellContext`x^3 + 
     8 $CellContext`b^2 $CellContext`c $CellContext`x^3 - 
     11 $CellContext`a $CellContext`b^2 $CellContext`c $CellContext`x^3 + 
     10 $CellContext`a^2 $CellContext`b^2 $CellContext`c $CellContext`x^3 - 
     5 $CellContext`a^3 $CellContext`b^2 $CellContext`c $CellContext`x^3 - 
     3 $CellContext`b^3 $CellContext`c $CellContext`x^3 + 
     5 $CellContext`a $CellContext`b^3 $CellContext`c $CellContext`x^3 - 
     4 $CellContext`a^2 $CellContext`b^3 $CellContext`c $CellContext`x^3 + 
     2 $CellContext`a^3 $CellContext`b^3 $CellContext`c $CellContext`x^3) \
$CellContext`Q[0, 0]}, 0, 8, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761352464763041*^9, 3.761352471376719*^9}, 
   3.761361147398007*^9, 3.761421153332925*^9, 3.761443773269911*^9, 
   3.7615146272065973`*^9, 3.7675810180083036`*^9, 3.7675835538603034`*^9, 
   3.7675881719143033`*^9, 3.767651537298805*^9, 3.7891586930728703`*^9},
 CellLabel->
  "Out[374]=",ExpressionUUID->"595c09d6-a517-4a0a-b5f0-50d5d2a9d8f3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", "setting", " ", "up", " ", "eqn", " ", 
    RowBox[{"(", "5.30", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["P", "0", "d"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["t", "2"]}], "+", "x", "-", 
        RowBox[{"a", " ", "x"}], "-", 
        RowBox[{"a", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "t", " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"]}], "+", "x", "-", 
        RowBox[{"b", " ", "x"}], "-", 
        RowBox[{"b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "t", " ", 
         SuperscriptBox["x", "2"]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Tau]", "0", "d"], "=", 
     RowBox[{"4", " ", "a", " ", "c", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"x", " ", 
           SubscriptBox["XX", "1"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"x", " ", 
           SubscriptBox["XX", "2"]}]}], ")"}], " ", 
        SubscriptBox["XX", "3"]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"1", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
            "xnegRHS2", "+", "xnegRHS3"}], ")"}], "/", "x"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{"1", "/", "x"}]}]}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "]"}], "//", "Factor"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"2", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
            "xnegRHS2", "+", "xnegRHS3"}], ")"}], "/", "x"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{"1", "/", "x"}]}]}], ",", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "]"}], "//", "Factor"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"3", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
            "xnegRHS2", "+", "xnegRHS3"}], ")"}], "/", "x"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{"1", "/", "x"}]}]}], ",", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]]}], "]"}], "//", "Factor"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"4", ",", "0"}]], "=", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
            "xnegRHS2", "+", "xnegRHS3"}], ")"}], "/", "x"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{"1", "/", "x"}]}]}], ",", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}], "]"}], "//", "Factor"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7613530488202667`*^9, 3.7613530964085817`*^9}, {
  3.761353128168689*^9, 3.761353182586357*^9}, {3.761353354199521*^9, 
  3.761353402204958*^9}, {3.761353444199944*^9, 3.761353449091559*^9}, {
  3.761353648547555*^9, 3.761353684389627*^9}, {3.761354972425343*^9, 
  3.761355023703319*^9}, {3.7613611620675898`*^9, 3.761361198490734*^9}, {
  3.761423052598613*^9, 3.761423055030846*^9}, {3.761888953655034*^9, 
  3.761888955405034*^9}, {3.789158359382913*^9, 3.789158359910223*^9}},
 CellLabel->
  "In[375]:=",ExpressionUUID->"92372634-3fe2-4deb-b60f-147a07369785"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "these", " ", "are", " ", "unwieldy", " ", "and", " ", "it", " ", "will", 
    " ", "be", " ", "more", " ", "useful", " ", "to", " ", "have", " ", 
    "series", " ", "expansions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", " ", "define", " ", "these"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
     SubsuperscriptBox["\[Tau]s", "0", "d"], ",", 
     SubscriptBox["\[Tau]s", 
      RowBox[{"1", ",", "0"}]], ",", 
     SubscriptBox["\[Tau]s", 
      RowBox[{"2", ",", "0"}]], ",", 
     SubscriptBox["\[Tau]s", 
      RowBox[{"3", ",", "0"}]], ",", "\[Tau]s", ",", 
     SubscriptBox["\[Tau]s", 
      RowBox[{"0", ",", "0"}]], ",", "xneg00"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "then", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Tau]s", "0", "d"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Tau]s", "0", "d"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["\[Tau]", "0", "d"], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{
           RowBox[{"t", ">", "0"}], "&&", 
           RowBox[{"x", ">", "0"}]}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]s", 
      RowBox[{"1", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Tau]s", 
       RowBox[{"1", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Tau]", 
           RowBox[{"1", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{
           RowBox[{"t", ">", "0"}], "&&", 
           RowBox[{"x", ">", "0"}]}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]s", 
      RowBox[{"2", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Tau]s", 
       RowBox[{"2", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Tau]", 
           RowBox[{"2", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{
           RowBox[{"t", ">", "0"}], "&&", 
           RowBox[{"x", ">", "0"}]}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]s", 
      RowBox[{"3", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Tau]s", 
       RowBox[{"3", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Tau]", 
           RowBox[{"3", ",", "0"}]], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{
           RowBox[{"t", ">", "0"}], "&&", 
           RowBox[{"x", ">", "0"}]}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"4", ",", "0"}]], " ", "is", " ", "a", " ", "polynomial", " ", 
     "so", " ", "we", " ", 
     RowBox[{"don", "'"}], "t", " ", "need", " ", "to", " ", "mess", " ", 
     "with", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"these", " ", "will", " ", "also", " ", "be", " ", "useful"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xneg00", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"xneg00", "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", 
                "+", "xnegRHS2", "+", "xnegRHS3"}], ")"}], "/", "x"}], "/.", 
             RowBox[{"x", "\[Rule]", 
              RowBox[{"1", "/", "x"}]}]}], ",", 
            RowBox[{"Q", "[", 
             RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"t", ">", "0"}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "then", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Tau]s", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"\[Tau]s", "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"xnegRHS4s", "[", "n", "]"}], "/", "x"}], "/.", 
              RowBox[{"x", "\[Rule]", 
               RowBox[{"1", "/", "x"}]}]}], ")"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               SubscriptBox["XX", "1"], "\[Rule]", 
               RowBox[{
                SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
              RowBox[{
               SubscriptBox["XX", "2"], "\[Rule]", 
               RowBox[{
                SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
              RowBox[{
               SubscriptBox["XX", "3"], "\[Rule]", 
               RowBox[{
                SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "//", 
           "Simplificate"}], ")"}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{
           RowBox[{"t", ">", "0"}], "&&", 
           RowBox[{"x", ">", "0"}]}]}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]s", 
      RowBox[{"0", ",", "0"}]], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Tau]s", 
       RowBox[{"0", ",", "0"}]], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"xnegRHS5s", "[", "n", "]"}], "/", 
                 RowBox[{"Q", "[", 
                  RowBox[{"0", ",", "0"}], "]"}]}], "/", "x"}], "/.", 
               RowBox[{"x", "\[Rule]", 
                RowBox[{"1", "/", "x"}]}]}], ")"}], "+", 
             RowBox[{"xneg00", "[", "n", "]"}]}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["XX", "1"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "2"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "3"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "//", 
          "Simplificate"}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{
           RowBox[{"t", ">", "0"}], "&&", 
           RowBox[{"x", ">", "0"}]}]}]}], "]"}]}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQrRhRmaTH9sZRY41hIYiO4PlaCqZn11SB6M2SUo0g
+mH1wZUg2kF071oQ7dGXvA5EtxUYZusD6QMJpmUgmuuLyTQQrX3u12IQHaE9
eQeIvsS7dCeIDs5I3geiW0x59oPoE3bf6syA9D2Nz/0gusH51RQQXeN0YBaI
Tri+cgmIVuL/vQVE67Zv3AWidzQpHADR00ylnoJomYOvnoHoKp45HOYg+Z0a
nCD6TmuJCojeYrEBTLsIndAF0Wrm9Xog+oGcpzGIlvupag6i9ynVzgHR+R7c
c0H0zDUHF4LoKbdEFoHoe2Hzl4HovlWaa0H0z6j3D0A064XGRyD6ZNokZSsg
XR/lqguif9WkRkUAaXnd8zEgGgA6TJsW
  "],
 CellLabel->
  "In[381]:=",ExpressionUUID->"7de0da3c-432b-4019-9623-0a99fd54a8a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SubsuperscriptBox["\[Tau]s", "0", "d"], "[", "9", "]"}]}], 
       SubsuperscriptBox["P", "0", "d"], 
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", "x", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"1", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"2", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"3", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Tau]", 
        RowBox[{"4", ",", "0"}]], 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]]}], "+", 
      RowBox[{"\[Tau]s", "[", "9", "]"}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"0", ",", "0"}]], "[", "9", "]"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQdk", "[", 
         RowBox[{"9", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "//", "Simplificate"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", "%"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761356201843919*^9, 3.761356273090871*^9}, {
  3.761356320258355*^9, 3.761356350563094*^9}, {3.761356384034071*^9, 
  3.761356387002584*^9}, {3.761356899372814*^9, 3.761356902655245*^9}, {
  3.761361265772295*^9, 3.761361286170684*^9}, {3.761361318822255*^9, 
  3.761361341420681*^9}, {3.7614230860345497`*^9, 3.761423090049605*^9}},
 CellLabel->
  "In[389]:=",ExpressionUUID->"820d3aed-691c-40d4-b236-940f20b3dfa4"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7613562759954653`*^9, 3.7613563344174767`*^9, 3.761356368601568*^9, 
   3.761356450794956*^9, 3.76135660974293*^9, 3.761357310771881*^9, {
   3.761361290890188*^9, 3.76136135482132*^9}, 3.7614211657201653`*^9, 
   3.761423092394971*^9, 3.761443785490376*^9, 3.761514638496807*^9, 
   3.7675810287353034`*^9, 3.767583298311303*^9, 3.7675835632613034`*^9, 
   3.7675881867653036`*^9, 3.7676515985136414`*^9, 3.789158733509467*^9},
 CellLabel->
  "Out[391]=",ExpressionUUID->"e1b04ea7-059d-4d53-bee5-da8538d4d26d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "roots", " ", "of", " ", 
    SubscriptBox["P", 
     RowBox[{"x", ",", "0"}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], "=", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "-", "a", "+", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "a"}], "+", 
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["t", "3"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["a", "4"], " ", 
           SuperscriptBox["t", "3"]}]}]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], "=", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "-", "a", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "a"}], "+", 
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["t", "3"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["a", "4"], " ", 
           SuperscriptBox["t", "3"]}]}]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "3"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "b"}], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["t", "3"]}]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "4"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "+", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "b"}], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["t", "3"]}]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "5"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b", "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", "a", "-", "b"}], ")"}], "2"], "-", 
         RowBox[{"8", " ", "a", " ", "b", " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}]}]]}], 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "6"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", "a", "-", "b"}], ")"}], "2"], "-", 
         RowBox[{"8", " ", "a", " ", "b", " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "t"}], "-", 
            RowBox[{"b", " ", "t"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "t"}]}], ")"}]}]}]]}], 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"so", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "1"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "2"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "3"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "4"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "5"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "6"]}]}]}], "}"}], "//", "Simplify"}]}]}]], "Input",\

 CellChangeTimes->{{3.761358135453123*^9, 3.761358177081191*^9}, {
  3.76135840489797*^9, 3.7613584866978693`*^9}, {3.761358975399332*^9, 
  3.761359015201329*^9}, {3.766448700939*^9, 3.7664487317539997`*^9}, {
  3.766448787245*^9, 3.7664487872460003`*^9}, {3.766448843071*^9, 
  3.766448909135*^9}},
 CellLabel->
  "In[392]:=",ExpressionUUID->"d178a5fd-56ad-4389-a8e7-87beb704d21d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.761359016250182*^9, 3.761361806753837*^9, 3.7614223380007267`*^9, 
   3.76144378580352*^9, 3.7615146387522383`*^9, 3.7675810291023035`*^9, 
   3.767583298455303*^9, 3.7675835633923035`*^9, {3.767588186889303*^9, 
   3.7675882110633035`*^9}, 3.7676516095725203`*^9, 3.789158733724605*^9},
 CellLabel->
  "Out[398]=",ExpressionUUID->"8f8dc6e4-cf86-4773-b297-a7e76302120a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "then", " ", "verifying", " ", "which", " ", "are", " ", 
    "power", " ", "series"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["x", "2"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "4"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"a", ">", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"0", "<", "a", "<", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "3"], ",", 
        SubscriptBox["x", "4"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "4"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"b", ">", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"0", "<", "b", "<", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "5"], ",", 
        SubscriptBox["x", "6"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "4"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{
       RowBox[{"a", "+", "b"}], ">", "2"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"0", "<", 
       RowBox[{"a", "+", "b"}], "<", "2"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761358524221263*^9, 3.761358624005843*^9}, 
   3.766448787256*^9, {3.766448843083*^9, 3.7664489091470003`*^9}},
 CellLabel->
  "In[399]:=",ExpressionUUID->"f1d95a86-4b9e-4827-acc2-38b13a98ec12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, 1, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a, 0, 0, (-1 + $CellContext`a)^(-1) $CellContext`a^4}, 
     1, 5, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     RowBox[{"a", " ", "t"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{"1", "-", "a"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, -2, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`a) $CellContext`a^(-2), 0, 0, -$CellContext`a, 0, 
      0, (1 - $CellContext`a)^(-1) $CellContext`a^4}, -2, 5, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.761358549179831*^9, 3.761358625113494*^9}, 
   3.761361808670224*^9, 3.761422338266088*^9, 3.761443786062475*^9, 
   3.761514638934567*^9, 3.767581029146303*^9, 3.7675832985513034`*^9, 
   3.7675835634443035`*^9, 3.767588212582303*^9, 3.7676516165414457`*^9, 
   3.789158733795569*^9},
 CellLabel->
  "Out[400]=",ExpressionUUID->"b914ae32-4862-4fe0-b57e-bff7f64019b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     RowBox[{"a", " ", "t"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, -2, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`a) $CellContext`a^(-2), 0, 0, -$CellContext`a, 0, 
      0, -(-1 + $CellContext`a)^(-1) $CellContext`a^4}, -2, 5, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, 1, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a, 0, 0, (-1 + $CellContext`a)^(-1) $CellContext`a^4}, 
     1, 5, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.761358549179831*^9, 3.761358625113494*^9}, 
   3.761361808670224*^9, 3.761422338266088*^9, 3.761443786062475*^9, 
   3.761514638934567*^9, 3.767581029146303*^9, 3.7675832985513034`*^9, 
   3.7675835634443035`*^9, 3.767588212582303*^9, 3.7676516165414457`*^9, 
   3.789158733799076*^9},
 CellLabel->
  "Out[401]=",ExpressionUUID->"a6556746-2b62-49ac-97a0-6898713ebb80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, 1, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b, 0, 0, (-1 + $CellContext`b)^(-1) $CellContext`b^4}, 
     1, 5, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     RowBox[{"b", " ", "t"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{"1", "-", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, -2, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`b) $CellContext`b^(-2), 0, 0, -$CellContext`b, 0, 
      0, (1 - $CellContext`b)^(-1) $CellContext`b^4}, -2, 5, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.761358549179831*^9, 3.761358625113494*^9}, 
   3.761361808670224*^9, 3.761422338266088*^9, 3.761443786062475*^9, 
   3.761514638934567*^9, 3.767581029146303*^9, 3.7675832985513034`*^9, 
   3.7675835634443035`*^9, 3.767588212582303*^9, 3.7676516165414457`*^9, 
   3.789158733802608*^9},
 CellLabel->
  "Out[403]=",ExpressionUUID->"db3175ca-d61e-4474-b25d-adfb8597c675"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     RowBox[{"b", " ", "t"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, -2, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`b) $CellContext`b^(-2), 0, 0, -$CellContext`b, 0, 
      0, -(-1 + $CellContext`b)^(-1) $CellContext`b^4}, -2, 5, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, 1, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b, 0, 0, (-1 + $CellContext`b)^(-1) $CellContext`b^4}, 
     1, 5, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.761358549179831*^9, 3.761358625113494*^9}, 
   3.761361808670224*^9, 3.761422338266088*^9, 3.761443786062475*^9, 
   3.761514638934567*^9, 3.767581029146303*^9, 3.7675832985513034`*^9, 
   3.7675835634443035`*^9, 3.767588212582303*^9, 3.7676516165414457`*^9, 
   3.789158733880968*^9},
 CellLabel->
  "Out[404]=",ExpressionUUID->"2afca94e-a953-4e18-bcda-bbef84de4693"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}], 
      RowBox[{"2", "-", "a", "-", "b"}]], "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", 
          RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "2"], " ", 
       SuperscriptBox["t", "4"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "3"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, 1, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(2 - $CellContext`a - $CellContext`b)^(-1) ($CellContext`a + \
$CellContext`b - 2 $CellContext`a $CellContext`b), 0, 0, 
      2 $CellContext`a $CellContext`b (-2 + $CellContext`a + \
$CellContext`b)^(-3) ($CellContext`a + $CellContext`b - 
        2 $CellContext`a $CellContext`b)^2}, 1, 5, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "2"]}], ")"}], " ", 
       SuperscriptBox["t", "4"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "3"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, -2, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 
        2] $CellContext`a^(-1) $CellContext`b^(-1) (-2 + $CellContext`a + \
$CellContext`b), 0, 
      0, (-2 + $CellContext`a + $CellContext`b)^(-1) ($CellContext`a + \
$CellContext`b - 2 $CellContext`a $CellContext`b), 0, 
      0, (-2) $CellContext`a $CellContext`b (-2 + $CellContext`a + \
$CellContext`b)^(-3) ($CellContext`a + $CellContext`b - 
        2 $CellContext`a $CellContext`b)^2}, -2, 5, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.761358549179831*^9, 3.761358625113494*^9}, 
   3.761361808670224*^9, 3.761422338266088*^9, 3.761443786062475*^9, 
   3.761514638934567*^9, 3.767581029146303*^9, 3.7675832985513034`*^9, 
   3.7675835634443035`*^9, 3.767588212582303*^9, 3.7676516165414457`*^9, 
   3.789158733955226*^9},
 CellLabel->
  "Out[406]=",ExpressionUUID->"b857f0cb-2846-4020-baa0-d4192066a558"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "2"]}], ")"}], " ", 
       SuperscriptBox["t", "4"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "3"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, -2, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 
        2] $CellContext`a^(-1) $CellContext`b^(-1) (-2 + $CellContext`a + \
$CellContext`b), 0, 
      0, (-2 + $CellContext`a + $CellContext`b)^(-1) ($CellContext`a + \
$CellContext`b - 2 $CellContext`a $CellContext`b), 0, 
      0, (-2) $CellContext`a $CellContext`b (-2 + $CellContext`a + \
$CellContext`b)^(-3) ($CellContext`a + $CellContext`b - 
        2 $CellContext`a $CellContext`b)^2}, -2, 5, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", 
          RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}], 
       RowBox[{
        RowBox[{"-", "2"}], "+", "a", "+", "b"}]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", 
          RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "2"], " ", 
       SuperscriptBox["t", "4"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "3"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "5"],
      SeriesData[$CellContext`t, 0, {}, 1, 5, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {-(-2 + $CellContext`a + $CellContext`b)^(-1) ($CellContext`a + \
$CellContext`b - 2 $CellContext`a $CellContext`b), 0, 0, 
      2 $CellContext`a $CellContext`b (-2 + $CellContext`a + \
$CellContext`b)^(-3) ($CellContext`a + $CellContext`b - 
        2 $CellContext`a $CellContext`b)^2}, 1, 5, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.761358549179831*^9, 3.761358625113494*^9}, 
   3.761361808670224*^9, 3.761422338266088*^9, 3.761443786062475*^9, 
   3.761514638934567*^9, 3.767581029146303*^9, 3.7675832985513034`*^9, 
   3.7675835634443035`*^9, 3.767588212582303*^9, 3.7676516165414457`*^9, 
   3.7891587339625683`*^9},
 CellLabel->
  "Out[407]=",ExpressionUUID->"b150adca-1e0c-40a1-9d31-4ca4273b7f92"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "roots", " ", "of", " ", 
    SubsuperscriptBox["P", "0", "d"]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "7"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "a"}], "+", 
         SuperscriptBox["a", "2"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox["t", "3"]}]}]]}], 
      RowBox[{"2", " ", "t", " ", "a", 
       RowBox[{"(", 
        RowBox[{"a", "-", "1"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "8"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "+", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "a"}], "+", 
         SuperscriptBox["a", "2"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox["t", "3"]}]}]]}], 
      RowBox[{"2", " ", "t", " ", "a", 
       RowBox[{"(", 
        RowBox[{"a", "-", "1"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "9"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "b"}], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["t", "3"]}]}]]}], 
      RowBox[{"2", " ", "t", " ", "b", 
       RowBox[{"(", 
        RowBox[{"b", "-", "1"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "10"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "+", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "b"}], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["t", "3"]}]}]]}], 
      RowBox[{"2", " ", "t", " ", "b", 
       RowBox[{"(", 
        RowBox[{"b", "-", "1"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"so", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "7"]}]}], ",", 
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "8"]}]}], ",", 
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "9"]}]}], ",", 
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "10"]}]}]}], "}"}], "//", "Simplify"}]}]}]], "Input",\

 CellChangeTimes->{{3.7613586478636312`*^9, 3.761358659882502*^9}, {
  3.7613588253064337`*^9, 3.7613588352393093`*^9}, {3.761358884911405*^9, 
  3.76135896268321*^9}, {3.761359022199407*^9, 3.761359047573941*^9}, {
  3.7664489418199997`*^9, 3.7664489762209997`*^9}},
 CellLabel->
  "In[408]:=",ExpressionUUID->"3e24e03c-5761-4497-9853-f8511dc31c13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7613590478265*^9, 3.761361811883726*^9, 
  3.761422338715027*^9, 3.761443786381207*^9, 3.761514639331339*^9, 
  3.7675810294593034`*^9, 3.767583298877303*^9, 3.7675835636973033`*^9, 
  3.7675882142933035`*^9, 3.767651621932582*^9, 3.789158734079689*^9},
 CellLabel->
  "Out[412]=",ExpressionUUID->"3731e86e-53be-4d70-b17c-2f8cd6b9e7c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "then", " ", "verifying", " ", "which", " ", "are", " ", 
    "power", " ", "series"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "7"], ",", 
        SubscriptBox["x", "8"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"a", ">", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"0", "<", "a", "<", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "9"], ",", 
        SubscriptBox["x", "10"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"b", ">", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"0", "<", "b", "<", "1"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761359063339978*^9, 3.761359078291861*^9}, {
  3.7664489418310003`*^9, 3.76644897623*^9}},
 CellLabel->
  "In[413]:=",ExpressionUUID->"c4861166-4855-48d1-903d-f7c7d1c4c1d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 2, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`a)^(-1) $CellContext`a^2, 0, 
      0, (-1 + $CellContext`a)^(-2) $CellContext`a^5}, 2, 6, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"a", " ", "t"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{"1", "-", "a"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, -1, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a^(-1), 0, 
      0, (1 - $CellContext`a)^(-1) $CellContext`a^2, 0, 
      0, -(-1 + $CellContext`a)^(-2) $CellContext`a^5}, -1, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.7613590785681543`*^9, 3.7613618147562943`*^9, 
  3.761422338856914*^9, 3.761443786649411*^9, 3.761514639519157*^9, 
  3.7675810295203037`*^9, 3.7675835637553034`*^9, 3.7675882155103035`*^9, 
  3.7676516251237497`*^9, 3.7891587341674347`*^9},
 CellLabel->
  "Out[414]=",ExpressionUUID->"cb11dcb9-1999-40b9-9003-0a3fbd3566c4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"a", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, -1, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a^(-1), 0, 
      0, -(-1 + $CellContext`a)^(-1) $CellContext`a^2, 0, 
      0, -(-1 + $CellContext`a)^(-2) $CellContext`a^5}, -1, 6, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 2, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`a)^(-1) $CellContext`a^2, 0, 
      0, (-1 + $CellContext`a)^(-2) $CellContext`a^5}, 2, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.7613590785681543`*^9, 3.7613618147562943`*^9, 
  3.761422338856914*^9, 3.761443786649411*^9, 3.761514639519157*^9, 
  3.7675810295203037`*^9, 3.7675835637553034`*^9, 3.7675882155103035`*^9, 
  3.7676516251237497`*^9, 3.7891587341703787`*^9},
 CellLabel->
  "Out[415]=",ExpressionUUID->"8ea7eec2-eb1e-484a-91bd-cf4f29778810"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 2, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`b)^(-1) $CellContext`b^2, 0, 
      0, (-1 + $CellContext`b)^(-2) $CellContext`b^5}, 2, 6, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"b", " ", "t"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{"1", "-", "b"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, -1, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b^(-1), 0, 
      0, (1 - $CellContext`b)^(-1) $CellContext`b^2, 0, 
      0, -(-1 + $CellContext`b)^(-2) $CellContext`b^5}, -1, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.7613590785681543`*^9, 3.7613618147562943`*^9, 
  3.761422338856914*^9, 3.761443786649411*^9, 3.761514639519157*^9, 
  3.7675810295203037`*^9, 3.7675835637553034`*^9, 3.7675882155103035`*^9, 
  3.7676516251237497`*^9, 3.789158734173335*^9},
 CellLabel->
  "Out[417]=",ExpressionUUID->"405dc034-eaf1-40c0-ad2d-9b72c1f77301"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"b", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, -1, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b^(-1), 0, 
      0, -(-1 + $CellContext`b)^(-1) $CellContext`b^2, 0, 
      0, -(-1 + $CellContext`b)^(-2) $CellContext`b^5}, -1, 6, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["t", "5"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 2, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-1 + $CellContext`b)^(-1) $CellContext`b^2, 0, 
      0, (-1 + $CellContext`b)^(-2) $CellContext`b^5}, 2, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.7613590785681543`*^9, 3.7613618147562943`*^9, 
  3.761422338856914*^9, 3.761443786649411*^9, 3.761514639519157*^9, 
  3.7675810295203037`*^9, 3.7675835637553034`*^9, 3.7675882155103035`*^9, 
  3.7676516251237497`*^9, 3.789158734176242*^9},
 CellLabel->
  "Out[418]=",ExpressionUUID->"850a9659-14c1-4a4f-a91d-6cc77c0a5b9f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"these", " ", "will", " ", "be", " ", "useful"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
     SubscriptBox["xs", "1"], ",", 
     SubscriptBox["xs", "2"], ",", 
     SubscriptBox["xs", "3"], ",", 
     SubscriptBox["xs", "4"], ",", 
     SubscriptBox["xs", "5"], ",", 
     SubscriptBox["xs", "6"], ",", 
     SubscriptBox["xs", "7"], ",", 
     SubscriptBox["xs", "8"], ",", 
     SubscriptBox["xs", "9"], ",", 
     SubscriptBox["xs", "10"]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "1"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "1"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"a", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "2"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "2"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "a", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "2"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "3"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "3"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"b", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "3"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "4"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "4"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "b", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "4"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "5"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "5"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{
             RowBox[{"a", "+", "b"}], ">", "2"}]}]}], "]"}], "]"}], "&"}], 
       ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "5"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "6"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "6"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", 
             RowBox[{"a", "+", "b"}], "<", "2"}]}]}], "]"}], "]"}], "&"}], 
       ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "6"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "7"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "7"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"a", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "7"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "8"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "8"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "a", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "8"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "9"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "9"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"b", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "9"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "10"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "10"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "b", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "10"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], 
      "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.761359189264847*^9, 3.76135930003512*^9}, {
  3.76644878727*^9, 3.766448798885*^9}, {3.7664488568859997`*^9, 
  3.7664489091610003`*^9}, {3.766448941844*^9, 3.766448976243*^9}, {
  3.766449017218*^9, 3.766449137847*^9}},
 CellLabel->
  "In[419]:=",ExpressionUUID->"df0d34f2-54b8-44dd-a84e-7a0bf6764df0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "verifying", " ", "what", " ", "happens", " ", "when", " ", 
    "we", " ", "cancel", " ", "the", " ", "kernel"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]s", "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"0", ",", "0"}]], "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"1", ",", "0"}]], "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"2", ",", "0"}]], "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"3", ",", "0"}]], "[", "9", "]"}], ",", 
       SubscriptBox["\[Sigma]", 
        RowBox[{"4", ",", "0"}]]}], "}"}], ".", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "//", "Simplificate"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"%", "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "1"], "[", "9", "]"}]}]}], ",", 
      RowBox[{"%", "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "3"], "[", "9", "]"}]}]}], ",", 
      RowBox[{"%", "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "5"], "[", "9", "]"}]}]}]}], "}"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplificate", "/@", "%"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Tau]s", "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"0", ",", "0"}]], "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"1", ",", "0"}]], "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"2", ",", "0"}]], "[", "9", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"3", ",", "0"}]], "[", "9", "]"}], ",", 
       SubscriptBox["\[Tau]", 
        RowBox[{"4", ",", "0"}]]}], "}"}], ".", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "//", "Simplificate"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"%", "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "7"], "[", "9", "]"}]}]}], ",", 
      RowBox[{"%", "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "9"], "[", "9", "]"}]}]}]}], "}"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplificate", "/@", "%"}]}]}]], "Input",
 CellChangeTimes->{{3.761422410448348*^9, 3.761422473557604*^9}, {
   3.761422543086108*^9, 3.7614225449229116`*^9}, {3.761423105409028*^9, 
   3.7614233234510727`*^9}, {3.761423354726282*^9, 3.7614234504325247`*^9}, {
   3.761423565509396*^9, 3.76142357328251*^9}, 3.7664490172320004`*^9, {
   3.766449053505*^9, 3.766449125994*^9}},
 CellLabel->
  "In[430]:=",ExpressionUUID->"f6c773af-0ee3-4944-9e3d-7af3995934e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614231949360933`*^9, 3.761423238292892*^9}, {
   3.761423272494342*^9, 3.76142332563311*^9}, {3.7614233972929688`*^9, 
   3.761423425219295*^9}, 3.761423577072741*^9, 3.7614437896387444`*^9, 
   3.761514642280704*^9, 3.7675810328663034`*^9, 3.7675833054613037`*^9, 
   3.7675835659273033`*^9, 3.7675882213153033`*^9, 3.767651635647028*^9, 
   3.7891587376790648`*^9},
 CellLabel->
  "Out[434]=",ExpressionUUID->"f3d0cf7e-9e1d-47e9-9126-7b062702e4fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "10"],
    SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614231949360933`*^9, 3.761423238292892*^9}, {
   3.761423272494342*^9, 3.76142332563311*^9}, {3.7614233972929688`*^9, 
   3.761423425219295*^9}, 3.761423577072741*^9, 3.7614437896387444`*^9, 
   3.761514642280704*^9, 3.7675810328663034`*^9, 3.7675833054613037`*^9, 
   3.7675835659273033`*^9, 3.7675882213153033`*^9, 3.767651635647028*^9, 
   3.789158739346366*^9},
 CellLabel->
  "Out[439]=",ExpressionUUID->"15c11fcd-7073-4ebf-b086-da1f7aaa64f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "we", " ", "have", " ", "5", " ", "equations", " ", "with", 
    " ", "5", " ", "unknowns"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "but", " ", "does", " ", "this", " ", "lead", " ", "to", " ", "a", " ", 
    RowBox[{"solution", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "form", " ", "the", " ", "5", "x5", " ", "matrix", " ", "of", " ", 
    "coefficients", " ", "and", " ", "find", " ", "the", " ", "determinant"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"xposcoeffs", "[", "n_", "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"0", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"1", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"2", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Sigma]s", 
         RowBox[{"3", ",", "0"}]], "[", "n", "]"}], ",", 
       SubscriptBox["\[Sigma]", 
        RowBox[{"4", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xnegcoeffs", "[", "n_", "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"0", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"1", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"2", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Tau]s", 
         RowBox[{"3", ",", "0"}]], "[", "n", "]"}], ",", 
       SubscriptBox["\[Tau]", 
        RowBox[{"4", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"xposcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "1"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xposcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "3"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xposcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "5"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xnegcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "7"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xnegcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "9"], "[", "12", "]"}]}]}]}], "}"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Simplificate", "/@", "#"}], "&"}], "/@", "%"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Det", "[", "%", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7614236597487717`*^9, 3.761423989137228*^9}, {
   3.761434699875793*^9, 3.761434776140442*^9}, 3.7664490172460003`*^9, {
   3.766449053519*^9, 3.766449126007*^9}, {3.767654341176701*^9, 
   3.767654344818873*^9}},
 CellLabel->
  "In[440]:=",ExpressionUUID->"f20bd80a-ea31-41be-a4f5-deb9f63963c4"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "40"],
  SeriesData[$CellContext`t, 0, {}, 40, 40, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.761423794275278*^9, {3.761423827778474*^9, 3.761423903357181*^9}, {
   3.761423950024542*^9, 3.761423995054824*^9}, 3.761434783781448*^9, 
   3.761443797114362*^9, 3.761514649431017*^9, 3.767581046988303*^9, 
   3.767583317457303*^9, 3.767583578016303*^9, 3.7675882356353035`*^9, 
   3.767651657476451*^9, 3.767654675298987*^9, 3.78915890472129*^9},
 CellLabel->
  "Out[444]=",ExpressionUUID->"b40d20a6-3aba-40ff-8ff7-f8ebea26a61e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"it", " ", "appears", " ", "not"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.761425920054514*^9, 3.7614259237733803`*^9}},
 CellLabel->
  "In[445]:=",ExpressionUUID->"ad238bd2-4a60-431f-a942-a1a5b80f812e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "introduce", " ", "a", " ", "sixth", " ", 
    "equation", " ", "by", " ", "taking", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{"x", "^", "0"}], "]"}], " ", "part", " ", "of", " ", "eqn", " ", 
    
    RowBox[{"(", "5.20", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"x", ",", "0"}]], "/", 
      RowBox[{"x", "^", "4"}]}], "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"x0LHS1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "4"}]}], "}"}]}], "]"}], "*", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "3"}]}], "}"}]}], "]"}], "*", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "2"}]}], "}"}]}], "]"}], "*", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], "*", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}], "//", "Simplify"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.761425930920553*^9, 3.7614259537442408`*^9}, {
  3.761426373764718*^9, 3.761426407481247*^9}, {3.761426474771332*^9, 
  3.7614264850907927`*^9}, {3.761426685511417*^9, 3.761426751786392*^9}},
 CellLabel->
  "In[446]:=",ExpressionUUID->"58314e3d-41e4-407f-9684-730db61131ea"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", 
     SubsuperscriptBox["XX", "3", "4"]}]], 
   RowBox[{"c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"4", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"8", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"32", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"96", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"3", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"18", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"36", " ", "t", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["t", "4"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"5", "+", 
                  RowBox[{"8", " ", 
                   SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"35", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"30", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"108", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"64", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"32", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"448", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"768", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"24", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"36", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"32", " ", "t", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"128", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"5", "+", 
                  RowBox[{"64", " ", 
                   SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"35", " ", 
             SuperscriptBox["t", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"240", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"192", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"512", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"256", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"128", " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"768", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "192"}], " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"256", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "-", 
            RowBox[{"384", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "-", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"9", " ", 
                SuperscriptBox["t", "2"]}], "-", 
               RowBox[{"8", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"24", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"48", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"16", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["t", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", 
                  RowBox[{"32", " ", 
                   SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
            "-", 
            RowBox[{"105", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"80", " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"144", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"288", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"768", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"384", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"384", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"12", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"24", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"18", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"24", " ", "t", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "4"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"5", "+", 
                  RowBox[{"80", " ", 
                   SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"35", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"120", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"144", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"64", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"320", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"640", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "t"}], "-", 
               RowBox[{"4", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"24", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"24", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"t", " ", 
                RowBox[{"(", 
                 RowBox[{"5", "-", 
                  RowBox[{"48", " ", 
                   SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"35", " ", "t", " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"40", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"144", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"192", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"384", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["XX", "3", "4"]}], "+", 
               RowBox[{"16", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "4"]}]}], ")"}]}], "+", 
            RowBox[{"35", " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"48", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"96", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"256", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"128", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", "b", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "t"}], "-", 
               RowBox[{"4", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"48", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"8", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"112", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "-", 
            RowBox[{"15", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"112", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"80", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"48", " ", "t", " ", 
                SubsuperscriptBox["XX", "3", "4"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "4"], " ", 
                SubsuperscriptBox["XX", "3", "4"]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "48"}], " ", "t", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "4"], " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "-", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "4"]}], "+", 
               RowBox[{
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", " ", 
                   SubscriptBox["XX", "3"]}], "-", 
                  RowBox[{"16", " ", 
                   SubsuperscriptBox["XX", "3", "4"]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"35", " ", 
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"288", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"64", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"64", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"1408", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"64", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"384", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "0"}]], " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"128", " ", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "4"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"12", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"80", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"18", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubscriptBox["XX", "3"]}], "-", 
               RowBox[{"80", " ", "t", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"176", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{
                SuperscriptBox["t", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"5", "+", 
                  RowBox[{"16", " ", 
                   SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"35", " ", 
             SuperscriptBox["t", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"120", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"480", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"704", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "+", 
            RowBox[{"64", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "3"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"128", " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}], "-", 
            RowBox[{"1536", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "4"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"32", " ", 
          SubsuperscriptBox["XX", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{"t", "-", 
               RowBox[{"4", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}], " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"8", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"16", " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "16"}], " ", 
          SubsuperscriptBox["XX", "3", "2"], " ", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], "+", 
         RowBox[{"12", " ", "b", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"2", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"8", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"16", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"2", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "t"}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"10", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"20", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"40", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"56", " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               SubscriptBox["XX", "3"]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "t"}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"12", " ", 
                SuperscriptBox["t", "2"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"40", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", " ", "t"}], "+", 
               RowBox[{"22", " ", 
                SubscriptBox["XX", "3"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"15", " ", 
                SuperscriptBox["t", "2"]}], "+", 
               RowBox[{"44", " ", "t", " ", 
                SubscriptBox["XX", "3"]}], "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "+", 
               RowBox[{"24", " ", 
                SuperscriptBox["t", "3"], " ", 
                SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7614263906278152`*^9, 3.761426407731395*^9}, {
   3.761426477927215*^9, 3.761426486638192*^9}, {3.7614267452150106`*^9, 
   3.7614267603634253`*^9}, 3.761443806457554*^9, 3.761514658542856*^9, 
   3.7675810567583036`*^9, {3.767583326488303*^9, 3.7675833266693034`*^9}, 
   3.7675835869663033`*^9, 3.7675882437833033`*^9, 3.767651679992113*^9, 
   3.78915891505541*^9},
 CellLabel->
  "Out[447]=",ExpressionUUID->"373ca76e-663d-4011-8404-2d6200829150"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Nu]", "0", "d"], "/", 
    RowBox[{"x", "^", "4"}]}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "Infinity", ",", 
         RowBox[{"-", "2"}]}], "}"}]}], "]"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "Infinity", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "//", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"#", ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{"t", ">", "0"}]}]}], "]"}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"Q21eqn", "\[Equal]", "0"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Q20eqn", "\[Equal]", "0"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Q30eqn", "\[Equal]", "0"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "1"}]]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"x0LHS2", "=", 
  RowBox[{"%", "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.761426413618462*^9, 3.761426439825796*^9}, {
  3.7614264941659803`*^9, 3.761426495237233*^9}, {3.761426783918199*^9, 
  3.761426843994231*^9}, {3.761432753661491*^9, 3.7614328875363894`*^9}},
 CellLabel->
  "In[448]:=",ExpressionUUID->"130726f9-7f5c-440a-8198-e3acf750b152"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "a", " ", "c", " ", "t", " ", 
  SqrtBox[
   SubscriptBox["XX", "3"]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "a"}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "0"}]]}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], "-", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]]}], ")"}], " ", "t"}]}], ")"}]}]}], 
      ")"}]}], "-", 
    FractionBox[
     RowBox[{"4", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "-", 
        RowBox[{"a", " ", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]], " ", "t"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "b"}], "+", 
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox["t", "3"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["XX", "1"], "+", 
           SubscriptBox["XX", "2"]}], ")"}]}]}], ")"}]}], "a"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "b"}], "+", 
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", 
           SuperscriptBox["t", "3"]}], "-", 
          RowBox[{"2", " ", "a", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "b"}], "+", 
             SuperscriptBox["b", "2"], "+", 
             RowBox[{
              SuperscriptBox["b", "3"], " ", 
              SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["t", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "b"}], "-", 
             SuperscriptBox["b", "2"], "+", 
             RowBox[{
              SuperscriptBox["b", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                SuperscriptBox["t", "3"]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "b"}], "-", 
             RowBox[{
              SuperscriptBox["b", "3"], " ", 
              SuperscriptBox["t", "3"]}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["XX", "1"], "-", 
           SubscriptBox["XX", "2"]}], ")"}], "2"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "b"}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "b"}], "+", 
                RowBox[{"a", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", " ", "b"}]}], ")"}]}]}], ")"}], " ", 
              SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["XX", "1"], "+", 
          SubscriptBox["XX", "2"]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.7614264230379267`*^9, 3.761426440285077*^9}, 
   3.761426495639264*^9, {3.7614268324157753`*^9, 3.7614268448225193`*^9}, {
   3.7614328107492247`*^9, 3.7614328900732803`*^9}, 3.761443807472254*^9, 
   3.761514659552512*^9, 3.767581057745303*^9, 3.767583327608303*^9, 
   3.7675835877983036`*^9, 3.7675882446873035`*^9, 3.767651690966029*^9, 
   3.78915891601366*^9},
 CellLabel->
  "Out[451]=",ExpressionUUID->"780e1dd4-288a-4e9d-a064-9b2cef2dd4c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"1", ",", "0"}]], "/", 
       RowBox[{"x", "^", "4"}]}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "+", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", 
        RowBox[{"1", ",", "0"}]], "/", 
       RowBox[{"x", "^", "4"}]}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"x0RHS1", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"t", ">", "0"}]}]}], "]"}], "*", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]]}]}]}], "Input",
 CellChangeTimes->{{3.7614269177704144`*^9, 3.761427029894157*^9}},
 CellLabel->
  "In[452]:=",ExpressionUUID->"7edafe85-8022-444d-92c4-365d68ee5b67"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["XX", "3", "3"]}]], 
   RowBox[{"c", " ", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["XX", "3"]}], "-", 
         RowBox[{"2", " ", "b", " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"b", " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"4", " ", 
             SubsuperscriptBox["XX", "3", 
              RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", "b"}]}], ")"}], " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"4", " ", "t", " ", 
          SubsuperscriptBox["XX", "3", 
           RowBox[{"3", "/", "2"}]]}], "+", 
         RowBox[{"b", " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["XX", "3", 
              RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SubsuperscriptBox["XX", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"4", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", 
              RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "6"}], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"24", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"t", " ", 
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", "3"]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{"4", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["XX", "3", "2"], "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"16", " ", 
                SubscriptBox["XX", "1"], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}], "+", 
               RowBox[{"16", " ", 
                SubscriptBox["XX", "2"], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"15", "-", 
               RowBox[{"48", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"16", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["XX", "1"], "+", 
                  SubscriptBox["XX", "2"]}], ")"}], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          SubsuperscriptBox["XX", "3", "3"]}], "-", 
         RowBox[{"4", " ", "b", " ", 
          SubscriptBox["XX", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["t", "2"]}], "+", 
            RowBox[{"22", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"3", " ", "t", " ", 
             SubscriptBox["XX", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"48", " ", 
                SubsuperscriptBox["XX", "3", "2"]}], "-", 
               RowBox[{"32", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"16", " ", 
                SubscriptBox["XX", "1"], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}], "+", 
               RowBox[{"16", " ", 
                SubscriptBox["XX", "2"], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"88", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "+", 
            RowBox[{"4", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"21", "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"16", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["XX", "1"], "+", 
                  SubscriptBox["XX", "2"]}], ")"}], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubsuperscriptBox["XX", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"t", "+", 
            RowBox[{"6", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"4", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", 
              RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             SuperscriptBox["t", "3"]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["t", "4"], " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "-", 
            RowBox[{"6", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{"t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"17", "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["t", "2"], " ", 
             SubscriptBox["XX", "3"]}], "-", 
            RowBox[{"48", " ", 
             SubsuperscriptBox["XX", "3", "3"]}], "-", 
            RowBox[{"16", " ", "t", " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"2", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"16", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"16", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["XX", "1"], "+", 
                  SubscriptBox["XX", "2"]}], ")"}], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", "t", " ", 
             SubscriptBox["XX", "3"]}], "+", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["XX", "3", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["t", "3"], " ", 
             SubsuperscriptBox["XX", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["t", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "15"}], "+", 
               RowBox[{"48", " ", 
                SubsuperscriptBox["XX", "3", "3"]}], "+", 
               RowBox[{"16", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["XX", "1"], "+", 
                  SubscriptBox["XX", "2"]}], ")"}], " ", 
                SubsuperscriptBox["XX", "3", 
                 RowBox[{"7", "/", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.761426929523447*^9, 3.761426939196048*^9}, {
   3.7614270096804447`*^9, 3.761427034101532*^9}, 3.761443810758189*^9, 
   3.7615146626448097`*^9, 3.7675810615663033`*^9, 3.7675833313053036`*^9, 
   3.7675835914963036`*^9, 3.7675882481373034`*^9, 3.767651698391986*^9, 
   3.789158920143406*^9},
 CellLabel->
  "Out[453]=",ExpressionUUID->"dbd4b95d-45c4-4f56-a02d-5a9f8c44e0b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"2", ",", "0"}]], "/", 
       RowBox[{"x", "^", "4"}]}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "+", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", 
        RowBox[{"2", ",", "0"}]], "/", 
       RowBox[{"x", "^", "4"}]}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"x0RHS2", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"t", ">", "0"}]}]}], "]"}], "*", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]]}]}]}], "Input",
 CellChangeTimes->{{3.761427048953059*^9, 3.761427056771077*^9}},
 CellLabel->
  "In[454]:=",ExpressionUUID->"16be9a26-8d90-48ee-b18c-afa8e0c8789e"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "b"}], ")"}], " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "0"}]], " ", 
   SuperscriptBox["t", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SubscriptBox["XX", "3"]}], "+", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "t"}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["XX", "3"]}], "+", 
        RowBox[{"4", " ", "t", " ", 
         SubsuperscriptBox["XX", "3", 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", 
        RowBox[{"2", " ", "b", " ", "t"}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["XX", "3"]}], "+", 
        RowBox[{"4", " ", "t", " ", 
         SubsuperscriptBox["XX", "3", 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   SubscriptBox["XX", "3"]}]]], "Output",
 CellChangeTimes->{3.76142705936271*^9, 3.76144381107076*^9, 
  3.761514662895553*^9, 3.767581061705303*^9, 3.7675833314253035`*^9, 
  3.7675835916473036`*^9, 3.7675882482693033`*^9, 3.767651702750168*^9, 
  3.7891589203080463`*^9},
 CellLabel->
  "Out[455]=",ExpressionUUID->"11cd1a88-a312-4104-81bc-6e316d71a32e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"3", ",", "0"}]], "/", 
       RowBox[{"x", "^", "4"}]}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "0"}], "}"}]}], "]"}], "+", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Nu]", 
        RowBox[{"3", ",", "0"}]], "/", 
       RowBox[{"x", "^", "4"}]}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "Infinity", ",", "0"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"x0RHS3", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"%", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"t", ">", "0"}]}]}], "]"}], "*", 
   SubscriptBox["Q", 
    RowBox[{"3", ",", "0"}]]}]}]}], "Input",
 CellChangeTimes->{{3.761427073365459*^9, 3.761427081814237*^9}},
 CellLabel->
  "In[456]:=",ExpressionUUID->"64b3cef0-dcd2-4586-8273-0f606ceee0c9"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
    SubscriptBox["Q", 
     RowBox[{"3", ",", "0"}]], " ", 
    SuperscriptBox["t", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "t"}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"4", " ", "t", " ", 
          SubsuperscriptBox["XX", "3", 
           RowBox[{"3", "/", "2"}]]}]}], ")"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", 
         RowBox[{"2", " ", "b", " ", "t"}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["XX", "3"]}], "+", 
         RowBox[{"4", " ", "t", " ", 
          SubsuperscriptBox["XX", "3", 
           RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], 
   SubscriptBox["XX", "3"]]}]], "Output",
 CellChangeTimes->{3.761427082161285*^9, 3.761443811337964*^9, 
  3.761514663076619*^9, 3.7675810617553034`*^9, 3.7675835917013035`*^9, 
  3.7675882483603034`*^9, 3.767651702906681*^9, 3.789158920390909*^9},
 CellLabel->
  "Out[457]=",ExpressionUUID->"230b9ce1-0c3e-4658-8e63-e6cbbd79e6d7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"x0RHS4s", "[", "N_", "]"}], ":=", 
  RowBox[{"ApplyToSeries", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", "#", "]"}], ",", "x", ",", "0"}], "]"}], "]"}],
      "&"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Mu]", "/", 
        RowBox[{"x", "^", "4"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Nu]", "/", 
        RowBox[{"x", "^", "4"}]}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SubscriptBox["\[CapitalDelta]", "0"], 
         SubscriptBox["\[CapitalDelta]", "m"]}], "]"}]}]}], "/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"\[Theta]s", "[", "N", "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.761274109051529*^9, 3.7612742618578367`*^9}, {
  3.761274538760294*^9, 3.761274592308329*^9}, {3.761274623731533*^9, 
  3.76127465082054*^9}, {3.761352398849794*^9, 3.761352422069652*^9}, {
  3.76142723566463*^9, 3.7614272794038477`*^9}},
 CellLabel->
  "In[458]:=",ExpressionUUID->"0775c64a-aa9d-4e18-9baa-ce667395ca46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x0RHS5s", "[", "N_", "]"}], ":=", 
  RowBox[{
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Factor", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", "#", "]"}], ",", "x", ",", "0"}], "]"}], 
       "]"}], "&"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"0", ",", "0"}]], "/", 
         RowBox[{"x", "^", "4"}]}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "0"}]], "/", 
         RowBox[{"x", "^", "4"}]}], "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", "0"], 
          SubscriptBox["\[CapitalDelta]", "m"]}], "]"}]}]}], "/.", 
      RowBox[{
       SubscriptBox["\[Theta]", 
        RowBox[{"0", ",", "0"}]], "\[Rule]", 
       RowBox[{
        SubscriptBox["\[Theta]s", 
         RowBox[{"0", ",", "0"}]], "[", "N", "]"}]}]}]}], "]"}], "*", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761274658211693*^9, 3.761274733576651*^9}, {
  3.7613524318801823`*^9, 3.76135245742839*^9}, {3.76142729443589*^9, 
  3.761427325845195*^9}, {3.761433756692326*^9, 3.7614337634066343`*^9}},
 CellLabel->
  "In[459]:=",ExpressionUUID->"1b3cc6aa-917d-4408-ab5b-fa8dda59274d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"1", ",", "0"}]], ",", 
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"2", ",", "0"}]], ",", 
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"3", ",", "0"}]], ",", 
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"4", ",", "0"}]], ",", "x000", ",", "\[Zeta]0s", ",", 
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"0", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Zeta]0", 
   RowBox[{"1", ",", "0"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "x0LHS1"}], "-", "x0LHS2", "+", "x0RHS1", "+", "x0RHS2", 
       "+", "x0RHS3"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "]"}], "//", "Simplify"}], "//", 
   "Factor"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Zeta]0", 
   RowBox[{"2", ",", "0"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "x0LHS1"}], "-", "x0LHS2", "+", "x0RHS1", "+", "x0RHS2", 
       "+", "x0RHS3"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], "]"}], "//", "Simplify"}], "//", 
   "Factor"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Zeta]0", 
   RowBox[{"3", ",", "0"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "x0LHS1"}], "-", "x0LHS2", "+", "x0RHS1", "+", "x0RHS2", 
       "+", "x0RHS3"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "0"}]]}], "]"}], "//", "Simplify"}], "//", 
   "Factor"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Zeta]0", 
   RowBox[{"4", ",", "0"}]], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "x0LHS1"}], "-", "x0LHS2", "+", "x0RHS1", "+", "x0RHS2", 
       "+", "x0RHS3"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"4", ",", "0"}]]}], "]"}], "//", "Simplify"}], "//", 
   "Factor"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"1", ",", "0"}]], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Zeta]0s", 
     RowBox[{"1", ",", "0"}]], "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0", 
         RowBox[{"1", ",", "0"}]], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["XX", "1"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "2"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "3"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"2", ",", "0"}]], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Zeta]0s", 
     RowBox[{"2", ",", "0"}]], "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0", 
         RowBox[{"2", ",", "0"}]], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["XX", "1"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "2"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "3"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"3", ",", "0"}]], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Zeta]0s", 
     RowBox[{"3", ",", "0"}]], "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0", 
         RowBox[{"3", ",", "0"}]], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["XX", "1"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "2"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "3"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"4", ",", "0"}]], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Zeta]0s", 
     RowBox[{"4", ",", "0"}]], "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0", 
         RowBox[{"4", ",", "0"}]], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["XX", "1"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "2"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "3"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x000", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"x000", "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "x0LHS1"}], "-", "x0LHS2", "+", "x0RHS1", "+", 
           "x0RHS2", "+", "x0RHS3"}], ",", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["XX", "1"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "2"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["XX", "3"], "\[Rule]", 
           RowBox[{
            SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]0s", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Zeta]0s", "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"x0RHS4s", "[", "n", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "//", 
         "Simplificate"}], ")"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Zeta]0s", 
    RowBox[{"0", ",", "0"}]], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Zeta]0s", 
     RowBox[{"0", ",", "0"}]], "[", "n", "]"}], "=", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"x0RHS5s", "[", "n", "]"}], "/", 
            RowBox[{"Q", "[", 
             RowBox[{"0", ",", "0"}], "]"}]}], "+", 
           RowBox[{"x000", "[", "n", "]"}]}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["XX", "1"], "\[Rule]", 
            RowBox[{
             SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
           RowBox[{
            SubscriptBox["XX", "2"], "\[Rule]", 
            RowBox[{
             SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
           RowBox[{
            SubscriptBox["XX", "3"], "\[Rule]", 
            RowBox[{
             SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "//", 
        "Simplificate"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"t", ">", "0"}]}]}], "]"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.761433161837509*^9, 3.7614332166998243`*^9}, {
  3.761433276789423*^9, 3.761433278093141*^9}, {3.761433360773334*^9, 
  3.761433409565021*^9}, {3.7614334602718573`*^9, 3.761433727914003*^9}, {
  3.7614337826700563`*^9, 3.761433819737208*^9}, {3.761433866866349*^9, 
  3.761433903282957*^9}, {3.761433946991905*^9, 3.761433978457222*^9}},
 CellLabel->
  "In[460]:=",ExpressionUUID->"6767a123-324b-43da-be73-66054575982e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["XX", "3", "2"]}]], 
  RowBox[{"c", " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["a", "3"], " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "4"], " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SubscriptBox["XX", "3"]}], "-", 
     RowBox[{"8", " ", "a", " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"24", " ", 
      SuperscriptBox["a", "2"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"20", " ", 
      SuperscriptBox["a", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "4"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"8", " ", "b", " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"40", " ", "a", " ", "b", " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"68", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"40", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "2"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"32", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"44", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"20", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"40", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "+", 
     RowBox[{"24", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubsuperscriptBox["XX", "3", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "2"], " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"24", " ", 
      SuperscriptBox["a", "3"], " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"16", " ", "a", " ", "b", " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"56", " ", 
      SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"16", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"40", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"24", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "t", " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", 
      SuperscriptBox["t", "4"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["t", "4"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "1"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "1"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "1"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "1"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", "b", " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubsuperscriptBox["XX", "3", 
       RowBox[{"5", "/", "2"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.761433211182518*^9, 3.7614332173705378`*^9}, 
   3.761433287280332*^9, {3.761433365720461*^9, 3.761433378037436*^9}, 
   3.7614334112723293`*^9, {3.761433500820238*^9, 3.761433553090164*^9}, 
   3.7614335964501657`*^9, {3.761433681281795*^9, 3.761433689661495*^9}, {
   3.761433806695714*^9, 3.76143382166322*^9}, 3.761434023689045*^9, 
   3.761443812371229*^9, 3.761514663953361*^9, 3.7675810628923035`*^9, 
   3.7675835927513037`*^9, 3.7675882494653034`*^9, 3.767651712378289*^9, 
   3.789158921665298*^9},
 CellLabel->
  "Out[461]=",ExpressionUUID->"e73ccafb-9a18-4815-9eb1-8a14f752974a"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["XX", "3", "2"]}]], 
   RowBox[{"c", " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"8", " ", "a", " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"52", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"28", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"40", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"76", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"64", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"20", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"32", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"44", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"20", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"48", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "+", 
      RowBox[{"48", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"48", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "3", "2"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"40", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"56", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"64", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"40", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "t", " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubsuperscriptBox["XX", "3", 
        RowBox[{"5", "/", "2"}]]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.761433211182518*^9, 3.7614332173705378`*^9}, 
   3.761433287280332*^9, {3.761433365720461*^9, 3.761433378037436*^9}, 
   3.7614334112723293`*^9, {3.761433500820238*^9, 3.761433553090164*^9}, 
   3.7614335964501657`*^9, {3.761433681281795*^9, 3.761433689661495*^9}, {
   3.761433806695714*^9, 3.76143382166322*^9}, 3.761434023689045*^9, 
   3.761443812371229*^9, 3.761514663953361*^9, 3.7675810628923035`*^9, 
   3.7675835927513037`*^9, 3.7675882494653034`*^9, 3.767651712378289*^9, 
   3.7891589232394457`*^9},
 CellLabel->
  "Out[462]=",ExpressionUUID->"91404755-7efe-4fbc-9f67-458980f024c7"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "b"}], ")"}], " ", "c", " ", 
  SuperscriptBox["t", "3"], " ", 
  RowBox[{"(", 
   RowBox[{"a", "+", "b", "-", 
    RowBox[{"2", " ", "a", " ", "b"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SqrtBox[
      SubscriptBox["XX", "3"]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.761433211182518*^9, 3.7614332173705378`*^9}, 
   3.761433287280332*^9, {3.761433365720461*^9, 3.761433378037436*^9}, 
   3.7614334112723293`*^9, {3.761433500820238*^9, 3.761433553090164*^9}, 
   3.7614335964501657`*^9, {3.761433681281795*^9, 3.761433689661495*^9}, {
   3.761433806695714*^9, 3.76143382166322*^9}, 3.761434023689045*^9, 
   3.761443812371229*^9, 3.761514663953361*^9, 3.7675810628923035`*^9, 
   3.7675835927513037`*^9, 3.7675882494653034`*^9, 3.767651712378289*^9, 
   3.789158923363366*^9},
 CellLabel->
  "Out[463]=",ExpressionUUID->"8be3e780-89a7-4681-be9e-8973c1f1f557"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
  SuperscriptBox["t", "4"], " ", 
  RowBox[{"(", 
   RowBox[{"a", "+", "b", "-", 
    RowBox[{"2", " ", "a", " ", "b"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SqrtBox[
      SubscriptBox["XX", "3"]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.761433211182518*^9, 3.7614332173705378`*^9}, 
   3.761433287280332*^9, {3.761433365720461*^9, 3.761433378037436*^9}, 
   3.7614334112723293`*^9, {3.761433500820238*^9, 3.761433553090164*^9}, 
   3.7614335964501657`*^9, {3.761433681281795*^9, 3.761433689661495*^9}, {
   3.761433806695714*^9, 3.76143382166322*^9}, 3.761434023689045*^9, 
   3.761443812371229*^9, 3.761514663953361*^9, 3.7675810628923035`*^9, 
   3.7675835927513037`*^9, 3.7675882494653034`*^9, 3.767651712378289*^9, 
   3.789158923472364*^9},
 CellLabel->
  "Out[464]=",ExpressionUUID->"cd1b3ead-0fad-4641-948a-06a5730d328f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"1", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"2", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"3", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"4", ",", "0"}]], "[", "9", "]"}], 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]]}], "+", 
      RowBox[{"\[Zeta]0s", "[", "9", "]"}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"0", ",", "0"}]], "[", "9", "]"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "2", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "3", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "4", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "//", "Simplificate"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", "%"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.761434114069665*^9, 3.761434237533805*^9}},
 CellLabel->
  "In[472]:=",ExpressionUUID->"75b93e75-2161-48a9-96e5-ee6477fa2b08"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761434188745977*^9, 3.761434241180501*^9}, 
   3.761443816665571*^9, 3.7615146674569693`*^9, 3.7675810657873034`*^9, 
   3.767583595502303*^9, 3.7675882521373034`*^9, 3.7676517267451477`*^9, 
   3.789158927829756*^9},
 CellLabel->
  "Out[474]=",ExpressionUUID->"fb13e624-4e0e-4c1c-897c-3967e63935f6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "combine", " ", "this", " ", "with", " ", "the", " ", "other", 
    " ", "equations", " ", "to", " ", "see", " ", "if", " ", "anything", " ", 
    "new", " ", "is", " ", "achieved"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "x0coeffs", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x0coeffs", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"x0coeffs", "[", "n", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"0", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"1", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"2", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"3", ",", "0"}]], "[", "n", "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Zeta]0s", 
         RowBox[{"4", ",", "0"}]], "[", "n", "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"xposcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "1"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xposcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "3"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xposcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "5"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xnegcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "7"], "[", "12", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"xnegcoeffs", "[", "12", "]"}], "/.", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         SubscriptBox["xs", "9"], "[", "12", "]"}]}]}], ",", 
      RowBox[{"x0coeffs", "[", "12", "]"}]}], "}"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Simplificate", "/@", "#"}], "&"}], "/@", "%"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "there", " ", "are", " ", "6", " ", "possible", " ", "combinations"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Det", "[", 
      RowBox[{"Drop", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Det", "[", 
      RowBox[{"Drop", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Det", "[", 
      RowBox[{"Drop", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", "3", "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Det", "[", 
      RowBox[{"Drop", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", "4", "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Det", "[", 
      RowBox[{"Drop", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", "5", "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Det", "[", 
      RowBox[{"Drop", "[", 
       RowBox[{"%", ",", 
        RowBox[{"{", "6", "}"}]}], "]"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.761434628479549*^9, 3.761434667316146*^9}, {
   3.7614347990695066`*^9, 3.761434870579287*^9}, {3.7614349255915194`*^9, 
   3.76143501422077*^9}, {3.761435056912006*^9, 3.76143506380516*^9}, {
   3.761446650670137*^9, 3.7614466621768427`*^9}, 3.766449017259*^9, {
   3.7664490535299997`*^9, 3.76644912602*^9}},
 CellLabel->
  "In[475]:=",ExpressionUUID->"b4f1acf2-11bb-4210-a42e-e43106652298"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "36"],
    SeriesData[$CellContext`t, 0, {}, 36, 36, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "36"],
    SeriesData[$CellContext`t, 0, {}, 36, 36, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "36"],
    SeriesData[$CellContext`t, 0, {}, 36, 36, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "36"],
    SeriesData[$CellContext`t, 0, {}, 36, 36, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "36"],
    SeriesData[$CellContext`t, 0, {}, 36, 36, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "40"],
    SeriesData[$CellContext`t, 0, {}, 40, 40, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.7614348782815847`*^9, 3.7614349586441593`*^9, 
  3.761434990784513*^9, 3.7614350299751797`*^9, 3.761435156979187*^9, 
  3.7614439115885897`*^9, 3.7614467302545033`*^9, 3.76151475984134*^9, 
  3.7675812670763035`*^9, 3.767583731139303*^9, 3.7675884036473036`*^9, 
  3.767651944126156*^9, 3.789159027336609*^9},
 CellLabel->
  "Out[479]=",ExpressionUUID->"b653ea38-77f2-4e9d-ae38-79cc14556cf1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 5.4",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.760824004669656*^9, 
  3.760824006907593*^9}, {3.760832918548829*^9, 3.760832918581484*^9}, {
  3.7614354513057213`*^9, 
  3.761435451330634*^9}},ExpressionUUID->"f9364c48-88c0-4979-a30b-\
5156a8142f79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "at", " ", "this", " ", "point", " ", "we", " ", "can", " ", 
    "\"\<cheat\>\"", " ", "and", " ", "use", " ", "the", " ", "fact", " ", 
    "that", " ", "we", " ", "already", " ", "know", " ", "the", " ", 
    "solution", " ", "to", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
     "and", " ", "know", " ", "that", " ", "it", " ", "is", " ", 
      "algebraic"}], ")"}], " ", "because", " ", 
    RowBox[{"it", "'"}], "s", " ", "the", " ", "same", " ", "for", " ", 
    "Kreweras", " ", "and", " ", "reverse", " ", "Kreweras"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"so", " ", "in", " ", "fact", " ", "we", " ", 
     RowBox[{"don", "'"}], "t", " ", "have", " ", "5", " ", "unknowns"}], ",",
     " ", 
    RowBox[{"we", " ", "only", " ", "have", " ", "4"}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7614354675234823`*^9, 3.761435522162425*^9}},
 CellLabel->
  "In[480]:=",ExpressionUUID->"bc849eb1-77dd-4122-9d3c-56f11f3ee00b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "from", " ", "our", " ", "6", " ", "equations", " ", "we", " ", "then", 
    " ", "have", " ", "15", " ", "possible", " ", "combinations"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "note", " ", "that", " ", "all", " ", "these", " ", "matrices", " ", 
    "contain", " ", "only", " ", "algebraic", " ", "terms"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "all6eqns", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"all6eqns", "[", "n_", "]"}], ":=", 
     RowBox[{
      RowBox[{"all6eqns", "[", "n", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Simplificate", "/@", "#"}], "&"}], "/@", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", "1", "}"}]}], "]"}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"xposcoeffs", "[", "n", "]"}], "/.", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              SubscriptBox["xs", "1"], "[", "n", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"xposcoeffs", "[", "n", "]"}], "/.", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              SubscriptBox["xs", "3"], "[", "n", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"xposcoeffs", "[", "n", "]"}], "/.", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              SubscriptBox["xs", "5"], "[", "n", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"xnegcoeffs", "[", "n", "]"}], "/.", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              SubscriptBox["xs", "7"], "[", "n", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"xnegcoeffs", "[", "n", "]"}], "/.", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              SubscriptBox["xs", "9"], "[", "n", "]"}]}]}], ",", 
           RowBox[{"x0coeffs", "[", "n", "]"}]}], "}"}]}], ")"}]}]}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "10", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "10", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "10", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "10", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "11", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "11", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "11", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "11", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "4", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "9", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"all6eqns", "[", "13", "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], "]"}]}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.761435556266782*^9, 3.761435683963278*^9}, {
   3.761435743208123*^9, 3.7614358572770023`*^9}, {3.761436081337688*^9, 
   3.761436170765121*^9}, {3.761436208038022*^9, 3.761436359240869*^9}, {
   3.761436398987875*^9, 3.761436424053356*^9}, {3.761436457773595*^9, 
   3.761436462799848*^9}, {3.761436542568111*^9, 3.761436579140354*^9}, {
   3.7614366454638844`*^9, 3.761436685399255*^9}, {3.761436724590788*^9, 
   3.761436792737225*^9}, {3.7614368652458267`*^9, 3.761436874689259*^9}, {
   3.761436957554432*^9, 3.761436982331316*^9}, {3.7614374558636017`*^9, 
   3.761437459242855*^9}, {3.7614384016073303`*^9, 3.761438422085394*^9}, {
   3.761444252189279*^9, 3.7614442610911922`*^9}, {3.761446681777268*^9, 
   3.761446696832333*^9}, 3.766449017266*^9, {3.7664490535369997`*^9, 
   3.766449126027*^9}, 3.7676543172695637`*^9, {3.767655342122447*^9, 
   3.767655348709223*^9}},
 CellLabel->
  "In[481]:=",ExpressionUUID->"d148db2e-cb41-4d32-ad5d-a94a9842d87c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"16", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], "3"], " ", 
     SuperscriptBox["a", "12"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], "5"], " ", 
     SuperscriptBox["b", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", 
       SuperscriptBox["a", "2"], "+", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", 
       RowBox[{"a", " ", "b"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "5"], " ", 
     SuperscriptBox["c", "4"], " ", 
     SuperscriptBox["t", "26"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "4"]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "28"],
    SeriesData[$CellContext`t, 0, {}, 26, 28, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   16 (-1 + $CellContext`a)^3 $CellContext`a^12 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^5 $CellContext`b^5 (-2 + \
$CellContext`a + $CellContext`b)^(-4) ((-2) $CellContext`a + $CellContext`a^2 + \
$CellContext`b) (-$CellContext`a - $CellContext`b + $CellContext`a \
$CellContext`b) (-$CellContext`a - $CellContext`b + 
      2 $CellContext`a $CellContext`b)^5 $CellContext`c^4}, 26, 28, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.7891591502511663`*^9},
 CellLabel->
  "Out[483]=",ExpressionUUID->"3ac24820-82f7-4f5f-a5b1-4109d7271344"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"512", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "5"], " ", 
        SuperscriptBox["a", "10"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "4"], " ", 
        SuperscriptBox["b", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", 
          RowBox[{"a", " ", "b"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "5"], " ", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      SuperscriptBox["t", "32"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "4"]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "34"],
    SeriesData[$CellContext`t, 0, {}, 32, 34, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-512) (-1 + $CellContext`a)^5 $CellContext`a^10 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^4 $CellContext`b^8 (-2 + \
$CellContext`a + $CellContext`b)^(-4) (-$CellContext`a - $CellContext`b + \
$CellContext`a $CellContext`b) (-$CellContext`a - $CellContext`b + 
      2 $CellContext`a $CellContext`b)^5 $CellContext`c^4}, 32, 34, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159229653245*^9},
 CellLabel->
  "Out[484]=",ExpressionUUID->"4290908e-e47a-44b6-befd-83801caccbb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "4"]], 
     RowBox[{"128", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "4"], " ", 
        SuperscriptBox["a", "8"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "4"], " ", 
        SuperscriptBox["b", "5"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"56", " ", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"84", " ", 
           SuperscriptBox["a", "3"]}], "+", 
          RowBox[{"28", " ", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"112", " ", "a", " ", "b"}], "-", 
          RowBox[{"392", " ", 
           SuperscriptBox["a", "2"], " ", "b"}], "+", 
          RowBox[{"395", " ", 
           SuperscriptBox["a", "3"], " ", "b"}], "-", 
          RowBox[{"111", " ", 
           SuperscriptBox["a", "4"], " ", "b"}], "+", 
          RowBox[{"56", " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"308", " ", "a", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"563", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"397", " ", 
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"82", " ", 
           SuperscriptBox["a", "4"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"56", " ", 
           SuperscriptBox["b", "3"]}], "+", 
          RowBox[{"196", " ", "a", " ", 
           SuperscriptBox["b", "3"]}], "-", 
          RowBox[{"223", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "3"]}], "+", 
          RowBox[{"82", " ", 
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["b", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "4"], " ", 
           SuperscriptBox["b", "3"]}]}], ")"}], " ", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      SuperscriptBox["t", "31"]}]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "32"],
    SeriesData[$CellContext`t, 0, {}, 31, 32, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-128) (-1 + $CellContext`a)^4 $CellContext`a^8 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^4 $CellContext`b^5 (-2 + \
$CellContext`a + $CellContext`b)^(-4) (-$CellContext`a - $CellContext`b + 
      2 $CellContext`a $CellContext`b)^5 (56 $CellContext`a^2 - 
     84 $CellContext`a^3 + 28 $CellContext`a^4 + 
     112 $CellContext`a $CellContext`b - 392 $CellContext`a^2 $CellContext`b + 
     395 $CellContext`a^3 $CellContext`b - 
     111 $CellContext`a^4 $CellContext`b + 56 $CellContext`b^2 - 
     308 $CellContext`a $CellContext`b^2 + 
     563 $CellContext`a^2 $CellContext`b^2 - 
     397 $CellContext`a^3 $CellContext`b^2 + 
     82 $CellContext`a^4 $CellContext`b^2 - 56 $CellContext`b^3 + 
     196 $CellContext`a $CellContext`b^3 - 
     223 $CellContext`a^2 $CellContext`b^3 + 
     82 $CellContext`a^3 $CellContext`b^3 + $CellContext`a^4 \
$CellContext`b^3) $CellContext`c^4}, 31, 32, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.7891593435563183`*^9},
 CellLabel->
  "Out[485]=",ExpressionUUID->"ad62f578-04b1-4486-b04f-6254c53ed2e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"16", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
       SuperscriptBox["a", "12"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
       SuperscriptBox["b", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "3"]}], "+", 
         RowBox[{"2", " ", "a", " ", "b"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b"}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["a", "3"], " ", "b"}], "-", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["b", "2"]}]}], ")"}], " ", 
       SuperscriptBox["c", "4"]}], ")"}], " ", 
     SuperscriptBox["t", "26"]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "28"],
    SeriesData[$CellContext`t, 0, {}, 26, 28, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-16) (-1 + $CellContext`a)^2 $CellContext`a^12 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^2 $CellContext`b^8 (-$CellContext`a - \
$CellContext`b + $CellContext`a $CellContext`b) (-$CellContext`a - \
$CellContext`b + 2 $CellContext`a $CellContext`b) (-$CellContext`a^2 + 
     2 $CellContext`a^3 + 
     2 $CellContext`a $CellContext`b - $CellContext`a^2 $CellContext`b - 
     3 $CellContext`a^3 $CellContext`b - $CellContext`b^2 + $CellContext`a \
$CellContext`b^2 - $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a^3 $CellContext`b^2) $CellContext`c^4}, 26, 28, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159343755118*^9},
 CellLabel->
  "Out[486]=",ExpressionUUID->"d5a9b846-985b-4e91-b60e-16dd8da732cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"16", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], "3"], " ", 
    SuperscriptBox["a", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], "5"], " ", 
    SuperscriptBox["b", "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", 
      SuperscriptBox["a", "2"], "+", "b"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", 
       RowBox[{"a", " ", "b"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox["t", "22"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "24"],
    SeriesData[$CellContext`t, 0, {}, 22, 24, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   16 (-1 + $CellContext`a)^3 $CellContext`a^12 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^5 $CellContext`b^5 ((-2) \
$CellContext`a + $CellContext`a^2 + $CellContext`b) (-$CellContext`a - \
$CellContext`b + $CellContext`a $CellContext`b)^2 $CellContext`c^4}, 22, 24, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159343846496*^9},
 CellLabel->
  "Out[487]=",ExpressionUUID->"ce6bd9bd-b7e9-4dcd-8283-60b6fc4fc403"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"512", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "5"], " ", 
       SuperscriptBox["a", "10"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "4"], " ", 
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", 
          RowBox[{"a", " ", "b"}]}], ")"}], "2"], " ", 
       SuperscriptBox["c", "4"]}], ")"}], " ", 
     SuperscriptBox["t", "28"]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "29"],
    SeriesData[$CellContext`t, 0, {}, 28, 29, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-512) (-1 + $CellContext`a)^5 $CellContext`a^10 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^4 $CellContext`b^8 (-$CellContext`a - \
$CellContext`b + $CellContext`a $CellContext`b)^2 $CellContext`c^4}, 28, 29, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.7891593489137077`*^9},
 CellLabel->
  "Out[488]=",ExpressionUUID->"4dc33e22-038b-48d6-b756-db30731975b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "3"], " ", 
        SuperscriptBox["a", "12"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
        SuperscriptBox["b", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "a"}], "+", 
          SuperscriptBox["a", "2"], "+", "b"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", 
          RowBox[{"a", " ", "b"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "5"], " ", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      SuperscriptBox["t", "26"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "4"]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "28"],
    SeriesData[$CellContext`t, 0, {}, 26, 28, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-16) (-1 + $CellContext`a)^3 $CellContext`a^12 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^2 $CellContext`b^6 (-2 + \
$CellContext`a + $CellContext`b)^(-4) ((-2) $CellContext`a + $CellContext`a^2 + \
$CellContext`b) (-$CellContext`a - $CellContext`b + $CellContext`a \
$CellContext`b) (-$CellContext`a - $CellContext`b + 
      2 $CellContext`a $CellContext`b)^5 $CellContext`c^4}, 26, 28, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159349239963*^9},
 CellLabel->
  "Out[489]=",ExpressionUUID->"737376ac-dfb5-4e62-9d63-cbfac78566fd"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "33"],
  SeriesData[$CellContext`t, 0, {}, 33, 33, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.78915959228936*^9},
 CellLabel->
  "Out[490]=",ExpressionUUID->"4c43310e-ad2d-41ba-9bc8-c94c0dc5b30a"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "33"],
  SeriesData[$CellContext`t, 0, {}, 33, 33, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.7891595950132847`*^9},
 CellLabel->
  "Out[491]=",ExpressionUUID->"311a99a3-1533-4a53-a0a0-d27d661a0fb4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"16", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], "3"], " ", 
    SuperscriptBox["a", "12"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
    SuperscriptBox["b", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", 
      SuperscriptBox["a", "2"], "+", "b"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", 
       RowBox[{"a", " ", "b"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox["t", "22"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "24"],
    SeriesData[$CellContext`t, 0, {}, 22, 24, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   16 (-1 + $CellContext`a)^3 $CellContext`a^12 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^2 $CellContext`b^6 ((-2) \
$CellContext`a + $CellContext`a^2 + $CellContext`b) (-$CellContext`a - \
$CellContext`b + $CellContext`a $CellContext`b)^2 $CellContext`c^4}, 22, 24, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159595164434*^9},
 CellLabel->
  "Out[492]=",ExpressionUUID->"9bf1dcf9-09d1-4c5b-8086-47c4badb5f60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"512", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
        SuperscriptBox["a", "11"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "4"], " ", 
        SuperscriptBox["b", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", 
          RowBox[{"a", " ", "b"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], "5"], " ", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      SuperscriptBox["t", "32"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "4"]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "33"],
    SeriesData[$CellContext`t, 0, {}, 32, 33, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-512) (-1 + $CellContext`a)^2 $CellContext`a^11 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^4 $CellContext`b^8 (-2 + \
$CellContext`a + $CellContext`b)^(-4) (-$CellContext`a - $CellContext`b + \
$CellContext`a $CellContext`b) (-$CellContext`a - $CellContext`b + 
      2 $CellContext`a $CellContext`b)^5 $CellContext`c^4}, 32, 33, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159598158519*^9},
 CellLabel->
  "Out[493]=",ExpressionUUID->"8eb70ae7-9d62-4822-a352-c6b885218d89"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "33"],
  SeriesData[$CellContext`t, 0, {}, 33, 33, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.7891596010568333`*^9},
 CellLabel->
  "Out[494]=",ExpressionUUID->"a17e57d6-a872-4166-bd6b-ad5f4dc6b205"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "33"],
  SeriesData[$CellContext`t, 0, {}, 33, 33, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159604964636*^9},
 CellLabel->
  "Out[495]=",ExpressionUUID->"0781d268-5e9b-4124-8d66-c0cb99ffdccb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"512", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
    SuperscriptBox["a", "11"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], "4"], " ", 
    SuperscriptBox["b", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", 
       RowBox[{"a", " ", "b"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox["t", "28"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "29"],
    SeriesData[$CellContext`t, 0, {}, 28, 29, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   512 (-1 + $CellContext`a)^2 $CellContext`a^11 ($CellContext`a - \
$CellContext`b)^3 (-1 + $CellContext`b)^4 $CellContext`b^8 (-$CellContext`a - \
$CellContext`b + $CellContext`a $CellContext`b)^2 $CellContext`c^4}, 28, 29, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159606192136*^9},
 CellLabel->
  "Out[496]=",ExpressionUUID->"d1538467-e9a2-4d5b-b420-919c1053d7d4"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "33"],
  SeriesData[$CellContext`t, 0, {}, 33, 33, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614357593611107`*^9, 3.761435813321019*^9}, 
   3.761435867900366*^9, 3.761436084073895*^9, 3.761436171697291*^9, {
   3.761436203448738*^9, 3.7614363074483833`*^9}, 3.761436426989057*^9, 
   3.761436465710648*^9, 3.761436583570484*^9, 3.761436687272019*^9, 
   3.7614367953919077`*^9, 3.761436879492765*^9, 3.761436996094199*^9, 
   3.7614374640420923`*^9, 3.761443921189283*^9, 3.761444266074195*^9, 
   3.761446730682817*^9, 3.761514768230958*^9, 3.767583738811303*^9, 
   3.7675884293933034`*^9, 3.7676520076169157`*^9, 3.76765432515714*^9, 
   3.7676553503511753`*^9, 3.789159609097563*^9},
 CellLabel->
  "Out[497]=",ExpressionUUID->"e9c6bc45-5fc6-4e4c-b639-9b5e51c9b011"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"ok", ",", " ", 
    RowBox[{
    "so", " ", "it", " ", "looks", " ", "like", " ", "at", " ", "least", " ", 
     "10", " ", "of", " ", "the", " ", "sets", " ", "will", " ", "work"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"generating", " ", "the", " ", "solutions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "xposknown", ",", "xnegknown", ",", "x0known", ",", "all6knowns"}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xposknown", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"xposknown", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "[", 
      RowBox[{
       RowBox[{"\[Sigma]s", "[", "n", "]"}], "+", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Sigma]s", 
          RowBox[{"0", ",", "0"}]], "[", "n", "]"}], "*", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"n", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xnegknown", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"xnegknown", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "[", 
      RowBox[{
       RowBox[{"\[Tau]s", "[", "n", "]"}], "+", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Tau]s", 
          RowBox[{"0", ",", "0"}]], "[", "n", "]"}], "*", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"n", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x0known", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"x0known", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "[", 
      RowBox[{
       RowBox[{"\[Zeta]0s", "[", "n", "]"}], "+", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Zeta]0s", 
          RowBox[{"0", ",", "0"}]], "[", "n", "]"}], "*", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"n", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"all6knowns", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"all6knowns", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "/@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"xposknown", "[", "n", "]"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{
           SubscriptBox["xs", "1"], "[", "n", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"xposknown", "[", "n", "]"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{
           SubscriptBox["xs", "3"], "[", "n", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"xposknown", "[", "n", "]"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{
           SubscriptBox["xs", "5"], "[", "n", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"xnegknown", "[", "n", "]"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{
           SubscriptBox["xs", "7"], "[", "n", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"xnegknown", "[", "n", "]"}], "/.", 
         RowBox[{"x", "\[Rule]", 
          RowBox[{
           SubscriptBox["xs", "9"], "[", "n", "]"}]}]}], ",", 
        RowBox[{"x0known", "[", "n", "]"}]}], "}"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.761438348725049*^9, 3.761438369866415*^9}, {
   3.76144113182113*^9, 3.761441140121811*^9}, {3.761441192515897*^9, 
   3.76144120451819*^9}, {3.7614413234456863`*^9, 3.76144138601926*^9}, {
   3.761441432865375*^9, 3.761441567193264*^9}, 3.7614416231450872`*^9, {
   3.761441760216874*^9, 3.761441838819998*^9}, 3.761442121384112*^9, {
   3.761442155898774*^9, 3.761442200156336*^9}, {3.7614422594296017`*^9, 
   3.761442262228116*^9}, {3.761442339381412*^9, 3.761442343203854*^9}, {
   3.761442430700391*^9, 3.761442466115981*^9}, {3.761442530330144*^9, 
   3.761442545516822*^9}, {3.761442840406062*^9, 3.761442843338863*^9}, {
   3.7614431263039827`*^9, 3.761443137281156*^9}, {3.7614432280810537`*^9, 
   3.761443239995263*^9}, {3.761444066604045*^9, 3.761444067019107*^9}, {
   3.761444439631365*^9, 3.761444513445573*^9}, {3.7614455309482813`*^9, 
   3.7614455477681017`*^9}, {3.761445596669553*^9, 3.7614456091837378`*^9}, {
   3.761445692640704*^9, 3.761445692750519*^9}, {3.761445759070259*^9, 
   3.761445770156*^9}, {3.7614458818690777`*^9, 3.761445914723892*^9}, {
   3.761446014511332*^9, 3.761446028219536*^9}, {3.761446345852091*^9, 
   3.76144636431901*^9}, {3.761446722930849*^9, 3.761446769483191*^9}, {
   3.761446853114403*^9, 3.761446855721106*^9}, {3.761446921987627*^9, 
   3.761446922556901*^9}, 3.7664490172720003`*^9, {3.766449053547*^9, 
   3.766449126032*^9}, {3.767654730767194*^9, 3.767654735019278*^9}, {
   3.767659255744646*^9, 3.767659296796363*^9}},
 CellLabel->
  "In[498]:=",ExpressionUUID->"73006410-e60f-465f-bf00-30292fe9bc3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Mathematica", " ", "seems", " ", "to", " ", "struggle", " ", "with", " ", 
    "expanding", " ", "some", " ", "of", " ", "the", " ", "matrix", " ", 
    "inverses"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "we", " ", "will", " ", "just", " ", "demonstrate", " ", "that",
     " ", "the", " ", "first", " ", "set", " ", "gives", " ", "the", " ", 
    "correct", " ", "result"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.767659300553288*^9, 3.7676593185205107`*^9}},
 CellLabel->
  "In[503]:=",ExpressionUUID->"3ccb8a7d-7883-4f02-b4b7-a2890d3cd0f9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"all6eqns", "[", "13", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"all6eqns", "[", "13", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"all6eqns", "[", "13", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"all6eqns", "[", "13", "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}], ".", 
    RowBox[{"-", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"all6knowns", "[", "13", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"all6knowns", "[", "13", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"all6knowns", "[", "13", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"all6knowns", "[", "13", "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplificate", "/@", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Expand", ",", "#"}], "]"}], "&"}], "/@", 
  RowBox[{"(", 
   RowBox[{"%", "//", "Simplify"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "-", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"QQcxy", "[", 
     RowBox[{"12", ",", "1", ",", "0"}], "]"}], ",", 
    RowBox[{"QQcxy", "[", 
     RowBox[{"12", ",", "2", ",", "0"}], "]"}], ",", 
    RowBox[{"QQcxy", "[", 
     RowBox[{"12", ",", "3", ",", "0"}], "]"}], ",", 
    RowBox[{"QQcxy", "[", 
     RowBox[{"12", ",", "4", ",", "0"}], "]"}]}], "}"}]}]}], "Input",
 CellLabel->
  "In[504]:=",ExpressionUUID->"f08db98b-1ffa-41c0-bf7b-9ec10d75520b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "5"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"16", " ", "a"}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"]}], "+", 
        RowBox[{"8", " ", "a", " ", "b"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      SuperscriptBox["t", "8"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "9"],
      SeriesData[$CellContext`t, 0, {}, 2, 9, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a, 0, 0, 2 $CellContext`a + 
      2 $CellContext`a^2 + $CellContext`a^3 + $CellContext`a $CellContext`b + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c, 0, 0, 16 $CellContext`a + 16 $CellContext`a^2 + 
      11 $CellContext`a^3 + 6 $CellContext`a^4 + 2 $CellContext`a^5 + 
      8 $CellContext`a $CellContext`b + 
      4 $CellContext`a^2 $CellContext`b + $CellContext`a^3 $CellContext`b + 
      3 $CellContext`a $CellContext`b^2 + $CellContext`a $CellContext`b^3 + 
      4 $CellContext`a^2 $CellContext`c + 4 $CellContext`a^3 $CellContext`c + 
      2 $CellContext`a^4 $CellContext`c + 
      4 $CellContext`a $CellContext`b $CellContext`c + 
      5 $CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a^3 \
$CellContext`b $CellContext`c + 
      3 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a \
$CellContext`b^3 $CellContext`c + $CellContext`a^3 $CellContext`c^2 + 
      2 $CellContext`a^2 $CellContext`b $CellContext`c^2 + $CellContext`a \
$CellContext`b^2 $CellContext`c^2}, 2, 9, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", 
        SuperscriptBox["a", "2"]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", "a"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "7"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "8"],
      SeriesData[$CellContext`t, 0, {}, 4, 8, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a + $CellContext`a^2, 0, 0, 8 $CellContext`a + 
      8 $CellContext`a^2 + 5 $CellContext`a^3 + 2 $CellContext`a^4 + 
      2 $CellContext`a $CellContext`b + $CellContext`a^2 $CellContext`b + \
$CellContext`a^2 $CellContext`c + $CellContext`a^3 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`c}, 4, 8, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["a", "3"]}], ")"}], " ", 
      SuperscriptBox["t", "6"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "7"],
      SeriesData[$CellContext`t, 0, {}, 6, 7, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     2 $CellContext`a + 2 $CellContext`a^2 + $CellContext`a^3}, 6, 7, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "6"],
    SeriesData[$CellContext`t, 0, {}, 6, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.761447167623206*^9, 3.7675840779413033`*^9, 
  3.7675886873423033`*^9, 3.767655074096561*^9, 3.789159882146867*^9},
 CellLabel->
  "Out[506]=",ExpressionUUID->"fe08ff45-3932-40e9-8abd-f887b9585acd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "9"],
    SeriesData[$CellContext`t, 0, {}, 9, 9, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "8"],
    SeriesData[$CellContext`t, 0, {}, 8, 8, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "7"],
    SeriesData[$CellContext`t, 0, {}, 7, 7, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "6"],
    SeriesData[$CellContext`t, 0, {}, 6, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.761447167623206*^9, 3.7675840779413033`*^9, 
  3.7675886873423033`*^9, 3.767655074096561*^9, 3.789159882150642*^9},
 CellLabel->
  "Out[507]=",ExpressionUUID->"4bd89840-cde9-4ad4-b734-4aa2a16cb59e"]
}, Open  ]]
}, Closed]]
},
WindowSize->{1317, 1250},
WindowMargins->{{109, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1416, 28, 302, "Subtitle",ExpressionUUID->"ecc4ad1b-d1f6-4a0d-9aad-7ed9e3c81bd0"],
Cell[1999, 52, 571, 14, 86, "Subtitle",ExpressionUUID->"06bc1e98-bb67-48f1-860b-ca8c8ac930d5"],
Cell[2573, 68, 754, 18, 58, "Input",ExpressionUUID->"59969c7c-7107-4b1c-a56d-abecfb14bd09"],
Cell[3330, 88, 2617, 70, 104, "Input",ExpressionUUID->"4da374a9-6e9a-40e4-89a3-f058473d49d3"],
Cell[5950, 160, 369, 7, 58, "Input",ExpressionUUID->"268b89fc-6837-4c98-880d-67e223590443"],
Cell[6322, 169, 597, 13, 58, "Input",ExpressionUUID->"9927e9db-bed3-4fef-aca5-db8a87bdf2c3"],
Cell[6922, 184, 4925, 133, 219, "Input",ExpressionUUID->"aa66d61f-48d9-4bb3-9c7b-437b67615d43"],
Cell[11850, 319, 9158, 257, 357, "Input",ExpressionUUID->"e0af43c6-dc8c-4768-bc3b-8f0f02cd2fd7"]
}, Closed]],
Cell[CellGroupData[{
Cell[21045, 581, 500, 8, 58, "Subtitle",ExpressionUUID->"9ba78d60-5b57-4183-aea1-831b648977d5"],
Cell[CellGroupData[{
Cell[21570, 593, 891, 24, 127, "Input",ExpressionUUID->"cae15228-a804-4dda-a000-dc3de29e661e"],
Cell[22464, 619, 457, 7, 56, "Output",ExpressionUUID->"746f0e25-8811-4ee7-884d-831d71a64537"],
Cell[22924, 628, 457, 7, 53, "Output",ExpressionUUID->"4154c0df-4528-4c87-bd39-fa3bbe4509ea"],
Cell[23384, 637, 437, 6, 38, "Output",ExpressionUUID->"cc6a7e46-bf80-4a08-8e29-21254408f0ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23858, 648, 2763, 76, 104, "Input",ExpressionUUID->"39ee226e-04ff-40c5-9c13-7f8c1054ef47"],
Cell[26624, 726, 574, 11, 38, "Output",ExpressionUUID->"b4a2c864-460a-4ee3-ac1c-09e4f924f22d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[27247, 743, 502, 8, 58, "Subtitle",ExpressionUUID->"6d6a9b38-9dae-46a5-b1fb-2d4c00edb6f9"],
Cell[27752, 753, 1710, 53, 173, "Input",ExpressionUUID->"894509c9-9782-425f-8146-a64321b72830"],
Cell[CellGroupData[{
Cell[29487, 810, 2068, 52, 150, "Input",ExpressionUUID->"620a52d8-f75c-41ff-a388-5b7849f8a4db"],
Cell[31558, 864, 3097, 87, 121, "Output",ExpressionUUID->"d847db8f-efd3-4bea-8d9a-87ae27768265"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34692, 956, 2983, 88, 150, "Input",ExpressionUUID->"00a6a211-5a35-4a1a-81fe-096a6bf550dc"],
Cell[37678, 1046, 1112, 27, 38, "Output",ExpressionUUID->"33f10168-7e84-45bd-a03b-ea300bdf1caf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38827, 1078, 980, 25, 58, "Input",ExpressionUUID->"585994ec-a4f0-4ce7-8c96-4fed50282cc0"],
Cell[39810, 1105, 3054, 93, 99, "Output",ExpressionUUID->"e6283703-d080-4aaf-bcd9-5c221778d47c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42901, 1203, 338, 7, 58, "Input",ExpressionUUID->"1e606ab0-1a92-496d-82c5-97c087c305fd"],
Cell[43242, 1212, 493, 7, 38, "Output",ExpressionUUID->"e1743b30-f032-46ad-9f0d-0bfcf40aa9ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43772, 1224, 1739, 47, 150, "Input",ExpressionUUID->"616dcae5-1e49-4429-b5f1-5ec85f32bc32"],
Cell[45514, 1273, 3915, 116, 142, "Output",ExpressionUUID->"64a33f26-3a84-4340-9dea-4043c0a54b91"],
Cell[49432, 1391, 601, 11, 38, "Output",ExpressionUUID->"f43d8978-1ff8-4b69-b1e2-0468a47840a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50070, 1407, 748, 20, 58, "Input",ExpressionUUID->"10392ece-dd4a-4ec8-9dd0-376b1b5cc25b"],
Cell[50821, 1429, 1841, 53, 62, "Output",ExpressionUUID->"22673ff1-dc1a-43d2-b2b2-76986ecc39f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52699, 1487, 1166, 33, 58, "Input",ExpressionUUID->"6a920c35-346a-4685-80f9-111dfd958d0a"],
Cell[53868, 1522, 4307, 131, 184, "Output",ExpressionUUID->"8114375c-5223-4adc-b855-9c5b01816d39"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58212, 1658, 6322, 188, 300, "Input",ExpressionUUID->"f080b300-8c8e-4a86-af8a-271dda84da23"],
Cell[64537, 1848, 1048, 23, 38, "Output",ExpressionUUID->"82e63fea-3f10-4711-b1f7-cb8c5a1212f1"],
Cell[65588, 1873, 2256, 62, 62, "Output",ExpressionUUID->"0a354dd7-933d-41fd-aa72-824b41424a80"],
Cell[67847, 1937, 2331, 64, 64, "Output",ExpressionUUID->"64b8830f-c01b-416c-97f2-67c7c9561e18"],
Cell[70181, 2003, 1071, 24, 38, "Output",ExpressionUUID->"1e767623-9649-46a9-a89d-bcaa36fee702"],
Cell[71255, 2029, 2524, 67, 86, "Output",ExpressionUUID->"5307c4f0-7c64-42f7-86d5-a5c22a7d70d0"],
Cell[73782, 2098, 2559, 69, 87, "Output",ExpressionUUID->"81dc04c2-75fb-467e-8747-bf473d4bfd30"],
Cell[76344, 2169, 2542, 68, 86, "Output",ExpressionUUID->"fe3d1f9e-6573-4eda-adcf-ae16e5aec497"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78923, 2242, 3943, 110, 263, "Input",ExpressionUUID->"14b6c708-60c4-4c83-b6e0-ba36e8f0d6c3"],
Cell[82869, 2354, 686, 13, 38, "Output",ExpressionUUID->"e774e3de-92e5-492a-81f2-62b63de48806"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83592, 2372, 28893, 844, 1740, "Input",ExpressionUUID->"3987d976-8bb6-45ea-a0c3-153ae310d457"],
Cell[112488, 3218, 1815, 45, 56, "Output",ExpressionUUID->"417743a3-2331-490f-99ab-24757d5da761"],
Cell[114306, 3265, 1069, 18, 38, "Output",ExpressionUUID->"ae1d319d-17c3-4e13-86f7-0f44b3e0d700"],
Cell[115378, 3285, 1812, 45, 56, "Output",ExpressionUUID->"628183de-afb3-460c-a105-c639588d732b"],
Cell[117193, 3332, 1069, 18, 38, "Output",ExpressionUUID->"5b0655d7-fd54-4360-a812-09e52bcde60a"],
Cell[118265, 3352, 1696, 40, 54, "Output",ExpressionUUID->"b2d53eaf-4a80-4dda-a61c-abbfba57d1d3"],
Cell[119964, 3394, 1072, 18, 38, "Output",ExpressionUUID->"e58d62ad-448a-4ca3-86e2-1ebe2fb76755"],
Cell[121039, 3414, 1694, 40, 55, "Output",ExpressionUUID->"ecfc80ad-ce7e-4364-b5f5-2a8c671fe8f9"],
Cell[122736, 3456, 1070, 18, 38, "Output",ExpressionUUID->"e85bb9f4-19fd-47dc-b205-1d8ab0a1eb46"],
Cell[123809, 3476, 1943, 50, 62, "Output",ExpressionUUID->"484e84ca-1150-4d7f-b1b6-cfb75e5d6d49"],
Cell[125755, 3528, 1072, 18, 38, "Output",ExpressionUUID->"ddc343ae-aa19-4d85-a28c-4484929aaf1b"],
Cell[126830, 3548, 1834, 45, 62, "Output",ExpressionUUID->"d74153a8-3768-406a-bbbb-e8bedbb45966"],
Cell[128667, 3595, 1070, 18, 38, "Output",ExpressionUUID->"62fcfb74-7af7-4988-9fb9-1e907262aac5"],
Cell[129740, 3615, 1770, 43, 62, "Output",ExpressionUUID->"2104043e-f39e-41a2-b5ec-850c500ac68e"],
Cell[131513, 3660, 1072, 18, 38, "Output",ExpressionUUID->"cd89b2f5-d2c1-4704-bdf8-9879c6a471c6"],
Cell[132588, 3680, 1188, 23, 41, "Output",ExpressionUUID->"78701672-07f6-4b23-a67d-f6ec14356d53"],
Cell[133779, 3705, 1070, 18, 38, "Output",ExpressionUUID->"9d34bccf-815e-4adb-ba91-37b71e1ec129"],
Cell[134852, 3725, 1184, 22, 41, "Output",ExpressionUUID->"53b9f1dd-77dc-42db-9517-e1b3086861e9"],
Cell[136039, 3749, 1072, 18, 38, "Output",ExpressionUUID->"c030b7f5-e1cf-471a-ba59-5264ccda11db"],
Cell[137114, 3769, 1188, 23, 41, "Output",ExpressionUUID->"4889b54f-72eb-4311-8940-b3ac27fb6773"],
Cell[138305, 3794, 1070, 18, 38, "Output",ExpressionUUID->"134be84f-543d-42b2-8ee6-5ff4ab37fc39"],
Cell[139378, 3814, 1255, 26, 41, "Output",ExpressionUUID->"5d729c74-16bd-4777-b063-6cadc8b9bc46"],
Cell[140636, 3842, 1070, 18, 38, "Output",ExpressionUUID->"72f54270-94a8-4621-9c2b-f89a28080a30"],
Cell[141709, 3862, 1190, 23, 41, "Output",ExpressionUUID->"47aaea37-dcb7-40c9-8b82-952cb29f0d0b"],
Cell[142902, 3887, 1070, 18, 38, "Output",ExpressionUUID->"d4ab3855-b77a-40cd-b605-e8e6ad926477"],
Cell[143975, 3907, 1190, 23, 41, "Output",ExpressionUUID->"f2989c27-88a7-4681-8ee3-64c233fa64bc"],
Cell[145168, 3932, 1070, 18, 38, "Output",ExpressionUUID->"696aea53-d4e1-4d4e-8cf6-df618d6b393a"],
Cell[146241, 3952, 1251, 26, 41, "Output",ExpressionUUID->"df187d4e-0825-4d89-8907-c86346973f3d"],
Cell[147495, 3980, 1070, 18, 38, "Output",ExpressionUUID->"9871ff4a-5c88-459f-852a-b0989e75da6f"],
Cell[148568, 4000, 1188, 23, 41, "Output",ExpressionUUID->"40c30140-da38-45ff-a910-c4166a13cff5"],
Cell[149759, 4025, 1070, 18, 38, "Output",ExpressionUUID->"e3137439-e88e-4904-b071-0ebe0c7ee2ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150866, 4048, 4948, 141, 425, "Input",ExpressionUUID->"6995ba39-8285-470d-823b-4aab814781b5"],
Cell[155817, 4191, 19386, 539, 469, "Output",ExpressionUUID->"bec3a94b-37c0-42e0-9086-75f5103a508e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175240, 4735, 2290, 65, 222, "Input",ExpressionUUID->"15532b2c-09eb-430e-8428-9d31c95b6970"],
Cell[177533, 4802, 588, 13, 38, "Output",ExpressionUUID->"a79f809a-4659-415d-ae3e-fb3087a2d446"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178158, 4820, 2656, 77, 196, "Input",ExpressionUUID->"82413766-2a09-41e3-8f73-131c5707933c"],
Cell[180817, 4899, 487, 9, 38, "Output",ExpressionUUID->"20783cff-cef8-4f93-aa35-a6cd0121f251"],
Cell[181307, 4910, 987, 25, 58, "Output",ExpressionUUID->"36a1e93a-0cb5-406c-a21a-ff2ce2c3edb8"],
Cell[182297, 4937, 1182, 31, 58, "Output",ExpressionUUID->"4fda3879-ae30-46eb-876e-43df7f9cf69f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183516, 4973, 1004, 29, 58, "Input",ExpressionUUID->"6d73a7bd-ab8b-4830-89fe-5bfca1d9dde2"],
Cell[184523, 5004, 395, 7, 38, "Output",ExpressionUUID->"21a66745-0e58-45ba-af6e-a27b174b4220"]
}, Open  ]],
Cell[184933, 5014, 1094, 33, 81, "Input",ExpressionUUID->"79b8c0a5-75c4-40e7-9758-94c6f61fa6ae"],
Cell[CellGroupData[{
Cell[186052, 5051, 2579, 67, 127, "Input",ExpressionUUID->"360ec4e7-5e94-45d3-a21a-b6330b0aa0e1"],
Cell[188634, 5120, 6738, 189, 175, "Output",ExpressionUUID->"a5b7d35d-b17b-4921-8f01-3157950f1250"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195409, 5314, 1860, 54, 173, "Input",ExpressionUUID->"7e3a8d04-560c-459e-b0b4-b21ca42b67df"],
Cell[197272, 5370, 589, 12, 38, "Output",ExpressionUUID->"caf59ac3-890b-4d1d-a346-7ec8d792eb4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197898, 5387, 1395, 38, 98, "Input",ExpressionUUID->"3b694bb2-9daa-409b-ac7a-10295711eee8"],
Cell[199296, 5427, 593, 12, 38, "Output",ExpressionUUID->"f63d2138-bdd6-4657-9a76-7589aebfaf34"]
}, Open  ]],
Cell[199904, 5442, 1225, 28, 81, "Input",ExpressionUUID->"86059985-c31c-44e3-9c06-10c96c4b9b34"],
Cell[CellGroupData[{
Cell[201154, 5474, 10534, 322, 516, "Input",ExpressionUUID->"3112156c-a446-4489-848f-340372e52ba1"],
Cell[211691, 5798, 913, 23, 60, "Output",ExpressionUUID->"c1121e73-2e6a-444b-a1f3-da2bfc66e33c"],
Cell[212607, 5823, 2045, 55, 60, "Output",ExpressionUUID->"47c50b9a-644a-400b-beb3-5f9a021c6765"],
Cell[214655, 5880, 5382, 165, 209, "Output",ExpressionUUID->"c397fac3-967b-4312-affb-95dac75b12f8"],
Cell[220040, 6047, 5401, 165, 209, "Output",ExpressionUUID->"1576c0a7-56bf-4fc8-ae5c-c407d0273db4"],
Cell[225444, 6214, 886, 23, 38, "Output",ExpressionUUID->"89323ce4-3da5-4d6b-b109-a3ae3c7fa752"],
Cell[226333, 6239, 750, 17, 41, "Output",ExpressionUUID->"0a104ed8-c6c4-4241-8c55-e03dff9aaeec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227120, 6261, 4224, 118, 237, "Input",ExpressionUUID->"01a31721-6cdb-4f0e-b646-6ac32e0e9040"],
Cell[231347, 6381, 854, 16, 38, "Output",ExpressionUUID->"567ec1db-89e3-4e75-8c31-93a8d9e9fe6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232238, 6402, 6199, 175, 410, "Input",ExpressionUUID->"de034dc0-d40b-4ee5-8353-a5a26c9a5dcd"],
Cell[238440, 6579, 17138, 480, 410, "Output",ExpressionUUID->"14fffdc5-8024-4da9-a794-1cfa594675ee"],
Cell[255581, 7061, 807, 15, 38, "Output",ExpressionUUID->"60b60e5a-5183-457e-8af2-1144f98d86a0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256425, 7081, 1846, 46, 177, "Input",ExpressionUUID->"e75d24bb-f92a-49d6-9db5-50160afc0bea"],
Cell[258274, 7129, 3372, 92, 94, "Output",ExpressionUUID->"b6f1376e-f670-49f2-a34b-1141800ad619"],
Cell[261649, 7223, 3474, 99, 94, "Output",ExpressionUUID->"c22730c7-d61a-45c7-a117-e1dc80c47760"],
Cell[265126, 7324, 629, 13, 41, "Output",ExpressionUUID->"ed97f5c6-a5b3-4d76-8c7f-65c1891403d6"]
}, Open  ]],
Cell[265770, 7340, 2906, 85, 108, "Input",ExpressionUUID->"31d15361-532b-49ff-8779-77053c27f584"],
Cell[CellGroupData[{
Cell[268701, 7429, 464, 11, 60, "Input",ExpressionUUID->"5b5cd206-7917-4fb0-b1d0-3db0ef5a0805"],
Cell[269168, 7442, 2758, 69, 60, "Output",ExpressionUUID->"a2b9cabc-5f6f-44e0-9aa1-84df4f892a6e"],
Cell[271929, 7513, 4790, 121, 106, "Output",ExpressionUUID->"900a7882-bb9e-477c-9a41-4658276e4c31"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[276768, 7640, 551, 9, 58, "Subtitle",ExpressionUUID->"8047f6f5-eb93-4c51-97e3-fb87da749da7"],
Cell[CellGroupData[{
Cell[277344, 7653, 1959, 54, 127, "Input",ExpressionUUID->"83a6d2d1-ab5e-46a9-90ea-dbaef77958f8"],
Cell[279306, 7709, 2285, 66, 120, "Output",ExpressionUUID->"9bcbc31d-46d7-4bf6-af83-f2c2adcd2d9e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281628, 7780, 1317, 39, 58, "Input",ExpressionUUID->"f9fba70c-954b-42ca-8f75-e66b06c0b034"],
Cell[282948, 7821, 4286, 130, 167, "Output",ExpressionUUID->"95b4a2b3-81ce-444e-ba06-857df9337ecc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287271, 7956, 2003, 57, 196, "Input",ExpressionUUID->"03b14200-7e24-48a2-8cf3-f3e2b38bb407"],
Cell[289277, 8015, 447, 8, 38, "Output",ExpressionUUID->"7f3ca92e-a1dc-47ce-845b-5b47b063134e"],
Cell[289727, 8025, 2632, 78, 58, "Output",ExpressionUUID->"4bc425cb-9171-42d2-907f-202936c5cc00"],
Cell[292362, 8105, 1428, 42, 58, "Output",ExpressionUUID->"fb1a96c4-de12-43e9-88f7-6d5a7db6ea8a"],
Cell[293793, 8149, 510, 10, 38, "Output",ExpressionUUID->"158d5896-cf71-404d-9244-6627c3cc6968"]
}, Open  ]],
Cell[294318, 8162, 707, 14, 34, "Input",ExpressionUUID->"1a609f62-d37d-432b-b0cb-f9fc8e74982c"],
Cell[CellGroupData[{
Cell[295050, 8180, 3287, 97, 220, "Input",ExpressionUUID->"52da4a75-0101-48be-a817-064e7b4b901e"],
Cell[298340, 8279, 1974, 53, 69, "Output",ExpressionUUID->"e468175a-dfa3-490c-aafa-1b0f0bf9f3b1"],
Cell[300317, 8334, 1084, 23, 38, "Output",ExpressionUUID->"cc6732af-1185-478f-9980-69f546006fd9"],
Cell[301404, 8359, 1223, 28, 58, "Output",ExpressionUUID->"a2c9d82e-e91a-470f-b0c8-2c5d7799bd11"],
Cell[302630, 8389, 1084, 23, 38, "Output",ExpressionUUID->"d16e08a1-b9b0-4764-a40f-4dc48e7f9d28"],
Cell[303717, 8414, 1143, 25, 55, "Output",ExpressionUUID->"62bc09f1-71f9-434d-816a-e8c4a8ea679d"],
Cell[304863, 8441, 1242, 28, 62, "Output",ExpressionUUID->"29fe1b58-a9d1-450d-a27b-2ee0d4e75fb8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306142, 8474, 1692, 49, 145, "Input",ExpressionUUID->"1bf9b6a3-4dfa-4bb1-9df4-3a953ca15a11"],
Cell[307837, 8525, 663, 13, 38, "Output",ExpressionUUID->"c368d05e-3105-47c1-a975-6909a8bbb79f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308537, 8543, 849, 24, 81, "Input",ExpressionUUID->"a4b0325f-854a-4c0d-9f77-3158dca9ea6a"],
Cell[309389, 8569, 5158, 156, 221, "Output",ExpressionUUID->"317493a8-42e1-42a0-843e-1f9ebc432ef0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314584, 8730, 1743, 44, 104, "Input",ExpressionUUID->"0d973736-0f9b-4e10-b708-5d5e16f90026"],
Cell[316330, 8776, 9312, 279, 284, "Output",ExpressionUUID->"5c4a7d67-c2e7-45c1-b328-966775229d5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325679, 9060, 2389, 69, 150, "Input",ExpressionUUID->"5cd8fc67-644f-42d9-820c-0901db0c05c1"],
Cell[328071, 9131, 683, 13, 38, "Output",ExpressionUUID->"4ada3a5f-caf5-488c-96fc-160e1f6fdda4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328791, 9149, 1564, 43, 130, "Input",ExpressionUUID->"1e8f5a9d-fefb-4002-ad72-af542857cb11"],
Cell[330358, 9194, 585, 12, 38, "Output",ExpressionUUID->"95beea4b-631d-4133-8cf9-e8fe8152a1aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[330980, 9211, 4450, 114, 216, "Input",ExpressionUUID->"c49ad65d-f460-4025-af29-c6dee62cb93d"],
Cell[335433, 9327, 1110, 19, 38, "Output",ExpressionUUID->"51f19f72-7422-482f-babe-40c609814247"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336580, 9351, 2497, 66, 131, "Input",ExpressionUUID->"5524d379-32b2-4278-86bd-1dfd14e7dd09"],
Cell[339080, 9419, 2022, 53, 41, "Output",ExpressionUUID->"fb01e04a-8d57-4072-8dd8-cd400bf29829"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341139, 9477, 1787, 46, 76, "Input",ExpressionUUID->"5f80b15f-c41e-4617-b2ce-ca208162e138"],
Cell[342929, 9525, 1625, 44, 41, "Output",ExpressionUUID->"74f5aedf-d689-40ab-9021-f657af2259b8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344591, 9574, 3432, 95, 174, "Input",ExpressionUUID->"ffbe3961-eb1b-44f8-b1d2-0050076af9f3"],
Cell[348026, 9671, 4182, 110, 91, "Output",ExpressionUUID->"fa3ca5bc-a520-41b6-b8f8-454cccba2eec"],
Cell[352211, 9783, 3836, 100, 66, "Output",ExpressionUUID->"5df33606-3120-4175-a236-55e327035501"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356084, 9888, 3161, 92, 174, "Input",ExpressionUUID->"63cf817a-a815-45d3-a9e6-2ad3fd4ff2d8"],
Cell[359248, 9982, 1192, 31, 41, "Output",ExpressionUUID->"e4ebb12a-ad93-4225-812b-349095ac1ac1"],
Cell[360443, 10015, 863, 22, 38, "Output",ExpressionUUID->"02a36909-80a0-47a0-a183-49a7364f0921"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361343, 10042, 3167, 92, 174, "Input",ExpressionUUID->"444eb12e-dcc6-40a3-8a60-3d7dabfc43cb"],
Cell[364513, 10136, 1223, 31, 41, "Output",ExpressionUUID->"d346b2cd-c442-460a-aa8d-c4631ce99a96"],
Cell[365739, 10169, 855, 20, 38, "Output",ExpressionUUID->"5cd21f95-12ed-4de8-8a9a-87c33ba2ab8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366631, 10194, 3439, 98, 174, "Input",ExpressionUUID->"d8ff1f5d-14f2-489f-b8e4-a1c1854315e2"],
Cell[370073, 10294, 28874, 822, 455, "Output",ExpressionUUID->"20f30584-2bf6-445e-bf37-91b57aeebc80"],
Cell[398950, 11118, 18307, 476, 273, "Output",ExpressionUUID->"793a25bc-a4cd-4454-88a5-bdfa24c0432c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[417294, 11599, 3722, 108, 210, "Input",ExpressionUUID->"1644d3f2-abf8-4530-8acb-3ebeb43a5195"],
Cell[421019, 11709, 11292, 304, 181, "Output",ExpressionUUID->"0a1684f1-79ad-4e8c-98cd-5c79d49cd38b"],
Cell[432314, 12015, 6046, 160, 112, "Output",ExpressionUUID->"2648df3c-ba7e-4f07-8bb1-469c1c11adc7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438397, 12180, 4317, 128, 148, "Input",ExpressionUUID->"3f35ea73-5821-45ad-ab9c-b65644a2457c"],
Cell[442717, 12310, 685, 13, 38, "Output",ExpressionUUID->"66a5f9c8-57f6-439e-9afd-8874488b67e4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[443439, 12328, 4617, 140, 255, "Input",ExpressionUUID->"8ece0b2e-3293-44cb-b395-c03f52e05848"],
Cell[448059, 12470, 863, 19, 41, "Output",ExpressionUUID->"afd21323-a8e1-43a6-aaa8-8de73560472d"],
Cell[448925, 12491, 865, 19, 41, "Output",ExpressionUUID->"41f8f614-23d1-48ae-95ac-4f5908fd1720"],
Cell[449793, 12512, 863, 19, 41, "Output",ExpressionUUID->"62320fac-3bff-4fab-b269-e1b147fbe97c"],
Cell[450659, 12533, 3070, 87, 103, "Output",ExpressionUUID->"e153f6b0-b5e4-4d82-82e9-802ad849e10b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453766, 12625, 1689, 47, 152, "Input",ExpressionUUID->"2bbbc3b3-749d-4571-9b21-dd5d139e1055"],
Cell[455458, 12674, 415, 7, 38, "Output",ExpressionUUID->"5f8c9a4d-c50c-4c3e-b606-492285aa115f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455910, 12686, 993, 28, 83, "Input",ExpressionUUID->"cf06ed3b-afd0-4f6a-bfa3-8b387cf56d14"],
Cell[456906, 12716, 956, 23, 38, "Output",ExpressionUUID->"b233b4e1-1354-48d2-9dd9-cdda48215a39"],
Cell[457865, 12741, 1039, 27, 58, "Output",ExpressionUUID->"65cc3c41-72bc-4984-9cb8-075297fbbaf7"]
}, Open  ]],
Cell[458919, 12771, 1605, 47, 129, "Input",ExpressionUUID->"5a48f4cf-3494-4efa-bde6-b80c9386e3ea"],
Cell[CellGroupData[{
Cell[460549, 12822, 1424, 38, 152, "Input",ExpressionUUID->"c090ac56-0eb8-4d9a-b3b5-3361841684fb"],
Cell[461976, 12862, 1788, 49, 62, "Output",ExpressionUUID->"b6f1ccc4-c0ff-40da-a9d3-1571d4f36f04"],
Cell[463767, 12913, 4191, 113, 61, "Output",ExpressionUUID->"f52dc292-f461-45c2-b749-6fffde9d35c9"]
}, Open  ]],
Cell[467973, 13029, 872, 20, 81, "Input",ExpressionUUID->"f7f43918-cbe0-4ecf-81df-16a4917251aa"],
Cell[CellGroupData[{
Cell[468870, 13053, 7401, 215, 306, "Input",ExpressionUUID->"bdff623e-1930-4495-8093-273dafadb9d7"],
Cell[476274, 13270, 32167, 904, 713, "Output",ExpressionUUID->"4ede5d14-225f-44d7-affc-068a6164f26a"],
Cell[508444, 14176, 756, 14, 38, "Output",ExpressionUUID->"d26c4638-5a0d-4710-ba3d-c459a8c862f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509237, 14195, 5400, 158, 275, "Input",ExpressionUUID->"a75a2105-a744-49d6-8b15-fc485fdbb9ca"],
Cell[514640, 14355, 3129, 90, 72, "Output",ExpressionUUID->"ffde5b46-7cdd-4584-9b2a-4380cec021d1"],
Cell[517772, 14447, 749, 14, 38, "Output",ExpressionUUID->"3c5c9af1-5c0a-41dc-b896-e1ac713e5754"]
}, Open  ]],
Cell[CellGroupData[{
Cell[518558, 14466, 5420, 156, 334, "Input",ExpressionUUID->"321cee97-87f5-436c-a66c-eedd014aa6f8"],
Cell[523981, 14624, 16758, 483, 582, "Output",ExpressionUUID->"ff9f7561-c26a-43ea-8c22-f8d090c060b7"],
Cell[540742, 15109, 834, 16, 38, "Output",ExpressionUUID->"627a5519-37cd-4ea2-b5be-df22fd5f06b8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[541613, 15130, 5583, 159, 334, "Input",ExpressionUUID->"03977d6c-cfbd-41ce-95f3-9d45b80edb12"],
Cell[547199, 15291, 2099, 59, 111, "Output",ExpressionUUID->"b63ead01-9a39-40b9-b30f-d1ae109f1e00"],
Cell[549301, 15352, 759, 14, 38, "Output",ExpressionUUID->"b68f58f9-14ef-45d9-8cd1-eb0eaf36eafb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[550097, 15371, 5229, 154, 334, "Input",ExpressionUUID->"536a099a-0a40-442b-a03c-51f6d0c4bbbc"],
Cell[555329, 15527, 2312, 69, 111, "Output",ExpressionUUID->"10c34935-1b67-44eb-b8ce-4d782e0c72a6"],
Cell[557644, 15598, 640, 13, 38, "Output",ExpressionUUID->"83b4a0a2-5fad-41b5-9a17-dd718ae5e5c8"]
}, Open  ]],
Cell[558299, 15614, 1539, 34, 83, "Input",ExpressionUUID->"415be329-0275-40fc-9620-351c65493371"],
Cell[559841, 15650, 1788, 49, 86, "Input",ExpressionUUID->"5c5dfa3d-4cb6-40ac-89c2-9bd9d7afad0a"],
Cell[561632, 15701, 2021, 59, 109, "Input",ExpressionUUID->"ac10c33c-ee2e-47b6-8c2e-b816542d5abf"],
Cell[CellGroupData[{
Cell[563678, 15764, 325, 6, 58, "Input",ExpressionUUID->"00a15730-a3b5-4525-94a3-9525e2c09a51"],
Cell[564006, 15772, 2108, 53, 41, "Output",ExpressionUUID->"33dea26d-176a-42b7-bab5-edec715237f5"],
Cell[566117, 15827, 5784, 137, 91, "Output",ExpressionUUID->"bdee20e8-2e93-4bab-b98a-fcc8f5274b5e"]
}, Open  ]],
Cell[571916, 15967, 5483, 146, 213, "Input",ExpressionUUID->"7f1eb6d0-d138-480f-8bdf-f95852a4e9af"],
Cell[577402, 16115, 11244, 310, 572, "Input",ExpressionUUID->"bf9cb6d8-0e7e-4468-a650-4b11015fcd54"],
Cell[CellGroupData[{
Cell[588671, 16429, 3713, 98, 132, "Input",ExpressionUUID->"1d276147-5b4d-4589-87ee-25a20f1455dd"],
Cell[592387, 16529, 1203, 21, 38, "Output",ExpressionUUID->"a5be4ae7-a134-4031-98ff-c6efb63f0c4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[593627, 16555, 6330, 178, 371, "Input",ExpressionUUID->"d6b8cc59-9f8a-4a73-aee0-3efa53cf90c5"],
Cell[599960, 16735, 4915, 144, 195, "Output",ExpressionUUID->"9a1bbb64-a0a5-4f65-89b2-d4c88c50a764"],
Cell[604878, 16881, 906, 16, 38, "Output",ExpressionUUID->"a2a786f4-4b28-442e-b84c-7e29594bd48e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605821, 16902, 7457, 225, 331, "Input",ExpressionUUID->"ba0a482d-7ea3-4c30-9e6a-6943cb4d00c8"],
Cell[613281, 17129, 79669, 2152, 1969, "Output",ExpressionUUID->"36bd8ae9-ddcd-4366-8b1a-14a51d8f0b58"],
Cell[692953, 19283, 730, 14, 38, "Output",ExpressionUUID->"0485db38-684a-457c-8d6b-30d7fac5ecd0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[693720, 19302, 5838, 158, 324, "Input",ExpressionUUID->"2365ba72-0227-4c3a-9a9d-e7650ce12b52"],
Cell[699561, 19462, 22471, 573, 406, "Output",ExpressionUUID->"95982eee-acd8-4717-af39-b3822321c088"],
Cell[722035, 20037, 1244, 21, 38, "Output",ExpressionUUID->"34e8311d-2ad1-4a5a-af9f-6716b53967fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[723316, 20063, 5516, 154, 324, "Input",ExpressionUUID->"97b5ae30-8653-4785-a618-88094450aea0"],
Cell[728835, 20219, 2668, 76, 92, "Output",ExpressionUUID->"0f98fd2d-d477-4622-abe4-2c5c411674cc"],
Cell[731506, 20297, 703, 14, 38, "Output",ExpressionUUID->"4834869e-a012-4f7e-bdb4-04d53f22dee9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[732246, 20316, 5344, 151, 324, "Input",ExpressionUUID->"fbb85a46-baf2-49dc-a4db-8b6428483d3f"],
Cell[737593, 20469, 2522, 72, 92, "Output",ExpressionUUID->"3cd92930-7131-478e-ac0d-26301c386306"],
Cell[740118, 20543, 532, 11, 38, "Output",ExpressionUUID->"e809f733-7f82-4c31-ba1e-5cd5852a1f92"]
}, Open  ]],
Cell[740665, 20557, 1539, 34, 83, "Input",ExpressionUUID->"c95a4e24-f84f-4cae-8bdd-e65840f9355d"],
Cell[742207, 20593, 1596, 44, 86, "Input",ExpressionUUID->"aafa0ba8-2615-4c8f-88fd-121e0254e221"],
Cell[743806, 20639, 1906, 56, 106, "Input",ExpressionUUID->"06008350-d6c2-498f-a4ef-5d15a5d3999b"],
Cell[CellGroupData[{
Cell[745737, 20699, 276, 5, 58, "Input",ExpressionUUID->"2eebf0f5-9e60-4863-aa86-aa2311d0e881"],
Cell[746016, 20706, 3057, 82, 60, "Output",ExpressionUUID->"e285e7b7-4468-4408-b63d-e7f4c0bde47e"],
Cell[749076, 20790, 9823, 236, 163, "Output",ExpressionUUID->"595c09d6-a517-4a0a-b5f0-50d5d2a9d8f3"]
}, Open  ]],
Cell[758914, 21029, 4788, 136, 197, "Input",ExpressionUUID->"92372634-3fe2-4deb-b60f-147a07369785"],
Cell[763705, 21167, 10855, 297, 573, "Input",ExpressionUUID->"7de0da3c-432b-4019-9623-0a99fd54a8a3"],
Cell[CellGroupData[{
Cell[774585, 21468, 3134, 88, 138, "Input",ExpressionUUID->"820d3aed-691c-40d4-b236-940f20b3dfa4"],
Cell[777722, 21558, 706, 14, 38, "Output",ExpressionUUID->"e1b04ea7-059d-4d53-bee5-da8538d4d26d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[778465, 21577, 5664, 167, 446, "Input",ExpressionUUID->"d178a5fd-56ad-4389-a8e7-87beb704d21d"],
Cell[784132, 21746, 511, 10, 38, "Output",ExpressionUUID->"8f8dc6e4-cf86-4773-b297-a7e76302120a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[784680, 21761, 2320, 67, 242, "Input",ExpressionUUID->"f1d95a86-4b9e-4827-acc2-38b13a98ec12"],
Cell[787003, 21830, 1758, 50, 59, "Output",ExpressionUUID->"b914ae32-4862-4fe0-b57e-bff7f64019b2"],
Cell[788764, 21882, 1783, 51, 59, "Output",ExpressionUUID->"a6556746-2b62-49ac-97a0-6898713ebb80"],
Cell[790550, 21935, 1758, 50, 59, "Output",ExpressionUUID->"db3175ca-d61e-4474-b25d-adfb8597c675"],
Cell[792311, 21987, 1783, 51, 59, "Output",ExpressionUUID->"2afca94e-a953-4e18-bcda-bbef84de4693"],
Cell[794097, 22040, 3115, 82, 63, "Output",ExpressionUUID->"b857f0cb-2846-4020-baa0-d4192066a558"],
Cell[797215, 22124, 3170, 84, 63, "Output",ExpressionUUID->"b150adca-1e0c-40a1-9d31-4ca4273b7f92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[800422, 22213, 3759, 109, 328, "Input",ExpressionUUID->"3e24e03c-5761-4497-9853-f8511dc31c13"],
Cell[804184, 22324, 451, 8, 38, "Output",ExpressionUUID->"3731e86e-53be-4d70-b17c-2f8cd6b9e7c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[804672, 22337, 1625, 46, 173, "Input",ExpressionUUID->"c4861166-4855-48d1-903d-f7c7d1c4c1d6"],
Cell[806300, 22385, 2035, 60, 61, "Output",ExpressionUUID->"cb11dcb9-1999-40b9-9003-0a3fbd3566c4"],
Cell[808338, 22447, 2060, 61, 61, "Output",ExpressionUUID->"8ea7eec2-eb1e-484a-91bd-cf4f29778810"],
Cell[810401, 22510, 2033, 60, 61, "Output",ExpressionUUID->"405dc034-eaf1-40c0-ad2d-9b72c1f77301"],
Cell[812437, 22572, 2058, 61, 61, "Output",ExpressionUUID->"850a9659-14c1-4a4f-a91d-6cc77c0a5b9f"]
}, Open  ]],
Cell[814510, 22636, 7540, 227, 288, "Input",ExpressionUUID->"df0d34f2-54b8-44dd-a84e-7a0bf6764df0"],
Cell[CellGroupData[{
Cell[822075, 22867, 5894, 170, 275, "Input",ExpressionUUID->"f6c773af-0ee3-4944-9e3d-7af3995934e8"],
Cell[827972, 23039, 1013, 25, 41, "Output",ExpressionUUID->"f3d0cf7e-9e1d-47e9-9126-7b062702e4fe"],
Cell[828988, 23066, 849, 20, 41, "Output",ExpressionUUID->"15c11fcd-7073-4ebf-b086-da1f7aaa64f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[829874, 23091, 3408, 94, 224, "Input",ExpressionUUID->"f20bd80a-ea31-41be-a4f5-deb9f63963c4"],
Cell[833285, 23187, 627, 13, 38, "Output",ExpressionUUID->"b40d20a6-3aba-40ff-8ff7-f8ebea26a61e"]
}, Open  ]],
Cell[833927, 23203, 254, 5, 34, "Input",ExpressionUUID->"ad238bd2-4a60-431f-a942-a1a5b80f812e"],
Cell[CellGroupData[{
Cell[834206, 23212, 2355, 67, 112, "Input",ExpressionUUID->"58314e3d-41e4-407f-9684-730db61131ea"],
Cell[836564, 23281, 41779, 1029, 805, "Output",ExpressionUUID->"373ca76e-663d-4011-8404-2d6200829150"]
}, Open  ]],
Cell[CellGroupData[{
Cell[878380, 24315, 2709, 82, 140, "Input",ExpressionUUID->"130726f9-7f5c-440a-8198-e3acf750b152"],
Cell[881092, 24399, 7028, 205, 185, "Output",ExpressionUUID->"780e1dd4-288a-4e9d-a064-9b2cef2dd4c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[888157, 24609, 1297, 38, 63, "Input",ExpressionUUID->"7edafe85-8022-444d-92c4-365d68ee5b67"],
Cell[889457, 24649, 12646, 333, 236, "Output",ExpressionUUID->"dbd4b95d-45c4-4f56-a02d-5a9f8c44e0b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[902140, 24987, 1295, 38, 63, "Input",ExpressionUUID->"16be9a26-8d90-48ee-b18c-afa8e0c8789e"],
Cell[903438, 25027, 1486, 44, 63, "Output",ExpressionUUID->"11cd1a88-a312-4104-81bc-6e316d71a32e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904961, 25076, 1295, 38, 63, "Input",ExpressionUUID->"64b3cef0-dcd2-4586-8273-0f606ceee0c9"],
Cell[906259, 25116, 1440, 41, 63, "Output",ExpressionUUID->"230b9ce1-0c3e-4658-8e63-e6cbbd79e6d7"]
}, Open  ]],
Cell[907714, 25160, 1205, 32, 37, "Input",ExpressionUUID->"0775c64a-aa9d-4e18-9baa-ce667395ca46"],
Cell[908922, 25194, 1492, 42, 37, "Input",ExpressionUUID->"1b3cc6aa-917d-4408-ab5b-fa8dda59274d"],
Cell[CellGroupData[{
Cell[910439, 25240, 10076, 300, 434, "Input",ExpressionUUID->"6767a123-324b-43da-be73-66054575982e"],
Cell[920518, 25542, 10144, 265, 178, "Output",ExpressionUUID->"e73ccafb-9a18-4815-9eb1-8a14f752974a"],
Cell[930665, 25809, 10836, 279, 178, "Output",ExpressionUUID->"91404755-7efe-4fbc-9f67-458980f024c7"],
Cell[941504, 26090, 1152, 27, 49, "Output",ExpressionUUID->"8be3e780-89a7-4681-be9e-8973c1f1f557"],
Cell[942659, 26119, 1123, 26, 49, "Output",ExpressionUUID->"cd1b3ead-0fad-4641-948a-06a5730d328f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[943819, 26150, 2461, 73, 132, "Input",ExpressionUUID->"75b93e75-2161-48a9-96e5-ee6477fa2b08"],
Cell[946283, 26225, 493, 11, 38, "Output",ExpressionUUID->"fb13e624-4e0e-4c1c-897c-3967e63935f6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[946813, 26241, 3703, 102, 198, "Input",ExpressionUUID->"b4f1acf2-11bb-4210-a42e-e43106652298"],
Cell[950519, 26345, 1439, 39, 41, "Output",ExpressionUUID->"b653ea38-77f2-4e9d-ae38-79cc14556cf1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[952007, 26390, 551, 9, 58, "Subtitle",ExpressionUUID->"f9364c48-88c0-4979-a30b-5156a8142f79"],
Cell[952561, 26401, 1112, 26, 104, "Input",ExpressionUUID->"bc849eb1-77dd-4122-9d3c-56f11f3ee00b"],
Cell[CellGroupData[{
Cell[953698, 26431, 12628, 341, 541, "Input",ExpressionUUID->"d148db2e-cb41-4d32-ad5d-a94a9842d87c"],
Cell[966329, 26774, 2459, 61, 63, "Output",ExpressionUUID->"3ac24820-82f7-4f5f-a5b1-4109d7271344"],
Cell[968791, 26837, 2388, 58, 63, "Output",ExpressionUUID->"4290908e-e47a-44b6-befd-83801caccbb8"],
Cell[971182, 26897, 4453, 107, 110, "Output",ExpressionUUID->"ad62f578-04b1-4486-b04f-6254c53ed2e3"],
Cell[975638, 27006, 3153, 76, 41, "Output",ExpressionUUID->"d5a9b846-985b-4e91-b60e-16dd8da732cd"],
Cell[978794, 27084, 2045, 51, 41, "Output",ExpressionUUID->"ce6bd9bd-b7e9-4dcd-8283-60b6fc4fc403"],
Cell[980842, 27137, 1964, 48, 41, "Output",ExpressionUUID->"4dc33e22-038b-48d6-b756-db30731975b8"],
Cell[982809, 27187, 2615, 64, 63, "Output",ExpressionUUID->"737376ac-dfb5-4e62-9d63-cbfac78566fd"],
Cell[985427, 27253, 871, 16, 38, "Output",ExpressionUUID->"4c43310e-ad2d-41ba-9bc8-c94c0dc5b30a"],
Cell[986301, 27271, 874, 16, 38, "Output",ExpressionUUID->"311a99a3-1533-4a53-a0a0-d27d661a0fb4"],
Cell[987178, 27289, 2045, 51, 41, "Output",ExpressionUUID->"9bf1dcf9-09d1-4c5b-8086-47c4badb5f60"],
Cell[989226, 27342, 2388, 58, 63, "Output",ExpressionUUID->"8eb70ae7-9d62-4822-a352-c6b885218d89"],
Cell[991617, 27402, 874, 16, 38, "Output",ExpressionUUID->"a17e57d6-a872-4166-bd6b-ad5f4dc6b205"],
Cell[992494, 27420, 872, 16, 38, "Output",ExpressionUUID->"0781d268-5e9b-4124-8d66-c0cb99ffdccb"],
Cell[993369, 27438, 1838, 45, 38, "Output",ExpressionUUID->"d1538467-e9a2-4d5b-b420-919c1053d7d4"],
Cell[995210, 27485, 872, 16, 38, "Output",ExpressionUUID->"e9c6bc45-5fc6-4e4c-b639-9b5e51c9b011"]
}, Open  ]],
Cell[996097, 27504, 4781, 113, 227, "Input",ExpressionUUID->"73006410-e60f-465f-bf00-30292fe9bc3a"],
Cell[1000881, 27619, 661, 14, 58, "Input",ExpressionUUID->"3ccb8a7d-7883-4f02-b4b7-a2890d3cd0f9"],
Cell[CellGroupData[{
Cell[1001567, 27637, 1905, 55, 127, "Input",ExpressionUUID->"f08db98b-1ffa-41c0-bf7b-9ec10d75520b"],
Cell[1003475, 27694, 6111, 156, 92, "Output",ExpressionUUID->"fe08ff45-3932-40e9-8abd-f887b9585acd"],
Cell[1009589, 27852, 909, 26, 41, "Output",ExpressionUUID->"4bd89840-cde9-4ad4-b734-4aa2a16cb59e"]
}, Open  ]]
}, Closed]]
}
]
*)

