(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    751507,      20325]
NotebookOptionsPosition[    721057,      19886]
NotebookOutlinePosition[    721396,      19901]
CellTagsIndexPosition[    721353,      19898]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Quarter-plane lattice paths with interacting boundaries: the \
Kreweras and reverse Kreweras models",
  FontColor->RGBColor[0.5, 0, 0.5]],
 "\n",
 StyleBox["Ruijie Xu, Nicholas R. Beaton and Aleksander L. Owczarek\n\nSome \
calculations accompanying the solution to ",
  FontSize->18],
 StyleBox["reverse Kreweras ",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["walks with general boundary weights (a,b,c). Symbols and equation \
numbers match the manuscript where possible.\n\nNote: Many symbols are reused \
between this notebook and the Kreweras notebook -- be sure to quit the kernel \
before switching to the other one, or use a different kernel for each.\n\n\
(This block needs to be expanded to run some preliminary commands!)",
  FontSize->18]
}], "Subtitle",
 CellChangeTimes->{{3.750824805958762*^9, 3.750824842119121*^9}, {
  3.7508249241054707`*^9, 3.750824928018138*^9}, {3.7508250192823887`*^9, 
  3.750825027737978*^9}, {3.750825098608947*^9, 3.750825158227562*^9}, {
  3.750825445963887*^9, 3.750825476209941*^9}, {3.7508255475293293`*^9, 
  3.750825586691904*^9}, {3.750830675618618*^9, 3.750830730296144*^9}, {
  3.759698024614566*^9, 3.759698061086362*^9}, {3.767989156976531*^9, 
  3.767989178398693*^9}},ExpressionUUID->"14d72825-f42e-4f48-b02c-\
a94ca9a0fe8b"],

Cell[TextData[{
 StyleBox["Preliminaries",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[0.5, 0, 0.5]],
 StyleBox["It will be useful to have some series to substitute into equations \
to check their validity.",
  FontSize->18,
  FontColor->GrayLevel[0.5]]
}], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 
  3.750826127406416*^9}},ExpressionUUID->"033d1b3b-319e-49c4-b883-\
d435f74b39b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "shorthand", " ", "to", " ", "apply", " ", "a", " ", "function", " ", "f", 
    " ", "to", " ", "the", " ", "terms", " ", "of", " ", "a", " ", "series"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"f_", ",", "S_"}], "]"}], ":=", 
   RowBox[{"MapAt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "/@", "#"}], "&"}], ",", "S", ",", "3"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.750825870168775*^9, 3.750825899254999*^9}, {
  3.750825949723229*^9, 3.750825950338171*^9}, {3.750826120147867*^9, 
  3.750826127406775*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"93f2a60d-9c96-4126-bf9e-d81a4cc4a766"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "mathematica", " ", "sometimes", " ", "has", " ", "trouble", " ", "when", 
    " ", "combining", " ", "multiple", " ", "series", " ", "in", " ", "the", 
    " ", "same", " ", "variable"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"so", " ", 
    RowBox[{"here", "'"}], "s", " ", "a", " ", "way", " ", "of", " ", 
    "dealing", " ", "with", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplificate", "[", "S_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", "n"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"-", "3"}], "]"}], "]"}], "/", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"S", "[", 
            RowBox[{"[", 
             RowBox[{"-", "3"}], "]"}], "]"}], "/", 
           RowBox[{"S", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"S", "[", 
               RowBox[{"[", "3", "]"}], "]"}], "]"}], "-", "1"}], ")"}], "/", 
           
           RowBox[{"S", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}]}]}], ",", 
         RowBox[{"1", "/", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}]}], "]"}], ".", 
     RowBox[{"S", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"O", "[", 
      RowBox[{"S", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"-", "2"}], "]"}], "]"}], "/", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.760746561361539*^9, 3.760746694864303*^9}, {
  3.760746750948298*^9, 3.760746775776778*^9}, {3.760747397991107*^9, 
  3.76074741402074*^9}, {3.760747472376697*^9, 3.760747520460362*^9}, {
  3.760748526894298*^9, 3.760748565932456*^9}, {3.7607494965192204`*^9, 
  3.7607495188361387`*^9}, {3.7608187259883013`*^9, 3.7608187274096518`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"ba04f7f3-d17e-43fa-987c-3ecbcb288fc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"this", " ", "will", " ", "also", " ", "be", " ", "useful"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.7508927273243437`*^9, 3.750892740092514*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c9cc4108-28d4-415c-9411-89cc65beb915"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  RowBox[{"ParsedBoxWrapper", "[", 
   RowBox[{"SubscriptBox", "[", 
    RowBox[{"\"\<_\>\"", ",", "\"\<_\>\""}], "]"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  RowBox[{"ParsedBoxWrapper", "[", 
   RowBox[{"SubsuperscriptBox", "[", 
    RowBox[{"\"\<_\>\"", ",", "\"\<_\>\"", ",", "\"\<_\>\""}], "]"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.750892947603434*^9, 3.750892947605592*^9}, {
  3.750898836843748*^9, 3.750898849890044*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"23f26057-d002-428b-bb28-74311849e201"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"calculate", " ", "the", " ", "coefficients", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"polynomials", " ", "in", " ", "a"}], ",", "b", ",", "c"}], 
     ")"}], " ", "recursively"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"let", " ", 
    RowBox[{"q", "[", 
     RowBox[{"n", ",", "i", ",", "j"}], "]"}], " ", "be", " ", "the", " ", 
    "total", " ", "weight", " ", "of", " ", "walks", " ", "of", " ", "length",
     " ", "n", " ", "ending", " ", "at", " ", "coordinate", " ", 
    RowBox[{"(", 
     RowBox[{"i", ",", "j"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "q", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"0", ",", "0", ",", "0"}], "]"}], "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"n_", ",", "i_", ",", "j_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", "[", 
         RowBox[{"n", ",", "i", ",", "j"}], "]"}], "=", "0"}], ")"}], "/;", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", "<", "0"}], "||", 
        RowBox[{"i", "<", "0"}], "||", 
        RowBox[{"j", "<", "0"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "i_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"n", ",", "i", ",", "j"}], "]"}], "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", 
           RowBox[{"i", "+", "1"}], ",", 
           RowBox[{"j", "+", "1"}]}], "]"}], "+", 
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", 
           RowBox[{"i", "-", "1"}], ",", "j"}], "]"}], "+", 
         RowBox[{"q", "[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", "i", ",", 
           RowBox[{"j", "-", "1"}]}], "]"}]}], "]"}]}], ")"}], "/;", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"i", ">", "0"}], "&&", 
       RowBox[{"j", ">", "0"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "0", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"n", ",", "0", ",", "j"}], "]"}], "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"b", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", "1", ",", 
            RowBox[{"j", "+", "1"}]}], "]"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", "0", ",", 
            RowBox[{"j", "-", "1"}]}], "]"}]}]}], "]"}]}], ")"}], "/;", 
     RowBox[{"(", 
      RowBox[{"j", ">", "0"}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "i_", ",", "0"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"n", ",", "i", ",", "0"}], "]"}], "=", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", 
            RowBox[{"i", "+", "1"}], ",", "1"}], "]"}]}], "+", 
         RowBox[{"a", " ", 
          RowBox[{"q", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", 
            RowBox[{"i", "-", "1"}], ",", "0"}], "]"}]}]}], "]"}]}], ")"}], "/;", 
     RowBox[{"(", 
      RowBox[{"i", ">", "0"}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"n_", ",", "0", ",", "0"}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"n", ",", "0", ",", "0"}], "]"}], "=", 
      RowBox[{"Expand", "[", 
       RowBox[{"c", " ", 
        RowBox[{"q", "[", 
         RowBox[{
          RowBox[{"n", "-", "1"}], ",", "1", ",", "1"}], "]"}]}], "]"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759698184234085*^9, 3.7596982217613163`*^9}, {
  3.759698258155881*^9, 3.759698294268837*^9}, {3.7596983789831038`*^9, 
  3.759698409898426*^9}, {3.759698510115234*^9, 3.7596985631260443`*^9}, {
  3.75969862392305*^9, 3.759698645612405*^9}, {3.759698687080782*^9, 
  3.7596986950233717`*^9}, {3.759698763211735*^9, 3.759698789660714*^9}, {
  3.759698829070547*^9, 3.759699035566721*^9}, {3.759699098111526*^9, 
  3.759699136189612*^9}, {3.759700762333128*^9, 3.759700766628811*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"ae75d89a-f956-4900-9247-263d60fd5b6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", "generating", " ", "functions"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "QQ", ",", "QQcx", ",", "QQcy", ",", "QQcxy", ",", "QQeval", ",", 
     "QQcxeval", ",", "QQcyeval", ",", "QQdk", ",", "QQdkeval"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQ", "[", "N_", "]"}], ":=", 
    RowBox[{
     RowBox[{"QQ", "[", "N", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"x", "^", "i"}], "*", 
           RowBox[{"y", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "coefficients", " ", "of", " ", "specific", " ", "powers", " ", "of", 
      " ", "x"}], ",", "y", ",", " ", 
     RowBox[{"or", " ", "both"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcx", "[", 
     RowBox[{"N_", ",", "i_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcx", "[", 
      RowBox[{"N", ",", "i"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"y", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcy", "[", 
     RowBox[{"N_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcy", "[", 
      RowBox[{"N", ",", "j"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"x", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcxy", "[", 
     RowBox[{"N_", ",", "i_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcxy", "[", 
      RowBox[{"N", ",", "i", ",", "j"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "evaluating", " ", "QQ", " ", "at", " ", "some", " ", "other", " ", 
     "values", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQeval", "[", 
     RowBox[{"N_", ",", "xx_", ",", "yy_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQeval", "[", 
      RowBox[{"N", ",", "xx", ",", "yy"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"xx", "^", "i"}], "*", 
           RowBox[{"yy", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcxeval", "[", 
     RowBox[{"N_", ",", "i_", ",", "yy_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcxeval", "[", 
      RowBox[{"N", ",", "i", ",", "yy"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"yy", "^", "j"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQcyeval", "[", 
     RowBox[{"N_", ",", "j_", ",", "xx_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQcyeval", "[", 
      RowBox[{"N", ",", "j", ",", "xx"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", "j"}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"xx", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", "generalised", " ", "diagonal", " ", "term"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQdk", "[", 
     RowBox[{"N_", ",", "k_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQdk", "[", 
      RowBox[{"N", ",", "k"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", 
             RowBox[{"i", "+", "k"}]}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"x", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QQdkeval", "[", 
     RowBox[{"N_", ",", "k_", ",", "xx_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"QQdkeval", "[", 
      RowBox[{"N", ",", "k", ",", "xx"}], "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "[", 
            RowBox[{"n", ",", "i", ",", 
             RowBox[{"i", "+", "k"}]}], "]"}], "*", 
           RowBox[{"t", "^", "n"}], "*", 
           RowBox[{"xx", "^", "i"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "N"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "t", "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"N", "+", "1"}], ")"}]}]}]}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.75969915207519*^9, 3.7596993469503727`*^9}, {
  3.759699380116457*^9, 3.7596994883664007`*^9}, {3.7597003963632097`*^9, 
  3.759700407060787*^9}, {3.759700439867523*^9, 3.7597007359779787`*^9}, {
  3.7597009771006403`*^9, 3.759701047997175*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"07755e85-2fbe-4bd1-8355-525bc71e0da1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 3",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 
  3.759706802186184*^9}},ExpressionUUID->"522f812f-0b4e-4546-ba48-\
2b947d56be60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "kernel", " ", "and", " ", "A"}], ",", "B", ",", 
    "G"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"K", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{"1", "-", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{"x", "+", "y", "+", 
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"A", "=", 
    RowBox[{"B", "=", 
     RowBox[{"G", "=", 
      RowBox[{
       RowBox[{"1", "/", "x"}], "/", "y"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.7597068364455233`*^9, 3.7597068644447937`*^9}, {
  3.759706895124421*^9, 3.759706897452722*^9}, {3.759802338630629*^9, 
  3.759802341677115*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"8c1d9d93-1a37-40d7-bc35-d08a878e76cf"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"x", " ", "y"}]]], "Output",
 CellChangeTimes->{{3.759706850045207*^9, 3.759706875626996*^9}, 
   3.759714707373336*^9, 3.759714939115477*^9, 3.7597861337534447`*^9, 
   3.759786989063778*^9, 3.759798488275082*^9, {3.759802342804743*^9, 
   3.759802348646983*^9}, 3.760316694933609*^9, 3.760323980589417*^9, 
   3.760387754712678*^9, 3.760651607468316*^9, 3.760660970630601*^9, 
   3.760736250476037*^9, 3.7608187396981297`*^9, 3.760820551721847*^9, 
   3.7609955669735537`*^9, 3.7612670618269444`*^9, 3.761522656636902*^9, 
   3.766376819767*^9, 3.766433858523869*^9, 3.767663679941848*^9, 
   3.7676637218076773`*^9, 3.767665054308235*^9, 3.78915664632003*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"fe13d0f8-af97-4ef1-9cc0-bdd088c8cb25"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "rhs", " ", "of", " ", "eqn", " ", 
    RowBox[{"(", "3.3", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"mainFE", "=", 
     RowBox[{
      RowBox[{"1", "/", "c"}], "+", 
      RowBox[{
       RowBox[{"1", "/", "a"}], 
       RowBox[{"(", 
        RowBox[{"a", "-", "1", "-", 
         RowBox[{"t", " ", "a", " ", "A"}]}], ")"}], 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", "b"}], 
       RowBox[{"(", 
        RowBox[{"b", "-", "1", "-", 
         RowBox[{"t", " ", "b", " ", "B"}]}], ")"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"a", " ", "b", " ", "c"}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "b", " ", "c"}]}], ")"}]}], "+", 
         RowBox[{"t", " ", "G"}]}], ")"}], 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "verifying", " ", "eqn", " ", 
     RowBox[{"(", "3.3", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE", "-", 
     RowBox[{
      RowBox[{"K", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "\[Rule]", 
       RowBox[{"QQ", "[", "12", "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], "\[Rule]", 
       RowBox[{"QQcx", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7597092880979433`*^9, 3.759709315881922*^9}, {
  3.759709403848383*^9, 3.759709475162389*^9}, {3.75970952212619*^9, 
  3.759709566303985*^9}, {3.75970972370592*^9, 3.759709791983199*^9}, {
  3.759802356788431*^9, 3.7598023582711487`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"707f22f9-286f-4364-9fc8-c4e932ceef3b"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.759709780292001*^9, 3.7597097935380917`*^9}, 
   3.759714708225222*^9, 3.759714941915785*^9, 3.7597861345199614`*^9, 
   3.759786994253148*^9, 3.759798493610426*^9, 3.760316695717956*^9, 
   3.76032398142412*^9, 3.7603877555081587`*^9, 3.760651608236393*^9, 
   3.760660971416857*^9, 3.760736251231958*^9, 3.760818740467081*^9, 
   3.760820552818282*^9, 3.7609955676974783`*^9, 3.761267062733615*^9, 
   3.761522657300983*^9, {3.7663768312980003`*^9, 3.766376857883*^9}, 
   3.766433860670662*^9, 3.767663680874349*^9, 3.767663722614068*^9, 
   3.7676650550803347`*^9, 3.789156647309297*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"90c3d861-2d31-4548-a958-c8925a549937"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4.2",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.759714184011848*^9, 
  3.7597141840676126`*^9}, {3.75979277755081*^9, 
  3.75979277760183*^9}},ExpressionUUID->"972b950b-4da4-4cdb-8081-\
8a388c90f089"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"apply", " ", "the", " ", "kernel", " ", "symmetries"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"mainFE0", "=", "mainFE"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE1", "=", 
     RowBox[{"mainFE0", "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE2", "=", 
     RowBox[{"mainFE1", "/.", 
      RowBox[{"{", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE3", "=", 
     RowBox[{"mainFE2", "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE4", "=", 
     RowBox[{"mainFE3", "/.", 
      RowBox[{"{", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mainFE5", "=", 
     RowBox[{"mainFE4", "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"x", " ", "y"}], ")"}]}]}], "}"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.75970989143775*^9, 3.7597100087953873`*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"c3cf040b-d892-4f14-ab1d-e0d95bac45b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "vector", " ", "V", " ", "from", " ", "eqn", " ", 
    RowBox[{"(", "4.5", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "order", " ", "is", " ", "arbitrary"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"V", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], ",", " ", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "0"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "the", " ", "coefficient", " ", "matrix", " ", "M"}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"M", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE0", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE1", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE2", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE3", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE4", ",", "V"}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE5", ",", "V"}], "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759711022762516*^9, 3.7597111342858763`*^9}, {
  3.759711278965399*^9, 3.7597112890881*^9}, {3.7597113272375603`*^9, 
  3.759711327867112*^9}, {3.759711364723501*^9, 3.7597113735658007`*^9}, {
  3.7891566667173843`*^9, 3.789156666761496*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"e632957b-9a16-410d-aaca-eaf944e869b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], 
        RowBox[{"x", " ", "y"}]]}], "a"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], 
        RowBox[{"x", " ", "y"}]]}], "b"], ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x"}]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x"}]}], "a"], ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x"}]}], "b"], ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x"}]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], 
        RowBox[{"x", " ", "y"}]]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], 
        RowBox[{"x", " ", "y"}]]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "y"}]}], "a"], ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "y"}]}], "b"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "y"}]}], "a"], ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "y"}]}], "b"], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.759711328224057*^9, 3.75971137895121*^9, 
  3.7597147084819*^9, 3.759714947559157*^9, 3.759786135117076*^9, 
  3.75978699468305*^9, 3.759798494109972*^9, 3.76031669599691*^9, 
  3.760323981874164*^9, 3.760387756131559*^9, 3.7606516084364862`*^9, 
  3.76066097156022*^9, 3.7607362515105257`*^9, 3.760818740748885*^9, 
  3.7608205554505577`*^9, 3.760995568628166*^9, 3.761267062997829*^9, 
  3.761522657566874*^9, 3.7663768618120003`*^9, 3.766433867581818*^9, 
  3.7676637359320383`*^9, 3.76766505521926*^9, 3.7891567557929907`*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"95d96a1f-1eb4-4ece-bc02-5e8cb4d5e045"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"write", " ", "this", " ", "using"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ap", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"1", "/", "a"}], 
     RowBox[{"(", 
      RowBox[{"a", "-", "1", "-", 
       RowBox[{"t", " ", 
        RowBox[{
         RowBox[{"a", "/", "x"}], "/", "y"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bp", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"1", "/", "b"}], 
     RowBox[{"(", 
      RowBox[{"b", "-", "1", "-", 
       RowBox[{"t", " ", 
        RowBox[{
         RowBox[{"b", "/", "x"}], "/", "y"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ap", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", "0", ",", "0", ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Bp", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", 
        RowBox[{"Ap", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", "0", 
        ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", "0", ",", 
        RowBox[{"Ap", "[", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"y", ",", "x"}], "]"}], ",", 
        RowBox[{"Ap", "[", 
         RowBox[{"y", ",", "x"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"Ap", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", "0", 
        ",", 
        RowBox[{"Bp", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", "0"}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ap", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", "0", ",", "0", 
        ",", 
        RowBox[{"Bp", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", "0", ",", "0"}],
        "}"}]}], "}"}], "-", "M"}]}]}]], "Input",
 CellChangeTimes->{{3.759711390291848*^9, 3.759711442540081*^9}, {
  3.75971199832868*^9, 3.759711998407507*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"57331295-609b-454c-b6c2-94afdc70b410"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7597120002794228`*^9, 3.759714708601512*^9, 
  3.759714950831501*^9, 3.7597861354345503`*^9, 3.7597869948206797`*^9, 
  3.759798494247531*^9, 3.760316696134872*^9, 3.760323982011878*^9, 
  3.760387756481448*^9, 3.7606516085367947`*^9, 3.760660973996252*^9, 
  3.7607362516310577`*^9, 3.760818740903359*^9, 3.76082055556839*^9, 
  3.760995568966875*^9, 3.7612670631184177`*^9, 3.761522657688319*^9, 
  3.766376864568*^9, 3.766433870594541*^9, 3.767663736007709*^9, 
  3.767665055283222*^9, 3.789156755803481*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"7eb744f1-9341-4378-a641-fd92b28b5536"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "vector", " ", "C", " ", "is", " ", "everything", " ", 
     "else"}], ",", " ", 
    RowBox[{"see", " ", "eqn", " ", 
     RowBox[{"(", "4.7", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"CC", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mainFE0", ",", "mainFE1", ",", "mainFE2", ",", "mainFE3", ",", 
      "mainFE4", ",", "mainFE5"}], "}"}], "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[Rule]", "0"}], "&"}], "/@", "V"}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7597120140910273`*^9, 3.759712036475932*^9}, {
  3.759712094055369*^9, 3.759712114046336*^9}, {3.759712164851583*^9, 
  3.759712209392116*^9}, {3.759714893942273*^9, 3.759714895606483*^9}, {
  3.789156681084229*^9, 3.789156681132411*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"c2621728-4374-46a8-a1d6-325126736a32"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       FractionBox["t", 
        RowBox[{"x", " ", "y"}]]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       FractionBox["t", 
        RowBox[{"x", " ", "y"}]]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "y"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "y"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.759712211997518*^9, 3.7597147087007637`*^9, 
  3.7597148973305187`*^9, 3.759714954695652*^9, 3.7597861355510283`*^9, 
  3.759786994948186*^9, 3.7597984943771772`*^9, 3.760316696264831*^9, 
  3.760323982140563*^9, 3.760387756794957*^9, 3.76065160863695*^9, 
  3.760660974161028*^9, 3.760736251760902*^9, 3.760818741054163*^9, 
  3.76082055568566*^9, 3.7609955691947813`*^9, 3.761267063247908*^9, 
  3.761522657800888*^9, 3.7663768665439997`*^9, 3.7664338732962713`*^9, 
  3.767663736020708*^9, 3.7676650552939663`*^9, 3.789156755867756*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"f4bb87f2-0d35-463f-96c0-48e2a07b8e74"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"M", " ", "has", " ", "rank", " ", "5"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"MatrixRank", "[", "M", "]"}]}]], "Input",
 CellChangeTimes->{{3.759712386802647*^9, 3.759712393591477*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"703e1fba-8633-415e-bbae-5af84091b8f2"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.759712394289402*^9, 3.759714708799501*^9, 
  3.759714899520401*^9, 3.759714956399487*^9, 3.759786135969574*^9, 
  3.759786995062524*^9, 3.7597984945134153`*^9, 3.760316696398967*^9, 
  3.760323982255557*^9, 3.760387757944488*^9, 3.760651608735195*^9, 
  3.760660974255704*^9, 3.7607362518767138`*^9, 3.76081874120348*^9, 
  3.760820555918652*^9, 3.760995569333682*^9, 3.7612670633871517`*^9, 
  3.761522657918085*^9, 3.7663768681099997`*^9, 3.766433875414921*^9, 
  3.767663736096457*^9, 3.767665055356873*^9, 3.7891567558769608`*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"5344341b-42e6-4631-a1d4-7eef09477b64"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "vector", " ", "N", " ", "spans", " ", "the", " ", 
     "nullspace", " ", "of", " ", "M"}], ",", " ", 
    RowBox[{"see", " ", "eqn", " ", 
     RowBox[{"(", "4.8", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NullSpace", "[", 
     RowBox[{"M", "\[Transpose]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "clean", " ", "up", " ", "the", " ", "denominators", " ", "a", " ", 
     "bit"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"NN", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"%", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}], "-", 
        RowBox[{"x", " ", "y"}], "+", 
        RowBox[{"a", " ", "x", " ", "y"}]}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "b", "+", 
         RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], "/", "x"}]}], "//", 
     "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"and", " ", "see"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NN", ".", "M"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.759712366015135*^9, 3.759712375500309*^9}, {
   3.759712898455113*^9, 3.759712940462441*^9}, {3.75971307863848*^9, 
   3.759713111848144*^9}, {3.759714069857847*^9, 3.7597140978913927`*^9}, 
   3.759714194601364*^9, {3.7597149080728283`*^9, 3.7597149107038183`*^9}, {
   3.759715046543272*^9, 3.75971505760037*^9}, {3.759715469886054*^9, 
   3.7597154899560823`*^9}, {3.789156691293466*^9, 3.789156691349976*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"cd7d8de0-926a-4f9b-b2b5-771a8b26e6a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], " ", "y", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "y"}]}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "t"}], "-", 
        RowBox[{"x", " ", "y"}], "+", 
        RowBox[{"b", " ", "x", " ", "y"}]}], ")"}]}], "x"]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "-", 
       RowBox[{"x", " ", "y"}], "+", 
       RowBox[{"a", " ", "x", " ", "y"}]}], ")"}]}], "x"], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", "y", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "y"}]}], ")"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "a", "+", 
       RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "-", 
       RowBox[{"x", " ", "y"}], "+", 
       RowBox[{"b", " ", "x", " ", "y"}]}], ")"}]}], "x"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}], "-", 
        RowBox[{"x", " ", "y"}], "+", 
        RowBox[{"a", " ", "x", " ", "y"}]}], ")"}]}], "x"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7597129044344997`*^9, {3.759713083757491*^9, 3.75971311209867*^9}, {
   3.759714073994361*^9, 3.759714098554687*^9}, 3.7597141956193542`*^9, 
   3.7597147089834967`*^9, 3.759714911148552*^9, 3.759714961663329*^9, {
   3.759715047048311*^9, 3.759715058113043*^9}, {3.759715477570415*^9, 
   3.75971549060592*^9}, 3.759786136121176*^9, 3.75978699518111*^9, 
   3.759798494648785*^9, 3.760316696530566*^9, 3.760323982372093*^9, 
   3.7603877585269327`*^9, 3.760651608836463*^9, 3.7606609743445797`*^9, 
   3.760736252014546*^9, 3.760818741354219*^9, 3.760820556173318*^9, 
   3.7609955695645313`*^9, 3.7612670635367947`*^9, 3.761522658034122*^9, 
   3.766376873148*^9, 3.766433877951618*^9, 3.7676637361722393`*^9, 
   3.7676650554240932`*^9, 3.789156755944161*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"e48c8eff-4f1a-43a4-8866-2887f2afe33f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7597129044344997`*^9, {3.759713083757491*^9, 3.75971311209867*^9}, {
   3.759714073994361*^9, 3.759714098554687*^9}, 3.7597141956193542`*^9, 
   3.7597147089834967`*^9, 3.759714911148552*^9, 3.759714961663329*^9, {
   3.759715047048311*^9, 3.759715058113043*^9}, {3.759715477570415*^9, 
   3.75971549060592*^9}, 3.759786136121176*^9, 3.75978699518111*^9, 
   3.759798494648785*^9, 3.760316696530566*^9, 3.760323982372093*^9, 
   3.7603877585269327`*^9, 3.760651608836463*^9, 3.7606609743445797`*^9, 
   3.760736252014546*^9, 3.760818741354219*^9, 3.760820556173318*^9, 
   3.7609955695645313`*^9, 3.7612670635367947`*^9, 3.761522658034122*^9, 
   3.766376873148*^9, 3.766433877951618*^9, 3.7676637361722393`*^9, 
   3.7676650554240932`*^9, 3.789156755947163*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"29d084d7-a3e9-44d8-8850-0bacec442958"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"we", " ", "observe", " ", "that", " ", 
     RowBox[{"N", ".", "C"}]}], " ", "=", " ", "0"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NN", ".", "CC"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", "%", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7597146196439657`*^9, 3.7597146793000793`*^9}, {
   3.759714719373914*^9, 3.759714721802312*^9}, {3.7597147648025007`*^9, 
   3.75971477314989*^9}, {3.75971496421024*^9, 3.759714964974946*^9}, 
   3.759715359947732*^9},
 CellLabel->"In[43]:=",ExpressionUUID->"3b0e7789-88b0-452e-a597-24eeef1e0485"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.759714632043879*^9, 3.759714679758254*^9}, {
   3.759714711627987*^9, 3.759714722138977*^9}, {3.759714765853565*^9, 
   3.7597147733860197`*^9}, 3.759714965948648*^9, 3.759715253759766*^9, 
   3.759786136257759*^9, 3.759786995317597*^9, 3.759798494860856*^9, 
   3.760316696667685*^9, 3.760323982509962*^9, 3.7603877586452208`*^9, 
   3.7606516089363728`*^9, 3.7606609745014*^9, 3.760736252165259*^9, 
   3.760818741520946*^9, 3.7608205563241043`*^9, 3.760995569944305*^9, 
   3.7612670636863747`*^9, 3.76152265817178*^9, 3.766433880143758*^9, 
   3.767663736242249*^9, 3.76766505548952*^9, 3.7891567560161867`*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"8361e65d-a145-4cfb-b2c3-1fd8c4e2d041"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", "we", " ", "need", " ", "to", " ", 
    RowBox[{"extract", " ", "[", 
     RowBox[{"y", "^", "0"}], "]"}], " ", "of", " ", 
    RowBox[{"N", ".", "Q"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fullOS", "=", 
    RowBox[{"NN", ".", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "x"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
      RowBox[{"QQeval", "[", 
       RowBox[{"12", ",", "ecks", ",", "why"}], "]"}]}], "}"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.759715310338621*^9, 3.7597153899176607`*^9}, {
  3.759715513917062*^9, 3.7597155409738913`*^9}, {3.759715583332856*^9, 
  3.759715606629644*^9}, {3.759715644555032*^9, 3.7597156454658213`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"ff8d3480-a78c-423e-8d52-f6d8cf85e468"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "-", 
       RowBox[{"x", " ", "y"}], "+", 
       RowBox[{"a", " ", "x", " ", "y"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", 
       FractionBox["1", 
        RowBox[{"x", " ", "y"}]]}], "]"}]}], "x"]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", "y", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "+", 
     RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", 
      RowBox[{"x", " ", "y"}], "+", 
      RowBox[{"b", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "x"}], "]"}]}], "x"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", 
      RowBox[{"x", " ", "y"}], "+", 
      RowBox[{"b", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "y"}], "]"}]}], "x"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "+", 
     RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", "y", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"y", ",", "x"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}], "-", 
      RowBox[{"x", " ", "y"}], "+", 
      RowBox[{"a", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"y", ",", 
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]]}], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{3.759715541903614*^9, 3.759715610374638*^9, 
  3.759715648537384*^9, 3.7597861365041027`*^9, 3.759786995645212*^9, 
  3.759798494977138*^9, 3.7603166968023367`*^9, 3.760323983022257*^9, 
  3.760387758744977*^9, 3.760651609036477*^9, 3.7606609746126966`*^9, 
  3.760736252297737*^9, 3.760818741699588*^9, 3.760820556503191*^9, 
  3.760995570082172*^9, 3.761267063814088*^9, 3.761522658304482*^9, 
  3.766376877538*^9, 3.766433882420823*^9, 3.7676637362540207`*^9, 
  3.767665055500682*^9, 3.789156756026526*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"1df98391-26b4-446d-b51d-0dfc69716cfc"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.759715541903614*^9, 3.759715610374638*^9, 
  3.759715648537384*^9, 3.7597861365041027`*^9, 3.759786995645212*^9, 
  3.759798494977138*^9, 3.7603166968023367`*^9, 3.760323983022257*^9, 
  3.760387758744977*^9, 3.760651609036477*^9, 3.7606609746126966`*^9, 
  3.760736252297737*^9, 3.760818741699588*^9, 3.760820556503191*^9, 
  3.760995570082172*^9, 3.761267063814088*^9, 3.761522658304482*^9, 
  3.766376877538*^9, 3.766433882420823*^9, 3.7676637362540207`*^9, 
  3.767665055500682*^9, 3.789156760137488*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"89d9e091-c249-476a-9d67-cff71576332c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"this", " ", "is", " ", "not", " ", "too", " ", "complicated"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSy0", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "term"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOS", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ",", "y"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"it", " ", "contributes", " ", "nothing"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", "0"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], " ", "term"}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOS", ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}]}], "]"}], 
     ",", "y"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "it", " ", "contributes", " ", "some", " ", "diagonal", " ", "terms"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "2"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], " ", "term"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOS", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "]"}], ",", "y"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"some", " ", "more", " ", "diagonal", " ", "terms"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "/", "x"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "2", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "/", 
       RowBox[{"x", "^", "2"}]}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"y", ",", "x"}], "]"}], " ", "term"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOS", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "x"}], "]"}]}], "]"}], ",", "y"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"gives", " ", "nothing"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "=", "0"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], " ", "term"}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOS", ",", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}]}], "]"}], 
     ",", "y"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "gives", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "/", "x"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], " ", "term"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"fullOS", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "]"}], ",", "y"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "gives", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "/", 
       "x"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.759715683718946*^9, 3.759715747335182*^9}, {
   3.7597158851514187`*^9, 3.75971593343347*^9}, {3.759716523047715*^9, 
   3.7597165460301247`*^9}, {3.7597166000414677`*^9, 
   3.7597167529312468`*^9}, {3.75971678675239*^9, 3.759716975134005*^9}, {
   3.759717010405552*^9, 3.75971710059664*^9}, 3.759717690009479*^9, {
   3.7597177876249847`*^9, 3.759717989776843*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"458f7cef-70ae-4abe-867d-37743639dfa5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b", "-", 
    RowBox[{"b", " ", "t", " ", "x"}], "-", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}]}], ",", 
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b", "-", 
      RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.789156760214467*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"cf8a72b1-98f3-410b-a327-311503399e72"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.789156760219368*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"c26f9d9d-2e94-4fa0-a3e7-32bac95fa4da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"b", " ", "t"}], "x"], "-", 
    FractionBox[
     RowBox[{"a", " ", "b", " ", "t"}], "x"]}], ",", 
   RowBox[{"1", "-", "a", "-", "b", "+", 
    RowBox[{"a", " ", "b"}], "+", 
    FractionBox[
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "x"]}], ",", 
   RowBox[{
    RowBox[{"a", " ", "t"}], "-", 
    RowBox[{"a", " ", "b", " ", "t"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.789156760221249*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"04496db4-2cf7-4889-95eb-da835dfceb96"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"b", " ", "t"}], "x"], "-", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", "t"}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "-", "b", "+", 
     RowBox[{"a", " ", "b"}], "+", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "1"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "-", 
     RowBox[{"a", " ", "b", " ", "t"}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "2"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.7891567602863073`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"8c9f8c9d-a884-449e-ab7b-75b6cb5f3480"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"a", " ", "t"}], "x"]}], "+", 
    FractionBox[
     RowBox[{"a", " ", "b", " ", "t"}], "x"]}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a", "+", "b", "-", 
    RowBox[{"a", " ", "b"}], "-", 
    FractionBox[
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "x"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "t"}], "+", 
    RowBox[{"a", " ", "b", " ", "t"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.7891567602886333`*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"188dcf2b-d7ed-4005-b250-07969671fa97"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a", " ", "t"}], "x"]}], "+", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", "t"}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a", "+", "b", "-", 
      RowBox[{"a", " ", "b"}], "-", 
      FractionBox[
       RowBox[{"a", " ", "b", " ", 
        SuperscriptBox["t", "2"]}], "x"]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{"a", " ", "b", " ", "t"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "2", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], 
   SuperscriptBox["x", "2"]]}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.78915676034986*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"9687f417-ab08-49a3-9900-2be5a2965a19"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"1", "-", "a", "+", 
    RowBox[{"a", " ", "t", " ", "x"}], "-", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "a", "+", 
       RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}]}], ",", 
   RowBox[{"b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.789156760352521*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"818e90aa-4ad2-4783-bf79-c2cffce7e9fc"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.789156760354391*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"0984cdae-3ac7-4cb1-a19d-b87228588fc3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"b", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}], "x"]}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a", "-", 
    RowBox[{"a", " ", "t", " ", "x"}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "a", "+", 
       RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.7891567603561773`*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"0e16a7eb-b89c-450a-9e05-a02a7c14f699"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"b", " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "a", "+", 
       RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], "x"]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a", "-", 
      RowBox[{"a", " ", "t", " ", "x"}], "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "+", 
         RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.789156760516313*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"a32e0800-f64f-44d7-b547-04f78a00e510"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"a", " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], "x"], ",", 
   RowBox[{"1", "-", "b", "+", 
    RowBox[{"b", " ", "t", " ", "x"}], "-", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "b", "+", 
       RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.78915676051861*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"bce14a29-cd59-4766-ad29-28362e764c30"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "b", "+", 
         RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.7597156996934566`*^9, 3.75971574762776*^9, {3.7597159300109673`*^9, 
   3.759715933695456*^9}, {3.759716708443694*^9, 3.7597167141929007`*^9}, 
   3.759716895198503*^9, 3.75971693834168*^9, 3.759717051117154*^9, 
   3.759717101435247*^9, 3.7597179062962217`*^9, 3.759717940478429*^9, 
   3.7597179932721577`*^9, 3.759786139319819*^9, 3.759786998664098*^9, 
   3.7597984978442717`*^9, 3.76031669985143*^9, 3.760323986092902*^9, 
   3.76038776166361*^9, 3.7606516117867327`*^9, 3.760660977544565*^9, 
   3.7607362551768293`*^9, 3.7608187444373207`*^9, 3.7608205597558517`*^9, 
   3.7609955729133797`*^9, 3.7612670669345512`*^9, 3.7615226612195997`*^9, 
   3.766376884816*^9, 3.7664338905931053`*^9, 3.767663739789373*^9, 
   3.76766505943046*^9, 3.7891567605825977`*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"e56ad07e-5ec4-44ea-ab1d-4dd241f324d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Total", "[", "fullOSy0", "]"}], "//", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "]"}], "&"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
     RowBox[{"QQcxeval", "[", 
      RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
     RowBox[{"QQcy", "[", 
      RowBox[{"12", ",", "0"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
     RowBox[{"QQcxeval", "[", 
      RowBox[{"12", ",", "1", ",", "x"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "\[Rule]", 
     RowBox[{"QQcy", "[", 
      RowBox[{"12", ",", "1"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", "0", ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", 
       RowBox[{"-", "2"}], "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", 
       RowBox[{"-", "1"}], "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", "1", ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", "2", "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", "2", ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.7597180009562187`*^9, 3.759718177004767*^9}, {
  3.759718210050725*^9, 3.7597182845605307`*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"4b8eb852-02e6-4346-9736-ffc0e02b7acf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"b", " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "a", "+", 
       RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], "x"]}], "+", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a", "-", 
      RowBox[{"a", " ", "t", " ", "x"}], "+", 
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "+", 
         RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "b", "+", 
         RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "x"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a", " ", "t"}], "x"]}], "+", 
     FractionBox[
      RowBox[{"b", " ", "t"}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a", "+", "b", "-", 
      RowBox[{"a", " ", "b"}], "-", 
      FractionBox[
       RowBox[{"a", " ", "b", " ", 
        SuperscriptBox["t", "2"]}], "x"]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "+", 
      RowBox[{"a", " ", "b", " ", "t"}]}], ")"}], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "2", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], 
   SuperscriptBox["x", "2"]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "-", "b", "+", 
     RowBox[{"a", " ", "b"}], "+", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "1"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t"}], "-", 
     RowBox[{"a", " ", "b", " ", "t"}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "2"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759718005734125*^9, 3.759718049109302*^9, 3.759718178434819*^9, {
   3.759718215324098*^9, 3.759718292234993*^9}, 3.7597861399223537`*^9, 
   3.759786999250319*^9, 3.75979849849971*^9, 3.7603167007191067`*^9, 
   3.760323986708928*^9, 3.7603877624309797`*^9, 3.7606516125370493`*^9, 
   3.760660978233151*^9, 3.760736256061648*^9, 3.760818745142037*^9, 
   3.7608205603725443`*^9, 3.760995573513665*^9, 3.7612670675537157`*^9, 
   3.76152266240195*^9, 3.766377082165*^9, 3.766433895878675*^9, 
   3.7676637400896797`*^9, 3.767665059767466*^9, 3.789156760591799*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"7c91ae20-a35c-4381-9d70-919408bbd9c8"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759718005734125*^9, 3.759718049109302*^9, 3.759718178434819*^9, {
   3.759718215324098*^9, 3.759718292234993*^9}, 3.7597861399223537`*^9, 
   3.759786999250319*^9, 3.75979849849971*^9, 3.7603167007191067`*^9, 
   3.760323986708928*^9, 3.7603877624309797`*^9, 3.7606516125370493`*^9, 
   3.760660978233151*^9, 3.760736256061648*^9, 3.760818745142037*^9, 
   3.7608205603725443`*^9, 3.760995573513665*^9, 3.7612670675537157`*^9, 
   3.76152266240195*^9, 3.766377082165*^9, 3.766433895878675*^9, 
   3.7676637400896797`*^9, 3.767665059767466*^9, 3.78915676110786*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"62110827-6c5c-4e46-846a-3367131162a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "some", " ", "boundary", " ", "and", " ", "diagonal", " ", "relations", 
    " ", "can", " ", "be", " ", "used", " ", "to", " ", "eliminate", " ", 
    "some", " ", "of", " ", "these"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "equation", " ", "for", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Qx0eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "a", " ", "x", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{"a", "/", "x"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]]}], "-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
     RowBox[{"t", " ", "c", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "1"}], "]"}]}]}], "}"}]}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"similarly", " ", "for", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q0xeqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "b", " ", "x", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{"b", "/", "x"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]]}], "-", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], ")"}]}], "+", 
     RowBox[{"t", " ", "c", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"12", ",", "1", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"then", " ", "for", " ", "diagonals"}], ",", " ", 
     RowBox[{
      RowBox[{"starting", " ", "with", " ", "the"}], " ", "-", "1"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Qdm1eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{"t", " ", "x", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "1"}], "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "1"}]], "/", 
         RowBox[{"x", "^", "2"}]}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "/", "x"}]}], ")"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{"a", "/", "x"}], " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{"a", "/", "x"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "2"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", 
         RowBox[{"-", "2"}], "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", 
         RowBox[{"-", "1"}], "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "the", " ", "0", " ", "diagonal"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Qd0eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "x", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]], "/", "x"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"t", " ", "c", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{"t", " ", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", 
         RowBox[{"-", "1"}], "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "the", " ", "1", " ", "diagonal"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Qdp1eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{"t", " ", "x", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "2"}]], "/", "x"}], "-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]]}], "+", 
     RowBox[{
      RowBox[{"t", "/", "x"}], " ", 
      RowBox[{
       SubsuperscriptBox["Q", "2", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{"t", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "2", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "2", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        RowBox[{"1", "/", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "2"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"now", " ", "with", " ", "all", " ", "these", " ", 
      RowBox[{"we", "'"}], "ve", " ", "introduced", " ", "some", " ", "point",
       " ", "terms", " ", "that", " ", "can", " ", "be", " ", "eliminated"}], 
     ",", " ", 
     RowBox[{"namely", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}], ",", " ", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]], " ", "and", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q10eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", " ", "a", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Q01eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{"t", " ", "b", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "2"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Q00eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", "1", "+", 
     RowBox[{"t", " ", "c", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "these", " ", "ones", " ", "will", " ", "be", " ", "useful", " ", "in", 
     " ", "a", " ", "bit"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Q11eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Q22eqn", "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"3", ",", "3"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]]}], "+", 
     RowBox[{"t", " ", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "1"}]]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "3", ",", "3"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "2"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "1", ",", "2"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "2", ",", "1"}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.759716946079315*^9, {3.759718323156206*^9, 3.759718385876161*^9}, {
   3.759718762556506*^9, 3.759718818547688*^9}, {3.759718899695365*^9, 
   3.75971902874518*^9}, {3.759719061360147*^9, 3.75971915470233*^9}, {
   3.759719200076581*^9, 3.759719372596601*^9}, 3.759719526152886*^9, {
   3.759719573852232*^9, 3.759719602865584*^9}, {3.75971983673606*^9, 
   3.759720102960145*^9}, {3.759720146601323*^9, 3.759720782326148*^9}, {
   3.759720870709035*^9, 3.759721011949295*^9}, {3.7597868721445303`*^9, 
   3.75978697266328*^9}, {3.759789144328034*^9, 3.759789217563608*^9}, {
   3.760396511742033*^9, 3.7603965764746523`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"ab2d61b5-314d-444d-97bf-43499c95b5f4"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "-", 
  RowBox[{"Q", "[", 
   RowBox[{"x", ",", "0"}], "]"}], "+", 
  RowBox[{"a", " ", "t", " ", "x", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", "x"}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], ")"}]}], 
   "x"]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.7891567611857157`*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"8458f36c-7442-49f8-917d-699285b50faa"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761247642*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"f0c02078-189b-44c4-9992-f970058b1314"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "-", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "x"}], "]"}], "+", 
  RowBox[{"b", " ", "t", " ", "x", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{"b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", "x"}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], ")"}]}], 
   "x"]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761316978*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"018d5739-cbb2-4de5-b905-f0a2dd029e41"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761390462*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"1304123a-144f-4cb0-acff-50628f551918"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a", " ", 
    SubscriptBox["Q", 
     RowBox[{"2", ",", "1"}]], " ", "t"}], "x"], "+", 
  FractionBox[
   RowBox[{"a", " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], "x"], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], ")"}]}], "x"], "-", 
  RowBox[{
   SubsuperscriptBox["Q", 
    RowBox[{"-", "1"}], "d"], "[", 
   FractionBox["1", "x"], "]"}], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SubscriptBox["Q", 
        RowBox[{"2", ",", "1"}]], 
       SuperscriptBox["x", "2"]]}], "-", 
     FractionBox[
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]], "x"], "+", 
     RowBox[{
      SubsuperscriptBox["Q", 
       RowBox[{"-", "1"}], "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "2"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761463801*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"7537cb4c-05e9-4f2a-b358-96c3b4d33e4a"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.7891567615343933`*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"97f38f08-77e9-4ca3-b5be-c92970856155"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "-", 
  RowBox[{
   SubsuperscriptBox["Q", "0", "d"], "[", 
   FractionBox["1", "x"], "]"}], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "x"]}], "-", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "+", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "+", 
  RowBox[{"t", " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "1"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761536911*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"a5391641-6452-4dfe-a50d-8b16efe38cac"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761538988*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"3ada8f98-b870-48c6-85cc-d922b7eec760"],

Cell[BoxData[
 RowBox[{
  RowBox[{"b", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{"b", " ", "t", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}], "-", 
  RowBox[{
   SubsuperscriptBox["Q", "1", "d"], "[", 
   FractionBox["1", "x"], "]"}], "+", 
  RowBox[{"t", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "-", 
     FractionBox[
      SubscriptBox["Q", 
       RowBox[{"1", ",", "2"}]], "x"], "+", 
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"t", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "2", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761628537*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"a6a70f6f-81ef-4006-8b5c-59d7a3c6387f"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761697091*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"5f4ae1b6-8d00-4eba-aa74-0254a4c81f84"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]]}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"a", " ", "t", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.7891567616986856`*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"fb28f5ae-a336-48d8-a9b5-b271b26a8611"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.7891567617006083`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"f60cfe8d-abe7-41c4-bd80-886c254562a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]]}], "+", 
  RowBox[{"b", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{"b", " ", "t", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761702651*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"68d72098-2266-4a38-81f0-f0a4a2814ccf"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761704875*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"966b6b5a-4f48-49db-ab88-77cf0099dcb6"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]], " ", "t"}], "-", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.7891567617069063`*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"7c8f7dc2-39ec-433e-931c-39335be80e65"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.78915676170881*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"eced1564-5791-448c-aaaa-004b9f985079"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "1"}]]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"2", ",", "2"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761797103*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"05bbf472-7f96-4d46-834f-dcede3b4f057"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761799164*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"acbc9774-23a1-4bf1-b085-f00b7bad06e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "2"}]]}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"1", ",", "2"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"2", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{
   SubscriptBox["Q", 
    RowBox[{"3", ",", "3"}]], " ", "t"}]}]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.789156761887916*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"26b2a211-4409-4d62-85e1-872354cb3aa6"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.759719091129109*^9, {3.759719140108924*^9, 3.759719155551199*^9}, 
   3.759719223265821*^9, 3.759719373619198*^9, 3.759720139501803*^9, {
   3.759720232781246*^9, 3.759720251105399*^9}, 3.759720474277268*^9, {
   3.759720685461258*^9, 3.75972070273622*^9}, 3.759720951499043*^9, 
   3.7597210122348623`*^9, 3.759786140385193*^9, 3.759786960988043*^9, 
   3.759787000116303*^9, 3.7597892191529703`*^9, 3.75979849894018*^9, 
   3.760316701235388*^9, 3.7603239872054*^9, 3.760387763060693*^9, 
   3.760396577656103*^9, 3.760651612996174*^9, 3.7606609787598457`*^9, 
   3.760736257547326*^9, 3.7608187455827103`*^9, 3.760820560819763*^9, 
   3.760995573990724*^9, 3.761267068011841*^9, 3.761522662877305*^9, 
   3.766376895369*^9, 3.766433900873012*^9, 3.767663740583638*^9, 
   3.767665060247452*^9, 3.7891567618901167`*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"6b2fd41f-ac1f-4ffc-8af1-e0a925fb6f19"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"applying", " ", "these", " ", "gives", " ", "eqn", " ", 
    RowBox[{"(", "4.10", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSy0", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qx0eqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"\[Bullet]", ",", "1"}]], "[", "x", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q0xeqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "\[Bullet]"}]], "[", "x", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qdm1eqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "2"}], "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qdp1eqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", "2", "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Qd0eqn", "\[Equal]", "0"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", 
          RowBox[{"-", "1"}], "d"], "[", 
         RowBox[{"1", "/", "x"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q01eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "2"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSy0v2", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Total", "[", "%", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], ",", 
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], ",", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], ",", 
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}]}], "}"}], ",", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxeval", "[", 
        RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"12", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"12", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"12", ",", "0", ",", "0"}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759786178628667*^9, 3.759786185744553*^9}, {
  3.7597866560370893`*^9, 3.7597868494091463`*^9}, {3.759787026316696*^9, 
  3.759787148897079*^9}, {3.7597871914914494`*^9, 3.759787269262601*^9}, {
  3.759787321429883*^9, 3.759787324005468*^9}, {3.789156722395588*^9, 
  3.789156722551786*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"7c2c29f1-33ee-4741-b764-48b23fb4b76d"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], 
   RowBox[{"c", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", "t"}], 
   RowBox[{"c", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "c"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", "b"}], "-", 
       RowBox[{"a", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"a", " ", "c"}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "c"}], "-", 
       RowBox[{"b", " ", "c"}], "-", 
       RowBox[{"a", " ", "b", " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "c"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"], " ", "c", " ", 
        SuperscriptBox["t", "3"]}]}], 
      RowBox[{"a", " ", "b", " ", "c", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "t"}], 
      RowBox[{"c", " ", "x"}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "b"}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", "x"}], 
      RowBox[{"a", " ", "b", " ", "c"}]], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "-", "a", "-", "b", "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "3"]}]}], 
       RowBox[{"b", " ", "t"}]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t"}], "x"], 
     "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "b"], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "a", "-", "b", "+", 
       RowBox[{"a", " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "b", " ", 
        SuperscriptBox["t", "3"]}]}], 
      RowBox[{"a", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t"}], "x"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "a"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", "b", "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["t", "3"]}]}], "t"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "a"}], "+", 
         RowBox[{"2", " ", "b"}], "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "t"}], "x"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "a"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}]}], " ", "t"}], "-", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], 
      SuperscriptBox["x", "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "1", "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.759787066489764*^9, 3.759787149362954*^9}, {
   3.759787192040955*^9, 3.759787214317812*^9}, {3.759787259264887*^9, 
   3.759787270333458*^9}, 3.759787325501993*^9, 3.759798499912636*^9, 
   3.760316702422306*^9, 3.760323988767777*^9, 3.7603877641039343`*^9, 
   3.76065161442446*^9, 3.760660980323427*^9, 3.76073625864254*^9, 
   3.760818746653781*^9, 3.7608205625574207`*^9, 3.760995574876367*^9, 
   3.761267069395245*^9, 3.761522664369438*^9, 3.766376902833*^9, 
   3.766433905058679*^9, 3.767663751921864*^9, 3.767665060904303*^9, 
   3.789156762085616*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"a8abe72c-4c4c-4a05-bbe5-0212427a8bc7"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.759787066489764*^9, 3.759787149362954*^9}, {
   3.759787192040955*^9, 3.759787214317812*^9}, {3.759787259264887*^9, 
   3.759787270333458*^9}, 3.759787325501993*^9, 3.759798499912636*^9, 
   3.760316702422306*^9, 3.760323988767777*^9, 3.7603877641039343`*^9, 
   3.76065161442446*^9, 3.760660980323427*^9, 3.76073625864254*^9, 
   3.760818746653781*^9, 3.7608205625574207`*^9, 3.760995574876367*^9, 
   3.761267069395245*^9, 3.761522664369438*^9, 3.766376902833*^9, 
   3.766433905058679*^9, 3.767663751921864*^9, 3.767665060904303*^9, 
   3.789156762284333*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"6c6066c1-234e-4ae8-9190-872c8ab8afdb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "now", " ", "take", " ", "the", " ", "positive", " ", "and", 
    " ", "negative", " ", "parts", " ", "wrt", " ", "x"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"this", " ", "is", " ", "straightforward"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.759787860793076*^9, 3.759787905642907*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"0f1c43bd-7a7d-4e23-a432-5893fd844fad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"for", " ", "the", " ", "positive", " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"eqn", " ", 
    RowBox[{"(", "4.11", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSy0xpos", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSy0v2", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", "__", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xpos", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{"Select", "[", 
     RowBox[{"%", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Exponent", "[", 
         RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xpos", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xpos", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "1"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xpos", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
          RowBox[{"-", "1"}]}], "&"}]}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{"x", " ", 
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xpos", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]], "/", "x"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xpos", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "=", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.75978790688517*^9, 3.759787937323319*^9}, {
  3.759787976294326*^9, 3.759788426336136*^9}, {3.761881056681034*^9, 
  3.7618810691560345`*^9}, {3.7618811059040346`*^9, 3.7618811106390343`*^9}, {
  3.789156731845861*^9, 3.789156731911058*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"6268ed7a-a61c-4012-aff1-2d823e23c3a5"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], 
   RowBox[{"c", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", "t"}], 
   RowBox[{"c", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "c"]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762372587*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"78e9ecd0-4c13-4abb-a9d7-bf94d1b31825"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "c"]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762374683*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"a07859ca-8c4b-4c2e-814b-0a576472512e"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"a", " ", "b"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c"}], "-", 
    RowBox[{"b", " ", "c"}], "-", 
    RowBox[{"a", " ", "b", " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "3"]}]}], 
   RowBox[{"a", " ", "b", " ", "c", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "t"}], 
   RowBox[{"c", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", "x"}], 
   RowBox[{"a", " ", "b", " ", "c"}]], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.7891567623768253`*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"2185b2b9-000b-4635-9f7e-7e122995eb7f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "b"}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", "x"}], 
      RowBox[{"a", " ", "b", " ", "c"}]]}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762379203*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"89d9d6a5-c65a-4e5e-ab35-ab6dc7bba89b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"1", "-", "a", "-", "b", "+", 
     RowBox[{"a", " ", "b"}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}]}], 
    RowBox[{"b", " ", "t"}]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t"}], "x"], "+", 
  
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "b"], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762382015*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"2330db85-7de5-4cb1-abce-1bc18c07548b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "b"], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "-", "b", "+", 
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], ")"}]}], 
   RowBox[{"b", " ", "t"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], " ", "x"}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], ")"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762384424*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"d72bf9cd-ffee-4323-93cf-429974b17027"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "-", "a", "-", "b", "+", 
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "3"]}]}], 
   RowBox[{"a", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t"}], "x"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "a"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762387108*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"2f94f493-aab2-4341-b630-ceb659bb2376"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", 
          RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "a"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "-", "b", "+", 
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}], 
   RowBox[{"a", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], " ", "x"}], "-", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "+", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], ")"}]}], "x"]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762389797*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"63771d43-9213-42cb-b5b3-596664800671"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", "b", "+", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "3"]}]}], "t"]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", 
      RowBox[{"2", " ", "b"}], "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "t"}], "x"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "a"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762392251*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"ae847fda-5b75-44d4-9464-ed160dbe19c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "a"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]], "x"], "+", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762394622*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"16479278-5137-4e61-879f-16ffc495a980"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", 
      RowBox[{"2", " ", "a", " ", "b"}]}], ")"}]}], " ", "t"}], "-", 
  FractionBox[
   RowBox[{"2", " ", "a", " ", "b", " ", 
    SuperscriptBox["t", "2"]}], 
   SuperscriptBox["x", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "2"}], "+", "a", "+", "b"}], "x"]}]], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.7891567623971367`*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"f0c3c653-5658-4b3f-850c-6d6b90242cf2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.759788019334875*^9, {3.759788049622995*^9, 3.759788077981801*^9}, {
   3.7597881106418867`*^9, 3.7597881346674547`*^9}, {3.759788232068041*^9, 
   3.759788243820715*^9}, {3.759788275095057*^9, 3.759788323895382*^9}, {
   3.7597883946726627`*^9, 3.7597884278278437`*^9}, 3.759798500246564*^9, 
   3.7603167027175217`*^9, 3.7603239891944227`*^9, 3.7603877644137373`*^9, 
   3.760651614737936*^9, 3.760660980633025*^9, 3.760736258928163*^9, 
   3.760818746951352*^9, 3.7608205627028103`*^9, 3.76099557515397*^9, 
   3.7612670697159557`*^9, 3.7615226646845913`*^9, 3.766376920764*^9, 
   3.766433910679689*^9, 3.767663757394561*^9, 3.767665061214159*^9, 
   3.789156762399241*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"cc762039-f295-4082-8032-2977e7a555d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Total", "[", "fullOSy0xpos", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fullOSy0xposv2", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "x"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "}"}], ",", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
     RowBox[{"QQcxeval", "[", 
      RowBox[{"12", ",", "0", ",", "x"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
     RowBox[{"QQcy", "[", 
      RowBox[{"12", ",", "0"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
     RowBox[{"QQcxy", "[", 
      RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]], "\[Rule]", 
     RowBox[{"QQcxy", "[", 
      RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]], "\[Rule]", 
     RowBox[{"QQcxy", "[", 
      RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.759788456332549*^9, 3.75978861555324*^9}, {
  3.7607553973847847`*^9, 3.760755398223711*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"b6f663ff-ab8f-45c6-85b0-5c7ce48a1cd4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", "b", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], " ", "x"}], "c"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}]}], 
      RowBox[{"a", " ", "b", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], " ", "t"}], "x"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "-", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", "x"}], 
      RowBox[{"a", " ", "b", " ", "c"}]]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "-", "a", "-", "b", "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "3"]}]}], 
       RowBox[{"b", " ", "t"}]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t"}], "x"], 
     "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "b"], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "a", "-", "b", "+", 
       RowBox[{"a", " ", "b"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "b", " ", 
        SuperscriptBox["t", "3"]}]}], 
      RowBox[{"a", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t"}], "x"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "a"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.759788462561881*^9, 3.7597885088889017`*^9}, {
   3.7597885425985394`*^9, 3.759788572258412*^9}, {3.759788602651424*^9, 
   3.7597886200249157`*^9}, 3.759798500487421*^9, 3.7603167029216022`*^9, 
   3.760323989606924*^9, 3.7603877646361017`*^9, 3.760651614926581*^9, 
   3.760660980871087*^9, 3.7607362591165857`*^9, 3.760755399352273*^9, 
   3.760818747172802*^9, 3.760820562908574*^9, 3.760995575365205*^9, 
   3.761267069937027*^9, 3.761522664890435*^9, 3.7663769234820004`*^9, 
   3.766433915344483*^9, 3.7676637655204487`*^9, 3.767665061303123*^9, 
   3.78915676248599*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"f6d844d9-f763-400c-b080-4ed8177faaba"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.759788462561881*^9, 3.7597885088889017`*^9}, {
   3.7597885425985394`*^9, 3.759788572258412*^9}, {3.759788602651424*^9, 
   3.7597886200249157`*^9}, 3.759798500487421*^9, 3.7603167029216022`*^9, 
   3.760323989606924*^9, 3.7603877646361017`*^9, 3.760651614926581*^9, 
   3.760660980871087*^9, 3.7607362591165857`*^9, 3.760755399352273*^9, 
   3.760818747172802*^9, 3.760820562908574*^9, 3.760995575365205*^9, 
   3.761267069937027*^9, 3.761522664890435*^9, 3.7663769234820004`*^9, 
   3.766433915344483*^9, 3.7676637655204487`*^9, 3.767665061303123*^9, 
   3.789156762574607*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"4a8cfb51-2bd9-42c2-b8d9-71ac6f10e29e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "then", " ", "for", " ", "the", " ", "negative", " ", "part", " ", "wrt", 
    " ", "x"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"eqn", " ", 
    RowBox[{"(", "4.12", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fullOSy0xneg", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fullOSy0v2", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", "__", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xneg", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{"Select", "[", 
     RowBox[{"%", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Exponent", "[", 
         RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xneg", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xneg", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
         RowBox[{"-", "1"}]}], "&"}]}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xneg", "[", 
     RowBox[{"[", "4", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"%", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Exponent", "[", 
          RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", 
         RowBox[{"-", "1"}]}], "&"}]}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xneg", "[", 
     RowBox[{"[", "5", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]], "/", "x"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "-", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "1"}]], "/", "x"}], "-", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "/", 
         RowBox[{"x", "^", "2"}]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"fullOSy0v2", ",", 
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fullOSy0xneg", "[", 
     RowBox[{"[", "6", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{"%", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Exponent", "[", 
           RowBox[{"#", ",", "x"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}], 
      "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], "-", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], ")"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.759788624557796*^9, 3.759788934440835*^9}, {
  3.759788976809*^9, 3.759789115647428*^9}, {3.7618810917060347`*^9, 
  3.7618811005080347`*^9}, {3.789156738731656*^9, 3.7891567387993526`*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"f3e88143-0dd2-47c3-9402-0f5359b845fe"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], 
   RowBox[{"c", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", "t"}], 
   RowBox[{"c", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "c"]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762584981*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"d480e93e-3a0c-410e-a2c2-5faae5fb74ad"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", "t"}], 
   RowBox[{"c", " ", "x"}]]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.7891567625875463`*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"07bd9d29-a07e-48c0-8f64-df83972cb3d1"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"a", " ", "b"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c"}], "-", 
    RowBox[{"b", " ", "c"}], "-", 
    RowBox[{"a", " ", "b", " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "3"]}]}], 
   RowBox[{"a", " ", "b", " ", "c", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "t"}], 
   RowBox[{"c", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", "x"}], 
   RowBox[{"a", " ", "b", " ", "c"}]], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762589697*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"c7f3babc-ad08-40bf-b02e-2416b189621c"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], 
   RowBox[{"c", " ", "x"}]]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762592353*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"d8cb10b8-7b5c-47c3-849a-869c9d702ae6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"1", "-", "a", "-", "b", "+", 
     RowBox[{"a", " ", "b"}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "3"]}]}], 
    RowBox[{"b", " ", "t"}]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t"}], "x"], "+", 
  
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "b"], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.78915676259452*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"8f57a10f-44c1-4b83-85dc-192a3dd8bfa8"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "x"]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762596716*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"5fe29186-7fd9-437c-a5fc-caf36f0e32e9"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "-", "a", "-", "b", "+", 
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "3"]}]}], 
   RowBox[{"a", " ", "t"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t"}], "x"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "x"}], "a"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762598836*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"ef5572c0-99fb-4d50-8849-d53631800076"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762600852*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"538200e1-c531-4fa8-beac-9f1706dac888"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", "b", "+", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "3"]}]}], "t"]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", 
      RowBox[{"2", " ", "b"}], "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "t"}], "x"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "a"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762603031*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"4d3c2e45-c449-4176-8ca0-f33aa52ebd10"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", 
      RowBox[{"2", " ", "b"}], "+", 
      RowBox[{"a", " ", "b"}]}], ")"}], " ", "t", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b", "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], ")"}]}], "t"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "a"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], "x"]}], "-", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "+", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
   SuperscriptBox["x", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], 
       SuperscriptBox["x", "2"]]}], "-", 
     FractionBox[
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]], "x"], "-", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "+", 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762605699*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"ec59f6b6-701c-4636-b837-c2111d3a118a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", 
      RowBox[{"2", " ", "a", " ", "b"}]}], ")"}]}], " ", "t"}], "-", 
  FractionBox[
   RowBox[{"2", " ", "a", " ", "b", " ", 
    SuperscriptBox["t", "2"]}], 
   SuperscriptBox["x", "2"]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "2"}], "+", "a", "+", "b"}], "x"]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762608502*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"613107c2-7499-4f5d-b381-b7c198dc6671"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "b", " ", 
        SuperscriptBox["t", "2"]}], 
       SuperscriptBox["x", "2"]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "1", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "a"}], "-", "b", "+", 
     RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.759788677847849*^9, 3.7597887308099937`*^9}, {
   3.759788784278347*^9, 3.759788830659091*^9}, {3.759788984493327*^9, 
   3.75978901930504*^9}, 3.759789063368045*^9, 3.75978911638638*^9, 
   3.759798500635952*^9, 3.7603167030502443`*^9, 3.760323989906866*^9, 
   3.760387764747067*^9, 3.760651615204939*^9, 3.760660981021789*^9, 
   3.760736259245565*^9, 3.760818747300968*^9, 3.760820563037434*^9, 
   3.760995575570911*^9, 3.76126707016565*^9, 3.7615226651209383`*^9, 
   3.766376925156*^9, 3.7664339186344633`*^9, 3.767663770610827*^9, 
   3.767665061428546*^9, 3.789156762611027*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"663ef61c-1779-4f4b-813a-587a34af149c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Total", "[", "fullOSy0xneg", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Q11eqn", "\[Equal]", "0"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "2"}]]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fullOSy0xnegv2", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], ",", 
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "}"}], ",", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], "]"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
     RowBox[{"QQcxy", "[", 
      RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]], "\[Rule]", 
     RowBox[{"QQcxy", "[", 
      RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]], "\[Rule]", 
     RowBox[{"QQcxy", "[", 
      RowBox[{"12", ",", "1", ",", "0"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", "0", ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["Q", "1", "d"], "[", 
      FractionBox["1", "x"], "]"}], "\[Rule]", 
     RowBox[{"QQdkeval", "[", 
      RowBox[{"12", ",", "1", ",", 
       RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.759789245497655*^9, 3.759789390939715*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"71d7395a-5b9f-495e-aee6-5c835fb2f2d0"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], 
   RowBox[{"c", " ", "t"}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t"}], "-", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t"}], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", "t"}], 
   RowBox[{"c", " ", "x"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "c"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "b", "-", "c", "+", 
       RowBox[{"b", " ", "c"}], "+", 
       RowBox[{"a", " ", "b", " ", "c", " ", 
        SuperscriptBox["t", "3"]}]}], 
      RowBox[{"c", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "-", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", "t"}], 
      RowBox[{"c", " ", "x"}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c", "+", 
         RowBox[{"a", " ", "c"}]}], ")"}], " ", "x"}], "c"], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", "b", "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["t", "3"]}]}], "t"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "a"}], "+", 
         RowBox[{"2", " ", "b"}], "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "t"}], "x"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "a"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}]}], " ", "t"}], "-", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], 
      SuperscriptBox["x", "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}], "x"]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "1", "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.759789248707492*^9, 3.7597893235026703`*^9}, 
   3.7597893921257553`*^9, 3.759798500884897*^9, 3.760316703255229*^9, 
   3.760323990127767*^9, 3.76038776493604*^9, 3.760651615421947*^9, 
   3.760660981236986*^9, 3.7607362594330997`*^9, 3.760818747542485*^9, 
   3.7608205637707443`*^9, 3.760995575760461*^9, 3.761267070732623*^9, 
   3.76152266568616*^9, 3.766376928351*^9, 3.766433922051403*^9, 
   3.7676637741537943`*^9, 3.76766506151829*^9, 3.7891567626979027`*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"fea55b32-0db4-46bb-a74d-8010113b797a"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 12, 12, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.759789248707492*^9, 3.7597893235026703`*^9}, 
   3.7597893921257553`*^9, 3.759798500884897*^9, 3.760316703255229*^9, 
   3.760323990127767*^9, 3.76038776493604*^9, 3.760651615421947*^9, 
   3.760660981236986*^9, 3.7607362594330997`*^9, 3.760818747542485*^9, 
   3.7608205637707443`*^9, 3.760995575760461*^9, 3.761267070732623*^9, 
   3.76152266568616*^9, 3.766376928351*^9, 3.766433922051403*^9, 
   3.7676637741537943`*^9, 3.76766506151829*^9, 3.7891567627007303`*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"a8baa86c-3c8e-4576-9e57-5753157f2834"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4.3",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.759714184011848*^9, 
  3.7597141840676126`*^9}, {3.75979277755081*^9, 
  3.7597927872206507`*^9}},ExpressionUUID->"061b746d-2d84-488c-9796-\
cf0f3e4d998f"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"we", " ", "now", " ", "compute", " ", "the", " ", "half"}], "-", 
   RowBox[{"orbit", " ", "sum"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.759793038883416*^9, 3.75979304465063*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"87a128cf-9561-46f6-adb5-a8dff5cb3c6c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "vector", " ", 
    SubscriptBox["V", "2"], " ", "from", " ", "eqn", " ", 
    RowBox[{"(", "4.13", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], ",", " ", 
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "0"}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "0"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"then", " ", "the", " ", "coefficient", " ", "matrix", " ", 
     SubscriptBox["M", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["M", "2"], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE0", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE1", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE2", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE3", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE4", ",", 
        SubscriptBox["V", "2"]}], "]"}], ",", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"mainFE5", ",", 
        SubscriptBox["V", "2"]}], "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759793271658119*^9, 3.759793383382826*^9}, {
  3.789156796288662*^9, 3.789156796338338*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"1846682e-7a54-4fd1-bf99-a13c39266ada"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       FractionBox[
        RowBox[{"b", " ", "t"}], 
        RowBox[{"x", " ", "y"}]]}], "b"], ",", "0", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x"}]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x"}]}], "a"], ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "x"}]}], "b"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "x"}]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       FractionBox[
        RowBox[{"a", " ", "t"}], 
        RowBox[{"x", " ", "y"}]]}], "a"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "a", "-", 
       RowBox[{"a", " ", "t", " ", "y"}]}], "a"], ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "b", "-", 
       RowBox[{"b", " ", "t", " ", "y"}]}], "b"], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.759793368567596*^9, 3.759793383866971*^9}, 
   3.7597985010291*^9, 3.760316703665843*^9, 3.7603239904750147`*^9, 
   3.760387765130632*^9, 3.7606516156413307`*^9, 3.76066098140086*^9, 
   3.760736259595249*^9, 3.7608187478154078`*^9, 3.760820563918811*^9, 
   3.760995575900413*^9, 3.761267071499345*^9, 3.761522666254033*^9, 
   3.766377217375*^9, 3.7664339276558323`*^9, 3.7676637818149023`*^9, 
   3.767665061661688*^9, 3.7891569334803677`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"d49d7cf5-a1fb-4dd7-8726-8d45ac9219a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "vector", " ", 
     SubscriptBox["C", "2"], " ", "is", " ", "everything", " ", "else"}], ",",
     " ", 
    RowBox[{"see", " ", "eqn", " ", 
     RowBox[{"(", "4.13", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["CC", "2"], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mainFE0", ",", "mainFE1", ",", "mainFE2", ",", "mainFE3", ",", 
      "mainFE4", ",", "mainFE5"}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "y"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}], ",", "0"}], "]"}], "\[Rule]", 
       "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"y", ",", "0"}], "]"}], "\[Rule]", "0"}]}], 
     "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759793479270163*^9, 3.7597935229640102`*^9}, {
  3.766377159793*^9, 3.766377192691*^9}, {3.766433993325013*^9, 
  3.7664339950339327`*^9}, {3.789156798706974*^9, 3.789156799237239*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"6f4b9a79-5124-48ca-ba6d-d49bea7ffdd3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       FractionBox["t", 
        RowBox[{"x", " ", "y"}]]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a", "-", 
        FractionBox[
         RowBox[{"a", " ", "t"}], 
         RowBox[{"x", " ", "y"}]]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "a"]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "x"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       FractionBox["t", 
        RowBox[{"x", " ", "y"}]]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b", "-", 
        FractionBox[
         RowBox[{"b", " ", "t"}], 
         RowBox[{"x", " ", "y"}]]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "b"]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "y"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b", "-", 
        RowBox[{"b", " ", "t", " ", "y"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}]}], "b"]}], ",", 
   RowBox[{
    FractionBox["1", "c"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", "b"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}]}], 
        RowBox[{"a", " ", "b", " ", "c"}]], "+", 
       RowBox[{"t", " ", "y"}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a", "-", 
        RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "a"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7597935242133417`*^9, 3.7597985012092*^9, 
  3.760316703788608*^9, 3.760323990589883*^9, 3.760387765230414*^9, 
  3.760651615742779*^9, 3.760660981520501*^9, 3.760736259719737*^9, 
  3.760818747939431*^9, 3.7608205640586367`*^9, 3.7609955760603456`*^9, 
  3.761267071648307*^9, 3.761522666503727*^9, 3.766377218594*^9, 
  3.7664339315414143`*^9, 3.767663781870716*^9, 3.767665061731121*^9, 
  3.789156933556999*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"f89cda72-55e9-4470-ad5a-49428cc34368"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["M", "2"], " ", "has", " ", "rank", " ", "4"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MatrixRank", "[", 
    SubscriptBox["M", "2"], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "so", " ", "we", " ", "have", " ", "two", " ", "choices", " ", "for", " ",
      "the", " ", "nullspace", " ", "vector", " ", 
     SubscriptBox["N", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"NullSpace", "[", 
    RowBox[{
     RowBox[{"(", 
      SubscriptBox["M", "2"], ")"}], "\[Transpose]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"choose", " ", "this", " ", "one"}], ",", " ", 
     RowBox[{"see", " ", "eqn", " ", 
      RowBox[{"(", "4.15", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["NN", "2"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"%", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Last", "[", "#", "]"}], "\[Equal]", "0"}], "&"}]}], "]"}],
        "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "b"}], " ", "t"}], "-", 
         RowBox[{"x", " ", "y"}], "+", 
         RowBox[{"b", " ", "x", " ", "y"}]}], ")"}], "/", "y"}]}], "//", 
     "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "check", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["NN", "2"], ".", 
     SubscriptBox["M", "2"]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.759793544972619*^9, 3.759793609949856*^9}, {
  3.7597937081430483`*^9, 3.759793739854918*^9}, {3.759793772166564*^9, 
  3.759793793462761*^9}, {3.759793966796061*^9, 3.759793977380196*^9}, {
  3.761002383200098*^9, 3.761002504733385*^9}, {3.7891568100475483`*^9, 
  3.789156810103335*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"bf5de7bd-8ef6-4e1c-b200-1c2273217a23"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{{3.759793556530909*^9, 3.7597936105928497`*^9}, {
   3.7597937113860607`*^9, 3.759793740146579*^9}, 3.7597937958304987`*^9, 
   3.759793977658087*^9, 3.759798501329382*^9, 3.7603167039008083`*^9, 
   3.7603239907075157`*^9, 3.7603877653308268`*^9, 3.7606516158546257`*^9, 
   3.7606609816340446`*^9, 3.760736259828804*^9, 3.7608187480666847`*^9, 
   3.7608205641885147`*^9, 3.7609955761706142`*^9, {3.761002406396884*^9, 
   3.761002505163252*^9}, 3.761267071766698*^9, 3.761522666625709*^9, 
   3.766377220078*^9, 3.7664340081791563`*^9, 3.767663781883584*^9, 
   3.7676650617961473`*^9, 3.7891569335676823`*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"44652ed7-773c-4768-8304-5cbe80016459"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "y"}]}], 
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "x"}]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "a", "+", 
          RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "b", "+", 
          RowBox[{"b", " ", "t", " ", "y"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "b", "+", 
          RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "a"}], " ", "t"}], "-", 
          RowBox[{"x", " ", "y"}], "+", 
          RowBox[{"a", " ", "x", " ", "y"}]}], ")"}]}]]}], ",", "0", ",", 
     "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "b", "+", 
          RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "a", "+", 
          RowBox[{"a", " ", "t", " ", "y"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "a", "+", 
          RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", "t"}], "-", 
          RowBox[{"x", " ", "y"}], "+", 
          RowBox[{"b", " ", "x", " ", "y"}]}], ")"}]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "y"}]}], 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x"}]}]]}], ",", "0", ",", "0", ",", "1", 
     ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.759793556530909*^9, 3.7597936105928497`*^9}, {
   3.7597937113860607`*^9, 3.759793740146579*^9}, 3.7597937958304987`*^9, 
   3.759793977658087*^9, 3.759798501329382*^9, 3.7603167039008083`*^9, 
   3.7603239907075157`*^9, 3.7603877653308268`*^9, 3.7606516158546257`*^9, 
   3.7606609816340446`*^9, 3.760736259828804*^9, 3.7608187480666847`*^9, 
   3.7608205641885147`*^9, 3.7609955761706142`*^9, {3.761002406396884*^9, 
   3.761002505163252*^9}, 3.761267071766698*^9, 3.761522666625709*^9, 
   3.766377220078*^9, 3.7664340081791563`*^9, 3.767663781883584*^9, 
   3.7676650617961473`*^9, 3.789156933570903*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"4bc3b289-6794-46f8-8b55-e09c285e67a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "x"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "y"}]}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "t"}], "-", 
        RowBox[{"x", " ", "y"}], "+", 
        RowBox[{"b", " ", "x", " ", "y"}]}], ")"}]}], "y"]}], ",", "0", ",", 
   "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", " ", "t"}], "+", 
        RowBox[{"x", " ", "y"}], "-", 
        RowBox[{"b", " ", "x", " ", "y"}]}], ")"}]}], "y"]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.759793556530909*^9, 3.7597936105928497`*^9}, {
   3.7597937113860607`*^9, 3.759793740146579*^9}, 3.7597937958304987`*^9, 
   3.759793977658087*^9, 3.759798501329382*^9, 3.7603167039008083`*^9, 
   3.7603239907075157`*^9, 3.7603877653308268`*^9, 3.7606516158546257`*^9, 
   3.7606609816340446`*^9, 3.760736259828804*^9, 3.7608187480666847`*^9, 
   3.7608205641885147`*^9, 3.7609955761706142`*^9, {3.761002406396884*^9, 
   3.761002505163252*^9}, 3.761267071766698*^9, 3.761522666625709*^9, 
   3.766377220078*^9, 3.7664340081791563`*^9, 3.767663781883584*^9, 
   3.7676650617961473`*^9, 3.7891569336330233`*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"77e9bb87-cbb6-4544-9910-a7402a29d866"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.759793556530909*^9, 3.7597936105928497`*^9}, {
   3.7597937113860607`*^9, 3.759793740146579*^9}, 3.7597937958304987`*^9, 
   3.759793977658087*^9, 3.759798501329382*^9, 3.7603167039008083`*^9, 
   3.7603239907075157`*^9, 3.7603877653308268`*^9, 3.7606516158546257`*^9, 
   3.7606609816340446`*^9, 3.760736259828804*^9, 3.7608187480666847`*^9, 
   3.7608205641885147`*^9, 3.7609955761706142`*^9, {3.761002406396884*^9, 
   3.761002505163252*^9}, 3.761267071766698*^9, 3.761522666625709*^9, 
   3.766377220078*^9, 3.7664340081791563`*^9, 3.767663781883584*^9, 
   3.7676650617961473`*^9, 3.7891569336349792`*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"c1b44949-795c-48b8-9614-773d390453a4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "this", " ", "time", " ", "we", " ", "divide", " ", "by", " ", "the", " ", 
    "kernel", " ", "and", " ", "take", " ", "the", " ", 
    RowBox[{"y", "^", "0"}], " ", "term"}], ",", " ", 
   RowBox[{"as", " ", "per", " ", "eqn", " ", 
    RowBox[{"(", "4.16", ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7597939110330343`*^9, 3.7597939367558737`*^9}, {
   3.789156817585394*^9, 3.789156817645276*^9}, 3.789156900882896*^9},
 CellLabel->
  "In[136]:=",ExpressionUUID->"6d908fde-078b-41d6-bbcd-b6d73f52111a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "LHS", " ", "is", " ", "straightforward"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"halfOSlhs", "=", 
   RowBox[{
    SubscriptBox["NN", "2"], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"y", ",", 
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"y", ",", "x"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", 
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}]}], "]"}]}], "}"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.759793938278565*^9, 3.759793953046056*^9}, {
  3.759794011359384*^9, 3.7597940399995203`*^9}, {3.7597984515359697`*^9, 
  3.7597984517470417`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"492fbb59-296d-4c15-9ed4-9d09b0e95486"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "x"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "+", 
     RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "t"}], "+", 
      RowBox[{"x", " ", "y"}], "-", 
      RowBox[{"b", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "x"}], "]"}]}], "y"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "t"}], "-", 
      RowBox[{"x", " ", "y"}], "+", 
      RowBox[{"b", " ", "x", " ", "y"}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"x", " ", "y"}]], ",", "y"}], "]"}]}], "y"]}]], "Output",
 CellChangeTimes->{{3.75979401610741*^9, 3.759794042127479*^9}, 
   3.759798452882329*^9, 3.7597985015956793`*^9, 3.76031670414998*^9, 
   3.7603239910939913`*^9, 3.760387765565858*^9, 3.7606516162377777`*^9, 
   3.7606609818838787`*^9, 3.760736260080905*^9, 3.7608187483502703`*^9, 
   3.7608205650879593`*^9, 3.760995576458099*^9, 3.761267072484157*^9, 
   3.7615226669039707`*^9, 3.766377222599*^9, 3.7664340150915813`*^9, 
   3.767663782006094*^9, 3.7676650619986343`*^9, 3.789156933702718*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"40ecf7d2-4684-436d-b8b8-526a54621b84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"eqn", " ", 
    RowBox[{"(", "4.17", ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"halfOSlhsy0", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"halfOSlhs", ",", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "y"}], "]"}], "&"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"halfOSlhs", ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "y"}], "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "y"}], "]"}], "&"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", 
        RowBox[{"-", "1"}]}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"%", ",", "y", ",", "1"}], "]"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"halfOSlhs", ",", 
      RowBox[{"Q", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "x"}], "/", "y"}], ",", "x"}], "]"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "y"}], "]"}], "&"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "y", ",", "0"}], "]"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.759794075865032*^9, 3.759794090246738*^9}, {
  3.759794205118841*^9, 3.7597942075476103`*^9}, {3.759794249366795*^9, 
  3.759794417487936*^9}, {3.759794959658799*^9, 3.7597949848571453`*^9}, {
  3.759795281941642*^9, 3.759795292954977*^9}, {3.759797673762973*^9, 
  3.759797797704213*^9}, {3.759797846992193*^9, 3.759797849016409*^9}, {
  3.759797882724353*^9, 3.759797926754135*^9}, {3.759798517597295*^9, 
  3.759798518585106*^9}, {3.759798816284112*^9, 3.759799064073001*^9}, {
  3.7597998761332817`*^9, 3.75979987714353*^9}, {3.7618814328850346`*^9, 
  3.7618814498870344`*^9}, {3.789156911919726*^9, 3.789156911963982*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"2cc70696-e2aa-46a9-8339-221d27b449f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a"}], ")"}]}], " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], "-", 
  RowBox[{"a", " ", "t", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "b", "+", 
     RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", "y"}]}]], "Output",
 CellChangeTimes->{
  3.759794208409441*^9, 3.759794256766824*^9, 3.759794310318162*^9, 
   3.759794379520844*^9, 3.759795294567024*^9, 3.7597976792781353`*^9, 
   3.759797737080295*^9, 3.759797770324738*^9, {3.759797899567173*^9, 
   3.7597979271747026`*^9}, 3.75979883180339*^9, 3.759798904262168*^9, {
   3.759799017565503*^9, 3.759799065815391*^9}, 3.759799878073229*^9, 
   3.760316704266782*^9, 3.7603239914230747`*^9, 3.760387765665883*^9, 
   3.760651616338722*^9, 3.760660982000148*^9, 3.760736260199046*^9, 
   3.760818748466918*^9, 3.760820565205413*^9, 3.760995576560178*^9, 
   3.761267072617527*^9, 3.761522667021121*^9, 3.766377224637*^9, 
   3.76643402415854*^9, 3.7676637820187073`*^9, 3.767665062065736*^9, 
   3.789156933712573*^9},
 CellLabel->
  "Out[139]=",ExpressionUUID->"a300a3a0-e4bd-4473-ab65-c1e405b6da7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{"1", "-", "a"}], ")"}]}], " ", "x", " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", "b", "+", 
    RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"x", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.759794208409441*^9, 3.759794256766824*^9, 3.759794310318162*^9, 
   3.759794379520844*^9, 3.759795294567024*^9, 3.7597976792781353`*^9, 
   3.759797737080295*^9, 3.759797770324738*^9, {3.759797899567173*^9, 
   3.7597979271747026`*^9}, 3.75979883180339*^9, 3.759798904262168*^9, {
   3.759799017565503*^9, 3.759799065815391*^9}, 3.759799878073229*^9, 
   3.760316704266782*^9, 3.7603239914230747`*^9, 3.760387765665883*^9, 
   3.760651616338722*^9, 3.760660982000148*^9, 3.760736260199046*^9, 
   3.760818748466918*^9, 3.760820565205413*^9, 3.760995576560178*^9, 
   3.761267072617527*^9, 3.761522667021121*^9, 3.766377224637*^9, 
   3.76643402415854*^9, 3.7676637820187073`*^9, 3.767665062065736*^9, 
   3.7891569337148027`*^9},
 CellLabel->
  "Out[140]=",ExpressionUUID->"995cfd80-35aa-4b48-a12b-9ae9af301fb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "b", " ", 
   SuperscriptBox["t", "2"]}], "+", "x", "-", 
  RowBox[{"a", " ", "x"}], "-", 
  RowBox[{"b", " ", "x"}], "+", 
  RowBox[{"a", " ", "b", " ", "x"}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "t"}], "+", 
    RowBox[{"a", " ", "b", " ", "t"}]}], "y"], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "t", " ", "x"}], "+", 
     RowBox[{"a", " ", "b", " ", "t", " ", "x"}]}], ")"}], " ", 
   "y"}]}]], "Output",
 CellChangeTimes->{
  3.759794208409441*^9, 3.759794256766824*^9, 3.759794310318162*^9, 
   3.759794379520844*^9, 3.759795294567024*^9, 3.7597976792781353`*^9, 
   3.759797737080295*^9, 3.759797770324738*^9, {3.759797899567173*^9, 
   3.7597979271747026`*^9}, 3.75979883180339*^9, 3.759798904262168*^9, {
   3.759799017565503*^9, 3.759799065815391*^9}, 3.759799878073229*^9, 
   3.760316704266782*^9, 3.7603239914230747`*^9, 3.760387765665883*^9, 
   3.760651616338722*^9, 3.760660982000148*^9, 3.760736260199046*^9, 
   3.760818748466918*^9, 3.760820565205413*^9, 3.760995576560178*^9, 
   3.761267072617527*^9, 3.761522667021121*^9, 3.766377224637*^9, 
   3.76643402415854*^9, 3.7676637820187073`*^9, 3.767665062065736*^9, 
   3.789156933716777*^9},
 CellLabel->
  "Out[141]=",ExpressionUUID->"9f49bb78-cb32-4418-8593-81ef1515b449"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"b", " ", "x"}], "+", 
     RowBox[{"a", " ", "b", " ", "x"}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b", " ", "t"}], "-", 
     RowBox[{"a", " ", "b", " ", "t"}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "1", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "t", " ", "x"}], "-", 
     RowBox[{"a", " ", "b", " ", "t", " ", "x"}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     RowBox[{"-", "1"}], "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759794208409441*^9, 3.759794256766824*^9, 3.759794310318162*^9, 
   3.759794379520844*^9, 3.759795294567024*^9, 3.7597976792781353`*^9, 
   3.759797737080295*^9, 3.759797770324738*^9, {3.759797899567173*^9, 
   3.7597979271747026`*^9}, 3.75979883180339*^9, 3.759798904262168*^9, {
   3.759799017565503*^9, 3.759799065815391*^9}, 3.759799878073229*^9, 
   3.760316704266782*^9, 3.7603239914230747`*^9, 3.760387765665883*^9, 
   3.760651616338722*^9, 3.760660982000148*^9, 3.760736260199046*^9, 
   3.760818748466918*^9, 3.760820565205413*^9, 3.760995576560178*^9, 
   3.761267072617527*^9, 3.761522667021121*^9, 3.766377224637*^9, 
   3.76643402415854*^9, 3.7676637820187073`*^9, 3.767665062065736*^9, 
   3.789156933718927*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"7f4850fa-950e-4c62-9c5e-0b56382ca225"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"b", " ", "x"}]}], ")"}]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "a", "+", 
     RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"b", " ", "t", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "a", "+", 
      RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}], "y"]}]], "Output",
 CellChangeTimes->{
  3.759794208409441*^9, 3.759794256766824*^9, 3.759794310318162*^9, 
   3.759794379520844*^9, 3.759795294567024*^9, 3.7597976792781353`*^9, 
   3.759797737080295*^9, 3.759797770324738*^9, {3.759797899567173*^9, 
   3.7597979271747026`*^9}, 3.75979883180339*^9, 3.759798904262168*^9, {
   3.759799017565503*^9, 3.759799065815391*^9}, 3.759799878073229*^9, 
   3.760316704266782*^9, 3.7603239914230747`*^9, 3.760387765665883*^9, 
   3.760651616338722*^9, 3.760660982000148*^9, 3.760736260199046*^9, 
   3.760818748466918*^9, 3.760820565205413*^9, 3.760995576560178*^9, 
   3.761267072617527*^9, 3.761522667021121*^9, 3.766377224637*^9, 
   3.76643402415854*^9, 3.7676637820187073`*^9, 3.767665062065736*^9, 
   3.789156933721697*^9},
 CellLabel->
  "Out[143]=",ExpressionUUID->"4c4f5cd8-858c-4d63-a405-7c55cc6acfb3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{"x", "-", 
     RowBox[{"b", " ", "x"}]}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", "a", "+", 
    RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "x"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.759794208409441*^9, 3.759794256766824*^9, 3.759794310318162*^9, 
   3.759794379520844*^9, 3.759795294567024*^9, 3.7597976792781353`*^9, 
   3.759797737080295*^9, 3.759797770324738*^9, {3.759797899567173*^9, 
   3.7597979271747026`*^9}, 3.75979883180339*^9, 3.759798904262168*^9, {
   3.759799017565503*^9, 3.759799065815391*^9}, 3.759799878073229*^9, 
   3.760316704266782*^9, 3.7603239914230747`*^9, 3.760387765665883*^9, 
   3.760651616338722*^9, 3.760660982000148*^9, 3.760736260199046*^9, 
   3.760818748466918*^9, 3.760820565205413*^9, 3.760995576560178*^9, 
   3.761267072617527*^9, 3.761522667021121*^9, 3.766377224637*^9, 
   3.76643402415854*^9, 3.7676637820187073`*^9, 3.767665062065736*^9, 
   3.789156933724041*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"e9f8016e-14ad-455d-8914-f475e3f4aa6e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"halfOSlhsy0", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Qd0eqn", "\[Equal]", "0"}], ",", 
      RowBox[{
       SubsuperscriptBox["Q", 
        RowBox[{"-", "1"}], "d"], "[", 
       RowBox[{"1", "/", "x"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"halfOSlhsy0v2", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Total", "[", "%", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], ",", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}], ",", 
      RowBox[{
       SubsuperscriptBox["Q", "1", "d"], "[", 
       FractionBox["1", "x"], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "x"}], "]"}], ",", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", "x", ",", "Factor"}], "]"}], "&"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.759798257877502*^9, 3.759798311738379*^9}, {
  3.7597983422504787`*^9, 3.759798342541759*^9}, {3.759798407702982*^9, 
  3.759798416467873*^9}, {3.7597990783860283`*^9, 3.759799151562456*^9}, {
  3.76643409528938*^9, 3.766434130694902*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"5e1b142b-f6e4-4674-ad87-75b3222b45cb"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "c"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "x"}], "c"], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "x"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "b"}], ")"}], " ", "x"}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", "0", "d"], "[", 
    FractionBox["1", "x"], "]"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", "t", " ", 
   RowBox[{
    SubsuperscriptBox["Q", "1", "d"], "[", 
    FractionBox["1", "x"], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7597982624395323`*^9, {3.75979830808171*^9, 3.759798312199564*^9}, 
   3.759798343726736*^9, 3.759798418167286*^9, {3.7597991210356503`*^9, 
   3.75979916284593*^9}, 3.759799885227263*^9, 3.760316704450809*^9, 
   3.760323991824395*^9, 3.760387765803763*^9, 3.7606516165380373`*^9, 
   3.7606609821715317`*^9, 3.760736260352903*^9, 3.7608187486390667`*^9, 
   3.760820565471128*^9, 3.76099557670792*^9, 3.761267073117503*^9, 
   3.761522667192984*^9, 3.766377228289*^9, 3.7664340310736017`*^9, 
   3.766434096812278*^9, {3.766434128293665*^9, 3.7664341312420273`*^9}, 
   3.767663782085211*^9, 3.76766506214109*^9, 3.78915693379058*^9},
 CellLabel->
  "Out[148]=",ExpressionUUID->"440c9585-30f9-4bdb-9239-935b7e8d1124"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"can", " ", "check", " ", "this", " ", "manually"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"halfOSlhs", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
      RowBox[{"QQeval", "[", 
       RowBox[{"10", ",", "ecks", ",", "why"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{"Expand", "@*", "Simplify"}], ",", "%"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"#", "+", 
          RowBox[{"y", "^", "\[Pi]"}], "+", 
          RowBox[{"y", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", "y", ",", "0"}], "]"}], 
       "&"}], ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSlhsy0v2", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"10", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"10", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "x"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxeval", "[", 
         RowBox[{"10", ",", "0", ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"10", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "1", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"10", ",", "1", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{"Expand", "@*", "Simplify"}], ",", "%"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.759799209851177*^9, 3.7597994718257437`*^9}, {
  3.7597999009158697`*^9, 3.7597999487095213`*^9}, {3.759800184555331*^9, 
  3.759800219445642*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"aae5f670-5d05-4b7a-b003-8d12cd2a0992"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.759799218766451*^9, 3.7597992699855824`*^9}, 
   3.759799329700244*^9, {3.759799410627778*^9, 3.7597994720973377`*^9}, {
   3.759799894575959*^9, 3.75979993715061*^9}, 3.759800082897243*^9, 
   3.759800208995253*^9, 3.759800273938689*^9, 3.760316752035036*^9, 
   3.760324039124934*^9, 3.760387811174184*^9, 3.7606516623780947`*^9, 
   3.7606610314706297`*^9, 3.76073630695859*^9, 3.7608187967421293`*^9, 
   3.76082061161436*^9, 3.760995623564657*^9, 3.761267119314207*^9, 
   3.761522714430471*^9, 3.766377275653*^9, 3.766434188060779*^9, 
   3.767663830895368*^9, 3.767665111771393*^9, 3.78915698120247*^9},
 CellLabel->
  "Out[155]=",ExpressionUUID->"3ed1b1cd-3f12-47b9-9bf9-e6ee653c337c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", "for", " ", "the", " ", "RHS"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "this", " ", "will", " ", "be", " ", "divided", " ", "by", " ", "the", " ",
     "kernel"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"halfOSrhs", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["NN", "2"], ".", 
     SubscriptBox["CC", "2"]}], "//", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Q", "[", "__", "]"}], ",", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"#", ",", "y", ",", "Factor"}], "]"}], "&"}]}], "]"}], 
     "&"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7598021484782257`*^9, 3.759802227139061*^9}, {
  3.759802839295354*^9, 3.759802846866691*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"a5237815-3a4d-4d85-9ecf-5d42295856a7"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "-", "x", "+", 
    RowBox[{"a", " ", "x"}], "+", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "b", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], "c"], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", 
    SuperscriptBox["t", "2"], " ", "x"}], 
   RowBox[{"c", " ", "y"}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "b", " ", 
    SuperscriptBox["t", "2"], " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "c"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"a", " ", "b", " ", "c"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{"a", " ", "b", " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", "x"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "x"}], "+", 
         RowBox[{"a", " ", "c", " ", "x"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c", " ", "x"}], "+", 
         RowBox[{"b", " ", "c", " ", "x"}], "-", 
         RowBox[{"3", " ", "a", " ", "b", " ", "c", " ", "x"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "x"}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c", " ", "x"}], "+", 
         RowBox[{"2", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c", " ", "x"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c", " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c", " ", 
          SuperscriptBox["t", "3"], " ", "x"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{"2", " ", "a", " ", 
          SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
          SuperscriptBox["x", "2"]}]}], ")"}]}]}], "+", 
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "t", " ", "x"}], "-", 
         RowBox[{"a", " ", "c", " ", "t", " ", "x"}], "-", 
         RowBox[{"b", " ", "c", " ", "t", " ", "x"}], "+", 
         RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", "x"}]}], ")"}]}], 
      RowBox[{"c", " ", "y"}]], "+", 
     FractionBox[
      RowBox[{"t", " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "c"}], "+", 
         RowBox[{"a", " ", "c"}], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         RowBox[{"a", " ", "b", " ", "c"}], "+", 
         RowBox[{"a", " ", "b", " ", "t", " ", "x"}], "-", 
         RowBox[{"a", " ", "c", " ", "t", " ", "x"}], "-", 
         RowBox[{"b", " ", "c", " ", "t", " ", "x"}], "+", 
         RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", "x"}]}], ")"}], " ", 
       "y"}], "c"]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "2"]}], "+", "x", "-", 
         RowBox[{"2", " ", "b", " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", "x"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "+", 
         RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}], "b"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "+", 
         RowBox[{"a", " ", "t", " ", "x"}]}], ")"}]}], "y"], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "t", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "a", "+", 
        RowBox[{"a", " ", "t", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", 
   
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "x"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["t", "2"]}], "+", "x", "-", 
         RowBox[{"2", " ", "a", " ", "x"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "x"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "b", "+", 
         RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], "a"], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "b", "+", 
         RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], "y"], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "t", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "b", "+", 
        RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", 
   
   RowBox[{"Q", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.75980215494637*^9, 3.759802199251075*^9}, 
   3.759802848246169*^9, 3.760316752172941*^9, 3.7603240393423767`*^9, 
   3.7603878113304853`*^9, 3.760651662572474*^9, 3.760661031656781*^9, 
   3.7607363071614037`*^9, 3.7608187968809977`*^9, 3.760820611782989*^9, 
   3.760995623678735*^9, 3.761267119485705*^9, 3.7615227146397133`*^9, 
   3.76637727577*^9, 3.766434192946533*^9, 3.7676638310027733`*^9, 
   3.7676651119088583`*^9, 3.7891569813275423`*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"e5603965-8333-450b-aec9-d7f28b00f5a5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4.4",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.759714184011848*^9, 
  3.7597141840676126`*^9}, {3.75979277755081*^9, 3.7597927872206507`*^9}, {
  3.760319928254059*^9, 3.760319928315466*^9}, {3.7663773170030003`*^9, 
  3.766377317835*^9}, {3.7663773556429996`*^9, 
  3.766377356531*^9}},ExpressionUUID->"bf0f230c-e0da-44b9-a4d4-4d2941b61ae0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "this", " ", "requires", " ", "factoring", " ", "the", " ", "kernel", " ", 
    "as", " ", "per", " ", "eqn", " ", 
    RowBox[{"(", "4.21", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "roots", " ", "of", " ", "K"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"t", " ", "x"}]}], ")"}], "^", "2"}], "-", 
      RowBox[{"4", 
       RowBox[{
        RowBox[{"t", "^", "2"}], "/", "x"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "0"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", " ", "x"}], "-", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "t"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Y", "1"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", " ", "x"}], "+", 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "t"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"K", "[", 
       RowBox[{"x", ",", 
        SubscriptBox["Y", "0"]}], "]"}], ",", 
      RowBox[{"K", "[", 
       RowBox[{"x", ",", 
        SubscriptBox["Y", "1"]}], "]"}]}], "}"}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{"Expand", "@*", "PowerExpand"}], ",", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["Y", "0"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{
     RowBox[{"Expand", "@*", "PowerExpand"}], ",", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["Y", "1"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.759801184994383*^9, 3.7598012289094143`*^9}, {
   3.759801367774067*^9, 3.7598014128729687`*^9}, {3.759801759596374*^9, 
   3.759801760481243*^9}, 3.7598021465555487`*^9, {3.760995538151132*^9, 
   3.7609955449556026`*^9}, 3.76643420062738*^9, {3.789157002340005*^9, 
   3.789157002383774*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"6fbe9229-1bed-4ddc-a766-6a3b77f8d5ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.759801415395876*^9, 3.759801761882717*^9, 
  3.759802367677697*^9, 3.7603167523085957`*^9, 3.760324039458735*^9, 
  3.7603878114714193`*^9, 3.76065166269501*^9, 3.760661031778017*^9, 
  3.7607363072777433`*^9, 3.760818797018553*^9, 3.760820611887023*^9, 
  3.7609956237790413`*^9, 3.7612671195879393`*^9, 3.7615227613192167`*^9, 
  3.766377275859*^9, 3.766377327526*^9, 3.766377598087*^9, 
  3.766434205757072*^9, 3.767664060525674*^9, 3.767665111996869*^9, 
  3.789157122876738*^9},
 CellLabel->
  "Out[160]=",ExpressionUUID->"f303e1fe-e675-4ae7-829c-128c32cab3b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["t", "x"], "+", 
   SuperscriptBox["t", "2"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", "2"]], "+", "x"}], ")"}], " ", 
    SuperscriptBox["t", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "4"],
    SeriesData[$CellContext`t, 0, {}, 1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {$CellContext`x^(-1), 1, $CellContext`x^(-2) + $CellContext`x}, 1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.759801415395876*^9, 3.759801761882717*^9, 
  3.759802367677697*^9, 3.7603167523085957`*^9, 3.760324039458735*^9, 
  3.7603878114714193`*^9, 3.76065166269501*^9, 3.760661031778017*^9, 
  3.7607363072777433`*^9, 3.760818797018553*^9, 3.760820611887023*^9, 
  3.7609956237790413`*^9, 3.7612671195879393`*^9, 3.7615227613192167`*^9, 
  3.766377275859*^9, 3.766377327526*^9, 3.766377598087*^9, 
  3.766434205757072*^9, 3.767664060525674*^9, 3.767665111996869*^9, 
  3.789157122885438*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"2512bb49-e374-4eaa-9451-55a925e26413"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", "t"], "-", "x", "-", 
   FractionBox["t", "x"], "-", 
   SuperscriptBox["t", "2"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        SuperscriptBox["x", "2"]]}], "-", "x"}], ")"}], " ", 
    SuperscriptBox["t", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "4"],
    SeriesData[$CellContext`t, 0, {}, -1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   1, -$CellContext`x, (-1)/$CellContext`x, -1, (-1) $CellContext`x^(-2) - \
$CellContext`x}, -1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.759801415395876*^9, 3.759801761882717*^9, 
  3.759802367677697*^9, 3.7603167523085957`*^9, 3.760324039458735*^9, 
  3.7603878114714193`*^9, 3.76065166269501*^9, 3.760661031778017*^9, 
  3.7607363072777433`*^9, 3.760818797018553*^9, 3.760820611887023*^9, 
  3.7609956237790413`*^9, 3.7612671195879393`*^9, 3.7615227613192167`*^9, 
  3.766377275859*^9, 3.766377327526*^9, 3.766377598087*^9, 
  3.766434205757072*^9, 3.767664060525674*^9, 3.767665111996869*^9, 
  3.789157122888569*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"68957905-7234-4581-ae77-4510310572ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "then", " ", "eqn", " ", 
    RowBox[{"(", "4.21", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"K", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["Y", "0"], "/", "y"}]}], ")"}]}], "+", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"y", "/", 
           SubscriptBox["Y", "1"]}]}], ")"}]}], "-", "1"}], ")"}]}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.759802634546508*^9, 3.75980264026827*^9}, {
  3.7598027541537943`*^9, 3.7598027958470488`*^9}, {3.7891570143551407`*^9, 
  3.7891570143877907`*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"3c17264a-d356-4280-97fb-ce4121175dde"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.7598027575100527`*^9, 3.7598027961373177`*^9, 
  3.7603167524387007`*^9, 3.7603240395932703`*^9, 3.760387811585455*^9, 
  3.760651662823571*^9, 3.760661031940918*^9, 3.760736307416003*^9, 
  3.7608187971575613`*^9, 3.760820612003701*^9, 3.7610020974165*^9, 
  3.761267119723401*^9, 3.761522761551518*^9, 3.766377276086*^9, 
  3.7663773294560003`*^9, 3.766434207984923*^9, 3.767664060682262*^9, 
  3.767665112087997*^9, 3.78915712302052*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"f4ce5d43-ef64-4fe1-ac21-9c0ce12bc138"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "now", " ", "we", " ", "can", " ", "compute", " ", "the", " ", 
    RowBox[{"y", "^", "0"}], " ", "term", " ", "of", " ", "the", " ", "RHS"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"halfOSrhs", ",", "y", ",", 
         RowBox[{"-", "1"}]}], "]"}], "/", 
       SubscriptBox["Y", "1"]}], "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"halfOSrhs", ",", "y", ",", "0"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"halfOSrhs", ",", "y", ",", "1"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["Y", "0"], "/", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"halfOSrhsy0", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Q", "[", "__", "]"}], ",", "Simplify"}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.759803086522902*^9, 3.7598032547533407`*^9}, {
  3.759803312805354*^9, 3.759803321141016*^9}},
 CellLabel->
  "In[164]:=",ExpressionUUID->"490d883f-b35d-4dfe-af38-5f2babd805cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "x"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"t", " ", "x"}], "+", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "t", " ", "x"}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "+", 
              SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}], "-", 
           SqrtBox[
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "t", " ", "x"}], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "5"}], " ", 
            SuperscriptBox["t", "3"], " ", "x"}], "-", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SqrtBox[
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "t", " ", "x"}], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["t", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["x", "3"]}], "+", 
              SqrtBox[
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "t", " ", "x"}], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["t", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
           "+", 
           RowBox[{"t", " ", 
            SuperscriptBox["x", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"2", " ", 
               SqrtBox[
                RowBox[{"1", "-", 
                 RowBox[{"2", " ", "t", " ", "x"}], "+", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["t", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"c", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"]}], "x"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "x"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["t", "2"]}], "x"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]]}], ")"}]}], ")"}]}], 
  "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "c", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"t", " ", "x"}], "+", 
          SqrtBox[
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "t", " ", "x"}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", 
                SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], "-", 
       
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t", " ", "x"}], "-", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
          "+", 
          RowBox[{"c", " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", " ", "x"}], "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
          "+", 
          RowBox[{"b", " ", "c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["t", "2"]}], "+", 
             RowBox[{"2", " ", "t", " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"2", " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SqrtBox[
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", "t", " ", "x"}], "+", 
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}],
             ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "c"}], " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t", " ", "x"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"t", " ", "x"}], "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
          "-", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"t", " ", "x"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"x", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"t", " ", "x"}], "-", 
                SqrtBox[
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", "t", " ", "x"}], "+", 
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
             "+", 
             RowBox[{"c", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["t", "2"]}], "+", 
                RowBox[{"2", " ", "t", " ", 
                 SuperscriptBox["x", "2"]}], "-", 
                RowBox[{"2", " ", "x", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SqrtBox[
                    RowBox[{"1", "-", 
                    RowBox[{"2", " ", "t", " ", "x"}], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}],
                ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"c", " ", 
              SuperscriptBox["t", "4"], " ", 
              SuperscriptBox["x", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "c"}], ")"}], " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SqrtBox[
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", "t", " ", "x"}], "+", 
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["t", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", "x"}], "+", 
                RowBox[{"2", " ", "c", " ", "x"}], "-", 
                RowBox[{"c", " ", "x", " ", 
                 SqrtBox[
                  RowBox[{"1", "-", 
                   RowBox[{"2", " ", "t", " ", "x"}], "+", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}]}], ")"}]}],
              "-", 
             RowBox[{"t", " ", 
              SuperscriptBox["x", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{"1", "-", 
                   RowBox[{"2", " ", "t", " ", "x"}], "+", 
                   FractionBox[
                    RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "+", 
                RowBox[{"c", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "+", 
                   SqrtBox[
                    RowBox[{"1", "-", 
                    RowBox[{"2", " ", "t", " ", "x"}], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}],
                ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["t", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["x", "3"]}], "-", 
                SqrtBox[
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", "t", " ", "x"}], "+", 
                  FractionBox[
                   RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]], "+", 
                RowBox[{"c", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   SuperscriptBox["x", "3"], "+", 
                   SqrtBox[
                    RowBox[{"1", "-", 
                    RowBox[{"2", " ", "t", " ", "x"}], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["t", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}],
                ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"a", " ", "b", " ", "c", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"]}], "x"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "x"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["t", "2"]}], "x"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]]}], ")"}]}], ")"}]}], 
  "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"t", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"x", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "t", " ", "x"}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "+", 
              SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
           SuperscriptBox["t", "3"], " ", "x"}], "-", 
          RowBox[{"t", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"x", " ", 
           SqrtBox[
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "t", " ", "x"}], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "+", 
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"2", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"2", " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}], 
         ")"}]}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "x"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"b", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"]}], "x"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "x"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["t", "2"]}], "x"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]]}], ")"}]}], ")"}]}], 
  "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"t", " ", "x"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"t", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"x", " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "t", " ", "x"}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "+", 
              SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
           SuperscriptBox["t", "3"], " ", "x"}], "-", 
          RowBox[{"t", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"x", " ", 
           SqrtBox[
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "t", " ", "x"}], "+", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", 
                 SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "+", 
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"2", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"2", " ", "x", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "t", " ", "x"}], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], ")"}]}]}], 
         ")"}]}]}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"a", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["t", "2"]}], "x"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "x"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["t", "2"]}], "x"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"t", " ", "x"}]}], ")"}], "2"]}]]}], ")"}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7598031183257103`*^9, 3.759803126125162*^9}, 
   3.759803160582849*^9, {3.7598032175262737`*^9, 3.759803244515986*^9}, 
   3.7598032853523283`*^9, {3.759803319249127*^9, 3.7598033249981956`*^9}, 
   3.760316756004303*^9, 3.760324043170982*^9, 3.760387815016486*^9, 
   3.7606516665370197`*^9, 3.7606610354153013`*^9, 3.7607363108754597`*^9, 
   3.7608188008382597`*^9, 3.760820615509658*^9, 3.761002100988772*^9, 
   3.761267123252779*^9, 3.761522765017932*^9, 3.7663773358310003`*^9, 
   3.766434215458621*^9, 3.767664064258896*^9, 3.767665116199565*^9, 
   3.789157126809423*^9},
 CellLabel->
  "Out[165]=",ExpressionUUID->"d7f6e243-fc53-47a8-b18f-d39756a291e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"we", " ", "can", " ", "check", " ", "it"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"halfOSrhs", "/", 
      RowBox[{"K", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
      RowBox[{"QQeval", "[", 
       RowBox[{"10", ",", "ecks", ",", "why"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"#", "+", 
          RowBox[{"y", "^", "\[Pi]"}], "+", 
          RowBox[{"y", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "y"}], "]"}], "\[Equal]", "0"}], "&"}]}], "]"}],
        "&"}], ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSrhsy0", "/.", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
      RowBox[{"QQeval", "[", 
       RowBox[{"10", ",", "ecks", ",", "why"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{"Expand", ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "-", "%%%"}]}]}]], "Input",
 CellChangeTimes->{{3.759803355062748*^9, 3.759803519864273*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"7b29eb3b-bd48-425b-bdc3-d757da01c93f"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.75980336975079*^9, 3.759803408385974*^9}, {
   3.759803448665468*^9, 3.759803521398299*^9}, 3.7603167578372927`*^9, 
   3.760324044951036*^9, 3.760387816552331*^9, 3.760651668195075*^9, 
   3.760661037133554*^9, 3.7607363124119873`*^9, 3.760818802549551*^9, 
   3.760820617143939*^9, 3.761002102640211*^9, 3.761267124851776*^9, 
   3.7615227666341667`*^9, 3.766377601026*^9, 3.766434224962489*^9, 
   3.7676640652838993`*^9, 3.767665117399679*^9, 3.7891571279032717`*^9},
 CellLabel->
  "Out[171]=",ExpressionUUID->"56fb8ee9-fdcf-4157-a9fa-bf168ea2deef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "check", " ", "it", " ", "some", " ", "more"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"halfOSlhsy0v2", "-", "halfOSrhsy0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"ecks_", ",", "why_"}], "]"}], "\[Rule]", 
       RowBox[{"QQeval", "[", 
        RowBox[{"10", ",", "ecks", ",", "why"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"10", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "1", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"10", ",", "1", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.759803643441286*^9, 3.7598037077875977`*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"294369c3-1ca3-4040-9444-f8d825763761"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 11, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.7598036585403767`*^9, 3.759803711485615*^9, 
  3.7603167593810387`*^9, 3.7603240465524197`*^9, 3.7603878179480143`*^9, 
  3.760651669599708*^9, 3.76066103853714*^9, 3.760736313954365*^9, 
  3.760818804120151*^9, 3.760820618914856*^9, 3.761002104146617*^9, 
  3.7612671266024523`*^9, 3.761522768079522*^9, 3.766377400027*^9, 
  3.766377457917*^9, 3.766377602631*^9, 3.766434228574828*^9, 
  3.7676640671092653`*^9, 3.767665119595394*^9, 3.7891571298197813`*^9},
 CellLabel->
  "Out[173]=",ExpressionUUID->"85238a43-550c-49cc-a29a-0e9113999d2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "we", " ", "can", " ", "use", " ", "the", " ", "equations", 
    " ", "from", " ", "the", " ", "full", " ", "orbit", " ", "sum", " ", "to",
     " ", "eliminate", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "x"}], "]"}], " ", "and", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "1", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "get", " ", "to", " ", "eqn", " ", 
    RowBox[{"(", "4.26", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"halfOSy0", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"halfOSlhsy0v2", "-", "halfOSrhsy0"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"fullOSy0xposv2", "\[Equal]", "0"}], ",", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "x"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"fullOSy0xnegv2", "\[Equal]", "0"}], ",", 
         RowBox[{
          SubsuperscriptBox["Q", "1", "d"], "[", 
          FractionBox["1", "x"], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"clean", " ", "up", " ", "some", " ", "denominators"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"halfOSy0v2", "=", 
     RowBox[{"halfOSy0", "*", "a", " ", "c", " ", 
      SqrtBox["\[CapitalDelta]"], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "x", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"t", " ", "x"}]}], ")"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "b", "+", 
           RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", 
           SuperscriptBox["x", "2"]}], ")"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Mu]", 
     RowBox[{"x", ",", "0"}]], "=", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"-", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"halfOSy0v2", ",", 
         RowBox[{"Q", "[", 
          RowBox[{"x", ",", "0"}], "]"}]}], "]"}]}], "]"}], "//", 
     "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubsuperscriptBox["\[Nu]", "0", "d"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"halfOSy0v2", ",", 
          RowBox[{
           SubsuperscriptBox["Q", "0", "d"], "[", 
           FractionBox["1", "x"], "]"}]}], "]"}]}], "/", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], "//", "Simplify"}], "//",
      "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"halfOSy0v2", ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]]}], "]"}], "//", "Simplify"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Numerator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}], "+", 
           SqrtBox["\[CapitalDelta]"]}], ")"}]}], "//", "Expand"}], "//", 
       "Simplify"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}], "+", 
           SqrtBox["\[CapitalDelta]"]}], ")"}]}], "//", "Expand"}], "//", 
       "Simplify"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Mu]", 
     RowBox[{"0", ",", "1"}]], "=", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]], "\[Rule]", "0"}]}],
      "//", "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Nu]", 
     RowBox[{"0", ",", "1"}]], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%%", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "]"}], "//", 
     "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"halfOSy0v2", ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "]"}], "//", "Simplify"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Numerator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}], "+", 
           SqrtBox["\[CapitalDelta]"]}], ")"}]}], "//", "Expand"}], "//", 
       "Simplify"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"t", " ", "x"}], "+", 
           SqrtBox["\[CapitalDelta]"]}], ")"}]}], "//", "Expand"}], "//", 
       "Simplify"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Mu]", 
     RowBox[{"1", ",", "0"}]], "=", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]], "\[Rule]", "0"}]}],
      "//", "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Nu]", 
     RowBox[{"1", ",", "0"}]], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%%", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "]"}], "//", 
     "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"halfOSy0v2", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "]"}], "//", "Simplify"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Numerator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"t", " ", "x"}], "-", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}]}], "//", 
        "Expand"}], "//", "Simplify"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"t", " ", "x"}], "-", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}]}], "//", 
        "Expand"}], "//", "Simplify"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Mu]", 
     RowBox[{"0", ",", "0"}]], "=", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]], "\[Rule]", "0"}]}],
      "//", "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Nu]", 
     RowBox[{"0", ",", "0"}]], "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%%", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "]"}], "//", 
     "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"halfOSy0v2", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Q", "[", "__", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}], ",", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"0", ",", "1"}]], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["Q", "0", "d"], "[", 
           FractionBox["1", "x"], "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
      "Simplify"}], "//", "Factor"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Numerator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"t", " ", "x"}], "-", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}]}], "//", 
        "Expand"}], "//", "Simplify"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", "%", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"t", " ", "x"}], "-", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}], ")"}]}], "//", 
        "Expand"}], "//", "Simplify"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"\[Mu]", "=", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]], "\[Rule]", "0"}]}],
      "//", "Factor"}]}], "\[IndentingNewLine]", 
   RowBox[{"\[Nu]", "=", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"%%", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "t", " ", "x"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SuperscriptBox["x", "3"]}], ")"}]}], "x"]}]]}], "]"}], "//", 
     "Factor"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7598037363573723`*^9, 3.75980376339748*^9}, {
   3.759803995456067*^9, 3.7598039977840357`*^9}, {3.759804084106412*^9, 
   3.7598041089586287`*^9}, {3.759804167415661*^9, 3.7598042125500813`*^9}, {
   3.759804272537414*^9, 3.759804278678699*^9}, {3.759804311226869*^9, 
   3.759804373833009*^9}, {3.7598044185432663`*^9, 3.759804423368191*^9}, {
   3.75980530551969*^9, 3.7598053355104*^9}, {3.759805371423547*^9, 
   3.7598053754486628`*^9}, {3.7598054760155354`*^9, 
   3.7598055319637957`*^9}, {3.759805578055551*^9, 3.7598055846459293`*^9}, {
   3.759805842076914*^9, 3.759805842876623*^9}, 3.759805962249954*^9, {
   3.7598060350375834`*^9, 3.75980619120642*^9}, {3.7598062323556757`*^9, 
   3.759806481388197*^9}, {3.7603169494743223`*^9, 3.7603169918660727`*^9}, {
   3.760317069612307*^9, 3.7603170817624607`*^9}, {3.760317140670579*^9, 
   3.760317169270176*^9}, {3.76031724195619*^9, 3.7603172467361298`*^9}, {
   3.760317440559825*^9, 3.760317440806698*^9}, {3.760317530101552*^9, 
   3.760317579251753*^9}, {3.760317772877405*^9, 3.760317773358533*^9}, {
   3.760317834887067*^9, 3.7603178358456697`*^9}, {3.7603179859003687`*^9, 
   3.76031799250806*^9}, {3.76031834083784*^9, 3.760318345084556*^9}, {
   3.760318505126059*^9, 3.76031852319304*^9}, {3.7603186106881742`*^9, 
   3.760318640015559*^9}, 3.761522808612245*^9, {3.7618828694271183`*^9, 
   3.7618828703610244`*^9}, {3.76637766771*^9, 3.766377675934*^9}, {
   3.766377726043*^9, 3.766377726045*^9}, {3.76637779005*^9, 
   3.766377825988*^9}, {3.766377968245*^9, 3.766377973104*^9}, {
   3.7891571070259733`*^9, 3.7891571070990667`*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"4e702f1c-9c6e-4b67-800c-68502faa197e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", "b", "+", 
    RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.789157130632213*^9},
 CellLabel->
  "Out[176]=",ExpressionUUID->"e4f777c2-7452-4402-92e4-3aeb79e7b473"],

Cell[BoxData[
 RowBox[{"2", " ", "a", " ", "c", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", "x", "-", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.7891571309432096`*^9},
 CellLabel->
  "Out[177]=",ExpressionUUID->"da8ab8ea-110e-41e3-9cb0-7fd5e5769e30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}]}], " ", "a", " ", "b", " ", "c", 
  " ", 
  SuperscriptBox["t", "2"], " ", "x", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.789157131931797*^9},
 CellLabel->
  "Out[180]=",ExpressionUUID->"c1e9493b-d7bc-495c-80b7-b65c84b7342b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
  RowBox[{"(", 
   RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", "c", " ", 
  SuperscriptBox["t", "2"], " ", 
  SuperscriptBox["x", "2"]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.789157131987516*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"60efe20f-c4fb-4547-89d8-1db2271becca"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["a", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
  SuperscriptBox["t", "2"], " ", "x", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.7891571325474243`*^9},
 CellLabel->
  "Out[184]=",ExpressionUUID->"e4e8c0ef-513c-4268-99fb-76f4c72271ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["a", "2"]}], " ", 
  RowBox[{"(", 
   RowBox[{"a", "-", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
  SuperscriptBox["t", "2"], " ", 
  SuperscriptBox["x", "2"]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.7891571326133623`*^9},
 CellLabel->
  "Out[185]=",ExpressionUUID->"cc97c726-0934-4649-b59c-2e9343001eee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"2", " ", "x"}], "-", 
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"b", " ", "x"}], "-", 
     RowBox[{"a", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"a", " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"a", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "x"}], "+", 
    RowBox[{"a", " ", "b", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "+", 
    RowBox[{"2", " ", "c", " ", "x"}], "-", 
    RowBox[{"2", " ", "a", " ", "c", " ", "x"}], "-", 
    RowBox[{"2", " ", "b", " ", "c", " ", "x"}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "3"], " ", "x"}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "b", " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"a", " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.7891571756143*^9},
 CellLabel->
  "Out[188]=",ExpressionUUID->"83bfb4b3-c41b-4b0a-9820-a5da49158a0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "a"}], " ", "x", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "x"}], "+", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "x"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "x"}], "-", 
    RowBox[{"2", " ", "c", " ", "x"}], "+", 
    RowBox[{"2", " ", "a", " ", "c", " ", "x"}], "+", 
    RowBox[{"2", " ", "b", " ", "c", " ", "x"}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", "x"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"], " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "3"], " ", "x"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "3"], " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.789157175688352*^9},
 CellLabel->
  "Out[189]=",ExpressionUUID->"68d6f4b0-4f1a-40eb-95da-7c9e0a7d6827"],

Cell[BoxData[
 RowBox[{"a", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "-", "x", "+", 
    RowBox[{"a", " ", "x"}], "+", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "b", " ", "x"}], "-", 
    RowBox[{"2", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.7891571938192787`*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"e82b5667-ada2-4d93-adc6-d2625760d122"],

Cell[BoxData[
 RowBox[{"a", " ", "x", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "x"}], "+", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "x"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "x"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "3"], " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "3"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.759804190106485*^9, 3.7598042131129704`*^9}, 
   3.759804279271144*^9, {3.759804312380475*^9, 3.7598043344609127`*^9}, {
   3.759804409317168*^9, 3.759804438328375*^9}, {3.759805319570373*^9, 
   3.7598053364079447`*^9}, 3.7598053763008423`*^9, {3.7598055005685062`*^9, 
   3.759805533248603*^9}, 3.7598055856645803`*^9, 3.759805846822279*^9, 
   3.759805964583102*^9, {3.759806049943233*^9, 3.759806069777367*^9}, 
   3.7598061036325817`*^9, 3.759806192029243*^9, 3.759806239487913*^9, {
   3.759806278669715*^9, 3.7598063305422087`*^9}, 3.759806385378048*^9, 
   3.759806420699069*^9, 3.759806482169055*^9, 3.760316803794327*^9, 
   3.7603169985311193`*^9, 3.760317086512265*^9, 3.760317170266612*^9, 
   3.760317249467772*^9, 3.760317443905168*^9, 3.7603175848312263`*^9, 
   3.760317774983326*^9, 3.7603178366789618`*^9, {3.760317987185237*^9, 
   3.760317993440193*^9}, 3.7603183458949623`*^9, 3.7603185244810534`*^9, 
   3.7603186408774757`*^9, 3.7603240473815002`*^9, 3.760387818646248*^9, 
   3.760651670278294*^9, 3.760661039224131*^9, 3.7607363154652967`*^9, 
   3.760818805005677*^9, 3.760820619612691*^9, 3.761002104923414*^9, 
   3.761267127435668*^9, 3.761522821182465*^9, 3.7663774594779997`*^9, 
   3.766377531844*^9, 3.766377603751*^9, 3.766377680007*^9, 
   3.766434236019855*^9, 3.7676640678548*^9, 3.767665120345853*^9, 
   3.789157193826331*^9},
 CellLabel->
  "Out[193]=",ExpressionUUID->"a5ccb507-d5c3-4e52-a927-3eb2689c4c56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "check", " ", "all", " ", "that"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Mu]", 
       RowBox[{"x", ",", "0"}]]}], 
     RowBox[{"Q", "[", 
      RowBox[{"x", ",", "0"}], "]"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Nu]", "0", "d"], " ", 
     RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}], 
     RowBox[{
      SubsuperscriptBox["Q", "0", "d"], "[", 
      FractionBox["1", "x"], "]"}]}], "+", 
    RowBox[{"(", 
     RowBox[{"\[Mu]", "+", 
      RowBox[{"\[Nu]", " ", 
       RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"0", ",", "0"}]], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", 
         RowBox[{"0", ",", "0"}]], 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"0", ",", "1"}]], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", 
         RowBox[{"0", ",", "1"}]], 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"1", ",", "0"}]], "+", 
       RowBox[{
        SubscriptBox["\[Nu]", 
         RowBox[{"1", ",", "0"}]], 
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcy", "[", 
       RowBox[{"12", ",", "0"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}], "\[Rule]", 
      RowBox[{"QQdkeval", "[", 
       RowBox[{"12", ",", "0", ",", 
        RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7603903178701477`*^9, 3.7603905529185038`*^9}, {
  3.761522831303485*^9, 3.7615228363864822`*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"30baffee-7810-4c66-9472-788ae4508059"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760390505830237*^9, 3.760390553990403*^9}, 
   3.760651728256871*^9, 3.760661095613228*^9, 3.7607363730259523`*^9, 
   3.760818864524544*^9, 3.760820677802836*^9, 3.761002161355728*^9, 
   3.761267185368739*^9, 3.761522877513685*^9, 3.76643433969447*^9, 
   3.767664126974187*^9, 3.7676651840135736`*^9, 3.7891571948146343`*^9},
 CellLabel->
  "Out[194]=",ExpressionUUID->"9ef3a17a-7323-492a-a522-87556fb4c153"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4.5",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.759714184011848*^9, 
  3.7597141840676126`*^9}, {3.75979277755081*^9, 3.7597927872206507`*^9}, {
  3.760319934346558*^9, 
  3.7603199344244328`*^9}},ExpressionUUID->"5bc6b4e2-1355-4848-837a-\
09043682c4e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "factorisation", " ", "of", " ", "\[CapitalDelta]"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "using", " ", "Root", " ", "instead", " ", "of", " ", "radicals", " ", 
    "seems", " ", "to", " ", "improve", " ", "performance"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "different", " ", "versions", " ", "of", " ", "Mathematica", " ", "may", 
     " ", "take", " ", 
     RowBox[{"Root", "[", "...", "]"}], " ", "in", " ", "different", " ", 
     "orders"}], ",", " ", 
    RowBox[{"so", " ", 
     RowBox[{"let", "'"}], "s", " ", "not", " ", "make", " ", "any", " ", 
     "assumptions"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Off", "[", 
    RowBox[{"Root", "::", "sbr"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "1"], "=", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["t", "2"]}], "+", "#", "-", 
         RowBox[{"2", " ", "t", " ", 
          SuperscriptBox["#", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["#", "3"]}]}], "&"}], ",", "1"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "2"], "=", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["t", "2"]}], "+", "#", "-", 
         RowBox[{"2", " ", "t", " ", 
          SuperscriptBox["#", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["#", "3"]}]}], "&"}], ",", "2"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "3"], "=", 
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["t", "2"]}], "+", "#", "-", 
         RowBox[{"2", " ", "t", " ", 
          SuperscriptBox["#", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          SuperscriptBox["#", "3"]}]}], "&"}], ",", "3"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["X", "1"], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["d", "1"], ",", 
         SubscriptBox["d", "2"], ",", 
         SubscriptBox["d", "3"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
         "\[Equal]", "0"}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["X", "2"], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["d", "1"], ",", 
         SubscriptBox["d", "2"], ",", 
         SubscriptBox["d", "3"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
         "\[Equal]", 
         RowBox[{
          RowBox[{"1", "/", "t"}], "+", 
          RowBox[{"2", 
           RowBox[{"Sqrt", "[", "t", "]"}]}]}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["X", "3"], "=", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["d", "1"], ",", 
         SubscriptBox["d", "2"], ",", 
         SubscriptBox["d", "3"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
         "\[Equal]", 
         RowBox[{
          RowBox[{"1", "/", "t"}], "-", 
          RowBox[{"2", 
           RowBox[{"Sqrt", "[", "t", "]"}]}]}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"then", " ", "eqns", " ", 
      RowBox[{"(", "4.33", ")"}]}], "-", 
     RowBox[{"(", "4.35", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["X", "1"], ",", 
       SubscriptBox["X", "2"], ",", 
       SubscriptBox["X", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.750902140999311*^9, 3.750902149380574*^9}, {
  3.750902208896585*^9, 3.750902370845623*^9}, {3.750902412257856*^9, 
  3.750902488514669*^9}, {3.750902547826901*^9, 3.75090263631989*^9}, {
  3.750902743061042*^9, 3.750902878628224*^9}, {3.750902921515088*^9, 
  3.750902922230826*^9}, {3.750905415551409*^9, 3.750905418860403*^9}, {
  3.76032191416638*^9, 3.760321936756075*^9}, {3.760322238053864*^9, 
  3.760322247675193*^9}, {3.760323324954328*^9, 3.760323328596746*^9}, {
  3.760323366376198*^9, 3.7603234071239767`*^9}, {3.76188309668439*^9, 
  3.761883100361022*^9}, {3.7891572477530727`*^9, 3.789157251497714*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"15c0aea5-3aab-403f-a393-a747ed195e86"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["t", "2"]}], "+", "#1", "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["#1", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["#1", "3"]}]}], "&"}], ",", "1"}], "]"}]], "Output",
 CellChangeTimes->{{3.760321907207533*^9, 3.760321937116259*^9}, {
   3.760322238445827*^9, 3.760322248076353*^9}, 3.760323368806017*^9, 
   3.760323408393414*^9, 3.760324106019458*^9, 3.7603878748156567`*^9, 
   3.760651728578039*^9, 3.760661095852648*^9, 3.760736373323827*^9, 
   3.760818865026576*^9, 3.760820678016191*^9, 3.761267185676149*^9, 
   3.761522889950755*^9, 3.76643435140871*^9, 3.767664141557357*^9, 
   3.767665192938644*^9, 3.789157297581377*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"00207ed5-c70f-4f00-83ed-69cdd733a2be"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["t", "2"]}], "+", "#1", "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["#1", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["#1", "3"]}]}], "&"}], ",", "3"}], "]"}]], "Output",
 CellChangeTimes->{{3.760321907207533*^9, 3.760321937116259*^9}, {
   3.760322238445827*^9, 3.760322248076353*^9}, 3.760323368806017*^9, 
   3.760323408393414*^9, 3.760324106019458*^9, 3.7603878748156567`*^9, 
   3.760651728578039*^9, 3.760661095852648*^9, 3.760736373323827*^9, 
   3.760818865026576*^9, 3.760820678016191*^9, 3.761267185676149*^9, 
   3.761522889950755*^9, 3.76643435140871*^9, 3.767664141557357*^9, 
   3.767665192938644*^9, 3.789157297705625*^9},
 CellLabel->
  "Out[200]=",ExpressionUUID->"49933a81-24be-4fdc-b97d-0722a86f1192"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["t", "2"]}], "+", "#1", "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["#1", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["#1", "3"]}]}], "&"}], ",", "2"}], "]"}]], "Output",
 CellChangeTimes->{{3.760321907207533*^9, 3.760321937116259*^9}, {
   3.760322238445827*^9, 3.760322248076353*^9}, 3.760323368806017*^9, 
   3.760323408393414*^9, 3.760324106019458*^9, 3.7603878748156567`*^9, 
   3.760651728578039*^9, 3.760661095852648*^9, 3.760736373323827*^9, 
   3.760818865026576*^9, 3.760820678016191*^9, 3.761267185676149*^9, 
   3.761522889950755*^9, 3.76643435140871*^9, 3.767664141557357*^9, 
   3.767665192938644*^9, 3.789157297834998*^9},
 CellLabel->
  "Out[201]=",ExpressionUUID->"12f2e8b5-231b-4475-bd6d-8a2a1540a506"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["t", "5"]}], "+", 
     RowBox[{"448", " ", 
      SuperscriptBox["t", "8"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "11"],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {4, 0, 0, 32, 0, 0, 448}, 2, 11, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox["1", "t"], "+", 
     RowBox[{"2", " ", 
      SqrtBox["t"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["t", 
       RowBox[{"7", "/", "2"}]]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["t", "5"]}], "+", 
     FractionBox[
      RowBox[{"231", " ", 
       SuperscriptBox["t", 
        RowBox[{"13", "/", "2"}]]}], "4"], "-", 
     RowBox[{"224", " ", 
      SuperscriptBox["t", "8"]}], "+", 
     FractionBox[
      RowBox[{"7293", " ", 
       SuperscriptBox["t", 
        RowBox[{"19", "/", "2"}]]}], "8"], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"21", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, -2, 21, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, 2, 0, 0, -2, 0, 0, 5, 0, 0, -16, 0, 0, 
      Rational[231, 4], 0, 0, -224, 0, 0, 
      Rational[7293, 8]}, -2, 21, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox["1", "t"], "-", 
     RowBox[{"2", " ", 
      SqrtBox["t"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["t", "2"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["t", 
       RowBox[{"7", "/", "2"}]]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["t", "5"]}], "-", 
     FractionBox[
      RowBox[{"231", " ", 
       SuperscriptBox["t", 
        RowBox[{"13", "/", "2"}]]}], "4"], "-", 
     RowBox[{"224", " ", 
      SuperscriptBox["t", "8"]}], "-", 
     FractionBox[
      RowBox[{"7293", " ", 
       SuperscriptBox["t", 
        RowBox[{"19", "/", "2"}]]}], "8"], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"21", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, -2, 21, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, -2, 0, 0, -2, 0, 0, -5, 0, 0, -16, 0, 0, 
      Rational[-231, 4], 0, 0, -224, 0, 0, 
      Rational[-7293, 8]}, -2, 21, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.760321907207533*^9, 3.760321937116259*^9}, {
   3.760322238445827*^9, 3.760322248076353*^9}, 3.760323368806017*^9, 
   3.760323408393414*^9, 3.760324106019458*^9, 3.7603878748156567`*^9, 
   3.760651728578039*^9, 3.760661095852648*^9, 3.760736373323827*^9, 
   3.760818865026576*^9, 3.760820678016191*^9, 3.761267185676149*^9, 
   3.761522889950755*^9, 3.76643435140871*^9, 3.767664141557357*^9, 
   3.767665192938644*^9, 3.789157297941638*^9},
 CellLabel->
  "Out[202]=",ExpressionUUID->"1a0e3e15-38db-4918-b0f8-024795732a30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", "factorisation"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "0"], "=", 
     RowBox[{
      RowBox[{"t", "^", "2"}], 
      SubscriptBox["X", "2"], 
      SubscriptBox["X", "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "p"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"x", "/", 
         SubscriptBox["X", "2"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"x", "/", 
         SubscriptBox["X", "3"]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "m"], "=", 
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["X", "1"], "/", "x"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"so", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalDelta]", "-", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "0"], 
      SubscriptBox["\[CapitalDelta]", "p"], 
      SubscriptBox["\[CapitalDelta]", "m"]}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760323792300898*^9, 3.760323890013915*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"caee7a8c-6bdd-4b69-90e9-eb834a9d9165"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.760323890499783*^9, 3.7603241069458647`*^9, 
  3.760387875441024*^9, 3.760651729296794*^9, 3.760661096440927*^9, 
  3.7607363741039257`*^9, 3.760818866178904*^9, 3.76082067872241*^9, 
  3.761267186462675*^9, 3.761522894001954*^9, 3.7664343565522842`*^9, 
  3.767664142120599*^9, 3.767665193571516*^9, 3.789157298120921*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"9d6122b0-7647-4c62-9d97-f17184af2674"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"and", " ", "then", " ", "verifying", " ", "eqns", " ", 
    RowBox[{"(", "4.39", ")"}]}], "-", 
   RowBox[{"(", "4.40", ")"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.760323901845254*^9, 3.760323911839363*^9}, {
  3.7618831376552925`*^9, 3.7618831402610345`*^9}, {3.789157286049192*^9, 
  3.789157291930975*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"ea9ab398-4160-4d79-8e49-1c5b0871f9f5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"1", "/", 
   RowBox[{"Sqrt", "[", 
    SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqrt", "[", 
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "0"], 
    SubscriptBox["\[CapitalDelta]", "m"]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.760323061988587*^9, 3.760323071400489*^9}, {
  3.760323918175362*^9, 3.7603239526785603`*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"ba1fefb4-6299-49a6-87de-fc09dddc5700"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{"x", " ", "t"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["t", "2"]}], "+", 
   RowBox[{
    SuperscriptBox["x", "3"], " ", 
    SuperscriptBox["t", "3"]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"48", " ", "x"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["x", "4"]}]}], ")"}], " ", 
    SuperscriptBox["t", "4"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"9", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 0, 9, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   1, 0, $CellContext`x, 0, $CellContext`x^2, 0, $CellContext`x^3, 0, 
    Rational[1, 8] (48 $CellContext`x + 8 $CellContext`x^4)}, 0, 9, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7603230645318413`*^9, 3.760323071740127*^9}, 
   3.7603239536911907`*^9, 3.76032410733454*^9, 3.760387875711694*^9, 
   3.7606517294743013`*^9, 3.760661096622199*^9, 3.760736374311252*^9, 
   3.760818866364612*^9, 3.760820678928172*^9, 3.761267186683669*^9, 
   3.761522896535613*^9, 3.766434360217368*^9, 3.767664142209633*^9, 
   3.7676651936653843`*^9, 3.789157298214817*^9},
 CellLabel->
  "Out[209]=",ExpressionUUID->"603a252c-9e59-40a9-ba5f-b9d88ffdacaf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["t", "2"]}], "x"], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["t", "3"]}], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["t", "4"]}], 
    SuperscriptBox["x", "2"]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "5"],
    SeriesData[$CellContext`t, 0, {}, 0, 10, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   1, 0, 0, 0, (-2)/$CellContext`x, 0, -4, 0, (-2) $CellContext`x^(-2)}, 0, 
   10, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7603230645318413`*^9, 3.760323071740127*^9}, 
   3.7603239536911907`*^9, 3.76032410733454*^9, 3.760387875711694*^9, 
   3.7606517294743013`*^9, 3.760661096622199*^9, 3.760736374311252*^9, 
   3.760818866364612*^9, 3.760820678928172*^9, 3.761267186683669*^9, 
   3.761522896535613*^9, 3.766434360217368*^9, 3.767664142209633*^9, 
   3.7676651936653843`*^9, 3.789157298384419*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"67d37d96-31e7-4f3a-aeb4-e2c6319c27b0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4.6",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.759714184011848*^9, 
  3.7597141840676126`*^9}, {3.75979277755081*^9, 3.7597927872206507`*^9}, {
  3.760319934346558*^9, 3.7603199344244328`*^9}, {3.760324898873787*^9, 
  3.760324898906824*^9}, {3.760411813758315*^9, 3.760411823252985*^9}, {
  3.7612552186693573`*^9, 
  3.761255218815363*^9}},ExpressionUUID->"c7b5485d-7692-4842-8f40-\
a403c6c5a9ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "now", " ", "wish", " ", "to", " ", "take", " ", "eqn", " ", 
     RowBox[{"(", "4.26", ")"}]}], ",", " ", 
    RowBox[{"divide", " ", "by", " ", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "+"], "]"}]}], ",", " ", 
    RowBox[{"and", " ", "take", " ", 
     RowBox[{"the", " ", "[", 
      RowBox[{
       RowBox[{"x", "^"}], ">"}], "]"}], " ", 
     RowBox[{"and", " ", "[", 
      RowBox[{
       RowBox[{"x", "^"}], "<"}], "]"}], " ", "parts", " ", "of", " ", 
     "that"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "must", " ", "divide", " ", "by", " ", "x", " ", "first"}], 
    ",", " ", 
    RowBox[{
    "otherwise", " ", "we", " ", "end", " ", "up", " ", "with", " ", "the", 
     " ", "term", " ", 
     SubscriptBox["Q", 
      RowBox[{"4", ",", "4"}]], " ", "which", " ", "cannot", " ", "be", " ", 
     "reduced", " ", "to", " ", "a", " ", "combination", " ", "of", " ", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], ",", " ", 
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]], " ", "and", " ", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "sadly", " ", "this", " ", "makes", " ", "the", " ", "calculations", " ", 
    "more", " ", "complicated"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.760388969690567*^9, 3.76038901928249*^9}, {
  3.760651750498103*^9, 3.760651783728959*^9}, {3.760651838226699*^9, 
  3.760651895568962*^9}, {3.76065299855536*^9, 3.760653000218486*^9}, {
  3.7618852958730345`*^9, 3.7618852965600348`*^9}, {3.789157317797223*^9, 
  3.789157318302265*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"41ee7869-27dd-4f02-b051-451498ecc8fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "it", " ", "is", " ", "simpler", " ", "to", " ", "leave", " ", "the", " ", 
    
    SubscriptBox["X", "i"], " ", "unevaluated", " ", "until", " ", "we", " ", 
    "need", " ", "them"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"so", " ", "define"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "=", 
     RowBox[{
      RowBox[{"t", "^", "2"}], 
      SubscriptBox["XX", "2"], 
      SubscriptBox["XX", "3"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"x", "/", 
         SubscriptBox["XX", "2"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"x", "/", 
         SubscriptBox["XX", "3"]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "=", 
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["XX", "1"], "/", "x"}]}]}], ";"}]}]}]], "Input",
 CellLabel->
  "In[213]:=",ExpressionUUID->"d7985ad0-c0a7-43d4-830c-0c74deb030af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "following", " ", "two", " ", "expansions", " ", "will", " ", 
    "be", " ", "useful"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "expansion", " ", "of", " ", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "+"], "]"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", "%"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"and", " ", "the", " ", "expansion", " ", "of", " ", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "-"], "]"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "Infinity", ",", "5"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7603889631514177`*^9, 3.760388965730166*^9}, {
  3.7603890219270363`*^9, 3.76038921003305*^9}, {3.760389943142742*^9, 
  3.760389949411768*^9}, {3.7603900449907913`*^9, 3.760390046687234*^9}, {
  3.760391019967896*^9, 3.760391031566201*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"9a0279bf-2037-49ea-8bc1-a8a9b57c6e85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["XX", "2"], "+", 
       SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
    RowBox[{"2", " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SubsuperscriptBox["XX", "2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
     SuperscriptBox["x", "2"]}], 
    RowBox[{"8", " ", 
     SubsuperscriptBox["XX", "2", "2"], " ", 
     SubsuperscriptBox["XX", "3", "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["XX", "2"], "+", 
       SubscriptBox["XX", "3"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        SubsuperscriptBox["XX", "2", "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}], "+", 
       RowBox[{"5", " ", 
        SubsuperscriptBox["XX", "3", "2"]}]}], ")"}], " ", 
     SuperscriptBox["x", "3"]}], 
    RowBox[{"16", " ", 
     SubsuperscriptBox["XX", "2", "3"], " ", 
     SubsuperscriptBox["XX", "3", "3"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"35", " ", 
        SubsuperscriptBox["XX", "2", "4"]}], "+", 
       RowBox[{"20", " ", 
        SubsuperscriptBox["XX", "2", "3"], " ", 
        SubscriptBox["XX", "3"]}], "+", 
       RowBox[{"18", " ", 
        SubsuperscriptBox["XX", "2", "2"], " ", 
        SubsuperscriptBox["XX", "3", "2"]}], "+", 
       RowBox[{"20", " ", 
        SubscriptBox["XX", "2"], " ", 
        SubsuperscriptBox["XX", "3", "3"]}], "+", 
       RowBox[{"35", " ", 
        SubsuperscriptBox["XX", "3", "4"]}]}], ")"}], " ", 
     SuperscriptBox["x", "4"]}], 
    RowBox[{"128", " ", 
     SubsuperscriptBox["XX", "2", "4"], " ", 
     SubsuperscriptBox["XX", "3", "4"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["XX", "2"], "+", 
       SubscriptBox["XX", "3"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"63", " ", 
        SubsuperscriptBox["XX", "2", "4"]}], "-", 
       RowBox[{"28", " ", 
        SubsuperscriptBox["XX", "2", "3"], " ", 
        SubscriptBox["XX", "3"]}], "+", 
       RowBox[{"58", " ", 
        SubsuperscriptBox["XX", "2", "2"], " ", 
        SubsuperscriptBox["XX", "3", "2"]}], "-", 
       RowBox[{"28", " ", 
        SubscriptBox["XX", "2"], " ", 
        SubsuperscriptBox["XX", "3", "3"]}], "+", 
       RowBox[{"63", " ", 
        SubsuperscriptBox["XX", "3", "4"]}]}], ")"}], " ", 
     SuperscriptBox["x", "5"]}], 
    RowBox[{"256", " ", 
     SubsuperscriptBox["XX", "2", "5"], " ", 
     SubsuperscriptBox["XX", "3", "5"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "6"],
    SeriesData[$CellContext`x, 0, {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {
   1, Rational[
     1, 2] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^(-1) \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-1) ($CellContext`XX\
\[UnderBracket]Subscript\[UnderBracket]2 + \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3), 
    Rational[1, 
      8] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^(-2) \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-2) (
     3 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^2 + 
     2 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3 + 
     3 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^2), 
    Rational[1, 
      16] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^(-3) \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-3) ($CellContext`XX\
\[UnderBracket]Subscript\[UnderBracket]2 + \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3) (
     5 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^2 - 
     2 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3 + 
     5 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^2), 
    Rational[1, 
      128] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^(-4) \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-4) (
     35 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^4 + 
     20 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^3 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3 + 
     18 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^2 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^2 + 
     20 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^3 + 
     35 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^4), 
    Rational[1, 
      256] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^(-5) \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^(-5) ($CellContext`XX\
\[UnderBracket]Subscript\[UnderBracket]2 + \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3) (
     63 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^4 - 
     28 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^3 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3 + 
     58 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2^2 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^2 - 
     28 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]2 \
$CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^3 + 
     63 $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]3^4)}, 0, 6, 1],
  
  Editable->False]], "Output",
 CellChangeTimes->{{3.760389081654098*^9, 3.760389096192975*^9}, {
   3.760389145105423*^9, 3.760389166408881*^9}, 3.760389211189851*^9, 
   3.7603899508093653`*^9, 3.760390046956859*^9, {3.760391020736744*^9, 
   3.760391031839615*^9}, 3.760654487575601*^9, 3.760661096906035*^9, 
   3.760736374666703*^9, 3.7608188670098*^9, 3.760820679244212*^9, 
   3.761522911868824*^9, 3.766434371834877*^9, 3.7676641855841703`*^9, 
   3.76766519947978*^9, 3.789157461748314*^9},
 CellLabel->
  "Out[217]=",ExpressionUUID->"b531c694-6709-41bb-9f2e-e8db0d371e95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    SubscriptBox["XX", "1"], 
    RowBox[{"2", " ", "x"}]], "-", 
   FractionBox[
    SubsuperscriptBox["XX", "1", "2"], 
    RowBox[{"8", " ", 
     SuperscriptBox["x", "2"]}]], "-", 
   FractionBox[
    SubsuperscriptBox["XX", "1", "3"], 
    RowBox[{"16", " ", 
     SuperscriptBox["x", "3"]}]], "-", 
   FractionBox[
    RowBox[{"5", " ", 
     SubsuperscriptBox["XX", "1", "4"]}], 
    RowBox[{"128", " ", 
     SuperscriptBox["x", "4"]}]], "-", 
   FractionBox[
    RowBox[{"7", " ", 
     SubsuperscriptBox["XX", "1", "5"]}], 
    RowBox[{"256", " ", 
     SuperscriptBox["x", "5"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "x"], "]"}], "6"],
    SeriesData[$CellContext`x, 
     DirectedInfinity[1], {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 
   DirectedInfinity[1], {
   1, Rational[-1, 2] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1,
     Rational[-1, 
      8] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1^2, 
    Rational[-1, 
      16] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1^3, 
    Rational[-5, 
      128] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1^4, 
    Rational[-7, 
      256] $CellContext`XX\[UnderBracket]Subscript\[UnderBracket]1^5}, 0, 6, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760389081654098*^9, 3.760389096192975*^9}, {
   3.760389145105423*^9, 3.760389166408881*^9}, 3.760389211189851*^9, 
   3.7603899508093653`*^9, 3.760390046956859*^9, {3.760391020736744*^9, 
   3.760391031839615*^9}, 3.760654487575601*^9, 3.760661096906035*^9, 
   3.760736374666703*^9, 3.7608188670098*^9, 3.760820679244212*^9, 
   3.761522911868824*^9, 3.766434371834877*^9, 3.7676641855841703`*^9, 
   3.76766519947978*^9, 3.789157461751431*^9},
 CellLabel->
  "Out[218]=",ExpressionUUID->"37d35e91-789d-45bb-b6a9-5dbf35b20249"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"first", " ", "take", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], ">"}], "]"}], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"first", " ", "the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"need", " ", "to", " ", "remove", " ", "the", " ", 
    RowBox[{"x", "^", "0"}], " ", "part"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"x", ",", "0"}]], "/", "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"x", ",", "0"}]], "/", "x"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["XX", "2"], "+", 
                SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "2"], " ", 
              SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
        "0"}], "]"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[Mu]", 
             RowBox[{"x", ",", "0"}]], "/", "x"}], "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["XX", "2"], "+", 
                 SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
              RowBox[{"2", " ", 
               SubscriptBox["XX", "2"], " ", 
               SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
         RowBox[{"-", "1"}]}], "]"}], "/", "x"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "*", "x"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"xposLHS1", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", "__", "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "}"}], ",", "Factor"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"x", ",", "0"}]], "/", "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcy", "[", 
        RowBox[{"9", ",", "0"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposLHS1", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"9", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760389242774406*^9, 3.7603892523114023`*^9}, {
   3.760389532648449*^9, 3.760389611940094*^9}, {3.7603896704870167`*^9, 
   3.760389788908091*^9}, {3.760389823638503*^9, 3.7603898418076077`*^9}, {
   3.760389956459552*^9, 3.7603900179764338`*^9}, {3.760390710977624*^9, 
   3.760390723935807*^9}, {3.760393702220612*^9, 3.760393812877884*^9}, {
   3.760393851885178*^9, 3.7603939723569727`*^9}, {3.760394051388468*^9, 
   3.760394054793619*^9}, {3.760394163755415*^9, 3.7603942242684603`*^9}, {
   3.760395008721504*^9, 3.760395014905861*^9}, {3.760395166663694*^9, 
   3.760395204520319*^9}, {3.760654544782304*^9, 3.760654578072089*^9}, {
   3.760654720254406*^9, 3.760654784333921*^9}, {3.7606548795701513`*^9, 
   3.7606548885132017`*^9}, {3.7606551356613197`*^9, 3.76065514028319*^9}, {
   3.7615230085751953`*^9, 3.7615230102721243`*^9}, 3.766434380912019*^9},
 CellLabel->
  "In[219]:=",ExpressionUUID->"7f292d52-a275-4738-8f51-d35b058ac814"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   SuperscriptBox["a", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", 
   SuperscriptBox["t", "4"]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"x", " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]], 
   RowBox[{"2", " ", "a", " ", "c", " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x", " ", 
       SubscriptBox["XX", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", "x", " ", 
       SubscriptBox["XX", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", "x", " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", "x", " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"2", " ", "a", " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"2", " ", "b", " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"5", " ", "a", " ", "b", " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", "x", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}], "-", 
  FractionBox[
   RowBox[{"2", " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "-", 
      RowBox[{"a", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"2", " ", "x"}], "-", 
      RowBox[{"a", " ", "x"}], "-", 
      RowBox[{"b", " ", "x"}], "-", 
      RowBox[{"a", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}]}], 
   RowBox[{"x", " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", 
         SubscriptBox["XX", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", 
         SubscriptBox["XX", "3"]}], ")"}]}], 
      RowBox[{
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}]]]}]]}]], "Output",
 CellChangeTimes->{
  3.760389538398467*^9, 3.760389789854953*^9, {3.760389972381316*^9, 
   3.760390018697256*^9}, 3.760390724857909*^9, 3.7603937540215693`*^9, {
   3.760393796335732*^9, 3.760393814574637*^9}, 3.760393852503937*^9, {
   3.760393899501945*^9, 3.76039397294077*^9}, 3.760394055485778*^9, {
   3.760394169387684*^9, 3.760394225239376*^9}, 3.76039501539403*^9, {
   3.7603951697879972`*^9, 3.760395204916972*^9}, {3.7606547699328136`*^9, 
   3.760654786939139*^9}, {3.7606551187450743`*^9, 3.76065514198573*^9}, 
   3.76066109710841*^9, 3.7607363749653397`*^9, 3.760818867359447*^9, 
   3.760820679498464*^9, 3.761522918022284*^9, 3.761523010985469*^9, {
   3.7664343758788147`*^9, 3.766434381489809*^9}, 3.767664190869402*^9, 
   3.76766519954285*^9, 3.7891574618183928`*^9},
 CellLabel->
  "Out[220]=",ExpressionUUID->"6655804f-37f4-4d10-b031-7e83f1ff9a64"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760389538398467*^9, 3.760389789854953*^9, {3.760389972381316*^9, 
   3.760390018697256*^9}, 3.760390724857909*^9, 3.7603937540215693`*^9, {
   3.760393796335732*^9, 3.760393814574637*^9}, 3.760393852503937*^9, {
   3.760393899501945*^9, 3.76039397294077*^9}, 3.760394055485778*^9, {
   3.760394169387684*^9, 3.760394225239376*^9}, 3.76039501539403*^9, {
   3.7603951697879972`*^9, 3.760395204916972*^9}, {3.7606547699328136`*^9, 
   3.760654786939139*^9}, {3.7606551187450743`*^9, 3.76065514198573*^9}, 
   3.76066109710841*^9, 3.7607363749653397`*^9, 3.760818867359447*^9, 
   3.760820679498464*^9, 3.761522918022284*^9, 3.761523010985469*^9, {
   3.7664343758788147`*^9, 3.766434381489809*^9}, 3.767664190869402*^9, 
   3.76766519954285*^9, 3.789157464667222*^9},
 CellLabel->
  "Out[224]=",ExpressionUUID->"f7e568e1-5b8f-4f65-a553-a888db6e2808"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"then", " ", "the", " ", "non"}], "-", 
    RowBox[{"Q", " ", "terms"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Mu]", "/", "x"}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"\[Mu]", "/", "x"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["XX", "2"], "+", 
               SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "2"], " ", 
             SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
       "0"}], "]"}], "-", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"\[Mu]", "/", "x"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["XX", "2"], "+", 
                SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "2"], " ", 
              SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
        RowBox[{"-", "1"}]}], "]"}], "/", "x"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{"\[Nu]", ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{"\[Nu]", ",", "x"}], "]"}], "]"}], "-", "1"}]}], 
          "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "3"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"3", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{"\[Nu]", ",", "x"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"xposRHS1", "=", 
    RowBox[{"%%", "+", 
     RowBox[{"%", "*", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
       "x"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Mu]", "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", "x"}],
      "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xposRHS1", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7603902577573147`*^9, 3.760390285319489*^9}, {
   3.760390572474988*^9, 3.7603906326062202`*^9}, {3.760390736817149*^9, 
   3.760390744489868*^9}, {3.76039079199092*^9, 3.760390795622756*^9}, {
   3.7603908283848352`*^9, 3.7603908599296417`*^9}, {3.760390895751816*^9, 
   3.760390897595769*^9}, {3.760390930593094*^9, 3.7603909441386223`*^9}, {
   3.76039100378903*^9, 3.7603910046881113`*^9}, {3.760391036560328*^9, 
   3.760391052637089*^9}, {3.7603910843867826`*^9, 3.760391159357048*^9}, {
   3.760391192366521*^9, 3.760391192461383*^9}, {3.760391579456379*^9, 
   3.760391664900669*^9}, {3.7603917849999523`*^9, 3.76039179706949*^9}, 
   3.760391852084796*^9, {3.7603919994865828`*^9, 3.760392005077084*^9}, {
   3.760395227426219*^9, 3.7603953505160437`*^9}, {3.76065521162285*^9, 
   3.760655248860668*^9}, {3.760655614737273*^9, 3.760655642013536*^9}, {
   3.767664885878851*^9, 3.76766489554102*^9}},
 CellLabel->
  "In[225]:=",ExpressionUUID->"a142f69e-8a58-466f-9b3f-8dbbf490018a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["a", "3"]}], " ", "b", " ", 
   SuperscriptBox["t", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["t", "2"]}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["t", "4"]}], "x"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["t", "4"]}], 
   SubscriptBox["XX", "2"]], "+", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"2", " ", "x"}], "-", 
      RowBox[{"a", " ", "x"}], "-", 
      RowBox[{"b", " ", "x"}], "-", 
      RowBox[{"a", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], "-", "x", "+", 
      RowBox[{"a", " ", "x"}], "+", 
      RowBox[{"b", " ", "x"}], "-", 
      RowBox[{"a", " ", "b", " ", "x"}], "-", 
      RowBox[{"2", " ", "b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "3"]}]}], ")"}]}], 
   RowBox[{"x", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["x", 
         SubscriptBox["XX", "2"]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["x", 
         SubscriptBox["XX", "3"]]}], ")"}]}]]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["t", "4"]}], 
   SubscriptBox["XX", "3"]], "+", 
  RowBox[{
   FractionBox["1", "x"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", 
         SuperscriptBox["a", "2"], "+", "b", "-", 
         RowBox[{"2", " ", "a", " ", "b"}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b"}], "-", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"]}]}], ")"}], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t", " ", 
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SubscriptBox["XX", "1"], 
          RowBox[{"2", " ", "x"}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SubscriptBox["XX", "1"], 
          RowBox[{"2", " ", "x"}]], "-", 
         FractionBox[
          SubsuperscriptBox["XX", "1", "2"], 
          RowBox[{"8", " ", 
           SuperscriptBox["x", "2"]}]]}], ")"}]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubscriptBox["XX", "3"]}]]}]}]}]], "Output",
 CellChangeTimes->{
  3.7603902857586184`*^9, 3.76039061345341*^9, 3.7603907449158373`*^9, 
   3.760390797616268*^9, {3.760390829656464*^9, 3.760390860281763*^9}, 
   3.760391054463902*^9, 3.7603910908892508`*^9, {3.7603911489067087`*^9, 
   3.760391160293515*^9}, 3.7603911932374287`*^9, 3.760391583663559*^9, {
   3.760391615205659*^9, 3.760391668460495*^9}, {3.760391791246828*^9, 
   3.7603917976987343`*^9}, 3.76039185300039*^9, 3.7603918931972227`*^9, 
   3.760392005449955*^9, {3.760395304131064*^9, 3.760395350903441*^9}, 
   3.7606556458237047`*^9, 3.760661099276772*^9, 3.760736377214739*^9, 
   3.760818869690669*^9, 3.7608206816697206`*^9, 3.7615229221226597`*^9, 
   3.766434384611738*^9, 3.767664199811921*^9, 3.767664898927309*^9, 
   3.767665202443433*^9, 3.78915746479464*^9},
 CellLabel->
  "Out[227]=",ExpressionUUID->"c558f6ac-68df-4529-8264-2f9ac540e1ca"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7603902857586184`*^9, 3.76039061345341*^9, 3.7603907449158373`*^9, 
   3.760390797616268*^9, {3.760390829656464*^9, 3.760390860281763*^9}, 
   3.760391054463902*^9, 3.7603910908892508`*^9, {3.7603911489067087`*^9, 
   3.760391160293515*^9}, 3.7603911932374287`*^9, 3.760391583663559*^9, {
   3.760391615205659*^9, 3.760391668460495*^9}, {3.760391791246828*^9, 
   3.7603917976987343`*^9}, 3.76039185300039*^9, 3.7603918931972227`*^9, 
   3.760392005449955*^9, {3.760395304131064*^9, 3.760395350903441*^9}, 
   3.7606556458237047`*^9, 3.760661099276772*^9, 3.760736377214739*^9, 
   3.760818869690669*^9, 3.7608206816697206`*^9, 3.7615229221226597`*^9, 
   3.766434384611738*^9, 3.767664199811921*^9, 3.767664898927309*^9, 
   3.767665202443433*^9, 3.789157465243334*^9},
 CellLabel->
  "Out[233]=",ExpressionUUID->"428b3fb0-b4a4-4a37-9878-9de147491b61"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}], " ", "terms"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"0", ",", "0"}]], "/", "x"}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "0"}]], "/", "x"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["XX", "2"], "+", 
               SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "2"], " ", 
             SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
       "0"}], "]"}], "-", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"0", ",", "0"}]], "/", "x"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["XX", "2"], "+", 
                SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "2"], " ", 
              SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
        RowBox[{"-", "1"}]}], "]"}], "/", "x"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "0"}]], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubscriptBox["\[Nu]", 
                RowBox[{"0", ",", "0"}]], ",", "x"}], "]"}], "]"}], "-", 
            "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "3"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"3", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubscriptBox["\[Nu]", 
             RowBox[{"0", ",", "0"}]], ",", "x"}], "]"}], "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xposRHS2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "+", 
       RowBox[{"%", "*", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
         "x"}]}]}], ")"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"0", ",", "0"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", "x"}],
      "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposRHS2", "/", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7603916932092447`*^9, 3.760391729562092*^9}, {
  3.7603918156232367`*^9, 3.760391849903163*^9}, {3.760391896015752*^9, 
  3.7603918990986443`*^9}, {3.760392008600019*^9, 3.7603920158096457`*^9}, {
  3.760395364489233*^9, 3.760395407238092*^9}, {3.76065569641733*^9, 
  3.760655751730837*^9}, {3.7676649080418863`*^9, 3.767664917355568*^9}},
 CellLabel->
  "In[234]:=",ExpressionUUID->"141b4e35-cb51-4e8c-98c8-014082557d6e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "-", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "5"]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"]}]}], "x"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "2"]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "2"]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "2"]], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"x", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["x", 
            SubscriptBox["XX", "2"]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["x", 
            SubscriptBox["XX", "3"]]}], ")"}]}]]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["t", "2"]}], "+", 
        RowBox[{"2", " ", "x"}], "-", 
        RowBox[{"a", " ", "x"}], "-", 
        RowBox[{"b", " ", "x"}], "-", 
        RowBox[{"a", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["t", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c", " ", 
         SuperscriptBox["t", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"]}], "-", 
        RowBox[{"a", " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "x"}], "+", 
        RowBox[{"a", " ", "b", " ", "x"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "+", 
        RowBox[{"2", " ", "c", " ", "x"}], "-", 
        RowBox[{"2", " ", "a", " ", "c", " ", "x"}], "-", 
        RowBox[{"2", " ", "b", " ", "c", " ", "x"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "3"], " ", "x"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", "c", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", "c", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{"a", " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}]}], ")"}]}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "3"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "3"]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "3"]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"]}], 
     SubscriptBox["XX", "3"]], "+", 
    RowBox[{
     FractionBox["1", "x"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", 
           SuperscriptBox["a", "2"], "+", "b", "-", 
           RowBox[{"2", " ", "a", " ", "b"}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           SuperscriptBox["b", "2"], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", "c"}], "+", 
           RowBox[{"2", " ", "a", " ", "c"}], "+", 
           RowBox[{"2", " ", "b", " ", "c"}], "-", 
           RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
            SuperscriptBox["t", "3"]}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"], " ", "c", " ", 
            SuperscriptBox["t", "3"]}]}], ")"}], " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "c"}], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", "c"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", "t", " ", 
         SuperscriptBox["x", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SubscriptBox["XX", "1"], 
            RowBox[{"2", " ", "x"}]]}], ")"}]}], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "c"}], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", "c"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "4"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SubscriptBox["XX", "1"], 
            RowBox[{"2", " ", "x"}]], "-", 
           FractionBox[
            SubsuperscriptBox["XX", "1", "2"], 
            RowBox[{"8", " ", 
             SuperscriptBox["x", "2"]}]]}], ")"}]}]}], ")"}], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}]}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.760391730647749*^9, {3.760391843995825*^9, 3.7603918554650927`*^9}, 
   3.76039189969963*^9, 3.7603920163325367`*^9, 3.760395410811376*^9, 
   3.760655757806327*^9, 3.760661099910161*^9, 3.760736377905715*^9, 
   3.760818870381084*^9, 3.760820682338834*^9, 3.761522925370962*^9, 
   3.766434387341564*^9, 3.767664205306654*^9, 3.767664920159368*^9, 
   3.767665208633491*^9, 3.789157465302387*^9},
 CellLabel->
  "Out[236]=",ExpressionUUID->"335c6de5-9895-42be-8410-0677277512d6"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760391730647749*^9, {3.760391843995825*^9, 3.7603918554650927`*^9}, 
   3.76039189969963*^9, 3.7603920163325367`*^9, 3.760395410811376*^9, 
   3.760655757806327*^9, 3.760661099910161*^9, 3.760736377905715*^9, 
   3.760818870381084*^9, 3.760820682338834*^9, 3.761522925370962*^9, 
   3.766434387341564*^9, 3.767664205306654*^9, 3.767664920159368*^9, 
   3.767665208633491*^9, 3.789157466024211*^9},
 CellLabel->
  "Out[242]=",ExpressionUUID->"de4f15ff-05d4-418c-8bdd-ae5ad39954f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"0", ",", "1"}]], " ", "terms"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"0", ",", "1"}]], "/", "x"}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "1"}]], "/", "x"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["XX", "2"], "+", 
               SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "2"], " ", 
             SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
       "0"}], "]"}], "-", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"0", ",", "1"}]], "/", "x"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["XX", "2"], "+", 
                SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "2"], " ", 
              SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
        RowBox[{"-", "1"}]}], "]"}], "/", "x"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "1"}]], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubscriptBox["\[Nu]", 
                RowBox[{"0", ",", "1"}]], ",", "x"}], "]"}], "]"}], "-", 
            "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "3"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"3", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubscriptBox["\[Nu]", 
             RowBox[{"0", ",", "1"}]], ",", "x"}], "]"}], "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xposRHS3", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "+", 
       RowBox[{"%", "*", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
         "x"}]}]}], ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"0", ",", "1"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "1"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", "x"}],
      "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposRHS3", "/", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.76039186827367*^9, 3.760391903041819*^9}, {
  3.760392021345845*^9, 3.7603920262507963`*^9}, {3.760395418175432*^9, 
  3.76039543114375*^9}, {3.7606557800525723`*^9, 3.7606558089354467`*^9}, {
  3.767664926278727*^9, 3.767664934723694*^9}},
 CellLabel->
  "In[243]:=",ExpressionUUID->"ac5d2511-39e9-43c8-93da-287614c2d4d6"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["Q", 
   RowBox[{"0", ",", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "4"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "4"]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "b", " ", "c", 
      " ", 
      SuperscriptBox["t", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["t", "2"]}], "+", 
        RowBox[{"2", " ", "x"}], "-", 
        RowBox[{"a", " ", "x"}], "-", 
        RowBox[{"b", " ", "x"}], "-", 
        RowBox[{"a", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}]}], ")"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["x", 
          SubscriptBox["XX", "2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["x", 
          SubscriptBox["XX", "3"]]}], ")"}]}]]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", "x", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.760391905869832*^9, 3.7603932820202436`*^9, 
  3.760395432656726*^9, 3.7606558099732103`*^9, 3.7606611008195057`*^9, 
  3.760736378834322*^9, 3.7608188714448147`*^9, 3.760820683258225*^9, 
  3.761522928506735*^9, 3.766434390959712*^9, 3.767664209527177*^9, 
  3.76766493730116*^9, 3.767665214367831*^9, 3.789157466124722*^9},
 CellLabel->
  "Out[245]=",ExpressionUUID->"4b1fcd95-8628-481b-879e-1c1a52562c77"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.760391905869832*^9, 3.7603932820202436`*^9, 
  3.760395432656726*^9, 3.7606558099732103`*^9, 3.7606611008195057`*^9, 
  3.760736378834322*^9, 3.7608188714448147`*^9, 3.760820683258225*^9, 
  3.761522928506735*^9, 3.766434390959712*^9, 3.767664209527177*^9, 
  3.76766493730116*^9, 3.767665214367831*^9, 3.78915746645545*^9},
 CellLabel->
  "Out[251]=",ExpressionUUID->"6d4f97d9-2732-4f3e-840d-4e220c484041"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"then", " ", "the", " ", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", "terms"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"1", ",", "0"}]], "/", "x"}], "/", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "0"}]], "/", "x"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["XX", "2"], "+", 
               SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "2"], " ", 
             SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
       "0"}], "]"}], "-", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"1", ",", "0"}]], "/", "x"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["XX", "2"], "+", 
                SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
             RowBox[{"2", " ", 
              SubscriptBox["XX", "2"], " ", 
              SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
        RowBox[{"-", "1"}]}], "]"}], "/", "x"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"1", ",", "0"}]], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubscriptBox["\[Nu]", 
                RowBox[{"1", ",", "0"}]], ",", "x"}], "]"}], "]"}], "-", 
            "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "3"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"3", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubscriptBox["\[Nu]", 
             RowBox[{"1", ",", "0"}]], ",", "x"}], "]"}], "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xposRHS4", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "+", 
       RowBox[{"%", "*", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
         "x"}]}]}], ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"1", ",", "0"}]], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"1", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", "x"}],
      "/", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposRHS4", "/", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "9"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7603919197880297`*^9, 3.760391943042593*^9}, {
  3.760392029074733*^9, 3.7603920343051*^9}, {3.7603954403498163`*^9, 
  3.7603954507992983`*^9}, {3.760655817935071*^9, 3.760655853043314*^9}, {
  3.767664942568905*^9, 3.767664950206646*^9}},
 CellLabel->
  "In[252]:=",ExpressionUUID->"cedd9ac3-74ea-476c-b566-d3d7ede15dc4"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["Q", 
   RowBox[{"1", ",", "0"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", "c", " ", 
     SuperscriptBox["t", "4"]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["t", "2"]}], "+", 
        RowBox[{"2", " ", "x"}], "-", 
        RowBox[{"a", " ", "x"}], "-", 
        RowBox[{"b", " ", "x"}], "-", 
        RowBox[{"a", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}]}], ")"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["x", 
          SubscriptBox["XX", "2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["x", 
          SubscriptBox["XX", "3"]]}], ")"}]}]]], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", "x", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7603919433663273`*^9, 3.76039203582508*^9, 
  3.760395457030344*^9, 3.760655853604464*^9, 3.76066110135286*^9, 
  3.7607363793884573`*^9, 3.76081887198285*^9, 3.760820683799686*^9, 
  3.7615229311934958`*^9, 3.7664343935216427`*^9, 3.767664212725822*^9, 
  3.767664951638816*^9, 3.7676652148102093`*^9, 3.7891574665087633`*^9},
 CellLabel->
  "Out[254]=",ExpressionUUID->"0f1898b0-d1db-406c-884e-0997fd5e3cf0"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 20, 20, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.7603919433663273`*^9, 3.76039203582508*^9, 
  3.760395457030344*^9, 3.760655853604464*^9, 3.76066110135286*^9, 
  3.7607363793884573`*^9, 3.76081887198285*^9, 3.760820683799686*^9, 
  3.7615229311934958`*^9, 3.7664343935216427`*^9, 3.767664212725822*^9, 
  3.767664951638816*^9, 3.7676652148102093`*^9, 3.7891574668159237`*^9},
 CellLabel->
  "Out[260]=",ExpressionUUID->"dc6cb440-9490-464c-b2f4-e81d8bdacf3a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "finally", " ", 
    RowBox[{"(", 
     RowBox[{"the", " ", "most", " ", "complicated"}], ")"}], " ", "the", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "0", "d"], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubsuperscriptBox["\[Nu]", "0", "d"], ",", "x"}], "]"}], "]"}],
             "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubsuperscriptBox["\[Nu]", "0", "d"], ",", "x"}], "]"}], "]"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CoefficientList", "[", 
     RowBox[{"%", ",", "x"}], "]"}], "*", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"x", "^", "n"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{"%", ",", "x"}], "]"}], "]"}], "-", "1"}]}], "}"}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"because", " ", 
     RowBox[{"I", "'"}], "ve", " ", "symbolised", " ", 
     SubscriptBox["Q", 
      RowBox[{"i", ",", "j"}]], " ", "this", " ", "last", " ", "thing", " ", 
     "has", " ", "to", " ", "be", " ", "done", " ", "manually"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "%", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", ".", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], ",", 
         RowBox[{
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], "/", "x"}]}], ",", 
         RowBox[{
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], "/", "x"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], "/", 
           RowBox[{"x", "^", "2"}]}]}]}], "}"}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"now", " ", "do", " ", "some", " ", "eliminations"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"xposLHS2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"%", "/", "x"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"Q11eqn", "\[Equal]", "0"}], ",", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "1"}]]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q01eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "2"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "/", "x"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"9", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"-", "\[Pi]"}], ")"}]}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], ">", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xposLHS2", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760391960608087*^9, 3.7603919834197187`*^9}, 
   3.7603920416968327`*^9, {3.760392842418928*^9, 3.760392965788568*^9}, {
   3.760392996916305*^9, 3.7603930383270273`*^9}, 3.760393078165422*^9, {
   3.760393174749264*^9, 3.760393260749192*^9}, {3.760393569286069*^9, 
   3.760393578207409*^9}, {3.760395462355057*^9, 3.760395462464364*^9}, {
   3.760395501033441*^9, 3.760395584021368*^9}, {3.760395685322665*^9, 
   3.760395803125942*^9}, {3.760395854778154*^9, 3.760395875275972*^9}, {
   3.7603959356133137`*^9, 3.760395993898451*^9}, {3.7603966228603773`*^9, 
   3.7603968242542477`*^9}, {3.760396897913062*^9, 3.760396898473608*^9}, 
   3.760410832119379*^9, {3.760656046625455*^9, 3.7606560477491217`*^9}, {
   3.760656080881551*^9, 3.7606561000179253`*^9}, {3.760656169367985*^9, 
   3.760656185437459*^9}, {3.761522978830449*^9, 3.761522992642233*^9}, {
   3.767664957104804*^9, 3.7676649654400883`*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"162f7e17-49c4-446d-aaa2-0df2db2dbf53"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b"}], "-", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"]}]}], ")"}], " ", "c", " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"a", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "-", "b", "+", 
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b", " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"]}]}], ")"}], " ", 
       SubscriptBox["XX", "1"]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a"}], ")"}], " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"]}]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "-", "b", "+", 
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", "b", " ", 
          SuperscriptBox["t", "3"]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a"}], ")"}], " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"]}]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["x", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "a"}], ")"}], " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "1"]}]}], ")"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
    SuperscriptBox["t", "2"], " ", 
    SuperscriptBox["x", "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.760393216535561*^9, {3.7603932497583923`*^9, 3.760393265180004*^9}, 
   3.760393578781515*^9, 3.7603955182655687`*^9, 3.760395584736071*^9, 
   3.760395803520356*^9, {3.760395855556259*^9, 3.760395875634178*^9}, {
   3.760395962356127*^9, 3.7603959947010603`*^9}, {3.7603967790416603`*^9, 
   3.7603967942088842`*^9}, 3.760396825711762*^9, 3.7603968997727423`*^9, 
   3.760656109086051*^9, 3.760656187260413*^9, 3.760661101798559*^9, 
   3.760736379864943*^9, 3.7608188727267523`*^9, 3.760820684257782*^9, 
   3.7615229352080317`*^9, {3.761522983375841*^9, 3.761522997516622*^9}, 
   3.766434398370069*^9, 3.767664228163385*^9, 3.767664966652253*^9, 
   3.7676652190064487`*^9, 3.78915746687125*^9},
 CellLabel->
  "Out[262]=",ExpressionUUID->"58da6db1-27b5-4fb5-a1f9-c39b9f976654"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.760393216535561*^9, {3.7603932497583923`*^9, 3.760393265180004*^9}, 
   3.760393578781515*^9, 3.7603955182655687`*^9, 3.760395584736071*^9, 
   3.760395803520356*^9, {3.760395855556259*^9, 3.760395875634178*^9}, {
   3.760395962356127*^9, 3.7603959947010603`*^9}, {3.7603967790416603`*^9, 
   3.7603967942088842`*^9}, 3.760396825711762*^9, 3.7603968997727423`*^9, 
   3.760656109086051*^9, 3.760656187260413*^9, 3.760661101798559*^9, 
   3.760736379864943*^9, 3.7608188727267523`*^9, 3.760820684257782*^9, 
   3.7615229352080317`*^9, {3.761522983375841*^9, 3.761522997516622*^9}, 
   3.766434398370069*^9, 3.767664228163385*^9, 3.767664966652253*^9, 
   3.7676652190064487`*^9, 3.789157466874998*^9},
 CellLabel->
  "Out[263]=",ExpressionUUID->"6f617a6a-3cbd-4027-b602-30ce971b7baf"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "x"], 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["t", "2"], " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "a", "-", "b", "+", 
           RowBox[{"a", " ", "b"}], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b", " ", 
            SuperscriptBox["t", "3"]}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t", " ", 
         SubscriptBox["XX", "1"]}], "+", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SubsuperscriptBox["XX", "1", "2"]}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["x", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "1"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], 
         RowBox[{"c", " ", "t", " ", "x"}]], "+", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["Q", 
             RowBox[{"0", ",", "1"}]]}], " ", "t"}], "-", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"Q", "[", 
             RowBox[{"0", ",", "0"}], "]"}]}], 
           RowBox[{"c", " ", "t"}]]}], 
         RowBox[{"t", " ", 
          SuperscriptBox["x", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], 
         RowBox[{"c", " ", "t", " ", "x"}]], "+", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.760393216535561*^9, {3.7603932497583923`*^9, 3.760393265180004*^9}, 
   3.760393578781515*^9, 3.7603955182655687`*^9, 3.760395584736071*^9, 
   3.760395803520356*^9, {3.760395855556259*^9, 3.760395875634178*^9}, {
   3.760395962356127*^9, 3.7603959947010603`*^9}, {3.7603967790416603`*^9, 
   3.7603967942088842`*^9}, 3.760396825711762*^9, 3.7603968997727423`*^9, 
   3.760656109086051*^9, 3.760656187260413*^9, 3.760661101798559*^9, 
   3.760736379864943*^9, 3.7608188727267523`*^9, 3.760820684257782*^9, 
   3.7615229352080317`*^9, {3.761522983375841*^9, 3.761522997516622*^9}, 
   3.766434398370069*^9, 3.767664228163385*^9, 3.767664966652253*^9, 
   3.7676652190064487`*^9, 3.789157466878261*^9},
 CellLabel->
  "Out[265]=",ExpressionUUID->"98266772-c334-4e9a-a2c2-2e9b6ea6c768"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760393216535561*^9, {3.7603932497583923`*^9, 3.760393265180004*^9}, 
   3.760393578781515*^9, 3.7603955182655687`*^9, 3.760395584736071*^9, 
   3.760395803520356*^9, {3.760395855556259*^9, 3.760395875634178*^9}, {
   3.760395962356127*^9, 3.7603959947010603`*^9}, {3.7603967790416603`*^9, 
   3.7603967942088842`*^9}, 3.760396825711762*^9, 3.7603968997727423`*^9, 
   3.760656109086051*^9, 3.760656187260413*^9, 3.760661101798559*^9, 
   3.760736379864943*^9, 3.7608188727267523`*^9, 3.760820684257782*^9, 
   3.7615229352080317`*^9, {3.761522983375841*^9, 3.761522997516622*^9}, 
   3.766434398370069*^9, 3.767664228163385*^9, 3.767664966652253*^9, 
   3.7676652190064487`*^9, 3.78915746721533*^9},
 CellLabel->
  "Out[269]=",ExpressionUUID->"4fb938e6-76da-460d-abd6-6ec4d3cb872c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
     "xposRHS2", "+", "xposRHS3", "+", "xposRHS4"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"12", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760393531760351*^9, 3.76039366846852*^9}, {
   3.760396005790112*^9, 3.760396089326351*^9}, 3.760396917182993*^9, {
   3.760656245137339*^9, 3.760656284241452*^9}, {3.760656342531588*^9, 
   3.7606563479055233`*^9}, {3.76152301707904*^9, 3.761523023727178*^9}},
 CellLabel->
  "In[270]:=",ExpressionUUID->"87be7d3e-8795-4ab6-a864-3548011e4637"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"25", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 25, 25, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7603936097285748`*^9, {3.760393644159584*^9, 3.760393669676441*^9}, {
   3.760396024824202*^9, 3.760396077287881*^9}, 3.7603961271729803`*^9, 
   3.760396929864087*^9, {3.760656242993279*^9, 3.760656290921775*^9}, 
   3.760656389703093*^9, 3.760661144027218*^9, 3.760736421769533*^9, 
   3.760818918278948*^9, 3.760820726040636*^9, 3.761522960958288*^9, 
   3.7615230655202627`*^9, 3.766434408823295*^9, 3.767664238352275*^9, 
   3.767665228685051*^9, 3.7891574733846817`*^9},
 CellLabel->
  "Out[272]=",ExpressionUUID->"78e39a14-e0c4-4171-ab70-626007b1e34f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"next", ",", " ", 
   RowBox[{
    RowBox[{"the", " ", "[", 
     RowBox[{
      RowBox[{"x", "^"}], "<"}], "]"}], " ", "part"}]}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.760397294839129*^9, 3.760397322046999*^9}},
 CellLabel->
  "In[273]:=",ExpressionUUID->"cbd03b66-6e54-4e1f-9a6b-b7f57d721af4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"contribution", " ", "from", " ", "the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"x", ",", "0"}], "]"}], " ", "part", " ", "is", " ", "easy"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"xnegLHS1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"x", ",", "0"}]], "/", "x"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["XX", "2"], "+", 
               SubscriptBox["XX", "3"]}], ")"}], " ", "x"}], 
            RowBox[{"2", " ", 
             SubscriptBox["XX", "2"], " ", 
             SubscriptBox["XX", "3"]}]]}], ")"}]}], "]"}], ",", "x", ",", 
       RowBox[{"-", "1"}]}], "]"}], "/", "x"}], "*", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.760397324154114*^9, 3.760397331463633*^9}, {
  3.760656553102316*^9, 3.7606566335073338`*^9}, {3.7615230819934196`*^9, 
  3.761523088810794*^9}},
 CellLabel->
  "In[274]:=",ExpressionUUID->"2c0ea740-e84c-4736-b762-09523cdeb143"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "2"], " ", "c", " ", 
      SuperscriptBox["t", "4"]}]}], ")"}], " ", 
   RowBox[{"Q", "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "x"]], "Output",
 CellChangeTimes->{3.760656635024268*^9, 3.7606611441299543`*^9, 
  3.760736421948532*^9, 3.7608189185258837`*^9, 3.7608207261746492`*^9, 
  3.761523093042984*^9, 3.766434414092392*^9, 3.767664241314233*^9, 
  3.7676652287799797`*^9, 3.78915747346382*^9},
 CellLabel->
  "Out[274]=",ExpressionUUID->"ed8c4ec8-db33-4fd5-9cc2-5532594ee33a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "non"}], "-", 
    RowBox[{"Q", " ", "term"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"\[Mu]", "/", "x"}], "]"}], ",", "x", ",", 
       RowBox[{"-", "1"}]}], "]"}], "/", "x"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{"\[Nu]", ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{"\[Nu]", ",", "x"}], "]"}], "]"}], "-", "1"}]}], 
          "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{"\[Nu]", ",", "x"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS1", "=", 
    RowBox[{"%%", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Nu]", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], "/", 
          "x"}]}], "-", 
        RowBox[{"%", "/", "x"}]}], ")"}], "*", 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]", "+", 
          RowBox[{"\[Nu]", " ", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"xnegRHS1", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760397352786476*^9, 3.760397359701936*^9}, 
   3.760397392935556*^9, {3.760397436982939*^9, 3.7603974534735937`*^9}, {
   3.7603977703981657`*^9, 3.760397864954494*^9}, {3.760410110891878*^9, 
   3.760410190253523*^9}, {3.760410220312467*^9, 3.760410291614792*^9}, {
   3.76065715360323*^9, 3.760657173792128*^9}, {3.760657394022314*^9, 
   3.760657423924028*^9}, {3.760657500800947*^9, 3.7606575051748447`*^9}, {
   3.760657536097733*^9, 3.760657548476571*^9}, {3.76065776624072*^9, 
   3.760657768318964*^9}, {3.7606578265628633`*^9, 3.760657845488748*^9}, {
   3.7606579497659483`*^9, 3.760657957662986*^9}, {3.7676649738006907`*^9, 
   3.767664982630137*^9}},
 CellLabel->
  "In[275]:=",ExpressionUUID->"51dc3cc7-85ea-46ae-9aa3-3455e5a9edd2"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["t", "4"]}], "x"], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["t", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"]}], "+", 
        RowBox[{"a", " ", "x"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "x"}], "+", 
        RowBox[{"b", " ", "x"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "x"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "x"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "3"], " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "t", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "3"]}]}], ")"}], " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         SubscriptBox["XX", "1"], "x"]}]]}], "-", 
     RowBox[{
      FractionBox["1", "x"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", 
         SuperscriptBox["t", "2"], " ", "x"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", 
           SuperscriptBox["a", "2"], "+", "b", "-", 
           RowBox[{"2", " ", "a", " ", "b"}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           SuperscriptBox["b", "2"], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}]}], ")"}], " ", 
         SuperscriptBox["x", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SubscriptBox["XX", "1"], 
            RowBox[{"2", " ", "x"}]]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t", " ", 
         SuperscriptBox["x", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SubscriptBox["XX", "1"], 
            RowBox[{"2", " ", "x"}]], "-", 
           FractionBox[
            SubsuperscriptBox["XX", "1", "2"], 
            RowBox[{"8", " ", 
             SuperscriptBox["x", "2"]}]]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", 
           RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "4"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SubscriptBox["XX", "1"], 
            RowBox[{"2", " ", "x"}]], "-", 
           FractionBox[
            SubsuperscriptBox["XX", "1", "2"], 
            RowBox[{"8", " ", 
             SuperscriptBox["x", "2"]}]], "-", 
           FractionBox[
            SubsuperscriptBox["XX", "1", "3"], 
            RowBox[{"16", " ", 
             SuperscriptBox["x", "3"]}]]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
   
   SqrtBox[
    RowBox[{
     SuperscriptBox["t", "2"], " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]]}]}]], "Output",
 CellChangeTimes->{
  3.760397453739797*^9, 3.7603977774382257`*^9, 3.760397865781007*^9, {
   3.760410191801564*^9, 3.760410291933815*^9}, 3.7606571789289103`*^9, {
   3.760657403070654*^9, 3.760657428300499*^9}, 3.760657505701331*^9, 
   3.7606575513512497`*^9, 3.760657643429577*^9, 3.76065776987079*^9, {
   3.7606578274893713`*^9, 3.760657846795575*^9}, {3.760657952779399*^9, 
   3.760657959381456*^9}, 3.76066114422885*^9, 3.760736422085847*^9, 
   3.7608189186647453`*^9, 3.7608207263032713`*^9, 3.761523098130487*^9, 
   3.7664344157558517`*^9, 3.767664244358419*^9, 3.767664983667604*^9, 
   3.767665228840384*^9, 3.789157473521916*^9},
 CellLabel->
  "Out[277]=",ExpressionUUID->"0f57406e-989c-425b-89e4-f965af71e0a5"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"25", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 25, 25, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760397453739797*^9, 3.7603977774382257`*^9, 3.760397865781007*^9, {
   3.760410191801564*^9, 3.760410291933815*^9}, 3.7606571789289103`*^9, {
   3.760657403070654*^9, 3.760657428300499*^9}, 3.760657505701331*^9, 
   3.7606575513512497`*^9, 3.760657643429577*^9, 3.76065776987079*^9, {
   3.7606578274893713`*^9, 3.760657846795575*^9}, {3.760657952779399*^9, 
   3.760657959381456*^9}, 3.76066114422885*^9, 3.760736422085847*^9, 
   3.7608189186647453`*^9, 3.7608207263032713`*^9, 3.761523098130487*^9, 
   3.7664344157558517`*^9, 3.767664244358419*^9, 3.767664983667604*^9, 
   3.767665228840384*^9, 3.789157473861661*^9},
 CellLabel->
  "Out[281]=",ExpressionUUID->"509afd8b-17b2-410a-9da9-d258c278a9fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"0", ",", "0"}]], "/", "x"}], "]"}], ",", "x", ",", 
       RowBox[{"-", "1"}]}], "]"}], "/", "x"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "0"}]], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubscriptBox["\[Nu]", 
                RowBox[{"0", ",", "0"}]], ",", "x"}], "]"}], "]"}], "-", 
            "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubscriptBox["\[Nu]", 
             RowBox[{"0", ",", "0"}]], ",", "x"}], "]"}], "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"0", ",", "0"}]], " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], "/", 
            "x"}]}], "-", 
          RowBox[{"%", "/", "x"}]}], ")"}], "*", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}]}]}], 
      ")"}], "*", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"0", ",", "0"}]], " ", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xnegRHS2", "/", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760410309967461*^9, 3.760410326287792*^9}, {
   3.760410602466049*^9, 3.760410671708572*^9}, {3.7606579858921127`*^9, 
   3.7606580415549088`*^9}, 3.767664991296131*^9},
 CellLabel->
  "In[282]:=",ExpressionUUID->"20fa6955-d2e6-4496-aeab-ce3a6204a472"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"]}]}], "x"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "c", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
           SuperscriptBox["t", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "c", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", "c", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"a", " ", "x"}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "x"}], "+", 
          RowBox[{"b", " ", "x"}], "-", 
          RowBox[{"2", " ", "a", " ", "b", " ", "x"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", "x"}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "x"}], "+", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", "x"}], "-", 
          RowBox[{"2", " ", "c", " ", "x"}], "+", 
          RowBox[{"2", " ", "a", " ", "c", " ", "x"}], "+", 
          RowBox[{"2", " ", "b", " ", "c", " ", "x"}], "-", 
          RowBox[{"2", " ", "a", " ", "b", " ", "c", " ", "x"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "3"], " ", "x"}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
           SuperscriptBox["t", "3"], " ", "x"}], "-", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", "c", " ", 
           SuperscriptBox["t", "3"], " ", "x"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"], " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}], "-", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "c", " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", "c", " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}], "-", 
          RowBox[{"a", " ", 
           SuperscriptBox["b", "2"], " ", "c", " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "3"]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           SubscriptBox["XX", "1"], "x"]}]]}], "-", 
       RowBox[{
        FractionBox["1", "x"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "c"}], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "c"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
           SuperscriptBox["t", "2"], " ", "x"}], "-", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", 
             SuperscriptBox["a", "2"], "+", "b", "-", 
             RowBox[{"2", " ", "a", " ", "b"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b"}], "-", 
             SuperscriptBox["b", "2"], "+", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "-", 
             RowBox[{"2", " ", "c"}], "+", 
             RowBox[{"2", " ", "a", " ", "c"}], "+", 
             RowBox[{"2", " ", "b", " ", "c"}], "-", 
             RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["t", "3"]}], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
              SuperscriptBox["t", "3"]}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"], " ", "c", " ", 
              SuperscriptBox["t", "3"]}]}], ")"}], " ", 
           SuperscriptBox["x", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox[
              SubscriptBox["XX", "1"], 
              RowBox[{"2", " ", "x"}]]}], ")"}]}], "+", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "c"}], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "c"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", "t", " ", 
           SuperscriptBox["x", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox[
              SubscriptBox["XX", "1"], 
              RowBox[{"2", " ", "x"}]], "-", 
             FractionBox[
              SubsuperscriptBox["XX", "1", "2"], 
              RowBox[{"8", " ", 
               SuperscriptBox["x", "2"]}]]}], ")"}]}], "-", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["b", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "c"}], "-", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", "c"}], "-", 
             RowBox[{"a", " ", 
              SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox[
              SubscriptBox["XX", "1"], 
              RowBox[{"2", " ", "x"}]], "-", 
             FractionBox[
              SubsuperscriptBox["XX", "1", "2"], 
              RowBox[{"8", " ", 
               SuperscriptBox["x", "2"]}]], "-", 
             FractionBox[
              SubsuperscriptBox["XX", "1", "3"], 
              RowBox[{"16", " ", 
               SuperscriptBox["x", "3"]}]]}], ")"}]}]}], ")"}]}]}], ")"}], 
     " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}]]}]}], ")"}], " ", 
  RowBox[{"Q", "[", 
   RowBox[{"0", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.760410661360353*^9, 3.7604106720733213`*^9}, {
   3.760658026615382*^9, 3.760658042189863*^9}, 3.760661144689749*^9, 
   3.76073642257076*^9, 3.760818919164716*^9, 3.7608207267713003`*^9, 
   3.761523100827208*^9, 3.766434419354999*^9, 3.767664249029914*^9, 
   3.767664993669248*^9, 3.7676652338826313`*^9, 3.78915747391713*^9},
 CellLabel->
  "Out[284]=",ExpressionUUID->"7003521c-cc20-422b-bb14-741fc3884ffe"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"25", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 25, 25, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760410661360353*^9, 3.7604106720733213`*^9}, {
   3.760658026615382*^9, 3.760658042189863*^9}, 3.760661144689749*^9, 
   3.76073642257076*^9, 3.760818919164716*^9, 3.7608207267713003`*^9, 
   3.761523100827208*^9, 3.766434419354999*^9, 3.767664249029914*^9, 
   3.767664993669248*^9, 3.7676652338826313`*^9, 3.789157474299406*^9},
 CellLabel->
  "Out[288]=",ExpressionUUID->"f080db58-2807-454e-a980-62bf5d839654"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    SubscriptBox["Q", 
     RowBox[{"0", ",", "1"}]], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"0", ",", "1"}]], "/", "x"}], "]"}], ",", "x", ",", 
       RowBox[{"-", "1"}]}], "]"}], "/", "x"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "1"}]], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubscriptBox["\[Nu]", 
                RowBox[{"0", ",", "1"}]], ",", "x"}], "]"}], "]"}], "-", 
            "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubscriptBox["\[Nu]", 
             RowBox[{"0", ",", "1"}]], ",", "x"}], "]"}], "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS3", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"0", ",", "1"}]], " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], "/", 
            "x"}]}], "-", 
          RowBox[{"%", "/", "x"}]}], ")"}], "*", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}]}]}], 
      ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "1"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"0", ",", "1"}]], " ", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xnegRHS3", "/", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760410680809763*^9, 3.760410724946745*^9}, {
   3.760658057252838*^9, 3.760658079283346*^9}, 3.7676649963584633`*^9},
 CellLabel->
  "In[289]:=",ExpressionUUID->"cda4d6fd-9c09-445f-a2c2-c901ccb2f9d1"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["Q", 
   RowBox[{"0", ",", "1"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", "x", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        SubscriptBox["XX", "1"], "x"]}]]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", "x", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SubscriptBox["XX", "1"], 
        RowBox[{"2", " ", "x"}]]}], ")"}]}]}], ")"}], " ", 
  SqrtBox[
   RowBox[{
    SuperscriptBox["t", "2"], " ", 
    SubscriptBox["XX", "2"], " ", 
    SubscriptBox["XX", "3"]}]]}]], "Output",
 CellChangeTimes->{3.760410727029338*^9, 3.760658079686344*^9, 
  3.760661145200643*^9, 3.760736423097868*^9, 3.7608189197765093`*^9, 
  3.760820727289276*^9, 3.761523103529628*^9, 3.766434421898035*^9, 
  3.767664253425795*^9, 3.767664999001361*^9, 3.767665234415296*^9, 
  3.789157474356161*^9},
 CellLabel->
  "Out[291]=",ExpressionUUID->"b4e2d28c-fbcc-449a-bfb8-601c28dae97e"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 26, 26, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.760410727029338*^9, 3.760658079686344*^9, 
  3.760661145200643*^9, 3.760736423097868*^9, 3.7608189197765093`*^9, 
  3.760820727289276*^9, 3.761523103529628*^9, 3.766434421898035*^9, 
  3.767664253425795*^9, 3.767664999001361*^9, 3.767665234415296*^9, 
  3.78915747459923*^9},
 CellLabel->
  "Out[295]=",ExpressionUUID->"0f5d2fc2-335d-483a-8b33-ecffbfacf848"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    SubscriptBox["Q", 
     RowBox[{"1", ",", "0"}]], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"1", ",", "0"}]], "/", "x"}], "]"}], ",", "x", ",", 
       RowBox[{"-", "1"}]}], "]"}], "/", "x"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"1", ",", "0"}]], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubscriptBox["\[Nu]", 
                RowBox[{"1", ",", "0"}]], ",", "x"}], "]"}], "]"}], "-", 
            "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubscriptBox["\[Nu]", 
             RowBox[{"1", ",", "0"}]], ",", "x"}], "]"}], "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegRHS4", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"1", ",", "0"}]], " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], "/", 
            "x"}]}], "-", 
          RowBox[{"%", "/", "x"}]}], ")"}], "*", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}]}]}], 
      ")"}], "*", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "0"}]], "+", 
          RowBox[{
           SubscriptBox["\[Nu]", 
            RowBox[{"1", ",", "0"}]], " ", 
           RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}]}]}], ")"}], "/", 
        "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xnegRHS4", "/", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["XX", "1"], "\[Rule]", 
          SubscriptBox["X", "1"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "2"], "\[Rule]", 
          SubscriptBox["X", "2"]}], ",", 
         RowBox[{
          SubscriptBox["XX", "3"], "\[Rule]", 
          SubscriptBox["X", "3"]}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "12"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7604107364992456`*^9, 3.760410779532193*^9}, {
   3.760658089260035*^9, 3.7606581164816093`*^9}, 3.767665004818474*^9},
 CellLabel->
  "In[296]:=",ExpressionUUID->"28f07404-2a91-41d2-8de9-ddfc39b92f17"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["Q", 
   RowBox[{"1", ",", "0"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", "x", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        SubscriptBox["XX", "1"], "x"]}]]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
     SuperscriptBox["t", "2"], " ", "x", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SubscriptBox["XX", "1"], 
        RowBox[{"2", " ", "x"}]]}], ")"}]}]}], ")"}], " ", 
  SqrtBox[
   RowBox[{
    SuperscriptBox["t", "2"], " ", 
    SubscriptBox["XX", "2"], " ", 
    SubscriptBox["XX", "3"]}]]}]], "Output",
 CellChangeTimes->{3.760410780298418*^9, 3.760658117581395*^9, 
  3.7606611456308527`*^9, 3.7607364235708313`*^9, 3.760818920263768*^9, 
  3.760820727753201*^9, 3.761523105899613*^9, 3.766434423967655*^9, 
  3.76766425711061*^9, 3.767665005790388*^9, 3.7676652393901*^9, 
  3.7891574746711483`*^9},
 CellLabel->
  "Out[298]=",ExpressionUUID->"52052aca-d238-4d42-9513-e78818b3007c"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "13"],
  SeriesData[$CellContext`t, 0, {}, 26, 26, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.760410780298418*^9, 3.760658117581395*^9, 
  3.7606611456308527`*^9, 3.7607364235708313`*^9, 3.760818920263768*^9, 
  3.760820727753201*^9, 3.761523105899613*^9, 3.766434423967655*^9, 
  3.76766425711061*^9, 3.767665005790388*^9, 3.7676652393901*^9, 
  3.789157474985071*^9},
 CellLabel->
  "Out[302]=",ExpressionUUID->"22e5a6f6-e69c-4e15-a457-7499e6fb908a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}], " ", "term"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "0", "d"], ",", "x"}], "]"}], "*", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"x", "^", "n"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"CoefficientList", "[", 
              RowBox[{
               SubsuperscriptBox["\[Nu]", "0", "d"], ",", "x"}], "]"}], "]"}],
             "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ".", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "Infinity", ",", 
             RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}], "+", 
         RowBox[{
          RowBox[{"O", "[", 
           RowBox[{"x", ",", "Infinity"}], "]"}], "*", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "-", "n"}], ")"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            SubsuperscriptBox["\[Nu]", "0", "d"], ",", "x"}], "]"}], "]"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CoefficientList", "[", 
      RowBox[{
       RowBox[{"%", "/", "x"}], ",", "x"}], "]"}], "*", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"x", "^", "n"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"CoefficientList", "[", 
            RowBox[{
             RowBox[{"%", "/", "x"}], ",", "x"}], "]"}], "]"}], "-", "1"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"because", " ", 
     RowBox[{"I", "'"}], "ve", " ", "symbolised", " ", 
     SubscriptBox["Q", 
      RowBox[{"i", ",", "j"}]], " ", "this", " ", "last", " ", "thing", " ", 
     "has", " ", "to", " ", "be", " ", "done", " ", "manually"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "%", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"%%", ".", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], ",", 
         RowBox[{
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], "/", "x"}]}], ",", 
         RowBox[{
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], "/", "x"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], "/", 
           RowBox[{"x", "^", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], "/", "x"}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], "/", 
           RowBox[{"x", "^", "2"}]}], "+", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"3", ",", "3"}]], "/", 
           RowBox[{"x", "^", "3"}]}]}]}], "}"}]}], ")"}], "*", 
     RowBox[{"Sqrt", "[", 
      SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"now", " ", "do", " ", "some", " ", "eliminations"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"%", "/.", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"Q22eqn", "\[Equal]", "0"}], ",", 
            SubscriptBox["Q", 
             RowBox[{"3", ",", "3"}]]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"Q11eqn", "\[Equal]", "0"}], ",", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"Q00eqn", "\[Equal]", "0"}], ",", 
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"Q10eqn", "\[Equal]", "0"}], ",", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "1"}]]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"Q01eqn", "\[Equal]", "0"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "2"}]]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"xnegLHS2", "=", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
       "x"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "-", "%"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "\[CapitalDelta]", "]"}], "/", "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}], "\[Rule]", 
       RowBox[{"QQdkeval", "[", 
        RowBox[{"9", ",", "0", ",", 
         RowBox[{"1", "/", "x"}]}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", "#", "]"}], "+", 
          RowBox[{"x", "^", "\[Pi]"}], "+", 
          RowBox[{"x", "^", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Exponent", "[", 
            RowBox[{"#", ",", "x"}], "]"}], "<", "0"}], "&"}]}], "]"}], "&"}],
       ",", "%"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"xnegLHS2", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"9", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7604108174614573`*^9, 3.760410837853647*^9}, {
   3.7604109020264473`*^9, 3.760410919137684*^9}, {3.760410953578261*^9, 
   3.76041095940361*^9}, 3.760659632359421*^9, {3.7606597388857193`*^9, 
   3.760659748285784*^9}, 3.760659780165773*^9, {3.7606598735934134`*^9, 
   3.760659897971431*^9}, {3.7606599713475647`*^9, 3.760659979582219*^9}, {
   3.760660020311243*^9, 3.760660122595335*^9}, {3.760660154547467*^9, 
   3.760660256892981*^9}, {3.76066029759616*^9, 3.76066041481356*^9}, {
   3.7606604699290657`*^9, 3.760660496253059*^9}, {3.760660534213482*^9, 
   3.760660619917616*^9}, {3.760660655909298*^9, 3.760660658865781*^9}, {
   3.760660695995735*^9, 3.7606607555615807`*^9}, {3.7606608358340693`*^9, 
   3.760660870111691*^9}, {3.761523111372348*^9, 3.761523119748907*^9}, {
   3.767664836839123*^9, 3.7676648397287807`*^9}},
 CellLabel->
  "In[303]:=",ExpressionUUID->"bb485126-d61a-470b-8d3c-0f64bd7cfe28"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{{3.7604109046031723`*^9, 3.7604109238364773`*^9}, {
   3.760410955914585*^9, 3.760410959932671*^9}, 3.760659633249572*^9, 
   3.760659781946455*^9, {3.76065987562738*^9, 3.760659898634451*^9}, 
   3.760659975291471*^9, 3.760660059670087*^9, 3.760660125506702*^9, 
   3.7606602154202127`*^9, {3.7606603194886627`*^9, 3.760660324789344*^9}, 
   3.7606604198195057`*^9, {3.760660470985333*^9, 3.760660496532563*^9}, {
   3.760660546292976*^9, 3.760660586422605*^9}, 3.760660620385706*^9, 
   3.760660660180884*^9, 3.760660756562436*^9, {3.760660841610236*^9, 
   3.7606608711524057`*^9}, 3.7606611460444*^9, 3.7607364239532633`*^9, 
   3.760818920664757*^9, 3.760820728128397*^9, 3.761523120717616*^9, 
   3.766434426304325*^9, 3.767664270734585*^9, 3.76766484657454*^9, 
   3.767665239795713*^9, 3.78915747504215*^9},
 CellLabel->
  "Out[305]=",ExpressionUUID->"3d9c6cc4-61c6-4cdb-8e67-88c4bcda6203"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubscriptBox["XX", "3"]}]]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b"}], "-", 
           SuperscriptBox["b", "2"], "+", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"]}]}], ")"}], " ", "c", " ", 
         SuperscriptBox["t", "2"]}], "-", 
        RowBox[{"a", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "a", "-", "b", "+", 
           RowBox[{"a", " ", "b"}], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b", " ", 
            SuperscriptBox["t", "3"]}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}]}], ")"}], " ", 
         SubscriptBox["XX", "1"]}], "+", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t", " ", 
         SubsuperscriptBox["XX", "1", "2"]}], "-", 
        RowBox[{
         FractionBox["1", "8"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SubsuperscriptBox["XX", "1", "3"]}]}], ")"}], " ", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "a", "-", "b", "+", 
           RowBox[{"a", " ", "b"}], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", "b", " ", 
            SuperscriptBox["t", "3"]}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["t", "3"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t", " ", 
         SubscriptBox["XX", "1"]}], "+", 
        RowBox[{
         FractionBox["1", "4"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SubsuperscriptBox["XX", "1", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], 
         RowBox[{"c", " ", "t", " ", "x"}]], "+", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", "t"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "1"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["Q", 
             RowBox[{"0", ",", "1"}]]}], " ", "t"}], "-", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"Q", "[", 
             RowBox[{"0", ",", "0"}], "]"}]}], 
           RowBox[{"c", " ", "t"}]]}], 
         RowBox[{"t", " ", 
          SuperscriptBox["x", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], 
         RowBox[{"c", " ", "t", " ", "x"}]], "+", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["x", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["Q", 
             RowBox[{"0", ",", "1"}]]}], " ", "t"}], "-", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"Q", "[", 
             RowBox[{"0", ",", "0"}], "]"}]}], 
           RowBox[{"c", " ", "t"}]]}], 
         RowBox[{"t", " ", 
          SuperscriptBox["x", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}]}], 
         RowBox[{"c", " ", "t", " ", "x"}]], "+", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["Q", 
               RowBox[{"0", ",", "1"}]]}], " ", "t"}], "-", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"1", ",", "0"}]], " ", "t"}], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"Q", "[", 
               RowBox[{"0", ",", "0"}], "]"}]}], 
             RowBox[{"c", " ", "t"}]]}], "t"], "-", 
          FractionBox[
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"1", ",", "0"}]], "-", 
            RowBox[{"a", " ", "t", " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], "a"], "-", 
          FractionBox[
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"0", ",", "1"}]], "-", 
            RowBox[{"b", " ", "t", " ", 
             RowBox[{"Q", "[", 
              RowBox[{"0", ",", "0"}], "]"}]}]}], "b"]}], 
         RowBox[{"t", " ", 
          SuperscriptBox["x", "3"]}]]}], ")"}]}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"2", " ", "a", " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], "+", "x", "-", 
      RowBox[{"a", " ", "x"}], "-", 
      RowBox[{"a", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}], "+", "x", "-", 
      RowBox[{"b", " ", "x"}], "-", 
      RowBox[{"b", " ", "t", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       SubscriptBox["XX", "1"], "x"]}]], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubscriptBox["XX", "3"]}]], " ", 
    RowBox[{
     SubsuperscriptBox["Q", "0", "d"], "[", 
     FractionBox["1", "x"], "]"}]}], "x"]}]], "Output",
 CellChangeTimes->{{3.7604109046031723`*^9, 3.7604109238364773`*^9}, {
   3.760410955914585*^9, 3.760410959932671*^9}, 3.760659633249572*^9, 
   3.760659781946455*^9, {3.76065987562738*^9, 3.760659898634451*^9}, 
   3.760659975291471*^9, 3.760660059670087*^9, 3.760660125506702*^9, 
   3.7606602154202127`*^9, {3.7606603194886627`*^9, 3.760660324789344*^9}, 
   3.7606604198195057`*^9, {3.760660470985333*^9, 3.760660496532563*^9}, {
   3.760660546292976*^9, 3.760660586422605*^9}, 3.760660620385706*^9, 
   3.760660660180884*^9, 3.760660756562436*^9, {3.760660841610236*^9, 
   3.7606608711524057`*^9}, 3.7606611460444*^9, 3.7607364239532633`*^9, 
   3.760818920664757*^9, 3.760820728128397*^9, 3.761523120717616*^9, 
   3.766434426304325*^9, 3.767664270734585*^9, 3.76766484657454*^9, 
   3.767665239795713*^9, 3.789157475046534*^9},
 CellLabel->
  "Out[308]=",ExpressionUUID->"13eec7e1-30ac-4042-98c3-261ac3438a5e"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "9"],
  SeriesData[$CellContext`t, 0, {}, 18, 18, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7604109046031723`*^9, 3.7604109238364773`*^9}, {
   3.760410955914585*^9, 3.760410959932671*^9}, 3.760659633249572*^9, 
   3.760659781946455*^9, {3.76065987562738*^9, 3.760659898634451*^9}, 
   3.760659975291471*^9, 3.760660059670087*^9, 3.760660125506702*^9, 
   3.7606602154202127`*^9, {3.7606603194886627`*^9, 3.760660324789344*^9}, 
   3.7606604198195057`*^9, {3.760660470985333*^9, 3.760660496532563*^9}, {
   3.760660546292976*^9, 3.760660586422605*^9}, 3.760660620385706*^9, 
   3.760660660180884*^9, 3.760660756562436*^9, {3.760660841610236*^9, 
   3.7606608711524057`*^9}, 3.7606611460444*^9, 3.7607364239532633`*^9, 
   3.760818920664757*^9, 3.760820728128397*^9, 3.761523120717616*^9, 
   3.766434426304325*^9, 3.767664270734585*^9, 3.76766484657454*^9, 
   3.767665239795713*^9, 3.789157475619946*^9},
 CellLabel->
  "Out[312]=",ExpressionUUID->"1d54042c-825d-4f7e-b773-55698cc6f04b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
     "xnegRHS2", "+", "xnegRHS3", "+", "xnegRHS4"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"12", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"12", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7606608913294687`*^9, 3.760660954915551*^9}, {
  3.7615231243968687`*^9, 3.76152312910918*^9}},
 CellLabel->
  "In[313]:=",ExpressionUUID->"2507bf1c-3d78-486c-8851-ef348e10ce30"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "12"],
  SeriesData[$CellContext`t, 0, {}, 24, 24, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.760660927502241*^9, 3.7606609571466227`*^9}, 
   3.7606611488254833`*^9, 3.760736426623886*^9, 3.76081892354858*^9, 
   3.7608207307610598`*^9, 3.7615231321204367`*^9, 3.766434432160817*^9, 
   3.767665245623802*^9, 3.789157477391294*^9},
 CellLabel->
  "Out[315]=",ExpressionUUID->"0832da08-1001-45ed-94c4-64ae8346e17e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"constructing", " ", "eqn", " ", 
   RowBox[{"(", "4.41", ")"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7606654566130238`*^9, 3.7606654990104113`*^9}, {
  3.7618854849420347`*^9, 3.7618854855190344`*^9}, {3.78915737355398*^9, 
  3.789157373676866*^9}},
 CellLabel->
  "In[316]:=",ExpressionUUID->"c07cd800-d698-40a4-895e-40a424d182e2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["P", 
   RowBox[{"x", ",", "0"}]], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["t", "2"]}], "+", "x", "-", 
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"a", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"2", " ", "x"}], "-", 
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"b", " ", "x"}], "-", 
     RowBox[{"a", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"x", ",", "0"}]], "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"xposLHS1", ",", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "]"}], "/", 
    SubscriptBox["P", 
     RowBox[{"x", ",", "0"}]]}]}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"and", " ", "then"}], ",", " ", 
    RowBox[{
    "without", " ", "bothering", " ", "to", " ", "try", " ", "simplifying", 
     " ", "anything"}], ","}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"0", ",", "0"}]], "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
      "xposRHS2", "+", "xposRHS3", "+", "xposRHS4"}], ",", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"0", ",", "1"}]], "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
      "xposRHS2", "+", "xposRHS3", "+", "xposRHS4"}], ",", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"1", ",", "0"}]], "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
      "xposRHS2", "+", "xposRHS3", "+", "xposRHS4"}], ",", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "xposLHS1"}], "-", "xposLHS2", "+", "xposRHS1", "+", 
       "xposRHS2", "+", "xposRHS3", "+", "xposRHS4"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]}], ")"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"check", " ", "it"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Sigma]", 
        RowBox[{"x", ",", "0"}]]}], 
      SubscriptBox["P", 
       RowBox[{"x", ",", "0"}]], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", "\[Sigma]", "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", 
       RowBox[{"0", ",", "0"}]], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", 
       RowBox[{"0", ",", "1"}]], "*", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["\[Sigma]", 
       RowBox[{"1", ",", "0"}]], "*", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["XX", "1"], "\[Rule]", 
       SubscriptBox["X", "1"]}], ",", 
      RowBox[{
       SubscriptBox["XX", "2"], "\[Rule]", 
       SubscriptBox["X", "2"]}], ",", 
      RowBox[{
       SubscriptBox["XX", "3"], "\[Rule]", 
       SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcy", "[", 
       RowBox[{"9", ",", "0"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]], "\[Rule]", 
      RowBox[{"QQcxy", "[", 
       RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.760661914089325*^9, 3.760661972642641*^9}, {
   3.760663490021769*^9, 3.760663516234123*^9}, {3.760665560809985*^9, 
   3.760665562980217*^9}, {3.7606655949896917`*^9, 3.760665708301837*^9}, 
   3.760665787517508*^9, {3.760665822876391*^9, 3.760665857031393*^9}, {
   3.760666114285017*^9, 3.760666144283123*^9}, {3.760666398081089*^9, 
   3.760666400026476*^9}, {3.760666888663582*^9, 3.7606668982706347`*^9}, {
   3.7606669676971188`*^9, 3.760667024049556*^9}, {3.760667070773574*^9, 
   3.760667251202286*^9}, {3.760667301203814*^9, 3.7606673021954927`*^9}, {
   3.760667351594449*^9, 3.760667359355794*^9}, {3.760667418804997*^9, 
   3.76066742818563*^9}, {3.76066769571033*^9, 3.760667734016201*^9}, {
   3.760667965054516*^9, 3.760667968608026*^9}, {3.76066815777208*^9, 
   3.760668173913146*^9}, {3.761523179496207*^9, 3.761523278002627*^9}},
 CellLabel->
  "In[317]:=",ExpressionUUID->"432f3052-5b3c-4479-a9ae-7c9d88eebcfb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["t", "2"]}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"2", " ", "x"}], "-", 
    RowBox[{"a", " ", "x"}], "-", 
    RowBox[{"b", " ", "x"}], "-", 
    RowBox[{"a", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{"b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", "t", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.7606619157987823`*^9, 3.760661973091557*^9}, {
   3.760663492461084*^9, 3.760663516598781*^9}, 3.760665563613274*^9, 
   3.760665632066753*^9, {3.760665694321403*^9, 3.760665708691963*^9}, 
   3.760665787956202*^9, 3.7606658608069353`*^9, 3.760666146061655*^9, 
   3.760666400527484*^9, {3.760667126480445*^9, 3.760667139499192*^9}, {
   3.760667233329446*^9, 3.760667254935902*^9}, 3.76066730309158*^9, 
   3.760667370273609*^9, 3.760667429142804*^9, 3.760667736690793*^9, 
   3.760667970986117*^9, 3.760668178361348*^9, 3.7607364267854652`*^9, 
   3.7608189237443237`*^9, 3.7608207308971643`*^9, 3.761523285375025*^9, 
   3.76643443596229*^9, 3.767665248515296*^9, 3.78915747751746*^9},
 CellLabel->
  "Out[317]=",ExpressionUUID->"50c9c690-587f-4009-8f28-6e57567dd76e"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "b", "+", 
      RowBox[{"b", " ", "t", " ", "x"}]}], ")"}]}], 
   RowBox[{"x", " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", 
         SubscriptBox["XX", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", 
         SubscriptBox["XX", "3"]}], ")"}]}], 
      RowBox[{
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}]]]}]]}]], "Output",
 CellChangeTimes->{{3.7606619157987823`*^9, 3.760661973091557*^9}, {
   3.760663492461084*^9, 3.760663516598781*^9}, 3.760665563613274*^9, 
   3.760665632066753*^9, {3.760665694321403*^9, 3.760665708691963*^9}, 
   3.760665787956202*^9, 3.7606658608069353`*^9, 3.760666146061655*^9, 
   3.760666400527484*^9, {3.760667126480445*^9, 3.760667139499192*^9}, {
   3.760667233329446*^9, 3.760667254935902*^9}, 3.76066730309158*^9, 
   3.760667370273609*^9, 3.760667429142804*^9, 3.760667736690793*^9, 
   3.760667970986117*^9, 3.760668178361348*^9, 3.7607364267854652`*^9, 
   3.7608189237443237`*^9, 3.7608207308971643`*^9, 3.761523285375025*^9, 
   3.76643443596229*^9, 3.767665248515296*^9, 3.789157477571954*^9},
 CellLabel->
  "Out[318]=",ExpressionUUID->"77143e5f-0b0f-4cc0-82d5-5e72ebf4f286"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7606619157987823`*^9, 3.760661973091557*^9}, {
   3.760663492461084*^9, 3.760663516598781*^9}, 3.760665563613274*^9, 
   3.760665632066753*^9, {3.760665694321403*^9, 3.760665708691963*^9}, 
   3.760665787956202*^9, 3.7606658608069353`*^9, 3.760666146061655*^9, 
   3.760666400527484*^9, {3.760667126480445*^9, 3.760667139499192*^9}, {
   3.760667233329446*^9, 3.760667254935902*^9}, 3.76066730309158*^9, 
   3.760667370273609*^9, 3.760667429142804*^9, 3.760667736690793*^9, 
   3.760667970986117*^9, 3.760668178361348*^9, 3.7607364267854652`*^9, 
   3.7608189237443237`*^9, 3.7608207308971643`*^9, 3.761523285375025*^9, 
   3.76643443596229*^9, 3.767665248515296*^9, 3.78915751151047*^9},
 CellLabel->
  "Out[323]=",ExpressionUUID->"7523587a-e2b3-4073-9545-2d6410a9f794"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"constructing", " ", "eqn", " ", 
    RowBox[{"(", "4.42", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["P", "0", "d"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"a", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "t"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
       RowBox[{"b", " ", "x"}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubsuperscriptBox["\[Tau]", "0", "d"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xnegLHS2", "/", 
           RowBox[{"x", "^", "3"}]}], "/.", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{"1", "/", "x"}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["Q", "0", "d"], "[", "x", "]"}]}], "]"}], "//", 
       "Factor"}], ")"}], "/", 
     SubsuperscriptBox["P", "0", "d"]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"and", " ", "then"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"0", ",", "0"}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
           "xnegRHS2", "+", "xnegRHS3", "+", "xnegRHS4"}], ")"}], "/", 
         RowBox[{"x", "^", "3"}]}], "/.", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"1", "/", "x"}]}]}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"0", ",", "1"}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
           "xnegRHS2", "+", "xnegRHS3", "+", "xnegRHS4"}], ")"}], "/", 
         RowBox[{"x", "^", "3"}]}], "/.", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"1", "/", "x"}]}]}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", 
      RowBox[{"1", ",", "0"}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
           "xnegRHS2", "+", "xnegRHS3", "+", "xnegRHS4"}], ")"}], "/", 
         RowBox[{"x", "^", "3"}]}], "/.", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"1", "/", "x"}]}]}], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Tau]", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "xnegLHS1"}], "-", "xnegLHS2", "+", "xnegRHS1", "+", 
           "xnegRHS2", "+", "xnegRHS3", "+", "xnegRHS4"}], ")"}], "/", 
         RowBox[{"x", "^", "3"}]}], "/.", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"1", "/", "x"}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubsuperscriptBox["Q", "0", "d"], "[", "x", "]"}], "\[Rule]", 
          "0"}], ",", 
         RowBox[{
          RowBox[{"Q", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"0", ",", "1"}]], "\[Rule]", "0"}], ",", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]}], ")"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["\[Tau]", "0", "d"]}], 
        SubsuperscriptBox["P", "0", "d"], "*", 
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", "x", "]"}]}], "+", "\[Tau]", 
       "+", 
       RowBox[{
        SubscriptBox["\[Tau]", 
         RowBox[{"0", ",", "0"}]], "*", 
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Tau]", 
         RowBox[{"0", ",", "1"}]], "*", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Tau]", 
         RowBox[{"1", ",", "0"}]], "*", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", "x", "]"}], "\[Rule]", 
        RowBox[{"QQdk", "[", 
         RowBox[{"9", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.760667741704624*^9, 3.7606677682621593`*^9}, {
   3.7606682408871927`*^9, 3.760668467950225*^9}, 3.760668537180945*^9, {
   3.760668605704918*^9, 3.760668824861261*^9}, {3.760668867299142*^9, 
   3.760668876747695*^9}, {3.760668929018647*^9, 3.7606689371848*^9}, {
   3.760669022960676*^9, 3.7606690293777514`*^9}, {3.761523346843525*^9, 
   3.761523437979927*^9}, {3.761523471473682*^9, 3.761523480033697*^9}, {
   3.761885491054034*^9, 3.7618854922160344`*^9}, {3.789157375748145*^9, 
   3.789157375820416*^9}},
 CellLabel->
  "In[324]:=",ExpressionUUID->"c6b3cbbb-172d-46bd-867d-a9abaef00a73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", "t"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "t"}], "+", "x", "-", 
    RowBox[{"a", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b"}], " ", "t"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "t"}], "+", "x", "-", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["x", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.760668230965003*^9, 3.76066847225351*^9, 3.760668539031308*^9, {
   3.760668630260077*^9, 3.760668656746482*^9}, 3.760668830221365*^9, 
   3.7606688775022917`*^9, 3.760668937521822*^9, 3.760669030170046*^9, 
   3.7607364787988453`*^9, 3.760818983531913*^9, 3.760820784065996*^9, 
   3.761523444642666*^9, 3.7615234872417994`*^9, 3.766434480318038*^9, 
   3.767665284981369*^9, 3.789157511584262*^9},
 CellLabel->
  "Out[324]=",ExpressionUUID->"46d6f245-1176-4732-8087-2530c5f11714"],

Cell[BoxData[
 RowBox[{"2", " ", "a", " ", "c", " ", 
  SqrtBox[
   RowBox[{"1", "-", 
    RowBox[{"x", " ", 
     SubscriptBox["XX", "1"]}]}]], " ", 
  SqrtBox[
   RowBox[{
    SuperscriptBox["t", "2"], " ", 
    SubscriptBox["XX", "2"], " ", 
    SubscriptBox["XX", "3"]}]]}]], "Output",
 CellChangeTimes->{
  3.760668230965003*^9, 3.76066847225351*^9, 3.760668539031308*^9, {
   3.760668630260077*^9, 3.760668656746482*^9}, 3.760668830221365*^9, 
   3.7606688775022917`*^9, 3.760668937521822*^9, 3.760669030170046*^9, 
   3.7607364787988453`*^9, 3.760818983531913*^9, 3.760820784065996*^9, 
   3.761523444642666*^9, 3.7615234872417994`*^9, 3.766434480318038*^9, 
   3.767665284981369*^9, 3.789157511645537*^9},
 CellLabel->
  "Out[325]=",ExpressionUUID->"8767c64e-f67d-4dcf-9859-bb0438090075"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "9"],
  SeriesData[$CellContext`t, 0, {}, 18, 18, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760668230965003*^9, 3.76066847225351*^9, 3.760668539031308*^9, {
   3.760668630260077*^9, 3.760668656746482*^9}, 3.760668830221365*^9, 
   3.7606688775022917`*^9, 3.760668937521822*^9, 3.760669030170046*^9, 
   3.7607364787988453`*^9, 3.760818983531913*^9, 3.760820784065996*^9, 
   3.761523444642666*^9, 3.7615234872417994`*^9, 3.766434480318038*^9, 
   3.767665284981369*^9, 3.789157545665597*^9},
 CellLabel->
  "Out[330]=",ExpressionUUID->"b65cd82e-50ab-40cc-81ab-557987b002e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "kernel", " ", "roots", " ", "in", " ", 
     RowBox[{"(", "4.45", ")"}]}], "-", 
    RowBox[{"(", "4.46", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], 
            RowBox[{"a", "^", "4"}], 
            RowBox[{"t", "^", "3"}]}], "+", 
           RowBox[{"4", 
            RowBox[{"a", "^", "3"}], 
            RowBox[{"t", "^", "3"}]}], "+", 
           RowBox[{"a", "^", "2"}], "-", 
           RowBox[{"2", "a"}], "+", "1"}], "]"}]}], "+", "a", "-", "1"}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "a", " ", "t", 
        RowBox[{"(", 
         RowBox[{"a", "-", "1"}], ")"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], 
           RowBox[{"a", "^", "4"}], 
           RowBox[{"t", "^", "3"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"a", "^", "3"}], 
           RowBox[{"t", "^", "3"}]}], "+", 
          RowBox[{"a", "^", "2"}], "-", 
          RowBox[{"2", "a"}], "+", "1"}], "]"}], "+", "a", "-", "1"}], ")"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{"2", "a", " ", "t", 
        RowBox[{"(", 
         RowBox[{"a", "-", "1"}], ")"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "3"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "2"}], ")"}], "^", "2"}], "-", 
           RowBox[{"8", "a", " ", "b", " ", 
            RowBox[{"t", "^", "3"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "a", " ", "b"}], "-", "a", "-", "b"}], 
             ")"}]}]}], "]"}]}], "+", "a", "+", "b", "-", "2"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "t", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "b"}], "-", "a", "-", "b"}], ")"}]}], 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "4"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "2"}], ")"}], "^", "2"}], "-", 
          RowBox[{"8", "a", " ", "b", " ", 
           RowBox[{"t", "^", "3"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "a", " ", "b"}], "-", "a", "-", "b"}], 
            ")"}]}]}], "]"}], "+", "a", "+", "b", "-", "2"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "t", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "b"}], "-", "a", "-", "b"}], ")"}]}], 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"so", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "1"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "2"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "3"]}]}], ",", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"x", ",", "0"}]], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "4"]}]}]}], "}"}], "//", "Simplify"}]}]}]], "Input",\

 CellChangeTimes->{{3.760670284757852*^9, 3.7606704510678253`*^9}, {
  3.7618855086390343`*^9, 3.7618855159810343`*^9}, {3.766434556291603*^9, 
  3.766434574583186*^9}, {3.7891573850633307`*^9, 3.789157387998266*^9}},
 CellLabel->
  "In[331]:=",ExpressionUUID->"f7479f8d-84dc-4c34-95ea-35397f1ff31b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.760670434670352*^9, 3.7607365184932632`*^9, 
  3.7608190303656883`*^9, 3.760820825190151*^9, 3.7615236166076612`*^9, 
  3.766434538613419*^9, 3.766434577424263*^9, 3.767665319416582*^9, 
  3.789157545873541*^9},
 CellLabel->
  "Out[335]=",ExpressionUUID->"7a4d2891-318d-48a9-9830-9b5b32c81c24"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "kernel", " ", "roots", " ", "in", " ", 
     RowBox[{"(", "4.47", ")"}]}], "-", 
    RowBox[{"(", "4.48", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "5"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], 
            RowBox[{"a", "^", "4"}], 
            RowBox[{"t", "^", "3"}]}], "+", 
           RowBox[{"4", 
            RowBox[{"a", "^", "3"}], 
            RowBox[{"t", "^", "3"}]}], "+", 
           RowBox[{"a", "^", "2"}], "-", 
           RowBox[{"2", "a"}], "+", "1"}], "]"}]}], "+", "a", "-", "1"}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"a", "^", "2"}], 
        RowBox[{"t", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "6"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], 
           RowBox[{"a", "^", "4"}], 
           RowBox[{"t", "^", "3"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"a", "^", "3"}], 
           RowBox[{"t", "^", "3"}]}], "+", 
          RowBox[{"a", "^", "2"}], "-", 
          RowBox[{"2", "a"}], "+", "1"}], "]"}], "+", "a", "-", "1"}], ")"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"a", "^", "2"}], 
        RowBox[{"t", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "7"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], 
            RowBox[{"b", "^", "4"}], 
            RowBox[{"t", "^", "3"}]}], "+", 
           RowBox[{"4", 
            RowBox[{"b", "^", "3"}], 
            RowBox[{"t", "^", "3"}]}], "+", 
           RowBox[{"b", "^", "2"}], "-", 
           RowBox[{"2", "b"}], "+", "1"}], "]"}]}], "+", "b", "-", "1"}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"b", "^", "2"}], 
        RowBox[{"t", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "8"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], 
           RowBox[{"b", "^", "4"}], 
           RowBox[{"t", "^", "3"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"b", "^", "3"}], 
           RowBox[{"t", "^", "3"}]}], "+", 
          RowBox[{"b", "^", "2"}], "-", 
          RowBox[{"2", "b"}], "+", "1"}], "]"}], "+", "b", "-", "1"}], ")"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{"2", 
        RowBox[{"b", "^", "2"}], 
        RowBox[{"t", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"so", " ", "that"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "5"]}]}], ",", 
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "6"]}]}], ",", 
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "7"]}]}], ",", 
      RowBox[{
       SubsuperscriptBox["P", "0", "d"], "/.", 
       RowBox[{"x", "\[Rule]", 
        SubscriptBox["x", "8"]}]}]}], "}"}], "//", "Simplify"}]}]}]], "Input",\

 CellChangeTimes->{{3.7606704400472097`*^9, 3.7606705765095797`*^9}, {
  3.7618855246970344`*^9, 3.7618855273670344`*^9}, {3.766434585135757*^9, 
  3.7664346095488243`*^9}, {3.789157393062194*^9, 3.789157396278015*^9}},
 CellLabel->
  "In[336]:=",ExpressionUUID->"a7d1f233-bc1d-43f8-b5d6-baf676503312"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7606705768586197`*^9, 3.76073651863617*^9, 
  3.760819030512412*^9, 3.760820825327614*^9, 3.76152361830266*^9, 
  3.766434610474452*^9, 3.767665319561903*^9, 3.789157545977415*^9},
 CellLabel->
  "Out[340]=",ExpressionUUID->"2801d0e8-7530-4b90-b238-36d60ca22f02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "verifying", " ", "which", " ", "terms", " ", "are", " ", 
    "power", " ", "series"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "which", " ", "one", " ", "of", " ", "these", " ", "is", " ", "a", " ", 
    "power", " ", "series", " ", "depends", " ", "on", " ", "the", " ", 
    "sign", " ", "of", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "1"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["x", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "2"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "which", " ", "one", " ", "of", " ", "these", " ", "is", " ", "a", " ", 
     "power", " ", "series", " ", "depends", " ", "on", " ", "the", " ", 
     "sign", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "-", "2"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "3"], ",", 
       SubscriptBox["x", "4"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "2"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "which", " ", "one", " ", "of", " ", "these", " ", "is", " ", "a", " ", 
     "power", " ", "series", " ", "depends", " ", "on", " ", "the", " ", 
     "sign", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "1"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "5"], ",", 
       SubscriptBox["x", "6"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "which", " ", "one", " ", "of", " ", "these", " ", "is", " ", "a", " ", 
     "power", " ", "series", " ", "depends", " ", "on", " ", "the", " ", 
     "sign", " ", "of", " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "1"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "7"], ",", 
       SubscriptBox["x", "8"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.760670647841227*^9, 3.7606708031567497`*^9}, {
  3.766434616321341*^9, 3.766434631137953*^9}},
 CellLabel->
  "In[341]:=",ExpressionUUID->"22707375-f134-4c2b-b4de-802369decf98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", "a"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "t"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "3"],
      SeriesData[$CellContext`t, 0, {}, -1, 3, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 
        2] (-1 + $CellContext`a)^(-1) $CellContext`a^(-1) (-1 - ((-1 + \
$CellContext`a)^2)^Rational[1, 2] + $CellContext`a), 0, 
      0, ((-1 + $CellContext`a)^2)^Rational[-1, 2] $CellContext`a^2}, -1, 3, 
     1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", "a"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "t"}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "3"],
      SeriesData[$CellContext`t, 0, {}, -1, 3, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 
        2] (-1 + $CellContext`a)^(-1) $CellContext`a^(-1) (-1 + ((-1 + \
$CellContext`a)^2)^Rational[1, 2] + $CellContext`a), 0, 
      0, -((-1 + $CellContext`a)^2)^Rational[-1, 2] $CellContext`a^2}, -1, 3, 
     1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.76067066861983*^9, 3.760670711233817*^9}, {
   3.7606707558929377`*^9, 3.7606708045757713`*^9}, 3.7607365187622557`*^9, 
   3.760819030650672*^9, 3.7608208254462967`*^9, 3.761523621114904*^9, 
   3.7664346326999187`*^9, 3.767665331749734*^9, 3.789157546046039*^9},
 CellLabel->
  "Out[341]=",ExpressionUUID->"a8ed9c5f-1488-4c64-ac8a-3afd2688b284"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b", "-", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "2"]]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}]], "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"]}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "3"],
      SeriesData[$CellContext`t, 0, {}, -1, 3, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 2] (-$CellContext`a - $CellContext`b + 
        2 $CellContext`a $CellContext`b)^(-1) (-2 + $CellContext`a + \
$CellContext`b - ((-2 + $CellContext`a + $CellContext`b)^2)^Rational[1, 2]), 
      0, 0, 2 $CellContext`a $CellContext`b ((-2 + $CellContext`a + \
$CellContext`b)^2)^Rational[-1, 2]}, -1, 3, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b", "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "2"]]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "a", " ", "b"}]}], ")"}], " ", "t"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"a", " ", "b"}], ")"}], " ", 
       SuperscriptBox["t", "2"]}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "a", "+", "b"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "3"],
      SeriesData[$CellContext`t, 0, {}, -1, 3, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 2] (-$CellContext`a - $CellContext`b + 
        2 $CellContext`a $CellContext`b)^(-1) (-2 + $CellContext`a + \
$CellContext`b + ((-2 + $CellContext`a + $CellContext`b)^2)^Rational[1, 2]), 
      0, 0, (-2) $CellContext`a $CellContext`b ((-2 + $CellContext`a + \
$CellContext`b)^2)^Rational[-1, 2]}, -1, 3, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.76067066861983*^9, 3.760670711233817*^9}, {
   3.7606707558929377`*^9, 3.7606708045757713`*^9}, 3.7607365187622557`*^9, 
   3.760819030650672*^9, 3.7608208254462967`*^9, 3.761523621114904*^9, 
   3.7664346326999187`*^9, 3.767665331749734*^9, 3.7891575465131817`*^9},
 CellLabel->
  "Out[342]=",ExpressionUUID->"a73189c7-070a-40bf-be92-453bccd933d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", "a"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "t"}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "2"],
      SeriesData[$CellContext`t, 0, {}, -2, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 2] $CellContext`a^(-2) (-1 - ((-1 + $CellContext`a)^2)^
       Rational[1, 2] + $CellContext`a), 0, 
      0, (-1 + $CellContext`a) ((-1 + $CellContext`a)^2)^
       Rational[-1, 2] $CellContext`a}, -2, 2, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]], "+", "a"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "t"}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "2"],
      SeriesData[$CellContext`t, 0, {}, -2, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 2] $CellContext`a^(-2) (-1 + ((-1 + $CellContext`a)^2)^
        Rational[1, 2] + $CellContext`a), 0, 
      0, -(-1 + $CellContext`a) ((-1 + $CellContext`a)^2)^
       Rational[-1, 2] $CellContext`a}, -2, 2, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.76067066861983*^9, 3.760670711233817*^9}, {
   3.7606707558929377`*^9, 3.7606708045757713`*^9}, 3.7607365187622557`*^9, 
   3.760819030650672*^9, 3.7608208254462967`*^9, 3.761523621114904*^9, 
   3.7664346326999187`*^9, 3.767665331749734*^9, 3.7891575465835114`*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"84464e38-d623-441c-9f5d-6dd07b48919f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]], "+", "b"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "t"}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "2"],
      SeriesData[$CellContext`t, 0, {}, -2, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 2] $CellContext`b^(-2) (-1 - ((-1 + $CellContext`b)^2)^
       Rational[1, 2] + $CellContext`b), 0, 
      0, (-1 + $CellContext`b) ((-1 + $CellContext`b)^2)^
       Rational[-1, 2] $CellContext`b}, -2, 2, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]], "+", "b"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "t"}], 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "2"],
      SeriesData[$CellContext`t, 0, {}, -2, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     Rational[1, 2] $CellContext`b^(-2) (-1 + ((-1 + $CellContext`b)^2)^
        Rational[1, 2] + $CellContext`b), 0, 
      0, -(-1 + $CellContext`b) ((-1 + $CellContext`b)^2)^
       Rational[-1, 2] $CellContext`b}, -2, 2, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.76067066861983*^9, 3.760670711233817*^9}, {
   3.7606707558929377`*^9, 3.7606708045757713`*^9}, 3.7607365187622557`*^9, 
   3.760819030650672*^9, 3.7608208254462967`*^9, 3.761523621114904*^9, 
   3.7664346326999187`*^9, 3.767665331749734*^9, 3.78915754658664*^9},
 CellLabel->
  "Out[344]=",ExpressionUUID->"dc854916-22a5-4f48-b95f-3dcf89a1a7df"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"these", " ", "will", " ", "be", " ", "useful"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
     SubscriptBox["xs", "1"], ",", 
     SubscriptBox["xs", "2"], ",", 
     SubscriptBox["xs", "3"], ",", 
     SubscriptBox["xs", "4"], ",", 
     SubscriptBox["xs", "5"], ",", 
     SubscriptBox["xs", "6"], ",", 
     SubscriptBox["xs", "7"], ",", 
     SubscriptBox["xs", "8"], ",", 
     SubscriptBox["Xs", "1"], ",", 
     SubscriptBox["Xs", "2"], ",", 
     SubscriptBox["Xs", "3"]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "1"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "1"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"a", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "2"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "2"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "a", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "2"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "3"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "3"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{
             RowBox[{"a", "+", "b"}], ">", "2"}]}]}], "]"}], "]"}], "&"}], 
       ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "3"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "4"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "4"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", 
             RowBox[{"a", "+", "b"}], "<", "2"}]}]}], "]"}], "]"}], "&"}], 
       ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "4"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "5"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "5"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"a", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "5"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "6"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "6"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "a", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "6"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "7"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "7"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"b", ">", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "7"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["xs", "8"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["xs", "8"], "[", "n", "]"}], "=", 
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Factor", "[", 
         RowBox[{"Simplify", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"0", "<", "b", "<", "1"}]}]}], "]"}], "]"}], "&"}], ",", 
       RowBox[{"Series", "[", 
        RowBox[{
         SubscriptBox["x", "8"], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Xs", "1"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["Xs", "1"], "[", "n", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["X", "1"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Xs", "2"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["Xs", "2"], "[", "n", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["X", "2"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Xs", "3"], "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["Xs", "3"], "[", "n", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       SubscriptBox["X", "3"], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.760742281773918*^9, 3.7607422994181223`*^9}, {
  3.7607423710051517`*^9, 3.760742407500828*^9}, {3.760742506606189*^9, 
  3.7607425333471317`*^9}, {3.7607425908038588`*^9, 3.76074259389769*^9}, {
  3.760742668757835*^9, 3.760742719743451*^9}, {3.76074276245074*^9, 
  3.7607428531685553`*^9}, {3.760820287704018*^9, 3.760820365632689*^9}, {
  3.761348691430297*^9, 3.7613486969227333`*^9}, {3.761359411169044*^9, 
  3.7613594201966553`*^9}, {3.766434639136977*^9, 3.7664347211962852`*^9}},
 CellLabel->
  "In[345]:=",ExpressionUUID->"b09d6e70-f8e3-4538-9f09-a261e57f811b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "we", " ", "can", " ", "evaluate", " ", "the", " ", 
    "coefficients", " ", "in", " ", 
    RowBox[{"(", "4.41", ")"}], " ", "and", " ", 
    RowBox[{"(", "4.42", ")"}], " ", "after", " ", "cancelling", " ", "the", 
    " ", "kernels"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"this", " ", "gives", " ", "the", " ", 
    SuperscriptBox["\[Zeta]", 
     RowBox[{"(", "i", ")"}]], " ", "coefficients", " ", "in", " ", 
    RowBox[{"(", "4.49", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"Hx1", ",", "Hx3", ",", "Hx5", ",", "Hx7"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hx1", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"Hx1", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ApplyToSeries", "[", 
          RowBox[{"Simplify", ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Sigma]", ",", 
             SubscriptBox["\[Sigma]", 
              RowBox[{"0", ",", "0"}]], ",", 
             SubscriptBox["\[Sigma]", 
              RowBox[{"0", ",", "1"}]], ",", 
             SubscriptBox["\[Sigma]", 
              RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["XX", "1"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "2"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "3"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "/.", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{
            SubscriptBox["xs", "1"], "[", "n", "]"}]}]}], ")"}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hx3", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"Hx3", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ApplyToSeries", "[", 
          RowBox[{"Simplify", ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Sigma]", ",", 
             SubscriptBox["\[Sigma]", 
              RowBox[{"0", ",", "0"}]], ",", 
             SubscriptBox["\[Sigma]", 
              RowBox[{"0", ",", "1"}]], ",", 
             SubscriptBox["\[Sigma]", 
              RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["XX", "1"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "2"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "3"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "/.", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{
            SubscriptBox["xs", "3"], "[", "n", "]"}]}]}], ")"}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hx5", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"Hx5", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ApplyToSeries", "[", 
          RowBox[{"Simplify", ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Tau]", ",", 
             SubscriptBox["\[Tau]", 
              RowBox[{"0", ",", "0"}]], ",", 
             SubscriptBox["\[Tau]", 
              RowBox[{"0", ",", "1"}]], ",", 
             SubscriptBox["\[Tau]", 
              RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["XX", "1"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "2"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "3"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "/.", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{
            SubscriptBox["xs", "5"], "[", "n", "]"}]}]}], ")"}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hx7", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"Hx7", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ApplyToSeries", "[", 
          RowBox[{"Simplify", ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Tau]", ",", 
             SubscriptBox["\[Tau]", 
              RowBox[{"0", ",", "0"}]], ",", 
             SubscriptBox["\[Tau]", 
              RowBox[{"0", ",", "1"}]], ",", 
             SubscriptBox["\[Tau]", 
              RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["XX", "1"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "2"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
             RowBox[{
              SubscriptBox["XX", "3"], "\[Rule]", 
              RowBox[{
               SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], "/.", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{
            SubscriptBox["xs", "7"], "[", "n", "]"}]}]}], ")"}]}], 
       ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"the", " ", "leading", " ", "order", " ", "terms"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", "#"}], "]"}], "&"}], "/@", 
    RowBox[{"Hx1", "[", "3", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", "#"}], "]"}], "&"}], "/@", 
    RowBox[{"Hx3", "[", "3", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", "#"}], "]"}], "&"}], "/@", 
    RowBox[{"Hx5", "[", "3", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Factor", ",", "#"}], "]"}], "&"}], "/@", 
    RowBox[{"Hx7", "[", "3", "]"}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQzdDouI2b9Y2j3E8fMG1baLEfRG/w5DgOos2ePb8H
ol0y7t0H0RmHjr4D0Xte8r8H0V/TlVl4gHSSZygniG4V1cwD0WFblMpA9Mu/
/dUgetVh/VoQvWXFlwYQ3aDh2wiid9d97ADRTy/LdYLoWy8tloPoTVddIfSq
yq0gustj9QEQrVNz9AhYv7TbWRA9I8PuEoi2+L3rMoj+NX2NkQDI3sIeExAd
/3f5dRC96nLTLRD9+gq7sBGQnqAUIAmi36/xlAfRfacV1UC0wG29IBD9LDMo
HkSL/0iusmJ/4yhbeRBMm8atenya/43jnCN7wHSn6fOy50A6tTCgFkTPU3zE
/gpIb+2M4wLRB2cztdhZv3G0CXgLpgGB+qJI
  "],
 CellLabel->
  "In[357]:=",ExpressionUUID->"4042b1db-e0d1-4180-a886-2b4dd14263fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"a", " ", "b"}]}], ")"}], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "4"],
      SeriesData[$CellContext`t, 0, {}, 4, 8, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     2 $CellContext`a^3 (-1 + $CellContext`b) (-1 + $CellContext`a \
$CellContext`b)}, 4, 8, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"a", " ", "b"}]}], ")"}]}], ")"}], " ", 
       SuperscriptBox["t", "2"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "4"],
      SeriesData[$CellContext`t, 0, {}, 4, 8, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) $CellContext`a^3 (-1 + $CellContext`b) (-1 + $CellContext`a \
$CellContext`b)}, 4, 8, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"a", " ", "b"}]}], ")"}], " ", "c", " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 8, 12, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     2 $CellContext`a^3 $CellContext`b (-1 + $CellContext`a $CellContext`b) \
$CellContext`c}, 8, 12, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "+", 
        RowBox[{"a", " ", "b"}]}], ")"}], " ", "c", " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 8, 12, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     2 $CellContext`a^3 (-1 + $CellContext`b) (-$CellContext`a + 
       2 $CellContext`b + $CellContext`a $CellContext`b) $CellContext`c}, 8, 
     12, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.760820826209556*^9, {3.760820888111533*^9, 3.760820895195912*^9}, {
   3.760820958222625*^9, 3.7608209871934834`*^9}, 3.761523634882777*^9, 
   3.7664347978065166`*^9, 3.766440022185699*^9, 3.7676653393609447`*^9, 
   3.7891575473624067`*^9},
 CellLabel->
  "Out[362]=",ExpressionUUID->"ab5cb5d3-9996-44e4-b47b-86c6a9676656"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", 
       SuperscriptBox["t", "2"]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "4"],
      SeriesData[$CellContext`t, 0, {}, 4, 8, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     4 (-1 + $CellContext`a) $CellContext`a^2 (-1 + $CellContext`b) \
$CellContext`b (-2 + $CellContext`a + $CellContext`b)^(-1) (-1 + \
$CellContext`a $CellContext`b)}, 4, 8, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"a", " ", "b"}]}], ")"}]}], ")"}], " ", 
        SuperscriptBox["t", "2"]}], 
       RowBox[{
        RowBox[{"-", "2"}], "+", "a", "+", "b"}]]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "4"],
      SeriesData[$CellContext`t, 0, {}, 4, 8, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-4) (-1 + $CellContext`a) $CellContext`a^2 (-1 + $CellContext`b) \
$CellContext`b (-2 + $CellContext`a + $CellContext`b)^(-1) (-1 + \
$CellContext`a $CellContext`b)}, 4, 8, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "c", " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 8, 12, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     4 (-1 + $CellContext`a) $CellContext`a^2 $CellContext`b^2 (-2 + \
$CellContext`a + $CellContext`b)^(-1) (-1 + $CellContext`a $CellContext`b) \
$CellContext`c}, 8, 12, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", "c", " ", 
       SuperscriptBox["t", "4"]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a", "+", "b"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], "6"],
      SeriesData[$CellContext`t, 0, {}, 8, 12, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     4 $CellContext`a^3 (-1 + $CellContext`b) $CellContext`b (-2 + \
$CellContext`a + $CellContext`b)^(-1) (-1 + $CellContext`a $CellContext`b) \
$CellContext`c}, 8, 12, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.760820826209556*^9, {3.760820888111533*^9, 3.760820895195912*^9}, {
   3.760820958222625*^9, 3.7608209871934834`*^9}, 3.761523634882777*^9, 
   3.7664347978065166`*^9, 3.766440022185699*^9, 3.7676653393609447`*^9, 
   3.7891575479091663`*^9},
 CellLabel->
  "Out[363]=",ExpressionUUID->"e1eb0e08-5296-4c98-9fed-5750103cd2f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"]}], ")"}], " ", 
       SuperscriptBox["t", "2"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"7", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 4, 7, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) (-1 + $CellContext`a) $CellContext`a^5 (-1 + $CellContext`b)^2},
      4, 7, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
      SuperscriptBox["a", "5"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"7", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 4, 7, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     2 (-1 + $CellContext`a) $CellContext`a^5 (-1 + $CellContext`b)^2}, 4, 7, 
     2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c"}], ")"}],
        " ", 
       SuperscriptBox["t", "4"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 8, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) (-1 + $CellContext`a) $CellContext`a^5 (-1 + $CellContext`b) \
$CellContext`b $CellContext`c}, 8, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", 
           RowBox[{"a", " ", "b"}]}], ")"}], " ", "c"}], ")"}], " ", 
       SuperscriptBox["t", "4"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 8, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) (-1 + $CellContext`a) $CellContext`a^4 (-1 + $CellContext`b) \
(-$CellContext`a + $CellContext`b + $CellContext`a $CellContext`b) \
$CellContext`c}, 8, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.760820826209556*^9, {3.760820888111533*^9, 3.760820895195912*^9}, {
   3.760820958222625*^9, 3.7608209871934834`*^9}, 3.761523634882777*^9, 
   3.7664347978065166`*^9, 3.766440022185699*^9, 3.7676653393609447`*^9, 
   3.7891575480975313`*^9},
 CellLabel->
  "Out[364]=",ExpressionUUID->"26085661-6411-4f35-841b-4c2fc6491045"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "4"]}], ")"}], " ", 
       SuperscriptBox["t", "2"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"7", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 4, 7, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) (-1 + $CellContext`a)^2 $CellContext`a (-1 + $CellContext`b) \
$CellContext`b^4}, 4, 7, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["t", "2"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"7", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 4, 7, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     2 (-1 + $CellContext`a)^2 $CellContext`a (-1 + $CellContext`b) \
$CellContext`b^4}, 4, 7, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", 
           RowBox[{"a", " ", "b"}]}], ")"}], " ", "c"}], ")"}], " ", 
       SuperscriptBox["t", "4"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 8, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) (-1 + $CellContext`a) $CellContext`a (-1 + $CellContext`b) \
$CellContext`b^3 ($CellContext`a - $CellContext`b + $CellContext`a \
$CellContext`b) $CellContext`c}, 8, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], ")"}], " ", 
       SuperscriptBox["t", "4"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 8, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {(-2) (-1 + $CellContext`a) $CellContext`a^2 (-1 + $CellContext`b) \
$CellContext`b^4 $CellContext`c}, 8, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.760820826209556*^9, {3.760820888111533*^9, 3.760820895195912*^9}, {
   3.760820958222625*^9, 3.7608209871934834`*^9}, 3.761523634882777*^9, 
   3.7664347978065166`*^9, 3.766440022185699*^9, 3.7676653393609447`*^9, 
   3.789157548252442*^9},
 CellLabel->
  "Out[365]=",ExpressionUUID->"f4bd0cf4-263a-4e86-9478-96a79b592cf5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "indeed", " ", "we", " ", "can", " ", "verify", " ", "that", 
    " ", "cancelling", " ", "the", " ", "kernel", " ", "works"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Hx1", "[", "9", "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
     "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "//", "Simplificate"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Hx3", "[", "9", "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
     "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "//", "Simplificate"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Hx5", "[", "9", "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
     "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "//", "Simplificate"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Hx7", "[", "9", "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
     "Simplify"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"%", "//", "Simplificate"}]}]}]], "Input",
 CellChangeTimes->{{3.760744414363662*^9, 3.760744563711501*^9}, {
   3.7607446229526873`*^9, 3.760744636399539*^9}, {3.76074484019632*^9, 
   3.7607448905221167`*^9}, {3.7607449818282537`*^9, 3.760745012090308*^9}, {
   3.760745139682253*^9, 3.7607451401302443`*^9}, {3.760747528370282*^9, 
   3.760747561708284*^9}, {3.760747740338299*^9, 3.760747763738818*^9}, {
   3.760747809967842*^9, 3.760747826381675*^9}, {3.760747921379669*^9, 
   3.7607479448479443`*^9}, {3.760748579276668*^9, 3.760748601460146*^9}, 
   3.760748638960104*^9, {3.760749280722907*^9, 3.760749298160407*^9}, {
   3.760749527409964*^9, 3.760749535277639*^9}, 3.7607496165353937`*^9, {
   3.760749658962483*^9, 3.760749678346841*^9}, {3.760750578823735*^9, 
   3.760750582537833*^9}, {3.760750722463182*^9, 3.7607507255973043`*^9}, {
   3.7607508026949577`*^9, 3.7607508198832703`*^9}, {3.7608210270431767`*^9, 
   3.760821031146443*^9}, {3.760821115350651*^9, 3.760821134258947*^9}, {
   3.766434803997805*^9, 3.766434816001688*^9}, {3.766440025592783*^9, 
   3.7664400278982983`*^9}},
 CellLabel->
  "In[366]:=",ExpressionUUID->"7bd7ab5c-2373-423a-91d4-177d95342ae1"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76074447747757*^9, 3.760744552243555*^9}, 
   3.760744584304029*^9, 3.760744909470624*^9, {3.760744992008959*^9, 
   3.76074501292735*^9}, 3.760745140388043*^9, {3.760747530807474*^9, 
   3.760747563217421*^9}, {3.760747748364929*^9, 3.7607477644317303`*^9}, {
   3.760747811464335*^9, 3.760747828520247*^9}, {3.760747925529011*^9, 
   3.7607479472886753`*^9}, {3.7607485825021467`*^9, 3.760748602278854*^9}, 
   3.760748639275374*^9, 3.760749300107609*^9, {3.760749530063949*^9, 
   3.760749535965897*^9}, 3.760749616861651*^9, 3.760749664457992*^9, 
   3.760749822908197*^9, {3.7607507108893843`*^9, 3.760750731239498*^9}, 
   3.760750823942113*^9, 3.760819142678748*^9, 3.760820833116312*^9, {
   3.7608211086502447`*^9, 3.760821135346813*^9}, 3.761523646708828*^9, 
   3.766434822930093*^9, 3.766440034365423*^9, 3.767665348921399*^9, 
   3.7891575538589373`*^9},
 CellLabel->
  "Out[368]=",ExpressionUUID->"bed9aeaa-4a65-4b1b-9f41-e6333126a8d1"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "10"],
  SeriesData[$CellContext`t, 0, {}, 10, 10, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76074447747757*^9, 3.760744552243555*^9}, 
   3.760744584304029*^9, 3.760744909470624*^9, {3.760744992008959*^9, 
   3.76074501292735*^9}, 3.760745140388043*^9, {3.760747530807474*^9, 
   3.760747563217421*^9}, {3.760747748364929*^9, 3.7607477644317303`*^9}, {
   3.760747811464335*^9, 3.760747828520247*^9}, {3.760747925529011*^9, 
   3.7607479472886753`*^9}, {3.7607485825021467`*^9, 3.760748602278854*^9}, 
   3.760748639275374*^9, 3.760749300107609*^9, {3.760749530063949*^9, 
   3.760749535965897*^9}, 3.760749616861651*^9, 3.760749664457992*^9, 
   3.760749822908197*^9, {3.7607507108893843`*^9, 3.760750731239498*^9}, 
   3.760750823942113*^9, 3.760819142678748*^9, 3.760820833116312*^9, {
   3.7608211086502447`*^9, 3.760821135346813*^9}, 3.761523646708828*^9, 
   3.766434822930093*^9, 3.766440034365423*^9, 3.767665348921399*^9, 
   3.789157567670405*^9},
 CellLabel->
  "Out[371]=",ExpressionUUID->"89a4c0b8-24b6-405f-b9c2-faa5e2c68b7b"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76074447747757*^9, 3.760744552243555*^9}, 
   3.760744584304029*^9, 3.760744909470624*^9, {3.760744992008959*^9, 
   3.76074501292735*^9}, 3.760745140388043*^9, {3.760747530807474*^9, 
   3.760747563217421*^9}, {3.760747748364929*^9, 3.7607477644317303`*^9}, {
   3.760747811464335*^9, 3.760747828520247*^9}, {3.760747925529011*^9, 
   3.7607479472886753`*^9}, {3.7607485825021467`*^9, 3.760748602278854*^9}, 
   3.760748639275374*^9, 3.760749300107609*^9, {3.760749530063949*^9, 
   3.760749535965897*^9}, 3.760749616861651*^9, 3.760749664457992*^9, 
   3.760749822908197*^9, {3.7607507108893843`*^9, 3.760750731239498*^9}, 
   3.760750823942113*^9, 3.760819142678748*^9, 3.760820833116312*^9, {
   3.7608211086502447`*^9, 3.760821135346813*^9}, 3.761523646708828*^9, 
   3.766434822930093*^9, 3.766440034365423*^9, 3.767665348921399*^9, 
   3.789157570946477*^9},
 CellLabel->
  "Out[374]=",ExpressionUUID->"ff3e2bf8-e13e-4b1e-871c-926b45c685de"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76074447747757*^9, 3.760744552243555*^9}, 
   3.760744584304029*^9, 3.760744909470624*^9, {3.760744992008959*^9, 
   3.76074501292735*^9}, 3.760745140388043*^9, {3.760747530807474*^9, 
   3.760747563217421*^9}, {3.760747748364929*^9, 3.7607477644317303`*^9}, {
   3.760747811464335*^9, 3.760747828520247*^9}, {3.760747925529011*^9, 
   3.7607479472886753`*^9}, {3.7607485825021467`*^9, 3.760748602278854*^9}, 
   3.760748639275374*^9, 3.760749300107609*^9, {3.760749530063949*^9, 
   3.760749535965897*^9}, 3.760749616861651*^9, 3.760749664457992*^9, 
   3.760749822908197*^9, {3.7607507108893843`*^9, 3.760750731239498*^9}, 
   3.760750823942113*^9, 3.760819142678748*^9, 3.760820833116312*^9, {
   3.7608211086502447`*^9, 3.760821135346813*^9}, 3.761523646708828*^9, 
   3.766434822930093*^9, 3.766440034365423*^9, 3.767665348921399*^9, 
   3.7891575739334373`*^9},
 CellLabel->
  "Out[377]=",ExpressionUUID->"28a1d37b-5a31-42e6-b874-13edc048ef4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "then", " ", "looking", " ", "at", " ", "the", " ", "coefficient", " ", 
    "matrices"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"which", " ", "combinations", " ", "give", " ", "independent", " ", 
    RowBox[{"equations", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "these", " ", "are", " ", "the", " ", "determinants", " ", "in", " ", 
     "eqns", " ", 
     RowBox[{"(", "4.50", ")"}]}], "-", 
    RowBox[{"(", "4.53", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hx1", "[", "3", "]"}], ",", 
       RowBox[{"Hx3", "[", "3", "]"}], ",", 
       RowBox[{"Hx5", "[", "3", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hx1", "[", "3", "]"}], ",", 
       RowBox[{"Hx3", "[", "3", "]"}], ",", 
       RowBox[{"Hx7", "[", "3", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hx1", "[", "3", "]"}], ",", 
       RowBox[{"Hx5", "[", "3", "]"}], ",", 
       RowBox[{"Hx7", "[", "3", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hx3", "[", "3", "]"}], ",", 
       RowBox[{"Hx5", "[", "3", "]"}], ",", 
       RowBox[{"Hx7", "[", "3", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.760751180081929*^9, 3.760751207400517*^9}, {
  3.760751239048664*^9, 3.760751277647979*^9}, {3.7607513366016607`*^9, 
  3.7607513378380947`*^9}, {3.7607513686988792`*^9, 3.760751435647848*^9}, {
  3.760753141542795*^9, 3.760753154571135*^9}, {3.760821176876627*^9, 
  3.7608212123591423`*^9}, {3.7618862066950345`*^9, 3.761886207134034*^9}, {
  3.766434842833675*^9, 3.76643486827031*^9}, {3.766440032433172*^9, 
  3.766440046111919*^9}, {3.789157443544134*^9, 3.789157447535931*^9}},
 CellLabel->
  "In[378]:=",ExpressionUUID->"fffd93cb-16b4-4591-8f4c-a49ae70a356a"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"23", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 23, 23, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76075131915423*^9, 3.7607513382459183`*^9}, {
   3.760751378428841*^9, 3.760751398181172*^9}, 3.760751437275201*^9, 
   3.760753159280334*^9, 3.760819267950898*^9, 3.760820867572967*^9, {
   3.76082118172154*^9, 3.760821212868287*^9}, 3.7615236714018087`*^9, 
   3.7664348709773827`*^9, 3.76644005391667*^9, 3.7676653849087753`*^9, 
   3.789157574072378*^9},
 CellLabel->
  "Out[379]=",ExpressionUUID->"69357699-0cf2-4b17-99a3-0399d9efb168"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"16", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "a"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"a", " ", "b"}]}], ")"}], " ", 
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["t", "10"]}], 
    RowBox[{
     RowBox[{"-", "2"}], "+", "a", "+", "b"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"23", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 20, 23, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   16 (-2 + $CellContext`a) (-1 + $CellContext`a) $CellContext`a^6 \
($CellContext`a - $CellContext`b)^2 (-1 + $CellContext`b)^2 $CellContext`b^4 \
(-2 + $CellContext`a + $CellContext`b)^(-1) (-1 + $CellContext`a \
$CellContext`b) $CellContext`c^2}, 20, 23, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76075131915423*^9, 3.7607513382459183`*^9}, {
   3.760751378428841*^9, 3.760751398181172*^9}, 3.760751437275201*^9, 
   3.760753159280334*^9, 3.760819267950898*^9, 3.760820867572967*^9, {
   3.76082118172154*^9, 3.760821212868287*^9}, 3.7615236714018087`*^9, 
   3.7664348709773827`*^9, 3.76644005391667*^9, 3.7676653849087753`*^9, 
   3.789157574075407*^9},
 CellLabel->
  "Out[381]=",ExpressionUUID->"619a483b-d75b-4518-9700-19c9a4f16401"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "a", "+", 
         RowBox[{"a", " ", "b"}]}], ")"}], " ", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     SuperscriptBox["t", "10"]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"23", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 20, 23, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-8) (-1 + $CellContext`a)^2 $CellContext`a^8 ($CellContext`a - \
$CellContext`b)^2 (-1 + $CellContext`b)^2 $CellContext`b^3 (
     1 - $CellContext`a + $CellContext`a $CellContext`b) $CellContext`c^2}, 
   20, 23, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76075131915423*^9, 3.7607513382459183`*^9}, {
   3.760751378428841*^9, 3.760751398181172*^9}, 3.760751437275201*^9, 
   3.760753159280334*^9, 3.760819267950898*^9, 3.760820867572967*^9, {
   3.76082118172154*^9, 3.760821212868287*^9}, 3.7615236714018087`*^9, 
   3.7664348709773827`*^9, 3.76644005391667*^9, 3.7676653849087753`*^9, 
   3.789157574084568*^9},
 CellLabel->
  "Out[383]=",ExpressionUUID->"59eb7243-3b19-460f-a7ee-ddf2f7489f10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
        SuperscriptBox["a", "7"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "b"}], ")"}], "2"], " ", 
        SuperscriptBox["b", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"a", " ", "b"}]}], ")"}], " ", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      SuperscriptBox["t", "10"]}], 
     RowBox[{
      RowBox[{"-", "2"}], "+", "a", "+", "b"}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"23", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 20, 23, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-16) (-1 + $CellContext`a)^2 $CellContext`a^7 ($CellContext`a - \
$CellContext`b)^2 (-1 + $CellContext`b)^2 $CellContext`b^4 (-2 + \
$CellContext`a + $CellContext`b)^(-1) (-1 + $CellContext`a $CellContext`b) \
$CellContext`c^2}, 20, 23, 2],
  Editable->False]], "Output",
 CellChangeTimes->{{3.76075131915423*^9, 3.7607513382459183`*^9}, {
   3.760751378428841*^9, 3.760751398181172*^9}, 3.760751437275201*^9, 
   3.760753159280334*^9, 3.760819267950898*^9, 3.760820867572967*^9, {
   3.76082118172154*^9, 3.760821212868287*^9}, 3.7615236714018087`*^9, 
   3.7664348709773827`*^9, 3.76644005391667*^9, 3.7676653849087753`*^9, 
   3.789157574160513*^9},
 CellLabel->
  "Out[385]=",ExpressionUUID->"1f6f50c0-c5fd-415c-9ad3-1fb77f470987"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "try", " ", "the", " ", "first", " ", "one", " ", "again", " ", "with", 
    " ", "higher", " ", "powers"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hx1", "[", "9", "]"}], ",", 
       RowBox[{"Hx3", "[", "9", "]"}], ",", 
       RowBox[{"Hx5", "[", "9", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7607516446515512`*^9, 3.76075167388511*^9}, {
   3.760751810264637*^9, 3.7607518139296923`*^9}, 3.7608212208540792`*^9, {
   3.760821514221114*^9, 3.760821526334985*^9}, {3.766434875594139*^9, 
   3.766434878991818*^9}, {3.766440053066201*^9, 3.7664400592743607`*^9}},
 CellLabel->
  "In[386]:=",ExpressionUUID->"4ef98c10-9f1e-4717-bf71-772e2e9ccf26"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"35", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 35, 35, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.760751750702897*^9, 3.760751911767652*^9, 3.760753237036661*^9, 
   3.7608193347056*^9, 3.7608208703895493`*^9, 3.760821223920889*^9, {
   3.760821518954001*^9, 3.76082152680477*^9}, 3.761523702440489*^9, 
   3.766434879762766*^9, 3.766440060949748*^9, 3.767665390896703*^9, 
   3.789157574263627*^9},
 CellLabel->
  "Out[387]=",ExpressionUUID->"f1e4d5cf-1ead-4d38-8d79-4090ff4fddf3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"finally", ",", " ", 
    RowBox[{
    "verify", " ", "that", " ", "we", " ", "do", " ", "indeed", " ", "get", 
     " ", "a", " ", "solution", " ", "out", " ", "at", " ", "the", " ", 
     "end"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Inverse", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hx1", "[", "9", "]"}], ",", 
           RowBox[{"Hx3", "[", "9", "]"}], ",", 
           RowBox[{"Hx7", "[", "9", "]"}]}], "}"}]}], "]"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Drop", "[", 
            RowBox[{"#", ",", 
             RowBox[{"-", "3"}]}], "]"}]}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hx1", "[", "9", "]"}], ",", 
           RowBox[{"Hx3", "[", "9", "]"}], ",", 
           RowBox[{"Hx7", "[", "9", "]"}]}], "}"}]}], ")"}]}], "//", 
      "Simplify"}], "//", "Flatten"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", "#"}], "]"}], "&"}], "/@", "%"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], ")"}], "-", 
    "%"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Inverse", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hx1", "[", "9", "]"}], ",", 
           RowBox[{"Hx5", "[", "9", "]"}], ",", 
           RowBox[{"Hx7", "[", "9", "]"}]}], "}"}]}], "]"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Drop", "[", 
            RowBox[{"#", ",", 
             RowBox[{"-", "3"}]}], "]"}]}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hx1", "[", "9", "]"}], ",", 
           RowBox[{"Hx5", "[", "9", "]"}], ",", 
           RowBox[{"Hx7", "[", "9", "]"}]}], "}"}]}], ")"}]}], "//", 
      "Simplify"}], "//", "Flatten"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", "#"}], "]"}], "&"}], "/@", "%"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], ")"}], "-", 
    "%"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Inverse", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hx3", "[", "9", "]"}], ",", 
           RowBox[{"Hx5", "[", "9", "]"}], ",", 
           RowBox[{"Hx7", "[", "9", "]"}]}], "}"}]}], "]"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Drop", "[", 
            RowBox[{"#", ",", 
             RowBox[{"-", "3"}]}], "]"}]}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hx3", "[", "9", "]"}], ",", 
           RowBox[{"Hx5", "[", "9", "]"}], ",", 
           RowBox[{"Hx7", "[", "9", "]"}]}], "}"}]}], ")"}]}], "//", 
      "Simplify"}], "//", "Flatten"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ApplyToSeries", "[", 
      RowBox[{"Expand", ",", "#"}], "]"}], "&"}], "/@", "%"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", 
         RowBox[{"QQcxy", "[", 
          RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], ")"}], "-", 
    "%"}]}]}]], "Input",
 CellChangeTimes->{{3.7608193489092493`*^9, 3.760819368029673*^9}, {
  3.7608213237495213`*^9, 3.7608214890893908`*^9}, {3.766434894584828*^9, 
  3.766434941239504*^9}, {3.766440054166226*^9, 3.766440092803833*^9}},
 CellLabel->
  "In[388]:=",ExpressionUUID->"e4039dc9-c9fe-477a-951b-3955153b5f34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      SuperscriptBox["t", "6"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"15", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 0, 15, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, 0, 0, 
      0, $CellContext`a $CellContext`c + $CellContext`b $CellContext`c, 0, 0, 
      0, 0, 0, 2 $CellContext`a $CellContext`c + 
      2 $CellContext`a^2 $CellContext`c + $CellContext`a^3 $CellContext`c + 
      2 $CellContext`b $CellContext`c + 
      2 $CellContext`a $CellContext`b $CellContext`c + 
      2 $CellContext`b^2 $CellContext`c + $CellContext`b^3 $CellContext`c + \
$CellContext`a^2 $CellContext`c^2 + 
      2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2}, 0, 15, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b, 0, 0, 0, 0, 
      0, $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c}, 2, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a, 0, 0, 0, 0, 
      0, $CellContext`a^2 + $CellContext`a^3 + $CellContext`a $CellContext`b + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c}, 2, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.760821331199109*^9, 3.760821368766727*^9, 
  3.760821421064844*^9, 3.760821495273101*^9, 3.761524301138813*^9, 
  3.766434946411483*^9, 3.7664401109722767`*^9, 3.767665397192574*^9, 
  3.78915757721535*^9},
 CellLabel->
  "Out[389]=",ExpressionUUID->"eca7fdfa-880d-4876-89b2-ebfe74c12820"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"15", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 15, 15, 2],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"11", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 11, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"11", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 11, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.760821331199109*^9, 3.760821368766727*^9, 
  3.760821421064844*^9, 3.760821495273101*^9, 3.761524301138813*^9, 
  3.766434946411483*^9, 3.7664401109722767`*^9, 3.767665397192574*^9, 
  3.789157577218704*^9},
 CellLabel->
  "Out[390]=",ExpressionUUID->"a2411aa1-0402-46c4-a190-ad44d65b7a74"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      SuperscriptBox["t", "6"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"15", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 0, 15, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, 0, 0, 
      0, $CellContext`a $CellContext`c + $CellContext`b $CellContext`c, 0, 0, 
      0, 0, 0, 2 $CellContext`a $CellContext`c + 
      2 $CellContext`a^2 $CellContext`c + $CellContext`a^3 $CellContext`c + 
      2 $CellContext`b $CellContext`c + 
      2 $CellContext`a $CellContext`b $CellContext`c + 
      2 $CellContext`b^2 $CellContext`c + $CellContext`b^3 $CellContext`c + \
$CellContext`a^2 $CellContext`c^2 + 
      2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2}, 0, 15, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b, 0, 0, 0, 0, 
      0, $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c}, 2, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a, 0, 0, 0, 0, 
      0, $CellContext`a^2 + $CellContext`a^3 + $CellContext`a $CellContext`b + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c}, 2, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.760821331199109*^9, 3.760821368766727*^9, 
  3.760821421064844*^9, 3.760821495273101*^9, 3.761524301138813*^9, 
  3.766434946411483*^9, 3.7664401109722767`*^9, 3.767665397192574*^9, 
  3.789157578357772*^9},
 CellLabel->
  "Out[392]=",ExpressionUUID->"c9cc199f-1a79-41dc-9c75-7cb4c309e222"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"15", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 15, 15, 2],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"11", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 11, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"11", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 11, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.760821331199109*^9, 3.760821368766727*^9, 
  3.760821421064844*^9, 3.760821495273101*^9, 3.761524301138813*^9, 
  3.766434946411483*^9, 3.7664401109722767`*^9, 3.767665397192574*^9, 
  3.789157578360565*^9},
 CellLabel->
  "Out[393]=",ExpressionUUID->"bb4da3ea-5433-4519-b4d4-b466411b411f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "3"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      SuperscriptBox["t", "6"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"15", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 0, 15, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 0, {
     1, 0, 0, 0, 0, 
      0, $CellContext`a $CellContext`c + $CellContext`b $CellContext`c, 0, 0, 
      0, 0, 0, 2 $CellContext`a $CellContext`c + 
      2 $CellContext`a^2 $CellContext`c + $CellContext`a^3 $CellContext`c + 
      2 $CellContext`b $CellContext`c + 
      2 $CellContext`a $CellContext`b $CellContext`c + 
      2 $CellContext`b^2 $CellContext`c + $CellContext`b^3 $CellContext`c + \
$CellContext`a^2 $CellContext`c^2 + 
      2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2}, 0, 15, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"b", " ", "t"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`b, 0, 0, 0, 0, 
      0, $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c}, 2, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"a", " ", "t"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}]}], ")"}], " ", 
      SuperscriptBox["t", "4"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "t", "]"}], 
       RowBox[{"11", "/", "2"}]],
      SeriesData[$CellContext`t, 0, {}, 2, 11, 2],
      Editable->False]}],
    SeriesData[$CellContext`t, 
     0, {$CellContext`a, 0, 0, 0, 0, 
      0, $CellContext`a^2 + $CellContext`a^3 + $CellContext`a $CellContext`b + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c}, 2, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.760821331199109*^9, 3.760821368766727*^9, 
  3.760821421064844*^9, 3.760821495273101*^9, 3.761524301138813*^9, 
  3.766434946411483*^9, 3.7664401109722767`*^9, 3.767665397192574*^9, 
  3.789157581046721*^9},
 CellLabel->
  "Out[395]=",ExpressionUUID->"4224df7a-ed17-4632-a701-14b25365b71a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"15", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 15, 15, 2],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"11", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 11, 11, 2],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"11", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 11, 11, 2],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.760821331199109*^9, 3.760821368766727*^9, 
  3.760821421064844*^9, 3.760821495273101*^9, 3.761524301138813*^9, 
  3.766434946411483*^9, 3.7664401109722767`*^9, 3.767665397192574*^9, 
  3.7891575810494432`*^9},
 CellLabel->
  "Out[396]=",ExpressionUUID->"9d0fe197-aa13-4792-a7d0-6f4a445d1a80"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4.7",
 FontColor->RGBColor[0, 0, 1]]], "Subtitle",
 CellChangeTimes->{{3.7508253912479973`*^9, 3.750825415520853*^9}, {
  3.7508254976778812`*^9, 3.750825500728297*^9}, {3.7508256112303343`*^9, 
  3.750825672996801*^9}, {3.75082612014727*^9, 3.750826127406416*^9}, {
  3.75970679944136*^9, 3.759706802186184*^9}, {3.766435040961451*^9, 
  3.766435042266073*^9}},ExpressionUUID->"5c8b04b5-73ff-4404-bd11-\
09ee1ebe72a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"constructing", " ", "another", " ", "equation", " ", "using", " ", 
    RowBox[{"the", " ", "[", 
     RowBox[{"x", "^", "0"}], "]"}], " ", "part", " ", "of", " ", "eqn", " ", 
    
    RowBox[{"(", "4.26", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "since", " ", "we", " ", "already", " ", "have", " ", "the", " ", 
     "positive", " ", "and", " ", "negative", " ", "parts"}], ",", " ", 
    RowBox[{
    "we", " ", "can", " ", "just", " ", "subtract", " ", "them", " ", 
     "away"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "LHS"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"x", ",", "0"}]], "/", "x"}], "/", 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"x", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      SubsuperscriptBox["\[Nu]", "0", "d"], 
      RowBox[{"Sqrt", "[", 
       SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
       "x"}], "*", 
      RowBox[{
       SubsuperscriptBox["Q", "0", "d"], "[", 
       FractionBox["1", "x"], "]"}]}], "-", "xposLHS1", "-", "xposLHS2", "-", 
     "xnegLHS1", "-", "xnegLHS2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"x0LHS", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]]}], "}"}], ",", "Factor"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"x", ",", "0"}]], "/", "x"}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"x", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       SubsuperscriptBox["\[Nu]", "0", "d"], 
       RowBox[{"Sqrt", "[", 
        SubscriptBox["\[CapitalDelta]", "m"], "]"}], 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]", "0"], "]"}], "/", "x"}], "*", 
       RowBox[{
        SubsuperscriptBox["Q", "0", "d"], "[", 
        FractionBox["1", "x"], "]"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcy", "[", 
         RowBox[{"9", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Q", "0", "d"], "[", 
         FractionBox["1", "x"], "]"}], "\[Rule]", 
        RowBox[{"QQdkeval", "[", 
         RowBox[{"9", ",", "0", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"#", ",", "x", ",", "0"}], "]"}], "&"}], ",", "%"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x0LHS", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "1"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.766436045181336*^9, 3.766436104175542*^9}, {
   3.76643684204247*^9, 3.766436903434627*^9}, {3.766436953092987*^9, 
   3.7664369533634377`*^9}, {3.7664370103581133`*^9, 
   3.7664370492816133`*^9}, {3.766437306755088*^9, 3.766437350697*^9}, {
   3.7664373879252167`*^9, 3.766437399545309*^9}, {3.766437468813048*^9, 
   3.766437629184125*^9}, {3.7664376604950666`*^9, 3.7664376667819843`*^9}, {
   3.7664377319902477`*^9, 3.766437739176796*^9}, {3.766437780681196*^9, 
   3.7664377918392267`*^9}, 3.766437841667962*^9, {3.789157599339531*^9, 
   3.7891575996977663`*^9}},
 CellLabel->
  "In[397]:=",ExpressionUUID->"b7fb5aab-b668-4856-8856-9e3466baaa7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "b", " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", 
     RowBox[{"2", " ", "a"}], "+", 
     RowBox[{"a", " ", "t", " ", 
      SubscriptBox["XX", "1"]}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["t", "2"], " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "t"}]], 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"8", "-", 
      RowBox[{"16", " ", "a"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"16", " ", "b"}], "+", 
      RowBox[{"32", " ", "a", " ", "b"}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"4", " ", "a", " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "+", 
      RowBox[{"4", " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "-", 
      RowBox[{"12", " ", "a", " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "+", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SubscriptBox["XX", "2"], " ", 
      SubscriptBox["XX", "3"]}]]}]}], "+", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", "t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "3"]}], "-", 
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "+", 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "-", 
     RowBox[{"b", " ", "t", " ", 
      SubscriptBox["XX", "1"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "+", 
     RowBox[{"a", " ", "b", " ", "t", " ", 
      SubscriptBox["XX", "1"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}]}], ")"}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", "t", " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]], 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "5"], " ", 
       SubscriptBox["XX", "2"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "5"], " ", 
       SubscriptBox["XX", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "5"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "5"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"32", " ", "a", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"32", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"80", " ", "a", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"48", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "6"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"16", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"32", " ", "a", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"32", " ", "b", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"64", " ", "a", " ", "b", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"32", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"32", " ", "a", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"48", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"48", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"24", " ", "a", " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", "c", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", "c", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "b", " ", "c", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", "a", " ", "b", " ", "c", " ", "t", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "a", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"a", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.766436849506246*^9, 3.76643695655658*^9, 3.766437050215136*^9, {
   3.7664373399117823`*^9, 3.766437351221661*^9}, 3.7664376301222763`*^9, 
   3.766437667480418*^9, 3.766437742415986*^9, 3.766437794806776*^9, 
   3.766437842265834*^9, 3.7676654463322973`*^9, 3.78915761472675*^9},
 CellLabel->
  "Out[398]=",ExpressionUUID->"e13500de-5def-4039-85c0-c9bafd66878e"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"13", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 13, 13, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.766436849506246*^9, 3.76643695655658*^9, 3.766437050215136*^9, {
   3.7664373399117823`*^9, 3.766437351221661*^9}, 3.7664376301222763`*^9, 
   3.766437667480418*^9, 3.766437742415986*^9, 3.766437794806776*^9, 
   3.766437842265834*^9, 3.7676654463322973`*^9, 3.7891576384171247`*^9},
 CellLabel->
  "Out[402]=",ExpressionUUID->"248314f2-9000-407d-bfbd-557c680da390"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "RHS"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Mu]", "/", "x"}], "/", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "+", 
       RowBox[{"\[Nu]", " ", 
        RowBox[{"Sqrt", "[", 
         SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
         "x"}]}]}], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "0"}]], "/", "x"}], "/", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
          "x"}]}]}], ")"}], "*", 
      RowBox[{"Q", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"0", ",", "1"}]], "/", "x"}], "/", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"0", ",", "1"}]], " ", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
          "x"}]}]}], ")"}], "*", 
      SubscriptBox["Q", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "0"}]], "/", "x"}], "/", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "p"], "]"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Nu]", 
          RowBox[{"1", ",", "0"}]], " ", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "m"], "]"}], 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]\[CapitalDelta]", "0"], "]"}], "/", 
          "x"}]}]}], ")"}], "*", 
      SubscriptBox["Q", 
       RowBox[{"1", ",", "0"}]]}], "-", "xposRHS1", "-", "xposRHS2", "-", 
     "xposRHS3", "-", "xposRHS4", "-", "xnegRHS1", "-", "xnegRHS2", "-", 
     "xnegRHS3", "-", "xnegRHS4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"x0RHS", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], ",", 
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], ",", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]]}], "}"}], ",", "Factor"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Mu]", "/", "x"}], "/", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"Sqrt", "[", 
          SubscriptBox["\[CapitalDelta]", "m"], "]"}], 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "0"], "]"}], "/", "x"}]}]}], ")"}],
       "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"0", ",", "0"}]], "/", "x"}], "/", 
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", 
           RowBox[{"0", ",", "0"}]], " ", 
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "m"], "]"}], 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]", "0"], "]"}], "/", "x"}]}]}], 
        ")"}], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"0", ",", "1"}]], "/", "x"}], "/", 
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", 
           RowBox[{"0", ",", "1"}]], " ", 
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "m"], "]"}], 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]", "0"], "]"}], "/", "x"}]}]}], 
        ")"}], "*", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"1", ",", "0"}]], "/", "x"}], "/", 
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "p"], "]"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", 
           RowBox[{"1", ",", "0"}]], " ", 
          RowBox[{"Sqrt", "[", 
           SubscriptBox["\[CapitalDelta]", "m"], "]"}], 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            SubscriptBox["\[CapitalDelta]", "0"], "]"}], "/", "x"}]}]}], 
        ")"}], "*", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "1"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApplyToSeries", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"#", ",", "x", ",", "0"}], "]"}], "&"}], ",", "%"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x0RHS", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["XX", "1"], "\[Rule]", 
         SubscriptBox["X", "1"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "2"], "\[Rule]", 
         SubscriptBox["X", "2"]}], ",", 
        RowBox[{
         SubscriptBox["XX", "3"], "\[Rule]", 
         SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "0"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"0", ",", "1"}]], "\[Rule]", 
        RowBox[{"QQcxy", "[", 
         RowBox[{"9", ",", "0", ",", "1"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "-", "%%"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.766437866214519*^9, 3.766437869295933*^9}, {
  3.766437922003565*^9, 3.766438246357902*^9}, {3.7664382784227133`*^9, 
  3.766438285294846*^9}},
 CellLabel->
  "In[403]:=",ExpressionUUID->"0b57d267-b3d0-4cba-9fff-a6cf0599a3c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", "a", " ", "b", " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"0", ",", "1"}]], " ", 
   SuperscriptBox["t", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"a", " ", 
      SubscriptBox["XX", "1"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "-", 
     RowBox[{"b", " ", 
      SubscriptBox["XX", "1"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b"}], ")"}], " ", "c", " ", 
   SubscriptBox["Q", 
    RowBox[{"1", ",", "0"}]], " ", 
   SuperscriptBox["t", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "a", " ", "b", " ", 
      SuperscriptBox["t", "2"]}], "+", 
     RowBox[{"a", " ", 
      SubscriptBox["XX", "1"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}], "-", 
     RowBox[{"b", " ", 
      SubscriptBox["XX", "1"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        SubscriptBox["XX", "2"], " ", 
        SubscriptBox["XX", "3"]}]]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]], 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "b", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", "b", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}]}], ")"}]}]}], "-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", 
     SubscriptBox["XX", "2"], " ", 
     SubscriptBox["XX", "3"]}]], 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "2"]}], "-", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "2"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "4"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"32", " ", "a", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"32", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"96", " ", "a", " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "-", 
      RowBox[{"48", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"80", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "5"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "b", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", "b", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "c", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", "a", " ", "c", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", "b", " ", "c", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"16", " ", "a", " ", "b", " ", "c", " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "3"], " ", 
       SubscriptBox["XX", "1"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "c", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "t", " ", 
       SubsuperscriptBox["XX", "1", "2"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", 
       SuperscriptBox["t", "2"], " ", 
       SubsuperscriptBox["XX", "1", "3"], " ", 
       SubscriptBox["XX", "2"], " ", 
       SubscriptBox["XX", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["t", "2"], " ", 
         SubscriptBox["XX", "2"], " ", 
         SubscriptBox["XX", "3"]}]]}]}], ")"}], " ", 
    RowBox[{"Q", "[", 
     RowBox[{"0", ",", "0"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.766438037159005*^9, {3.766438102944976*^9, 3.7664381184943447`*^9}, 
   3.766438246856495*^9, 3.766438287230157*^9, 3.767665469726693*^9, 
   3.7891576385500097`*^9},
 CellLabel->
  "Out[404]=",ExpressionUUID->"70e79096-8b84-4585-ab49-ba32926038d6"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"19", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 19, 19, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.766438037159005*^9, {3.766438102944976*^9, 3.7664381184943447`*^9}, 
   3.766438246856495*^9, 3.766438287230157*^9, 3.767665469726693*^9, 
   3.789157668536332*^9},
 CellLabel->
  "Out[408]=",ExpressionUUID->"1783447b-525c-430c-9742-96a1aa57bda8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"combining", " ", "these"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Upsilon]", 
      RowBox[{"0", ",", "0"}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "x0LHS"}], "+", "x0RHS"}], ",", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Upsilon]", 
      RowBox[{"0", ",", "1"}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "x0LHS"}], "+", "x0RHS"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Upsilon]", 
      RowBox[{"1", ",", "0"}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "x0LHS"}], "+", "x0RHS"}], ",", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Upsilon]", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "x0LHS"}], "+", "x0RHS"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"0", ",", "1"}]], "\[Rule]", "0"}], ",", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"check", " ", "it"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Upsilon]", "+", 
      RowBox[{
       SubscriptBox["\[Upsilon]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Upsilon]", 
        RowBox[{"0", ",", "1"}]], "*", 
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Upsilon]", 
        RowBox[{"1", ",", "0"}]], "*", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["XX", "1"], "\[Rule]", 
        SubscriptBox["X", "1"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "2"], "\[Rule]", 
        SubscriptBox["X", "2"]}], ",", 
       RowBox[{
        SubscriptBox["XX", "3"], "\[Rule]", 
        SubscriptBox["X", "3"]}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"9", ",", "1", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"9", ",", "0", ",", "1"}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.766438568725724*^9, 3.7664386085609703`*^9}, {
  3.766439162149556*^9, 3.766439275304945*^9}},
 CellLabel->
  "In[409]:=",ExpressionUUID->"565907a5-08ed-4d41-88b5-a3cd81f483ea"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "9"],
  SeriesData[$CellContext`t, 0, {}, 18, 18, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.7664393483597107`*^9, 3.7676655719177837`*^9, 
  3.789157743038563*^9},
 CellLabel->
  "Out[413]=",ExpressionUUID->"de2e9cc6-4f7e-4579-8249-dd5950fb06ec"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"give", " ", "it", " ", "a", " ", "name"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "H0", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"H0", "[", "n_", "]"}], ":=", 
    RowBox[{
     RowBox[{"H0", "[", "n", "]"}], "=", 
     RowBox[{"Simplificate", "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ApplyToSeries", "[", 
          RowBox[{"Simplify", ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[Upsilon]", ",", 
            SubscriptBox["\[Upsilon]", 
             RowBox[{"0", ",", "0"}]], ",", 
            SubscriptBox["\[Upsilon]", 
             RowBox[{"0", ",", "1"}]], ",", 
            SubscriptBox["\[Upsilon]", 
             RowBox[{"1", ",", "0"}]]}], "}"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["XX", "1"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "1"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "2"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "2"], "[", "n", "]"}]}], ",", 
            RowBox[{
             SubscriptBox["XX", "3"], "\[Rule]", 
             RowBox[{
              SubscriptBox["Xs", "3"], "[", "n", "]"}]}]}], "}"}]}], ")"}]}], 
       ")"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.7664394370720387`*^9, 3.766439476064068*^9}},
 CellLabel->
  "In[414]:=",ExpressionUUID->"29f77ee4-e43b-43d2-ad2b-b24a4c6aafb4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", "9", "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"Q", "[", 
      RowBox[{"0", ",", "0"}], "]"}], ",", 
     SubscriptBox["Q", 
      RowBox[{"0", ",", "1"}]], ",", 
     SubscriptBox["Q", 
      RowBox[{"1", ",", "0"}]]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"9", ",", "0", ",", "0"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"0", ",", "1"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"9", ",", "0", ",", "1"}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", 
       RowBox[{"QQcxy", "[", 
        RowBox[{"9", ",", "1", ",", "0"}], "]"}]}]}], "}"}]}], "//", 
   "Simplify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "Simplificate"}]}], "Input",
 CellChangeTimes->{{3.766439535149836*^9, 3.766439542451191*^9}},
 CellLabel->
  "In[416]:=",ExpressionUUID->"c229614c-c18a-4735-ba7f-cf4c75e68f6d"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "9"],
  SeriesData[$CellContext`t, 0, {}, 18, 18, 2],
  Editable->False]], "Output",
 CellChangeTimes->{3.7664395442097197`*^9, 3.767665573482758*^9, 
  3.789157744480857*^9},
 CellLabel->
  "Out[418]=",ExpressionUUID->"650ee8a1-f5cb-4ada-a410-a632d3aec94b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "now", " ", "can", " ", "this", " ", "equation", " ", "be", " ", 
    "combined", " ", "with", " ", "any", " ", "of", " ", "the", " ", 
    RowBox[{"others", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H0", "[", "5", "]"}], ",", 
       RowBox[{"Hx1", "[", "5", "]"}], ",", 
       RowBox[{"Hx3", "[", "5", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H0", "[", "5", "]"}], ",", 
       RowBox[{"Hx1", "[", "5", "]"}], ",", 
       RowBox[{"Hx5", "[", "5", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H0", "[", "5", "]"}], ",", 
       RowBox[{"Hx3", "[", "5", "]"}], ",", 
       RowBox[{"Hx5", "[", "5", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H0", "[", "3", "]"}], ",", 
       RowBox[{"Hx1", "[", "3", "]"}], ",", 
       RowBox[{"Hx7", "[", "3", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H0", "[", "5", "]"}], ",", 
       RowBox[{"Hx3", "[", "5", "]"}], ",", 
       RowBox[{"Hx7", "[", "5", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H0", "[", "3", "]"}], ",", 
       RowBox[{"Hx5", "[", "3", "]"}], ",", 
       RowBox[{"Hx7", "[", "3", "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ApplyToSeries", "[", 
    RowBox[{"Factor", ",", 
     RowBox[{"Det", "[", "%", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.766439607353674*^9, 3.766439664999652*^9}, {
  3.766439708887247*^9, 3.766439708912039*^9}, {3.766439750098041*^9, 
  3.766439849176762*^9}, {3.7664400743100433`*^9, 3.766440095650425*^9}},
 CellLabel->
  "In[419]:=",ExpressionUUID->"932f9b74-0d2c-4c0b-8ec5-45367558c7dd"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 22, 22, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7664396528269577`*^9, 3.766439711632601*^9, {3.766439752737754*^9, 
   3.7664398495064287`*^9}, 3.766440117822583*^9, 3.767665575983982*^9, 
   3.789157747045885*^9},
 CellLabel->
  "Out[420]=",ExpressionUUID->"764a566c-8766-4c40-90a1-44e664ed0344"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], 
   RowBox[{"21", "/", "2"}]],
  SeriesData[$CellContext`t, 0, {}, 21, 21, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7664396528269577`*^9, 3.766439711632601*^9, {3.766439752737754*^9, 
   3.7664398495064287`*^9}, 3.766440117822583*^9, 3.767665575983982*^9, 
   3.7891577474596987`*^9},
 CellLabel->
  "Out[422]=",ExpressionUUID->"13a54985-28f6-47a0-85e8-b473a0d2addb"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 22, 22, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7664396528269577`*^9, 3.766439711632601*^9, {3.766439752737754*^9, 
   3.7664398495064287`*^9}, 3.766440117822583*^9, 3.767665575983982*^9, 
   3.789157747553005*^9},
 CellLabel->
  "Out[424]=",ExpressionUUID->"2313c998-1c2a-4f28-beb7-438e9d6d1ebd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "a"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "2"], " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     SuperscriptBox["t", "7"]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"17", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 14, 17, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-8) (-2 + $CellContext`a) (-1 + $CellContext`a)^2 $CellContext`a^5 \
($CellContext`a - $CellContext`b)^2 (-1 + $CellContext`b)^3 $CellContext`b^3 \
$CellContext`c^2}, 14, 17, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7664396528269577`*^9, 3.766439711632601*^9, {3.766439752737754*^9, 
   3.7664398495064287`*^9}, 3.766440117822583*^9, 3.767665575983982*^9, 
   3.789157747639842*^9},
 CellLabel->
  "Out[426]=",ExpressionUUID->"16bd947f-d0ff-4748-a24a-36436646b6bc"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "t", "]"}], "11"],
  SeriesData[$CellContext`t, 0, {}, 22, 22, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7664396528269577`*^9, 3.766439711632601*^9, {3.766439752737754*^9, 
   3.7664398495064287`*^9}, 3.766440117822583*^9, 3.767665575983982*^9, 
   3.789157748438936*^9},
 CellLabel->
  "Out[428]=",ExpressionUUID->"e00a597c-2107-4ffd-998b-2f8ff385dc5a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "a"}], ")"}], "3"], " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "b"}], ")"}], "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     SuperscriptBox["t", "7"]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], 
     RowBox[{"17", "/", "2"}]],
    SeriesData[$CellContext`t, 0, {}, 14, 17, 2],
    Editable->False]}],
  SeriesData[$CellContext`t, 
   0, {(-8) (-1 + $CellContext`a)^3 $CellContext`a^6 ($CellContext`a - \
$CellContext`b)^2 (-1 + $CellContext`b)^3 $CellContext`b^3 $CellContext`c^2}, 
   14, 17, 2],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7664396528269577`*^9, 3.766439711632601*^9, {3.766439752737754*^9, 
   3.7664398495064287`*^9}, 3.766440117822583*^9, 3.767665575983982*^9, 
   3.789157748494083*^9},
 CellLabel->
  "Out[430]=",ExpressionUUID->"faf666af-0295-4398-ad8e-196f4e0443aa"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"yes", " ", "--"}], " ", "it", " ", "can", " ", "be", " ", 
   "combined", " ", "with", " ", 
   RowBox[{"{", 
    RowBox[{"x1", ",", "x7"}], "}"}], " ", "or", " ", 
   RowBox[{"{", 
    RowBox[{"x5", ",", "x7"}], "}"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.76644016499732*^9, 3.7664402020841503`*^9}},
 CellLabel->
  "In[431]:=",ExpressionUUID->"adb17717-f1dd-44ea-bc5a-89a15308d09b"]
}, Closed]]
},
WindowSize->{1105, 1022},
WindowMargins->{{266, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1314, 25, 337, "Subtitle",ExpressionUUID->"14d72825-f42e-4f48-b02c-a94ca9a0fe8b"],
Cell[1897, 49, 571, 14, 86, "Subtitle",ExpressionUUID->"033d1b3b-319e-49c4-b883-d435f74b39b9"],
Cell[2471, 65, 728, 18, 58, "Input",ExpressionUUID->"93f2a60d-9c96-4126-bf9e-d81a4cc4a766"],
Cell[3202, 85, 2617, 70, 127, "Input",ExpressionUUID->"ba04f7f3-d17e-43fa-987c-3ecbcb288fc5"],
Cell[5822, 157, 369, 7, 58, "Input",ExpressionUUID->"c9cc4108-28d4-415c-9411-89cc65beb915"],
Cell[6194, 166, 597, 13, 58, "Input",ExpressionUUID->"23f26057-d002-428b-bb28-74311849e201"],
Cell[6794, 181, 4722, 128, 219, "Input",ExpressionUUID->"ae75d89a-f956-4900-9247-263d60fd5b6f"],
Cell[11519, 311, 9158, 257, 472, "Input",ExpressionUUID->"07755e85-2fbe-4bd1-8355-525bc71e0da1"]
}, Closed]],
Cell[CellGroupData[{
Cell[20714, 573, 403, 7, 58, "Subtitle",ExpressionUUID->"522f812f-0b4e-4546-ba48-2b947d56be60"],
Cell[CellGroupData[{
Cell[21142, 584, 870, 25, 81, "Input",ExpressionUUID->"8c1d9d93-1a37-40d7-bc35-d08a878e76cf"],
Cell[22015, 611, 784, 12, 56, "Output",ExpressionUUID->"fe13d0f8-af97-4ef1-9cc0-bdd088c8cb25"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22836, 628, 2714, 75, 104, "Input",ExpressionUUID->"707f22f9-286f-4364-9fc8-c4e932ceef3b"],
Cell[25553, 705, 863, 15, 38, "Output",ExpressionUUID->"90c3d861-2d31-4548-a958-c8925a549937"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[26465, 726, 500, 8, 58, "Subtitle",ExpressionUUID->"972b950b-4da4-4cdb-8081-8a388c90f089"],
Cell[26968, 736, 1710, 53, 173, "Input",ExpressionUUID->"c3cf040b-d892-4f14-ab1d-e0d95bac45b6"],
Cell[CellGroupData[{
Cell[28703, 793, 2070, 52, 150, "Input",ExpressionUUID->"e632957b-9a16-410d-aaca-eaf944e869b5"],
Cell[30776, 847, 2943, 82, 165, "Output",ExpressionUUID->"95d96a1f-1eb4-4ece-bc02-5e8cb4d5e045"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33756, 934, 3001, 91, 150, "Input",ExpressionUUID->"57331295-609b-454c-b6c2-94afdc70b410"],
Cell[36760, 1027, 1282, 29, 38, "Output",ExpressionUUID->"7eb744f1-9341-4378-a641-fd92b28b5536"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38079, 1061, 937, 24, 58, "Input",ExpressionUUID->"c2621728-4374-46a8-a1d6-325126736a32"],
Cell[39019, 1087, 3693, 109, 103, "Output",ExpressionUUID->"f4bb87f2-0d35-463f-96c0-48e2a07b8e74"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42749, 1201, 336, 7, 58, "Input",ExpressionUUID->"703e1fba-8633-415e-bbae-5af84091b8f2"],
Cell[43088, 1210, 663, 9, 38, "Output",ExpressionUUID->"5344341b-42e6-4631-a1d4-7eef09477b64"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43788, 1224, 1807, 44, 150, "Input",ExpressionUUID->"cd7d8de0-926a-4f9b-b2b5-771a8b26e6a9"],
Cell[45598, 1270, 2841, 77, 97, "Output",ExpressionUUID->"e48c8eff-4f1a-43a4-8866-2887f2afe33f"],
Cell[48442, 1349, 982, 16, 38, "Output",ExpressionUUID->"29d084d7-a3e9-44d8-8850-0bacec442958"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49461, 1370, 668, 15, 81, "Input",ExpressionUUID->"3b0e7789-88b0-452e-a597-24eeef1e0485"],
Cell[50132, 1387, 745, 10, 38, "Output",ExpressionUUID->"8361e65d-a145-4cfb-b2c3-1fd8c4e2d041"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50914, 1402, 1706, 46, 104, "Input",ExpressionUUID->"ff8d3480-a78c-423e-8d52-f6d8cf85e468"],
Cell[52623, 1450, 3054, 89, 122, "Output",ExpressionUUID->"1df98391-26b4-446d-b51d-0dfc69716cfc"],
Cell[55680, 1541, 779, 14, 38, "Output",ExpressionUUID->"89d9e091-c249-476a-9d67-cff71576332c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56496, 1560, 7111, 208, 622, "Input",ExpressionUUID->"458f7cef-70ae-4abe-867d-37743639dfa5"],
Cell[63610, 1770, 1355, 28, 38, "Output",ExpressionUUID->"cf8a72b1-98f3-410b-a327-311503399e72"],
Cell[64968, 1800, 898, 13, 38, "Output",ExpressionUUID->"c26f9d9d-2e94-4fa0-a3e7-32bac95fa4da"],
Cell[65869, 1815, 1335, 28, 57, "Output",ExpressionUUID->"04496db4-2cf7-4889-95eb-da835dfceb96"],
Cell[67207, 1845, 1768, 44, 62, "Output",ExpressionUUID->"8c9f8c9d-a884-449e-ab7b-75b6cb5f3480"],
Cell[68978, 1891, 1400, 31, 57, "Output",ExpressionUUID->"188dcf2b-d7ed-4005-b250-07969671fa97"],
Cell[70381, 1924, 1876, 48, 68, "Output",ExpressionUUID->"9687f417-ab08-49a3-9900-2be5a2965a19"],
Cell[72260, 1974, 1290, 25, 38, "Output",ExpressionUUID->"818e90aa-4ad2-4783-bf79-c2cffce7e9fc"],
Cell[73553, 2001, 898, 13, 38, "Output",ExpressionUUID->"0984cdae-3ac7-4cb1-a19d-b87228588fc3"],
Cell[74454, 2016, 1352, 28, 55, "Output",ExpressionUUID->"0e16a7eb-b89c-450a-9e05-a02a7c14f699"],
Cell[75809, 2046, 1563, 35, 57, "Output",ExpressionUUID->"a32e0800-f64f-44d7-b547-04f78a00e510"],
Cell[77375, 2083, 1305, 26, 55, "Output",ExpressionUUID->"bce14a29-cd59-4766-ad29-28362e764c30"],
Cell[78683, 2111, 1518, 33, 57, "Output",ExpressionUUID->"e56ad07e-5ec4-44ea-ab1d-4dd241f324d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80238, 2149, 2673, 79, 178, "Input",ExpressionUUID->"4b8eb852-02e6-4346-9736-ffc0e02b7acf"],
Cell[82914, 2230, 3531, 105, 170, "Output",ExpressionUUID->"7c91ae20-a35c-4381-9d70-919408bbd9c8"],
Cell[86448, 2337, 838, 15, 38, "Output",ExpressionUUID->"62110827-6c5c-4e46-846a-3367131162a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87323, 2357, 19430, 559, 1086, "Input",ExpressionUUID->"ab2d61b5-314d-444d-97bf-43499c95b5f4"],
Cell[106756, 2918, 1612, 37, 58, "Output",ExpressionUUID->"8458f36c-7442-49f8-917d-699285b50faa"],
Cell[108371, 2957, 1093, 19, 38, "Output",ExpressionUUID->"f0c02078-189b-44c4-9992-f970058b1314"],
Cell[109467, 2978, 1610, 37, 58, "Output",ExpressionUUID->"018d5739-cbb2-4de5-b905-f0a2dd029e41"],
Cell[111080, 3017, 1093, 19, 38, "Output",ExpressionUUID->"1304123a-144f-4cb0-acff-50628f551918"],
Cell[112176, 3038, 2153, 57, 67, "Output",ExpressionUUID->"7537cb4c-05e9-4f2a-b358-96c3b4d33e4a"],
Cell[114332, 3097, 1095, 19, 38, "Output",ExpressionUUID->"97f38f08-77e9-4ca3-b5be-c92970856155"],
Cell[115430, 3118, 1785, 43, 67, "Output",ExpressionUUID->"a5391641-6452-4dfe-a50d-8b16efe38cac"],
Cell[117218, 3163, 1093, 19, 38, "Output",ExpressionUUID->"3ada8f98-b870-48c6-85cc-d922b7eec760"],
Cell[118314, 3184, 1980, 50, 67, "Output",ExpressionUUID->"a6a70f6f-81ef-4006-8b5c-59d7a3c6387f"],
Cell[120297, 3236, 1093, 19, 38, "Output",ExpressionUUID->"5f4ae1b6-8d00-4eba-aa74-0254a4c81f84"],
Cell[121393, 3257, 1219, 24, 41, "Output",ExpressionUUID->"fb28f5ae-a336-48d8-a9b5-b271b26a8611"],
Cell[122615, 3283, 1095, 19, 38, "Output",ExpressionUUID->"f60cfe8d-abe7-41c4-bd80-886c254562a3"],
Cell[123713, 3304, 1217, 24, 41, "Output",ExpressionUUID->"68d72098-2266-4a38-81f0-f0a4a2814ccf"],
Cell[124933, 3330, 1093, 19, 38, "Output",ExpressionUUID->"966b6b5a-4f48-49db-ab88-77cf0099dcb6"],
Cell[126029, 3351, 1118, 20, 41, "Output",ExpressionUUID->"7c8f7dc2-39ec-433e-931c-39335be80e65"],
Cell[127150, 3373, 1092, 19, 38, "Output",ExpressionUUID->"eced1564-5791-448c-aaaa-004b9f985079"],
Cell[128245, 3394, 1272, 27, 41, "Output",ExpressionUUID->"05bbf472-7f96-4d46-834f-dcede3b4f057"],
Cell[129520, 3423, 1093, 19, 38, "Output",ExpressionUUID->"acbc9774-23a1-4bf1-b085-f00b7bad06e5"],
Cell[130616, 3444, 1272, 27, 41, "Output",ExpressionUUID->"26b2a211-4409-4d62-85e1-872354cb3aa6"],
Cell[131891, 3473, 1095, 19, 38, "Output",ExpressionUUID->"6b2fd41f-ac1f-4ffc-8af1-e0a925fb6f19"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133023, 3497, 5190, 146, 401, "Input",ExpressionUUID->"7c2c29f1-33ee-4741-b764-48b23fb4b76d"],
Cell[138216, 3645, 6329, 193, 316, "Output",ExpressionUUID->"a8abe72c-4c4c-4a05-bbe5-0212427a8bc7"],
Cell[144548, 3840, 834, 15, 38, "Output",ExpressionUUID->"6c6066c1-234e-4ae8-9190-872c8ab8afdb"]
}, Open  ]],
Cell[145397, 3858, 484, 11, 58, "Input",ExpressionUUID->"0f1c43bd-7a7d-4e23-a432-5893fd844fad"],
Cell[CellGroupData[{
Cell[145906, 3873, 6570, 197, 464, "Input",ExpressionUUID->"6268ed7a-a61c-4012-aff1-2d823e23c3a5"],
Cell[152479, 4072, 1191, 27, 56, "Output",ExpressionUUID->"78e9ecd0-4c13-4abb-a9d7-bf94d1b31825"],
Cell[153673, 4101, 1008, 20, 56, "Output",ExpressionUUID->"a07859ca-8c4b-4c2e-814b-0a576472512e"],
Cell[154684, 4123, 2396, 63, 106, "Output",ExpressionUUID->"2185b2b9-000b-4635-9f7e-7e122995eb7f"],
Cell[157083, 4188, 1788, 43, 65, "Output",ExpressionUUID->"89d9d6a5-c65a-4e5e-ab35-ab6dc7bba89b"],
Cell[158874, 4233, 1573, 40, 58, "Output",ExpressionUUID->"2330db85-7de5-4cb1-abce-1bc18c07548b"],
Cell[160450, 4275, 2253, 62, 104, "Output",ExpressionUUID->"d72bf9cd-ffee-4323-93cf-429974b17027"],
Cell[162706, 4339, 1571, 40, 58, "Output",ExpressionUUID->"2f94f493-aab2-4341-b630-ceb659bb2376"],
Cell[164280, 4381, 2312, 65, 104, "Output",ExpressionUUID->"63771d43-9213-42cb-b5b3-596664800671"],
Cell[166595, 4448, 1514, 39, 58, "Output",ExpressionUUID->"ae847fda-5b75-44d4-9464-ed160dbe19c7"],
Cell[168112, 4489, 1383, 34, 61, "Output",ExpressionUUID->"16479278-5137-4e61-879f-16ffc495a980"],
Cell[169498, 4525, 1199, 27, 58, "Output",ExpressionUUID->"f0c3c653-5658-4b3f-850c-6d6b90242cf2"],
Cell[170700, 4554, 812, 13, 38, "Output",ExpressionUUID->"cc762039-f295-4082-8032-2977e7a555d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171549, 4572, 2206, 65, 160, "Input",ExpressionUUID->"b6f663ff-ab8f-45c6-85b0-5c7ce48a1cd4"],
Cell[173758, 4639, 4030, 123, 199, "Output",ExpressionUUID->"f6d844d9-f763-400c-b080-4ed8177faaba"],
Cell[177791, 4764, 855, 16, 38, "Output",ExpressionUUID->"4a8cfb51-2bd9-42c2-b8d9-71ac6f10e29e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178683, 4785, 6708, 201, 528, "Input",ExpressionUUID->"f3e88143-0dd2-47c3-9402-0f5359b845fe"],
Cell[185394, 4988, 1104, 26, 56, "Output",ExpressionUUID->"d480e93e-3a0c-410e-a2c2-5faae5fb74ad"],
Cell[186501, 5016, 819, 15, 56, "Output",ExpressionUUID->"07bd9d29-a07e-48c0-8f64-df83972cb3d1"],
Cell[187323, 5033, 2307, 62, 106, "Output",ExpressionUUID->"c7f3babc-ad08-40bf-b02e-2416b189621c"],
Cell[189633, 5097, 966, 20, 56, "Output",ExpressionUUID->"d8cb10b8-7b5c-47c3-849a-869c9d702ae6"],
Cell[190602, 5119, 1485, 39, 58, "Output",ExpressionUUID->"8f57a10f-44c1-4b83-85dc-192a3dd8bfa8"],
Cell[192090, 5160, 908, 18, 55, "Output",ExpressionUUID->"5fe29186-7fd9-437c-a5fc-caf36f0e32e9"],
Cell[193001, 5180, 1480, 38, 58, "Output",ExpressionUUID->"ef5572c0-99fb-4d50-8849-d53631800076"],
Cell[194484, 5220, 932, 19, 55, "Output",ExpressionUUID->"538200e1-c531-4fa8-beac-9f1706dac888"],
Cell[195419, 5241, 1423, 37, 58, "Output",ExpressionUUID->"4d3c2e45-c449-4176-8ca0-f33aa52ebd10"],
Cell[196845, 5280, 2545, 75, 113, "Output",ExpressionUUID->"ec59f6b6-701c-4636-b837-c2111d3a118a"],
Cell[199393, 5357, 1106, 25, 58, "Output",ExpressionUUID->"613107c2-7499-4f5d-b381-b7c198dc6671"],
Cell[200502, 5384, 1503, 39, 62, "Output",ExpressionUUID->"663ef61c-1779-4f4b-813a-587a34af149c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202042, 5428, 2642, 79, 231, "Input",ExpressionUUID->"71d7395a-5b9f-495e-aee6-5c835fb2f2d0"],
Cell[204687, 5509, 3865, 119, 206, "Output",ExpressionUUID->"fea55b32-0db4-46bb-a74d-8010113b797a"],
Cell[208555, 5630, 745, 14, 38, "Output",ExpressionUUID->"a8baa86c-3c8e-4576-9e57-5753157f2834"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[209349, 5650, 503, 8, 58, "Subtitle",ExpressionUUID->"061b746d-2d84-488c-9796-cf0f3e4d998f"],
Cell[209855, 5660, 330, 7, 34, "Input",ExpressionUUID->"87a128cf-9561-46f6-adb5-a8dff5cb3c6c"],
Cell[CellGroupData[{
Cell[210210, 5671, 1917, 53, 127, "Input",ExpressionUUID->"1846682e-7a54-4fd1-bf99-a13c39266ada"],
Cell[212130, 5726, 2164, 63, 120, "Output",ExpressionUUID->"d49d7cf5-a1fb-4dd7-8726-8d45ac9219a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214331, 5794, 1404, 40, 81, "Input",ExpressionUUID->"6f4b9a79-5124-48ca-ba6d-d49bea7ffdd3"],
Cell[215738, 5836, 4657, 145, 215, "Output",ExpressionUUID->"f89cda72-55e9-4470-ad5a-49428cc34368"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220432, 5986, 2161, 58, 196, "Input",ExpressionUUID->"bf5de7bd-8ef6-4e1c-b200-1c2273217a23"],
Cell[222596, 6046, 744, 11, 38, "Output",ExpressionUUID->"44652ed7-773c-4768-8304-5cbe80016459"],
Cell[223343, 6059, 2679, 69, 103, "Output",ExpressionUUID->"4bc3b289-6794-46f8-8b55-e09c285e67a0"],
Cell[226025, 6130, 1779, 46, 58, "Output",ExpressionUUID->"77e9bb87-cbb6-4544-9910-a7402a29d866"],
Cell[227807, 6178, 809, 13, 38, "Output",ExpressionUUID->"c1b44949-795c-48b8-9614-773d390453a4"]
}, Open  ]],
Cell[228631, 6194, 579, 12, 34, "Input",ExpressionUUID->"6d908fde-078b-41d6-bbcd-b6d73f52111a"],
Cell[CellGroupData[{
Cell[229235, 6210, 1191, 35, 58, "Input",ExpressionUUID->"492fbb59-296d-4c15-9ed4-9d09b0e95486"],
Cell[230429, 6247, 1799, 49, 69, "Output",ExpressionUUID->"40ecf7d2-4684-436d-b8b8-526a54621b84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232265, 6301, 3318, 89, 197, "Input",ExpressionUUID->"2cc70696-e2aa-46a9-8339-221d27b449f8"],
Cell[235586, 6392, 1231, 26, 38, "Output",ExpressionUUID->"a300a3a0-e4bd-4473-ab65-c1e405b6da7a"],
Cell[236820, 6420, 1118, 23, 38, "Output",ExpressionUUID->"995cfd80-35aa-4b48-a12b-9ae9af301fb5"],
Cell[237941, 6445, 1378, 32, 58, "Output",ExpressionUUID->"9f49bb78-cb32-4418-8593-81ef1515b449"],
Cell[239322, 6479, 1716, 43, 53, "Output",ExpressionUUID->"7f4850fa-950e-4c62-9c5e-0b56382ca225"],
Cell[241041, 6524, 1253, 28, 58, "Output",ExpressionUUID->"4c4f5cd8-858c-4d63-a405-7c55cc6acfb3"],
Cell[242297, 6554, 1132, 24, 38, "Output",ExpressionUUID->"e9f8016e-14ad-455d-8914-f475e3f4aa6e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[243466, 6583, 1738, 49, 131, "Input",ExpressionUUID->"5e1b142b-f6e4-4674-ad87-75b3222b45cb"],
Cell[245207, 6634, 3106, 94, 95, "Output",ExpressionUUID->"440c9585-30f9-4bdb-9239-935b7e8d1124"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248350, 6733, 2708, 77, 245, "Input",ExpressionUUID->"aae5f670-5d05-4b7a-b003-8d12cd2a0992"],
Cell[251061, 6812, 886, 16, 38, "Output",ExpressionUUID->"3ed1b1cd-3f12-47b9-9bf9-e6ee653c337c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251984, 6833, 899, 25, 81, "Input",ExpressionUUID->"a5237815-3a4d-4d85-9ecf-5d42295856a7"],
Cell[252886, 6860, 7486, 198, 318, "Output",ExpressionUUID->"e5603965-8333-450b-aec9-d7f28b00f5a5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[260421, 7064, 643, 9, 58, "Subtitle",ExpressionUUID->"bf0f230c-e0da-44b9-a4d4-4d2941b61ae0"],
Cell[CellGroupData[{
Cell[261089, 7077, 2600, 76, 196, "Input",ExpressionUUID->"6fbe9229-1bed-4ddc-a766-6a3b77f8d5ea"],
Cell[263692, 7155, 661, 12, 38, "Output",ExpressionUUID->"f303e1fe-e675-4ae7-829c-128c32cab3b4"],
Cell[264356, 7169, 1160, 28, 54, "Output",ExpressionUUID->"2512bb49-e374-4eaa-9451-55a925e26413"],
Cell[265519, 7199, 1256, 31, 54, "Output",ExpressionUUID->"68957905-7234-4581-ae77-4510310572ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266812, 7235, 1033, 30, 58, "Input",ExpressionUUID->"3c17264a-d356-4280-97fb-ce4121175dde"],
Cell[267848, 7267, 573, 9, 38, "Output",ExpressionUUID->"f4ce5d43-ef64-4fe1-ac21-9c0ce12bc138"]
}, Open  ]],
Cell[CellGroupData[{
Cell[268458, 7281, 1343, 36, 104, "Input",ExpressionUUID->"490d883f-b35d-4dfe-af38-5f2babd805cb"],
Cell[269804, 7319, 22500, 653, 1457, "Output",ExpressionUUID->"d7f6e243-fc53-47a8-b18f-d39756a291e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292341, 7977, 1725, 50, 173, "Input",ExpressionUUID->"7b29eb3b-bd48-425b-bdc3-d757da01c93f"],
Cell[294069, 8029, 747, 14, 38, "Output",ExpressionUUID->"56fb8ee9-fdcf-4157-a9fa-bf168ea2deef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294853, 8048, 1188, 33, 98, "Input",ExpressionUUID->"294369c3-1ca3-4040-9444-f8d825763761"],
Cell[296044, 8083, 735, 14, 38, "Output",ExpressionUUID->"85238a43-550c-49cc-a29a-0e9113999d2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[296816, 8102, 13050, 371, 1034, "Input",ExpressionUUID->"4e702f1c-9c6e-4b67-800c-68502faa197e"],
Cell[309869, 8475, 2444, 51, 41, "Output",ExpressionUUID->"e4f777c2-7452-4402-92e4-3aeb79e7b473"],
Cell[312316, 8528, 2218, 45, 41, "Output",ExpressionUUID->"da8ab8ea-110e-41e3-9cb0-7fd5e5769e30"],
Cell[314537, 8575, 2137, 42, 41, "Output",ExpressionUUID->"c1e9493b-d7bc-495c-80b7-b65c84b7342b"],
Cell[316677, 8619, 1734, 30, 38, "Output",ExpressionUUID->"60efe20f-c4fb-4547-89d8-1db2271becca"],
Cell[318414, 8651, 2129, 41, 41, "Output",ExpressionUUID->"e4e8c0ef-513c-4268-99fb-76f4c72271ea"],
Cell[320546, 8694, 1769, 32, 38, "Output",ExpressionUUID->"cc97c726-0934-4649-b59c-2e9343001eee"],
Cell[322318, 8728, 4120, 93, 91, "Output",ExpressionUUID->"83bfb4b3-c41b-4b0a-9820-a5da49158a0f"],
Cell[326441, 8823, 5153, 124, 89, "Output",ExpressionUUID->"68d6f4b0-4f1a-40eb-95da-7c9e0a7d6827"],
Cell[331597, 8949, 2481, 50, 41, "Output",ExpressionUUID->"e82b5667-ada2-4d93-adc6-d2625760d122"],
Cell[334081, 9001, 3241, 73, 66, "Output",ExpressionUUID->"a5ccb507-d5c3-4e52-a927-3eb2689c4c56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337359, 9079, 2882, 88, 147, "Input",ExpressionUUID->"30baffee-7810-4c66-9472-788ae4508059"],
Cell[340244, 9169, 604, 12, 38, "Output",ExpressionUUID->"9ef3a17a-7323-492a-a522-87556fb4c153"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[340897, 9187, 554, 9, 58, "Subtitle",ExpressionUUID->"5bc6b4e2-1355-4848-837a-09043682c4e7"],
Cell[CellGroupData[{
Cell[341476, 9200, 5630, 160, 319, "Input",ExpressionUUID->"15c0aea5-3aab-403f-a393-a747ed195e86"],
Cell[347109, 9362, 920, 21, 41, "Output",ExpressionUUID->"00207ed5-c70f-4f00-83ed-69cdd733a2be"],
Cell[348032, 9385, 920, 21, 41, "Output",ExpressionUUID->"49933a81-24be-4fdc-b97d-0722a86f1192"],
Cell[348955, 9408, 920, 21, 41, "Output",ExpressionUUID->"12f2e8b5-231b-4475-bd6d-8a2a1540a506"],
Cell[349878, 9431, 3199, 92, 103, "Output",ExpressionUUID->"1a0e3e15-38db-4918-b0f8-024795732a30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353114, 9528, 1406, 43, 152, "Input",ExpressionUUID->"caee7a8c-6bdd-4b69-90e9-eb834a9d9165"],
Cell[354523, 9573, 456, 7, 38, "Output",ExpressionUUID->"9d6122b0-7647-4c62-9d97-f17184af2674"]
}, Open  ]],
Cell[354994, 9583, 460, 10, 34, "Input",ExpressionUUID->"ea9ab398-4160-4d79-8e49-1c5b0871f9f5"],
Cell[CellGroupData[{
Cell[355479, 9597, 803, 24, 106, "Input",ExpressionUUID->"ba1fefb4-6299-49a6-87de-fc09dddc5700"],
Cell[356285, 9623, 1361, 35, 54, "Output",ExpressionUUID->"603a252c-9e59-40a9-ba5f-b9d88ffdacaf"],
Cell[357649, 9660, 1101, 28, 58, "Output",ExpressionUUID->"67d37d96-31e7-4f3a-aeb4-e2c6319c27b0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[358799, 9694, 700, 11, 58, "Subtitle",ExpressionUUID->"c7b5485d-7692-4842-8f40-a403c6c5a9ad"],
Cell[359502, 9707, 1877, 46, 109, "Input",ExpressionUUID->"41ee7869-27dd-4f02-b051-451498ecc8fc"],
Cell[361382, 9755, 1276, 37, 128, "Input",ExpressionUUID->"d7985ad0-c0a7-43d4-830c-0c74deb030af"],
Cell[CellGroupData[{
Cell[362683, 9796, 1619, 40, 152, "Input",ExpressionUUID->"9a0279bf-2037-49ea-8bc1-a8a9b57c6e85"],
Cell[364305, 9838, 6473, 153, 172, "Output",ExpressionUUID->"b531c694-6709-41bb-9f2e-e8db0d371e95"],
Cell[370781, 9993, 1959, 52, 59, "Output",ExpressionUUID->"37d35e91-789d-45bb-b6a9-5dbf35b20249"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372777, 10050, 6279, 176, 317, "Input",ExpressionUUID->"7f292d52-a275-4738-8f51-d35b058ac814"],
Cell[379059, 10228, 5212, 139, 188, "Output",ExpressionUUID->"6655804f-37f4-4d10-b031-7e83f1ff9a64"],
Cell[384274, 10369, 1067, 20, 38, "Output",ExpressionUUID->"f7e568e1-5b8f-4f65-a553-a888db6e2808"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385378, 10394, 6152, 169, 382, "Input",ExpressionUUID->"a142f69e-8a58-466f-9b3f-8dbbf490018a"],
Cell[391533, 10565, 4909, 138, 247, "Output",ExpressionUUID->"c558f6ac-68df-4529-8264-2f9ac540e1ca"],
Cell[396445, 10705, 1072, 20, 38, "Output",ExpressionUUID->"428b3fb0-b4a4-4a37-9878-9de147491b61"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397554, 10730, 6308, 185, 390, "Input",ExpressionUUID->"141b4e35-cb51-4e8c-98c8-014082557d6e"],
Cell[403865, 10917, 10628, 288, 511, "Output",ExpressionUUID->"335c6de5-9895-42be-8410-0677277512d6"],
Cell[414496, 11207, 699, 15, 38, "Output",ExpressionUUID->"de4f15ff-05d4-418c-8bdd-ae5ad39954f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[415232, 11227, 6190, 184, 398, "Input",ExpressionUUID->"ac5d2511-39e9-43c8-93da-287614c2d4d6"],
Cell[421425, 11413, 2243, 63, 221, "Output",ExpressionUUID->"4b1fcd95-8628-481b-879e-1c1a52562c77"],
Cell[423671, 11478, 599, 12, 38, "Output",ExpressionUUID->"6d4f97d9-2732-4f3e-840d-4e220c484041"]
}, Open  ]],
Cell[CellGroupData[{
Cell[424307, 11495, 6190, 184, 398, "Input",ExpressionUUID->"cedd9ac3-74ea-476c-b566-d3d7ede15dc4"],
Cell[430500, 11681, 2225, 62, 221, "Output",ExpressionUUID->"0f1898b0-d1db-406c-884e-0997fd5e3cf0"],
Cell[432728, 11745, 602, 12, 38, "Output",ExpressionUUID->"dc6cb440-9490-464c-b2f4-e81d8bdacf3a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433367, 11762, 8372, 229, 438, "Input",ExpressionUUID->"162f7e17-49c4-446d-aaa2-0df2db2dbf53"],
Cell[441742, 11993, 5044, 137, 162, "Output",ExpressionUUID->"58da6db1-27b5-4fb5-a1f9-c39b9f976654"],
Cell[446789, 12132, 836, 13, 38, "Output",ExpressionUUID->"6f617a6a-3cbd-4027-b602-30ce971b7baf"],
Cell[447628, 12147, 4841, 133, 217, "Output",ExpressionUUID->"98266772-c334-4e9a-a2c2-2e9b6ea6c768"],
Cell[452472, 12282, 1001, 19, 38, "Output",ExpressionUUID->"4fb938e6-76da-460d-abd6-6ec4d3cb872c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453510, 12306, 1926, 53, 129, "Input",ExpressionUUID->"87be7d3e-8795-4ab6-a864-3548011e4637"],
Cell[455439, 12361, 778, 16, 38, "Output",ExpressionUUID->"78e39a14-e0c4-4171-ab70-626007b1e34f"]
}, Open  ]],
Cell[456232, 12380, 350, 10, 34, "Input",ExpressionUUID->"cbd03b66-6e54-4e1f-9a6b-b7f57d721af4"],
Cell[CellGroupData[{
Cell[456607, 12394, 1285, 35, 79, "Input",ExpressionUUID->"2c0ea740-e84c-4736-b762-09523cdeb143"],
Cell[457895, 12431, 787, 20, 59, "Output",ExpressionUUID->"ed8c4ec8-db33-4fd5-9cc2-5532594ee33a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[458719, 12456, 4802, 133, 267, "Input",ExpressionUUID->"51dc3cc7-85ea-46ae-9aa3-3455e5a9edd2"],
Cell[463524, 12591, 5673, 151, 268, "Output",ExpressionUUID->"0f57406e-989c-425b-89e4-f965af71e0a5"],
Cell[469200, 12744, 924, 18, 38, "Output",ExpressionUUID->"509afd8b-17b2-410a-9da9-d258c278a9fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[470161, 12767, 5005, 148, 281, "Input",ExpressionUUID->"20fa6955-d2e6-4496-aeab-ce3a6204a472"],
Cell[475169, 12917, 10440, 262, 370, "Output",ExpressionUUID->"7003521c-cc20-422b-bb14-741fc3884ffe"],
Cell[485612, 13181, 630, 13, 38, "Output",ExpressionUUID->"f080db58-2807-454e-a980-62bf5d839654"]
}, Open  ]],
Cell[CellGroupData[{
Cell[486279, 13199, 4935, 147, 286, "Input",ExpressionUUID->"cda4d6fd-9c09-445f-a2c2-c901ccb2f9d1"],
Cell[491217, 13348, 1372, 40, 69, "Output",ExpressionUUID->"b4e2d28c-fbcc-449a-bfb8-601c28dae97e"],
Cell[492592, 13390, 550, 12, 38, "Output",ExpressionUUID->"0f5d2fc2-335d-483a-8b33-ecffbfacf848"]
}, Open  ]],
Cell[CellGroupData[{
Cell[493179, 13407, 4937, 147, 286, "Input",ExpressionUUID->"28f07404-2a91-41d2-8de9-ddfc39b92f17"],
Cell[498119, 13556, 1429, 43, 69, "Output",ExpressionUUID->"52052aca-d238-4d42-9513-e78818b3007c"],
Cell[499551, 13601, 550, 12, 38, "Output",ExpressionUUID->"22e5a6f6-e69c-4e15-a457-7499e6fb908a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[500138, 13618, 9614, 267, 518, "Input",ExpressionUUID->"bb485126-d61a-470b-8d3c-0f64bd7cfe28"],
Cell[509755, 13887, 946, 14, 38, "Output",ExpressionUUID->"3d9c6cc4-61c6-4cdb-8e67-88c4bcda6203"],
Cell[510704, 13903, 9974, 281, 471, "Output",ExpressionUUID->"13eec7e1-30ac-4042-98c3-261ac3438a5e"],
Cell[520681, 14186, 1088, 19, 38, "Output",ExpressionUUID->"1d54042c-825d-4f7e-b773-55698cc6f04b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[521806, 14210, 1842, 53, 145, "Input",ExpressionUUID->"2507bf1c-3d78-486c-8851-ef348e10ce30"],
Cell[523651, 14265, 514, 11, 38, "Output",ExpressionUUID->"0832da08-1001-45ed-94c4-64ae8346e17e"]
}, Open  ]],
Cell[524180, 14279, 388, 8, 34, "Input",ExpressionUUID->"c07cd800-d698-40a4-895e-40a424d182e2"],
Cell[CellGroupData[{
Cell[524593, 14291, 6288, 178, 263, "Input",ExpressionUUID->"432f3052-5b3c-4479-a9ae-7c9d88eebcfb"],
Cell[530884, 14471, 1626, 37, 41, "Output",ExpressionUUID->"50c9c690-587f-4009-8f28-6e57567dd76e"],
Cell[532513, 14510, 1339, 31, 86, "Output",ExpressionUUID->"77143e5f-0b0f-4cc0-82d5-5e72ebf4f286"],
Cell[533855, 14543, 988, 18, 38, "Output",ExpressionUUID->"7523587a-e2b3-4073-9545-2d6410a9f794"]
}, Open  ]],
Cell[CellGroupData[{
Cell[534880, 14566, 7022, 201, 334, "Input",ExpressionUUID->"c6b3cbbb-172d-46bd-867d-a9abaef00a73"],
Cell[541905, 14769, 1189, 32, 41, "Output",ExpressionUUID->"46d6f245-1176-4732-8087-2530c5f11714"],
Cell[543097, 14803, 796, 19, 48, "Output",ExpressionUUID->"8767c64e-f67d-4dcf-9859-bb0438090075"],
Cell[543896, 14824, 676, 14, 38, "Output",ExpressionUUID->"b65cd82e-50ab-40cc-81ab-557987b002e6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544609, 14843, 4333, 132, 175, "Input",ExpressionUUID->"f7479f8d-84dc-4c34-95ea-35397f1ff31b"],
Cell[548945, 14977, 409, 8, 38, "Output",ExpressionUUID->"7a4d2891-318d-48a9-9830-9b5b32c81c24"]
}, Open  ]],
Cell[CellGroupData[{
Cell[549391, 14990, 4060, 124, 180, "Input",ExpressionUUID->"a7d1f233-bc1d-43f8-b5d6-baf676503312"],
Cell[553454, 15116, 378, 7, 38, "Output",ExpressionUUID->"2801d0e8-7530-4b90-b238-36d60ca22f02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[553869, 15128, 2698, 74, 219, "Input",ExpressionUUID->"22707375-f134-4c2b-b4de-802369decf98"],
Cell[556570, 15204, 2638, 78, 77, "Output",ExpressionUUID->"a8ed9c5f-1488-4c64-ac8a-3afd2688b284"],
Cell[559211, 15284, 2989, 80, 77, "Output",ExpressionUUID->"a73189c7-070a-40bf-be92-453bccd933d1"],
Cell[562203, 15366, 2625, 76, 77, "Output",ExpressionUUID->"84464e38-d623-441c-9f5d-6dd07b48919f"],
Cell[564831, 15444, 2622, 76, 77, "Output",ExpressionUUID->"dc854916-22a5-4f48-b95f-3dcf89a1a7df"]
}, Open  ]],
Cell[567468, 15523, 7586, 226, 311, "Input",ExpressionUUID->"b09d6e70-f8e3-4538-9f09-a261e57f811b"],
Cell[CellGroupData[{
Cell[575079, 15753, 7670, 207, 572, "Input",ExpressionUUID->"4042b1db-e0d1-4180-a886-2b4dd14263fa"],
Cell[582752, 15962, 3231, 95, 67, "Output",ExpressionUUID->"ab5cb5d3-9996-44e4-b47b-86c6a9676656"],
Cell[585986, 16059, 4167, 119, 106, "Output",ExpressionUUID->"e1eb0e08-5296-4c98-9fed-5750103cd2f8"],
Cell[590156, 16180, 3676, 110, 67, "Output",ExpressionUUID->"26085661-6411-4f35-841b-4c2fc6491045"],
Cell[593835, 16292, 3738, 109, 67, "Output",ExpressionUUID->"f4bd0cf4-263a-4e86-9478-96a79b592cf5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597610, 16406, 5885, 156, 331, "Input",ExpressionUUID->"7bd7ab5c-2373-423a-91d4-177d95342ae1"],
Cell[603498, 16564, 1143, 20, 38, "Output",ExpressionUUID->"bed9aeaa-4a65-4b1b-9f41-e6333126a8d1"],
Cell[604644, 16586, 1141, 20, 38, "Output",ExpressionUUID->"89a4c0b8-24b6-405f-b9c2-faa5e2c68b7b"],
Cell[605788, 16608, 1165, 21, 38, "Output",ExpressionUUID->"ff3e2bf8-e13e-4b1e-871c-926b45c685de"],
Cell[606956, 16631, 1167, 21, 38, "Output",ExpressionUUID->"28a1d37b-5a31-42e6-b874-13edc048ef4d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[608160, 16657, 3049, 81, 265, "Input",ExpressionUUID->"fffd93cb-16b4-4591-8f4c-a49ae70a356a"],
Cell[611212, 16740, 658, 14, 38, "Output",ExpressionUUID->"69357699-0cf2-4b17-99a3-0399d9efb168"],
Cell[611873, 16756, 1766, 47, 58, "Output",ExpressionUUID->"619a483b-d75b-4518-9700-19c9a4f16401"],
Cell[613642, 16805, 1674, 44, 41, "Output",ExpressionUUID->"59eb7243-3b19-460f-a7ee-ddf2f7489f10"],
Cell[615319, 16851, 1816, 48, 60, "Output",ExpressionUUID->"1f6f50c0-c5fd-415c-9ad3-1fb77f470987"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617172, 16904, 1042, 26, 81, "Input",ExpressionUUID->"4ef98c10-9f1e-4717-bf71-772e2e9ccf26"],
Cell[618217, 16932, 603, 14, 38, "Output",ExpressionUUID->"f1e4d5cf-1ead-4d38-8d79-4090ff4fddf3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618857, 16951, 6597, 196, 248, "Input",ExpressionUUID->"e4039dc9-c9fe-477a-951b-3955153b5f34"],
Cell[625457, 17149, 3990, 107, 67, "Output",ExpressionUUID->"eca7fdfa-880d-4876-89b2-ebfe74c12820"],
Cell[629450, 17258, 929, 26, 41, "Output",ExpressionUUID->"a2411aa1-0402-46c4-a190-ad44d65b7a74"],
Cell[630382, 17286, 3991, 107, 67, "Output",ExpressionUUID->"c9cc199f-1a79-41dc-9c75-7cb4c309e222"],
Cell[634376, 17395, 929, 26, 41, "Output",ExpressionUUID->"bb4da3ea-5433-4519-b4d4-b466411b411f"],
Cell[635308, 17423, 3991, 107, 67, "Output",ExpressionUUID->"4224df7a-ed17-4632-a701-14b25365b71a"],
Cell[639302, 17532, 931, 26, 41, "Output",ExpressionUUID->"9d0fe197-aa13-4792-a7d0-6f4a445d1a80"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[640282, 17564, 451, 7, 58, "Subtitle",ExpressionUUID->"5c8b04b5-73ff-4404-bd11-09ee1ebe72a4"],
Cell[CellGroupData[{
Cell[640758, 17575, 5280, 144, 283, "Input",ExpressionUUID->"b7fb5aab-b668-4856-8856-9e3466baaa7b"],
Cell[646041, 17721, 24731, 694, 716, "Output",ExpressionUUID->"e13500de-5def-4039-85c0-c9bafd66878e"],
Cell[670775, 18417, 585, 13, 38, "Output",ExpressionUUID->"248314f2-9000-407d-bfbd-557c680da390"]
}, Open  ]],
Cell[CellGroupData[{
Cell[671397, 18435, 8124, 235, 305, "Input",ExpressionUUID->"0b57d267-b3d0-4cba-9fff-a6cf0599a3c7"],
Cell[679524, 18672, 25675, 727, 740, "Output",ExpressionUUID->"70e79096-8b84-4585-ab49-ba32926038d6"],
Cell[705202, 19401, 466, 12, 38, "Output",ExpressionUUID->"1783447b-525c-430c-9742-96a1aa57bda8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[705705, 19418, 3386, 104, 212, "Input",ExpressionUUID->"565907a5-08ed-4d41-88b5-a3cd81f483ea"],
Cell[709094, 19524, 345, 9, 38, "Output",ExpressionUUID->"de2e9cc6-4f7e-4579-8249-dd5950fb06ec"]
}, Open  ]],
Cell[709454, 19536, 1618, 45, 129, "Input",ExpressionUUID->"29f77ee4-e43b-43d2-ad2b-b24a4c6aafb4"],
Cell[CellGroupData[{
Cell[711097, 19585, 1208, 36, 86, "Input",ExpressionUUID->"c229614c-c18a-4735-ba7f-cf4c75e68f6d"],
Cell[712308, 19623, 343, 9, 38, "Output",ExpressionUUID->"650ee8a1-f5cb-4ada-a410-a632d3aec94b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712688, 19637, 3320, 96, 311, "Input",ExpressionUUID->"932f9b74-0d2c-4c0b-8ec5-45367558c7dd"],
Cell[716011, 19735, 444, 11, 38, "Output",ExpressionUUID->"764a566c-8766-4c40-90a1-44e664ed0344"],
Cell[716458, 19748, 470, 12, 38, "Output",ExpressionUUID->"13a54985-28f6-47a0-85e8-b473a0d2addb"],
Cell[716931, 19762, 444, 11, 38, "Output",ExpressionUUID->"2313c998-1c2a-4f28-beb7-438e9d6d1ebd"],
Cell[717378, 19775, 1429, 41, 41, "Output",ExpressionUUID->"16bd947f-d0ff-4748-a24a-36436646b6bc"],
Cell[718810, 19818, 444, 11, 38, "Output",ExpressionUUID->"e00a597c-2107-4ffd-998b-2f8ff385dc5a"],
Cell[719257, 19831, 1317, 38, 41, "Output",ExpressionUUID->"faf666af-0295-4398-ad8e-196f4e0443aa"]
}, Open  ]],
Cell[720589, 19872, 452, 11, 34, "Input",ExpressionUUID->"adb17717-f1dd-44ea-bc5a-89a15308d09b"]
}, Closed]]
}
]
*)

